;* ------------------------------------------------------------------------
;*  Title     :	ALCONS AUDIO BV DDP Module
;*  Version   :	1.7
;*  File      :	DDP_V1.7.001.A51
;*		V1.7.1 BC543 cardioid as complementary active speaker preset
;*		V1.7.0 BC543/BQ211 added, VR12 bassboost fix, QR/QM combined, 75Hz presets removed, QB gain fix
;*		V1.6.0 added LR7, LR7B. Delay coarse/fine switch bug fixed.
;*			Limitlog disable feature added.
;*  Part of   :	-
;*  Author    :	R. Kuipers
;*  Project   :	-
;*  Purpose   :	-
;*  Created   :	22-4-2011
;*  Modified  :	-
;* ------------------------------------------------------------------------

;* ------------------------------------------------------------------------
;*  DataFlash Memory Map:
;*  Page 0-17	   : DSP program
;*  Page 18	   : Serial code
;*  Page 19	   : Settings page address (20-255)
;*  Page 20-255	   : Settings (one moving page)
;*  Page 256	   : Log page address (257-511)
;*  Page 257-511   : Log with starts and hours counters (one moving page)
;*  Page 512-524   : DDP user presets 
;*  Page 525	   : Speaker presets version code, boot status byte
;*  Page 526-1023  : Reserved for speaker presets
;*  Page 1024	   : Limitlog page address (1025-8191)
;*  Page 1025-8191 : Limitlog with speaker preset and limit data
;* ------------------------------------------------------------------------

NAME	SAMPLE

FIRMWARE EQU	017H			; Firmware ID-code

LAST_MODEL EQU	59			; Last speaker preset model code - was 58 voor toevoeging van LR7..64->62=>LR7-90 160Hz en LR7-120 160Hz verwijderd					; Without non-selectable presets
DSP_ADR EQU	0B0H			; DSP I2C slave address shifted 1 bit left
RTC_EE	EQU	0AEH			; ISL12026 realtime clock EEPROM I2C slave address shifted 1 bit left
RTC_CCR	EQU	0DEH			; ISL12026 realtime clock CCR I2C slave address shifted 1 bit left

STACK	SEGMENT	IDATA

	RSEG  	STACK
	DS    	018H  			; Stack

BITCNT	DATA	018H			; I2C bit counter
BYTECNTL DATA	019H			; I2C byte counter low byte
BYTECNTH DATA	01AH			; I2C byte counter high byte
SLVADR	DATA	01BH			; I2C slave address

OPCODE	DATA	01CH			; FLASH opcode
OPCODE1	DATA	01DH			; FLASH opcode1
OPCODE2	DATA	01EH			; FLASH opcode2
OPCODE3	DATA	01FH			; FLASH opcode3

FLAGS0	DATA	020H			; Flags register
NOACK	BIT	FLAGS0.0		; I2C no acknowledge flag
CHAN2	BIT	FLAGS0.1		; Channel1/2 adjustment flag
S_CLK	BIT	FLAGS0.2		; Clock has just been set
INF	BIT	FLAGS0.3		; Info option selected
SECT_0	BIT	FLAGS0.4		; eq section1-4
SECT_1	BIT	FLAGS0.5		; 
DIS	BIT	FLAGS0.6		; Display option selected
LINE	BIT	FLAGS0.7		; Text underlined

FLAGS1	DATA	021H			; Flags register
LEFT	BIT	FLAGS1.0		; Encoder turn left flag
RIGHT	BIT	FLAGS1.1		; Encoder turn right flag
PUS	BIT	FLAGS1.2		; Encoder pushbutton flag
ENC	BIT	FLAGS1.3		; Encoder action
ENC_FAST BIT	FLAGS1.4		; Encoder turning fast
INV	BIT	FLAGS1.5		; Text inversed
GRAPH	BIT	FLAGS1.6		; parametric eq graph has changed
SPITXC	BIT	FLAGS1.7		; SPI transmit complete flag

FLAGS4	DATA	022H
LOG_1ST	BIT	FLAGS4.0		; First log sample has been read (log does not use first sample)
MAIN	BIT	FLAGS4.1		; DDP is in main menu
PSWAP	BIT	FLAGS4.2		; Preset swap active
BYP	BIT	FLAGS4.3		; Current section is bypassed
RTC_IRP	BIT	FLAGS4.4		; Real time clock interrupt pending
NXT_PG	BIT	FLAGS4.5		; Flag indicates settings or log page has moved
LOG_REF	BIT	FLAGS4.6		; Flag indicates log refresh
DBLANK	BIT	FLAGS4.7		; Flag indicates display blank due to timeout

BURNCH	DATA	023H			; Flash burncounter high byte
BURNCL	DATA	024H			; Flash burncounter low byte

FLAGS5	DATA	025H			; Settings flags register
STIME	BIT	FLAGS5.0		; Summertime
CTIME	BIT	FLAGS5.1		; Check time for summer/wintertime
DST_EUR	BIT	FLAGS5.2		; DST for europe
DST_USA	BIT	FLAGS5.3		; DST for USA
DT_FRM	BIT	FLAGS5.4		; Date format 0=dd-mm-yy; 1=mm-dd-yy
DABS	BIT	FLAGS5.5		; Delay indication absolute
SET_CLK	BIT	FLAGS5.6		; Set clock at next startup


FLAGS2	DATA	026H			; Settings flags register
MUTE1	BIT	FLAGS2.0		; CH1 is muted
MUTE2	BIT	FLAGS2.1		; CH2 is muted
EQ1	BIT	FLAGS2.2		; CH1 eq on
EQ2	BIT	FLAGS2.3		; CH2 eq on
GAINREL	BIT	FLAGS2.4		; Gain indication relative
D1	BIT	FLAGS2.5		; Delay ch1 on
D2	BIT	FLAGS2.6		; Delay ch2 on
DUNIT	BIT	FLAGS2.7		; Delay in meters

FLAGS6	DATA	027H			; Settings flags register

FLAGS3	DATA	028H			; Settings flags register
PUMUTE	BIT	FLAGS3.0		; Mute on at power up
PLOCK	BIT	FLAGS3.1		; Preset lock active
ALOCK	BIT	FLAGS3.2		; All functions locked (except mute)
PRMUTE	BIT	FLAGS3.3		; Mute on after preset change
HCORR1	BIT	FLAGS3.4		; High correction active on ch1
HCORR2	BIT	FLAGS3.5		; High correction active on ch2
D_FINE	BIT	FLAGS3.6		; Delay in fine mode
P_ALT	BIT	FLAGS3.7		; Preset altered

EQFLAGS	DATA	029H			; Pareq flags register
CH1S1	BIT	EQFLAGS.0		; CH1 section1 bypass
CH1S2	BIT	EQFLAGS.1		; CH1 section2 bypass
CH1S3	BIT	EQFLAGS.2		; CH1 section3 bypass
CH1S4	BIT	EQFLAGS.3		; CH1 section4 bypass
CH2S1	BIT	EQFLAGS.4		; CH2 section1 bypass
CH2S2	BIT	EQFLAGS.5		; CH2 section2 bypass
CH2S3	BIT	EQFLAGS.6		; CH2 section3 bypass
CH2S4	BIT	EQFLAGS.7		; CH2 section4 bypass

INPSET	DATA	02AH			; Input settings bits 3..0 for input routing
					; Bits	1 0
					; 	0 0 Not used
					;	0 1 Channel1 input to channel1
					;	1 0 Channel2 input to channel1
					;	1 1 Channel1+2 input to channel1
					; Bits	3 2
					; 	0 0 Not used
					;	0 1 Channel1 input to channel2
					;	1 0 Channel2 input to channel2
					;	1 1 Channel1+2 input to channel2
STEREO	BIT	INPSET.4		; Bits	5 4
ACTIVE	BIT	INPSET.5		; 	0 0 Dual channel mode
					; 	1 0 2-way active mode
					; 	0 1 Stereo mode
					; 	1 1 bridged mono mode
EQLINK	BIT	INPSET.6		; Channel2 eq is linked to ch1
DLINK	BIT	INPSET.7		; Channel2 delay is linked to ch1

LIMIT1	DATA	02BH			; LIMIT LOG ENABLE
LENABLE BIT	LIMIT1.0
DELAYF	DATA	02CH			; Extra data byte
D_FINE1	BIT	DELAYF.0
D_FINE2	BIT	DELAYF.1

FREQ1	DATA	02DH			; Frequency parametric eq section1
QF1	DATA	02EH			; Q-factor parametric eq section1
GAIN1	DATA	02FH			; gain parametric eq section1
FREQ2	DATA	030H			; Frequency parametric eq section2
QF2	DATA	031H			; Q-factor parametric eq section2
GAIN2	DATA	032H			; gain parametric eq section2
FREQ3	DATA	033H			; Frequency parametric eq section3
QF3	DATA	034H			; Q-factor parametric eq section3
GAIN3	DATA	035H			; gain parametric eq section3
FREQ4	DATA	036H			; Frequency parametric eq section4
QF4	DATA	037H			; Q-factor parametric eq section4
GAIN4	DATA	038H			; gain parametric eq section4

FREQ5	DATA	039H			; Frequency parametric eq section1
QF5	DATA	03AH			; Q-factor parametric eq section1
GAIN5	DATA	03BH			; gain parametric eq section1
FREQ6	DATA	03CH			; Frequency parametric eq section2
QF6	DATA	03DH			; Q-factor parametric eq section2
GAIN6	DATA	03EH			; gain parametric eq section2
FREQ7	DATA	03FH			; Frequency parametric eq section3
QF7	DATA	040H			; Q-factor parametric eq section3
GAIN7	DATA	041H			; gain parametric eq section3
FREQ8	DATA	042H			; Frequency parametric eq section4
QF8	DATA	043H			; Q-factor parametric eq section4
GAIN8	DATA	044H			; gain parametric eq section4

D_LOW1	DATA	045H
D_MID1	DATA	046H
D_HI1	DATA	047H
D_LOW2	DATA	048H
D_MID2	DATA	049H
D_HI2	DATA	04AH

G_LOW1	DATA	04BH
G_HI1	DATA	04CH
G_LOW2	DATA	04DH
G_HI2	DATA	04EH

MOD1	DATA	04FH			; Model count speaker type channel1
MOD2	DATA	050H			; Model count speaker type channel2

SPOPT	DATA	051H			; Speaker preset options
					; Bits	3-0: Array length ch1
					; Bits	7-4: Array length ch2

LIGHT	DATA	052H			; Backlight timeout/intensity data
CONTR	DATA	053H			; LCD contrast data

PIN12	DATA	054H
PIN34	DATA	055H

PRESET	DATA	056H			; DDP preset

PGADDL	DATA	057H			; FLASH page address low byte
PGADDH	DATA	058H			; FLASH page address high byte

PAGECNTH DATA	059H			; FLASH byte in page counter high byte
PAGECNTL DATA	05AH			; FLASH byte in page counter low byte

ENC_TIM	DATA	05BH			; Countdown timer for encoder speed detect

SPISDAT	DATA	05CH			; SPI serial data
SPIRDAT	DATA	05DH			; SPI received data

I2C_TX	DATA	05EH			; 3 bytes (24 bit word)
I2C_TX2	DATA	05FH			; 
I2C_TX3	DATA	060H			; 

FREQ	DATA	061H			; Index to frequency lookup table
QF	DATA	062H			; Index to Q-factor lookup table
GAIN	DATA	063H			; Index to gain lookup table

TEMP	DATA	064H			; Speaker model in speaker select menu, Preset number in preset menu
PPRESET	DATA	065H			; Previous preset

DSP_OPCODE DATA	066H

GRAPH4	DATA	067H			; graph bytes for LCD graphs
GRAPH3	DATA	068H			;
GRAPH2	DATA	069H			;
GRAPH1	DATA	06AH			;

DNCHAR	DATA	06BH
CCNT	DATA	06CH

SECS	DATA	06DH			; Seconds counter
SEC_IN_PAGE DATA 06EH

D_HI	DATA	06FH
D_MID	DATA	070H
D_LOW	DATA	071H

G_HI	DATA	072H
G_LOW	DATA	073H

COUNT1	DATA	074H
COUNT2	DATA	075H

BTOCNT	DATA	076H			; Backlight TimeOut counter

LCD_PG	DATA  	077H			; 1 Byte
CHAR	DATA  	078H			; 1 Byte

SPPRESET1 DATA	079H			; Extra menus for speaker preset channel1
					; Bit	0: Low correction option enable
					; Bit	1: High correction option enable
					; Bit	2: Active speaker
					; Bit	4-7: Low correction option text for array length

SPPRESET2 DATA	07AH			; Extra menus for speaker preset channel2
					; Bit	0: Low correction option enable
					; Bit	1: High correction option enable
					; Bit	2: Active speaker
					; Bit	4-7: Low correction option text for array length

ACT_2ND DATA	07BH			; Modelnumber of 2nd part of active speaker

DELH1	DATA	07CH
DELL1	DATA	07DH
DELH2	DATA	07EH
DELL2	DATA	07FH

SCLPIN	BIT	0C0H.0			; I2C clock line (P4.0)
SDAPIN	BIT	0C0H.1			; I2C data line (P4.1)

AMP_ON	BIT	P0.1
FLASH_BUSY BIT	P0.2
ADSTACK	BIT	P0.3
DAC_MUTE BIT	P0.7
	
IR_EYE	BIT	P1.0
FLASH_CS BIT	P1.1
ENC_SW	BIT	P1.2
ENC_B	BIT	P1.3
ENC_A	BIT	P1.4

LCD_DATA BIT	P2.0
LCD_CLK	BIT	P2.1
LCD_RST	BIT	P2.2			; Keep this bit allways high!!
LCD_CS	BIT	P2.3
LCD_DCNTRL BIT	P2.4
DSP_RST	BIT	P2.5
RTC_IRQ BIT	P2.6
DSP_HREQ BIT	P2.7

CNV_RST	BIT	P3.0
PFO	BIT	P3.2
BCKLGHT1 BIT	P3.3
BCKLGHT2 BIT	P3.5
BCKLGHT3 BIT	P3.6
BCKLGHT4 BIT	P3.7
	
;* ------------------------------------------------------------------------
;*  Interrupt vectors:
;* ------------------------------------------------------------------------

	CSEG  	AT 000H			; Reset vector
	USING	0  			; Register-Bank 0
	LJMP	07C16H			;

	CSEG  	AT 003H			; INT0 interrupt vector
	LJMP	EXT_INT0		; 

	CSEG  	AT 00BH			; Timer0 interrupt vector
	LJMP	TIMER0			; 

	CSEG	AT 04BH			; SPI interrupt vector
	LJMP	07C00H                ;

;* ------------------------------------------------------------------------
;*  Main program starts here:
;* ------------------------------------------------------------------------

	CSEG  	AT 04EH			; 

	DB	002H

NORMAL_OPERATION:
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	FLAGS0,#00H		; Clear all flags
	MOV	FLAGS1,#00H		; Clear all flags
	MOV	FLAGS2,#00H		; Clear all flags

	LJMP	READ_SETTINGS		; Get settings from FLASH memory
START1:

	MOV	08FH,#00H		; Clock to X1 (/12) mode
	MOV	0AFH,#00H		; 

; Set startup mute settings:
	JB	ENC_SW,NO_POWER_UP_MUTE1
	JNB	AMP_ON,NO_POWER_UP_MUTE1
	SETB	MUTE1
	SETB	MUTE2
NO_POWER_UP_MUTE1:

	JNB	PUMUTE,NO_POWER_UP_MUTE2
	SETB	MUTE1
	SETB	MUTE2
NO_POWER_UP_MUTE2:

	CLR	RTC_IRP
	CLR	NXT_PG
	CLR	LOG_REF
	CLR	DBLANK
	CLR	LOG_1ST

	JNB	AMP_ON,NO_INC_STARTS
	LCALL	INC_STARTS		; Increase starts counter in log
NO_INC_STARTS:

	LCALL	INIT_ADC
	LCALL	INIT_DSP

	CLR	ADSTACK

; Display boot screen:
	LCALL	LCD_CLEAR		; Clear LCD data RAM
	MOV	DPTR,#0000H		; Start address in LCD ERAM memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ALCONS_LOGO	; Pointer to graph data in CODE memory
	LCALL	LCD_GRAPH		; Write graph to LCD ERAM memory

	MOV	DPTR,#00A6H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BOOT1
	LCALL	LCD_TEXT

	MOV	DPTR,#0126H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BOOT2
	LCALL	LCD_TEXT

	MOV	DPTR,#01A6H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BOOT3
	LCALL	LCD_TEXT

	MOV	DPTR,#0226H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BOOT4
	LCALL	LCD_TEXT

	MOV	DPTR,#02A6H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BOOT5
	LCALL	LCD_TEXT

	MOV	DPTR,#0326H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BOOT6
	LCALL	LCD_TEXT

	MOV	A,#FIRMWARE
	SWAP	A
	ANL	A,#0FH
	MOV	DPTR,#0344H		; Start address in LCD memory
	LCALL	LCD_NUMBER

	MOV	A,#FIRMWARE
	ANL	A,#0FH
	MOV	DPTR,#0350H		; Start address in LCD memory
	LCALL	LCD_NUMBER

	LCALL	LCD_REFRESH		; Refresh LCD display data

	LCALL	DSP_LOAD_PROGRAM	; Bootstrap DSP
					; Also provides delay for splash screen

	MOV	08FH,#0FFH		; Clock to X2 (/6) mode
	MOV	0AFH,#001H		; 

	MOV	R5,#0			; Wait for DSP to startup
	LCALL	LWAIT			;

;DSP firmware check:
	MOV	I2C_TX,#01H		; Get opcode for DSP log/watchdog read

	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 

        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	MOV	BYTECNTH,#01H		; Number of bytes high byte
	MOV	BYTECNTL,#04H		; Number of bytes low byte

	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	INC	SLVADR			; Set slave address for reading
	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,$			; Check for slave not responding

	LCALL	RCVBYTE			; Receive next data byte from DSP
	CLR	C
;	SUBB	A,#FIRMWARE
	SUBB	A,#014H			; This version uses DSP firmware V1.4
	JZ	WD_LOOP2

	LCALL	SENDSTOP		; Done, send an I2C stop condition

	LCALL	LCD_CLEAR		; Clear LCD data RAM
	MOV	DPTR,#018AH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#FIRMERROR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

	SJMP	$

WD_LOOP2:
	LCALL	RCVBYTE			; Receive next 4 bytes from DSP
	DJNZ	BYTECNTL,WD_LOOP2	; All bytes received?
	LCALL	SENDSTOP		; Done, send an I2C stop condition


; Various inits:
	MOV	BTOCNT,#0CBH		; Backlight timeout value for 10sec

	MOV	TMOD,#001H		; Set timer0 to 16 bits
	MOV	TCON,#011H		; Enable timer0, set IT0

	ORL	0A8H,#003H		; Enable timer0 and INT0 interrupt in IEN0
	ORL	0B7H,#001H		; Set interrupt priority in IPH0
	ORL	0B8H,#001H		; Set interrupt priority in IPL0
	
	MOV	SECS,#50		; Start seconds counter for log at 50 seconds

	LCALL	SETUP_DSP

; Enable watchdog
	MOV	0A7H,#007H		; Set watchdog timeout to 2s in WDTPRG
	LCALL	RESET_WDT	

	JB	SET_CLK,SET_CLOCK1

; Check RTC battery failure:
	MOV	I2C_TX,#00H		; SR adress in RTC
	MOV	I2C_TX+1,#03FH		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX
	JNB	ACC.0,NO_FAIL
	LCALL	INIT_RTC
SET_CLOCK1:
	LCALL	SET_CLOCK
	LCALL	CHECK_DST
	CLR	SET_CLK
	LCALL	WRITE_SETTINGS
	SJMP	CHECKTIME
NO_FAIL:	

	LCALL	CHECK_DST

	JNB	CTIME,CHECKTIME
	LCALL	CHECK_CLOCK
	LCALL	CHECK_DST
	CLR	CTIME
	LCALL	WRITE_SETTINGS
CHECKTIME:

	CLR	PSWAP
	MOV	PPRESET,PRESET

;* ------------------------------------------------------------------------
;*  MAIN MENU:
;* ------------------------------------------------------------------------
MAINMENU:
	SETB	MAIN

	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BLANKLINE
	SETB	LINE
	LCALL	LCD_TEXT

; Display preset name:
	MOV	A,PRESET

	MOV	DPTR,#0000H		; Start address in LCD memory
	SETB	INV
	LCALL	PRESETNAME1		; Display first part

	MOV	DPTR,#0048H		; Start address in LCD memory
	SETB	INV
	LCALL	PRESETNAME2		; Display second part

	MOV	A,#07FH			; Last column on LCD
	MOVX	@DPTR,A			;
	CLR	INV			; Reset flag

; Display '*' when user preset changed:
	MOV	A,PRESET
	JZ	OVER_ALT
	JNB	P_ALT,OVER_ALT
	MOV	DPTR,#0078H		; Start address in LCD memory
	SETB	INV
	MOV	A,#'*'
	LCALL	LCD_CHAR
	CLR	INV
OVER_ALT:

; LOCK icon:
	JNB	ALOCK,NO_LOCK1
	MOV	DPTR,#03F9H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK_ICON
	LCALL	LCD_ICON
NO_LOCK1:

; STEREO/ACTIVE/BRIDGE icon:
	MOV	DPTR,#03E9H		; Start address in LCD memory
	JNB	ALOCK,NO_LOCK8
	MOV	DPTR,#03E2H		; Start address in LCD memory
NO_LOCK8:
	JB	STEREO,STEREO_BRIDGE
	JB	ACTIVE,ACTIVE_MODE
DUAL_MODE:
	SJMP	MAIN_OVER1

ACTIVE_MODE:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ACTIVE_ICON
	LCALL	LCD_ICON
	SJMP	MAIN_OVER1

STEREO_BRIDGE:
	JB	ACTIVE,BRIDGE_MODE
STEREO_MODE:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#STEREO_ICON
	LCALL	LCD_ICON
	SJMP	MAIN_OVER1

BRIDGE_MODE:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BRIDGE_ICON
	LCALL	LCD_ICON

; Speaker model channel1:
MAIN_OVER1:
	MOV	DPTR,#0086H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LIN

	MOV	COUNT1,MOD1
	MOV	A,COUNT1
	JZ	COUNT_NEXT2
COUNT_NEXT1A:
	MOV	COUNT2,#21
COUNT_NEXT1:
	INC	DPTR
	DJNZ	COUNT2,COUNT_NEXT1
	DJNZ	COUNT1,COUNT_NEXT1A
COUNT_NEXT2:
	LCALL	LCD_TEXT

; Speaker version channel1:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	INC	DPTR
	SETB	LINE
	LCALL	LCD_TEXT

; Speaker model channel2:
	JNB	ACTIVE,NO_BRIDGE
	JNB	STEREO,NO_BRIDGE
	LJMP	OVER_MODEL_CH2		; Jump if in bridge mode

NO_BRIDGE:
	MOV	DPTR,#00C8H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LIN

	MOV	COUNT1,MOD2
	MOV	A,COUNT1
	JZ	COUNT_NEXT4
COUNT_NEXT3A:
	MOV	COUNT2,#21
COUNT_NEXT3:
	INC	DPTR
	DJNZ	COUNT2,COUNT_NEXT3
	DJNZ	COUNT1,COUNT_NEXT3A
COUNT_NEXT4:
	LCALL	LCD_TEXT

; Speaker version channel2:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#0148H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	INC	DPTR
	SETB	LINE
	LCALL	LCD_TEXT
OVER_MODEL_CH2:

; Gain channel1:
	MOV	DPTR,#0186H		; Start address in LCD memory
	MOV	G_LOW,G_LOW1
	MOV	G_HI,G_HI1
	LCALL	GAIN_DATA

; Input icon channel1:
	MOV	DPTR,#01BBH		; Start address in LCD memory
	JNB	D1,INPUT_ICON1

	JB	DUNIT,OVER_DELAY5
	MOV	A,D_LOW1
	CJNE	A,#0,INPUT_ICON3
	MOV	A,D_MID1
	CJNE	A,#1,INPUT_ICON3
	MOV	A,D_HI1
	CJNE	A,#0,INPUT_ICON3
	SJMP	INPUT_ICON1
OVER_DELAY5:
	MOV	A,D_LOW1
	CJNE	A,#4,INPUT_ICON3
	MOV	A,D_MID1
	CJNE	A,#3,INPUT_ICON3
	MOV	A,D_HI1
	CJNE	A,#0,INPUT_ICON3
	SJMP	INPUT_ICON1
INPUT_ICON3:
	MOV	DPTR,#01B5H		; Start address in LCD memory
	JNB	DLINK,INPUT_ICON1
	JB	STEREO,INPUT_ICON1
	JB	ACTIVE,INPUT_ICON1
	MOV	DPTR,#01B1H		; Start address in LCD memory
INPUT_ICON1:
	INC	0A2H			; Switch data pointers
	JNB	INPSET.1,CH1_IN1
	JNB	INPSET.0,CH1_IN2 
	MOV	DPTR,#INPUT12_ICON
	SJMP	OVER_INPUT1
CH1_IN1:
	MOV	DPTR,#INPUT1_ICON
	SJMP	OVER_INPUT1
CH1_IN2:
	MOV	DPTR,#INPUT2_ICON
OVER_INPUT1:
	LCALL	LCD_ICON

; Delay icon channel1:
	JNB	D1,OVER_DELAY1
	JB	DUNIT,OVER_DELAY3
	MOV	A,D_LOW1
	CJNE	A,#0,DELAY_ICON1
	MOV	A,D_MID1
	CJNE	A,#1,DELAY_ICON1
	MOV	A,D_HI1
	CJNE	A,#0,DELAY_ICON1
	SJMP	OVER_DELAY1
OVER_DELAY3:
	MOV	A,D_LOW1
	CJNE	A,#4,DELAY_ICON1
	MOV	A,D_MID1
	CJNE	A,#3,DELAY_ICON1
	MOV	A,D_HI1
	CJNE	A,#0,DELAY_ICON1
	SJMP	OVER_DELAY1
DELAY_ICON1:
	INC	0A2H			; Switch data pointers		
	INC	DPTR
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DELAY_ICON
	JNB	DLINK,NO_LINK10
	JB	STEREO,NO_LINK10
	JB	ACTIVE,NO_LINK10
	MOV	DPTR,#DELAYLINK_ICON
NO_LINK10:
	LCALL	LCD_ICON
OVER_DELAY1:

	JNB	STEREO,OVER_ICON2
	JB	ACTIVE,OVER_ICON2
; Input icon channel2:
	MOV	DPTR,#01F9H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#INPUT2_ICON
	LCALL	LCD_ICON
OVER_ICON2:

; EQ ON/OFF channel1:
	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQON
	JB	EQ1,EQON1
	MOV	DPTR,#EQOFF
EQON1:	
	LCALL	LCD_TEXT

; EQ icon:
	LCALL	EQ_ICON_CH1

; Mute ON/OFF channel1:
	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#UMT
	JNB	MUTE1,MUTE3
	MOV	DPTR,#0207H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MT
	SETB	INV
MUTE3:	
	LCALL	LCD_TEXT

; SETTINGS menu option:
	MOV	DPTR,#0306H		; Start address in LCD memory
	JB	STEREO,SINGLE_MENU3
	JB	ACTIVE,SINGLE_MENU3
	MOV	DPTR,#0348H		; Start address in LCD memory
SINGLE_MENU3:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SETT	
	LCALL	LCD_TEXT

; OPTIONS menu option:
	MOV	DPTR,#0386H		; Start address in LCD memory
	JB	STEREO,SINGLE_MENU4
	JB	ACTIVE,SINGLE_MENU4
	MOV	DPTR,#03C8H		; Start address in LCD memory
SINGLE_MENU4:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MOPT	
	LCALL	LCD_TEXT

	JB	ACTIVE,JMP_TO_MAIN_1	; Single menu in active or bridge mode
	JB	STEREO,JMP_TO_MAIN_1	; Single menu in stereo mode
	SJMP	DUAL_MENU		; Dual menu in dual channel mode
JMP_TO_MAIN_1:
	LJMP	START_MENU

DUAL_MENU:
; Gain channel2:
	MOV	DPTR,#01C8H		; Start address in LCD memory
	MOV	G_LOW,G_LOW2
	MOV	G_HI,G_HI2
	LCALL	GAIN_DATA

; Input icon channel2:
	MOV	DPTR,#01F9H		; Start address in LCD memory
	JNB	D2,INPUT_ICON2

	JB	DUNIT,OVER_DELAY6
	MOV	A,D_LOW2
	CJNE	A,#0,INPUT_ICON4
	MOV	A,D_MID2
	CJNE	A,#1,INPUT_ICON4
	MOV	A,D_HI2
	CJNE	A,#0,INPUT_ICON4
	SJMP	INPUT_ICON2
OVER_DELAY6:
	MOV	A,D_LOW2
	CJNE	A,#4,INPUT_ICON4
	MOV	A,D_MID2
	CJNE	A,#3,INPUT_ICON4
	MOV	A,D_HI2
	CJNE	A,#0,INPUT_ICON4
	SJMP	INPUT_ICON2
INPUT_ICON4:

	MOV	DPTR,#01F3H		; Start address in LCD memory
INPUT_ICON2:
	INC	0A2H			; Switch data pointers
	JNB	INPSET.3,CH2_IN1
	JNB	INPSET.2,CH2_IN2 
	MOV	DPTR,#INPUT12_ICON
	SJMP	OVER_INPUT2
CH2_IN1:
	MOV	DPTR,#INPUT1_ICON
	SJMP	OVER_INPUT2
CH2_IN2:
	MOV	DPTR,#INPUT2_ICON
OVER_INPUT2:
	LCALL	LCD_ICON

; Delay icon channel2:
	JNB	D2,OVER_DELAY2
	JB	DUNIT,OVER_DELAY4

	MOV	A,D_LOW2
	CJNE	A,#0,DELAY_ICON2
	MOV	A,D_MID2
	CJNE	A,#1,DELAY_ICON2
	MOV	A,D_HI2
	CJNE	A,#0,DELAY_ICON2
	SJMP	OVER_DELAY2
OVER_DELAY4:
	MOV	A,D_LOW2
	CJNE	A,#4,DELAY_ICON2
	MOV	A,D_MID2
	CJNE	A,#3,DELAY_ICON2
	MOV	A,D_HI2
	CJNE	A,#0,DELAY_ICON2
	SJMP	OVER_DELAY2
DELAY_ICON2:
	INC	0A2H			; Switch data pointers		
	INC	DPTR
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DELAY_ICON
	LCALL	LCD_ICON
OVER_DELAY2:

; EQ ON/OFF channel2:
	MOV	DPTR,#02C8H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQON
	JB	EQ2,EQON2
	MOV	DPTR,#EQOFF
EQON2:	
	LCALL	LCD_TEXT

; EQ icon:
	LCALL	EQ_ICON_CH2

; Mute ON/OFF channel2:
	MOV	DPTR,#0248H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#UMT
	JNB	MUTE2,MUTE4
	MOV	DPTR,#0249H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MT
	SETB	INV
MUTE4:	
	LCALL	LCD_TEXT

START_MENU:

MAIN_1:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	JNB	ALOCK,CURSOR_1
	MOV	DPTR,#CURSOR2
CURSOR_1:
	LCALL	LCD_TEXT
MAIN_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	
WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_MAIN_1
	JB	LEFT,MAIN_1A

SELECT_MAIN_1:
	JB	ALOCK,MAIN_1A

	CLR	CHAN2
	MOV	G_LOW,G_LOW1
	MOV	G_HI,G_HI1

	MOV	DPTR,#0186H		; Start address in LCD memory
	LCALL	ENTER_GAIN

	MOV	G_LOW1,G_LOW
	MOV	G_HI1,G_HI

	JB	STEREO,GAIN_COPY
	JB	ACTIVE,GAIN_COPY

	LCALL	WRITE_SETTINGS
	SJMP	MAIN_1A

GAIN_COPY:
	MOV	G_LOW2,G_LOW
	MOV	G_HI2,G_HI

	LCALL	WRITE_SETTINGS
	SJMP	MAIN_1A

JUMP_OFF_MAIN_1:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

MAIN_2:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
MAIN_2A:
	LCALL	LCD_REFRESH		; Refresh LCD display data
WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT2
	CLR	ENC
	JNB	PUS,JUMP_OFF_MAIN_2

SELECT_MAIN_2:
	LCALL	MUTE_DAC

	CPL	MUTE1

	MOV	I2C_TX,#020H		; DSP opcode for unmute ch1
	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#UMT
	JNB	MUTE1,MUTE5
	MOV	I2C_TX,#018H		; DSP opcode for mute ch1
	MOV	DPTR,#0207H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MT
	SETB	INV
MUTE5:
	LCALL	LCD_TEXT

	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	JB	STEREO,MUTE_LINK1
	JB	ACTIVE,MUTE_LINK1
	
	SJMP	OVER_MUTE_LINK

MUTE_LINK1:
	MOV	C,MUTE1
	MOV	MUTE2,C

	INC	I2C_TX
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

OVER_MUTE_LINK:
	LCALL	WRITE_SETTINGS
	CLR	DAC_MUTE		; Unmute DA converter
	SJMP	MAIN_2A

JUMP_OFF_MAIN_2:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,MAIN_3
	LJMP	MAIN_1

MAIN_3:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	JNB	ALOCK,CURSOR_2
	MOV	DPTR,#CURSOR2
CURSOR_2:
	LCALL	LCD_TEXT
MAIN_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data
WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT3
	CLR	ENC
	JB	PUS,SELECT_MAIN_3
	LJMP	JUMP_OFF_MAIN_3

SELECT_MAIN_3:
	JB	ALOCK,MAIN_3A

	SETB	P_ALT
	MOV	A,PRESET
	JZ	OVER_ALT1
	MOV	DPTR,#0078H		; Start address in LCD memory
	SETB	INV
	MOV	A,#'*'
	LCALL	LCD_CHAR
	CLR	INV
OVER_ALT1:

	CPL	EQ1

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQON
	MOV	I2C_TX,#029H		; DSP opcode for unbypass eq ch1
	JB	EQ1,EQON3
	MOV	DPTR,#EQOFF
	MOV	I2C_TX,#027H		; DSP opcode for bypass eq ch1
EQON3:
	LCALL	LCD_TEXT

	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

; EQ icon:
	LCALL	EQ_ICON_CH1
	
	JB	STEREO,EQ_LINK1
	JB	ACTIVE,EQ_LINK1
	JB	EQLINK,EQ_LINK1

	LCALL	WRITE_SETTINGS
	LJMP	MAIN_3A

EQ_LINK1:
	MOV	C,EQ1
	MOV	EQ2,C

	INC	I2C_TX
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	JB	ACTIVE,SINGLE_MENU11
	JB	STEREO,SINGLE_MENU11

	MOV	DPTR,#02C8H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQON
	JB	EQ2,EQON6
	MOV	DPTR,#EQOFF
EQON6:	
	LCALL	LCD_TEXT

; EQ icon:
	LCALL	EQ_ICON_CH2

SINGLE_MENU11:
	LCALL	WRITE_SETTINGS
	LJMP	MAIN_3A

JUMP_OFF_MAIN_3:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,JUMP_OFF_MAIN_3R
	LJMP	MAIN_2

JUMP_OFF_MAIN_3R:
	JB	STEREO,SINGLE_MENU5
	JB	ACTIVE,SINGLE_MENU5
	SJMP	MAIN_4
SINGLE_MENU5:
	LJMP	MAIN_7

MAIN_4:
	MOV	DPTR,#01C2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	JNB	ALOCK,CURSOR_3
	MOV	DPTR,#CURSOR2
CURSOR_3:
	LCALL	LCD_TEXT
MAIN_4A:	
	LCALL	LCD_REFRESH		; Refresh LCD display data

WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT4
	CLR	ENC
	JNB	PUS,JUMP_OFF_MAIN_4

SELECT_MAIN_4:
	JB	ALOCK,MAIN_4A

	SETB 	CHAN2
	MOV	G_LOW,G_LOW2
	MOV	G_HI,G_HI2

	MOV	DPTR,#01C8H		; Start address in LCD memory
	LCALL	ENTER_GAIN

	MOV	G_LOW2,G_LOW
	MOV	G_HI2,G_HI

	LCALL	WRITE_SETTINGS
	SJMP	MAIN_4A

JUMP_OFF_MAIN_4:
	MOV	DPTR,#01C2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,MAIN_5
	LJMP	MAIN_3

MAIN_5:
	MOV	DPTR,#0242H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
MAIN_5A:
	LCALL	LCD_REFRESH		; Refresh LCD display data
WAIT5:	
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT5
	CLR	ENC
	JNB	PUS,JUMP_OFF_MAIN_5

SELECT_MAIN_5:
	LCALL	MUTE_DAC

	CPL	MUTE2

	MOV	I2C_TX,#021H		; DSP opcode for unmute ch2
	MOV	DPTR,#0248H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#UMT
	JNB	MUTE2,MUTE7
	MOV	I2C_TX,#019H		; DSP opcode for mute ch2
	MOV	DPTR,#0249H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MT
	SETB	INV
MUTE7:
	LCALL	LCD_TEXT

	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus
	LCALL	WRITE_SETTINGS
	CLR	DAC_MUTE		; Unmute DA converter

	SJMP	MAIN_5A

JUMP_OFF_MAIN_5:
	MOV	DPTR,#0242H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,JUMP_OFF_MAIN_5R
	LJMP	MAIN_4
JUMP_OFF_MAIN_5R:

MAIN_6:
	MOV	DPTR,#02C2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	JNB	ALOCK,CURSOR_4
	MOV	DPTR,#CURSOR2
CURSOR_4:
	LCALL	LCD_TEXT
MAIN_6A:
	LCALL	LCD_REFRESH		; Refresh LCD display data
WAIT6:	
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT6
	CLR	ENC
	JB	PUS,SELECT_MAIN_6
	LJMP	JUMP_OFF_MAIN_6

SELECT_MAIN_6:
	JB	ALOCK,MAIN_6A
	CPL	EQ2

	SETB	P_ALT
	MOV	A,PRESET
	JZ	OVER_ALT2
	MOV	DPTR,#0078H		; Start address in LCD memory
	SETB	INV
	MOV	A,#'*'
	LCALL	LCD_CHAR
	CLR	INV
OVER_ALT2:

	MOV	DPTR,#02C8H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQON
	MOV	I2C_TX,#02AH		; DSP opcode for unbypass eq ch2
	JB	EQ2,EQON4
	MOV	DPTR,#EQOFF
	MOV	I2C_TX,#028H		; DSP opcode for bypass eq ch2
EQON4:
	LCALL	LCD_TEXT

	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

; EQ icon:
	LCALL	EQ_ICON_CH2

	JB	EQLINK,EQ_LINK2
	LCALL	WRITE_SETTINGS
	SJMP	MAIN_6A

EQ_LINK2:
	MOV	C,EQ2
	MOV	EQ1,C

	DEC	I2C_TX
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQON
	JB	EQ1,EQON8
	MOV	DPTR,#EQOFF
EQON8:	
	LCALL	LCD_TEXT

; EQ icon:
	LCALL	EQ_ICON_CH1

	LCALL	WRITE_SETTINGS
	LJMP	MAIN_6A

JUMP_OFF_MAIN_6:
	MOV	DPTR,#02C2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,MAIN_7
	LJMP	MAIN_5

MAIN_7:
	MOV	DPTR,#0300H		; Start address in LCD memory
	JB	STEREO,SINGLE_MENU6
	JB	ACTIVE,SINGLE_MENU6
	MOV	DPTR,#0342H		; Start address in LCD memory
SINGLE_MENU6:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

WAIT7:	
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT7
	CLR	ENC
	JNB	PUS,JUMP_OFF_MAIN_7

SELECT_MAIN_7:
	CLR	MAIN
	LJMP	SETUP_MENU

JUMP_OFF_MAIN_7:
	MOV	DPTR,#0300H		; Start address in LCD memory
	JB	STEREO,SINGLE_MENU7
	JB	ACTIVE,SINGLE_MENU7
	MOV	DPTR,#0342H		; Start address in LCD memory
SINGLE_MENU7:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	LEFT,JUMP_OFF_MAIN_7L
	JB	RIGHT,MAIN_8

JUMP_OFF_MAIN_7L:
	JB	STEREO,SINGLE_MENU10
	JB	ACTIVE,SINGLE_MENU10
	LJMP	MAIN_6
SINGLE_MENU10:
	LJMP	MAIN_3

MAIN_8:
	MOV	DPTR,#0380H		; Start address in LCD memory
	JB	STEREO,SINGLE_MENU8
	JB	ACTIVE,SINGLE_MENU8
	MOV	DPTR,#03C2H		; Start address in LCD memory
SINGLE_MENU8:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data	

WAIT8:	
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT8
	CLR	ENC
	JB	LEFT,JUMP_OFF_MAIN_8
	LCALL	LCD_REFRESH		; Refresh LCD display data
	JB	RIGHT,WAIT8

SELECT_MAIN_8:
	CLR	MAIN
	LJMP	OPTIONS_MENU

JUMP_OFF_MAIN_8:
	MOV	DPTR,#0380H		; Start address in LCD memory
	JB	STEREO,SINGLE_MENU9
	JB	ACTIVE,SINGLE_MENU9
	MOV	DPTR,#03C2H		; Start address in LCD memory

SINGLE_MENU9:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	LJMP	MAIN_7


EQ_ICON_CH1:
	MOV	DPTR,#02B4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQB_ICON
	JNB	EQ1,OVER_EQ3

	JB	CH1S1,SECT1_OFF
	MOV	A,GAIN1
	CJNE	A,#029H,EQ_ON1
SECT1_OFF:
	JB	CH1S2,SECT2_OFF
	MOV	A,GAIN2
	CJNE	A,#029H,EQ_ON1
SECT2_OFF:
	JB	CH1S3,SECT3_OFF
	MOV	A,GAIN3
	CJNE	A,#029H,EQ_ON1
SECT3_OFF:
	JB	CH1S4,SECT4_OFF
	MOV	A,GAIN4
	CJNE	A,#029H,EQ_ON1
SECT4_OFF:
	SJMP	OVER_EQ3
EQ_ON1:
	MOV	DPTR,#02B8H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQ_ICON
	JNB	EQLINK,NO_LINK3
	JB	STEREO,NO_LINK3
	JB	ACTIVE,NO_LINK3
	MOV	DPTR,#02B4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQLINK_ICON
NO_LINK3:
OVER_EQ3:
	LCALL	LCD_ICON
	RET

EQ_ICON_CH2:
	MOV	DPTR,#02F2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQB_ICON

	JNB	EQ2,OVER_EQ5

	JB	CH2S1,SECT5_OFF
	MOV	A,GAIN5
	CJNE	A,#029H,EQ_ON2
SECT5_OFF:
	JB	CH2S2,SECT6_OFF
	MOV	A,GAIN6
	CJNE	A,#029H,EQ_ON2
SECT6_OFF:
	JB	CH2S3,SECT7_OFF
	MOV	A,GAIN7
	CJNE	A,#029H,EQ_ON2
SECT7_OFF:
	JB	CH2S4,SECT8_OFF
	MOV	A,GAIN8
	CJNE	A,#029H,EQ_ON2
SECT8_OFF:
	SJMP	OVER_EQ5
EQ_ON2:
	MOV	DPTR,#02F6H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQ_ICON
OVER_EQ5:
	LCALL	LCD_ICON
	RET


;* ------------------------------------------------------------------------
;*  TEST MENU:
;* ------------------------------------------------------------------------

TEST_MENU:
	CLR	DIS
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

	JNB	ENC_SW,$
	CLR	ENC

	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#TESTM
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#NORMAL
	LCALL	LCD_TEXT

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#UMT
	LCALL	LCD_TEXT

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#FIN
	LCALL	LCD_TEXT

TEST_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
TEST_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

TEST_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,TEST_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_TEST_1
	JB	LEFT,TEST_1A

SELECT_TEST_1:
	RET

JUMP_OFF_TEST_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

TEST_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
TEST_2A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

TEST_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,TEST_WAIT2
	CLR	ENC
	JNB	PUS,JUMP_OFF_TEST_2

SELECT_TEST_2:
	JB	ADSTACK,TEST1

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#STCKD
	LCALL	LCD_TEXT
	SETB	ADSTACK
	SJMP	TEST_2A
TEST1:	
	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#NORMAL
	LCALL	LCD_TEXT
	CLR	ADSTACK
	SJMP	TEST_2A

JUMP_OFF_TEST_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,TEST_3
	SJMP	TEST_1

TEST_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
TEST_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

TEST_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,TEST_WAIT3
	CLR	ENC
	JNB	PUS,JUMP_OFF_TEST_3

SELECT_TEST_3:
	JB	DAC_MUTE,TEST2

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MT
	SETB	INV
	LCALL	LCD_TEXT
	SETB	DAC_MUTE		; Mute DA converter
	SJMP	TEST_3A
TEST2:	
	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#UMT
	LCALL	LCD_TEXT
	CLR	DAC_MUTE		; Unmute DA converter
	SJMP	TEST_3A

JUMP_OFF_TEST_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,TEST_4
	LJMP	TEST_2

TEST_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
TEST_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

TEST_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,TEST_WAIT4
	CLR	ENC
	JNB	PUS,JUMP_OFF_TEST_4

SELECT_TEST_4:
	MOV	PRESET,#0
	LCALL	PRESET_ADDRESS		; Calculate address location of preset in FLASH

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	LCALL	FLASH_OPCODE		;

	MOV	R1,#FLAGS2

TEST_LOOP3:
	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	MOV	@R1,A
	INC	R1
	CJNE	R1,#LIGHT,TEST_LOOP3

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	SETB	SET_CLK
	LCALL	WRITE_SETTINGS

	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#01AEH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#READY
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH		; Refresh LCD display data

FINISH:
	LCALL	RESET_WDT
	SJMP	FINISH

JUMP_OFF_TEST_4:
	JB	RIGHT,TEST_WAIT4
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LJMP	TEST_3


JMF_MENU:
	CLR	INF
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

HOLD:
	LCALL	RESET_WDT
	JNB	ENC_SW,HOLD
	CLR	ENC

	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#L1_ICON
	LCALL	LCD_TEXT

	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#L2_ICON
	LCALL	LCD_TEXT

	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#L3_ICON
	LCALL	LCD_TEXT

	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#L4_ICON
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

JMF_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,JMF_WAIT
	CLR	ENC
	RET

;* ------------------------------------------------------------------------
;*  SETUP MENU:
;* ------------------------------------------------------------------------

SETUP_MENU:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	JNB	ALOCK,NO_LOCK2
	MOV	DPTR,#03F9H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK_ICON
	LCALL	LCD_ICON
	SJMP	NO_LOCK10
NO_LOCK2:

	JNB	PLOCK,NO_LOCK10
	MOV	DPTR,#0372H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK_ICON
	LCALL	LCD_ICON

	MOV	DPTR,#02F2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK_ICON
	LCALL	LCD_ICON
NO_LOCK10:

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SETTM
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SET1
	LCALL	LCD_TEXT

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SET2
	LCALL	LCD_TEXT

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PRESETS
	LCALL	LCD_TEXT

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DUAL

	MOV	A,INPSET
	SWAP	A
	ANL	A,#003H
	JZ	SET_OVER1
	MOV	COUNT1,A
SET_COUNT2:
	MOV	COUNT2,#18
SET_COUNT1:
	INC	DPTR
	DJNZ	COUNT2,SET_COUNT1
	DJNZ	COUNT1,SET_COUNT2
SET_OVER1:
	LCALL	LCD_TEXT

	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LNK
	LCALL	LCD_TEXT

	MOV	DPTR,#03A4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOFF
	JB	EQLINK,LINK_EQ_DELAY
	JB	DLINK,LINK_DELAY
	SJMP	NO_LINK

LINK_EQ_DELAY:
	MOV	DPTR,#EQL
	JNB	DLINK,NO_LINK
	MOV	DPTR,#EQDLYL
	SJMP	NO_LINK
LINK_DELAY:
	MOV	DPTR,#DLYL
NO_LINK:
	LCALL	LCD_TEXT

SETTINGS_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
SETTINGS_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETTINGS_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETTINGS_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_SETTINGS_1
	JB	LEFT,SETTINGS_1A

SELECT_SETTINGS_1:
	LJMP	MAINMENU

JUMP_OFF_SETTINGS_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

SETTINGS_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETTINGS_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETTINGS_WAIT2
	CLR	ENC
	JNB	PUS,JUMP_OFF_SETTINGS_2

SELECT_SETTINGS_2:
	CLR	CHAN2
	LJMP	SETUP12_MENU

JUMP_OFF_SETTINGS_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,SETTINGS_3
	LJMP	SETTINGS_1

SETTINGS_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	STEREO,CURSOR_5
	JB	ACTIVE,CURSOR_5
	MOV	DPTR,#CURSOR
CURSOR_5:
	LCALL	LCD_TEXT
SETTINGS_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETTINGS_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETTINGS_WAIT3
	CLR	ENC
	JNB	PUS,JUMP_OFF_SETTINGS_3

SELECT_SETTINGS_3:
	JB	STEREO,SETTINGS_3A	; No ch2 selection in stereo or bridge mode
	JB	ACTIVE,SETTINGS_3A	; No ch2 selection in active mode
	SETB	CHAN2
	LJMP	SETUP12_MENU

JUMP_OFF_SETTINGS_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,SETTINGS_4
	LJMP	SETTINGS_2


SETTINGS_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	PLOCK,CURSOR_6
	MOV	DPTR,#CURSOR
CURSOR_6:
	LCALL	LCD_TEXT
SETTINGS_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETTINGS_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETTINGS_WAIT4
	CLR	ENC
	JNB	PUS,JUMP_OFF_SETTINGS_4

SELECT_SETTINGS_4:
	JB	PLOCK,SETTINGS_4A
	LJMP	PRESET_MENU

JUMP_OFF_SETTINGS_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,SETTINGS_5
	LJMP	SETTINGS_3

SETTINGS_5:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	PLOCK,CURSOR_7
	MOV	A,SPPRESET1
	JB	ACC.2,CURSOR_7
	MOV	DPTR,#CURSOR
CURSOR_7:
	LCALL	LCD_TEXT
SETTINGS_5A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETTINGS_WAIT5:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETTINGS_WAIT5
	CLR	ENC
	JNB	PUS,JUMP_OFF_SETTINGS_5

	JB	PLOCK,SETTINGS_5A
	MOV	A,SPPRESET1
	JB	ACC.2,SETTINGS_5A
	LJMP	SELECT_SETTINGS_5

JUMP_OFF_SETTINGS_5:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,SETTINGS_6B
	LJMP	SETTINGS_4
SETTINGS_6B:
	LJMP	SETTINGS_6

SELECT_SETTINGS_5:
	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DUAL

	MOV	A,INPSET
	SWAP	A
	ANL	A,#003H
	JZ	SET_OVER2
	MOV	COUNT1,A
SET_COUNT4:
	MOV	COUNT2,#18
SET_COUNT3:
	INC	DPTR
	DJNZ	COUNT2,SET_COUNT3
	DJNZ	COUNT1,SET_COUNT4
SET_OVER2:
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SELECT_SETTINGS5A:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SELECT_SETTINGS5A
	CLR	ENC
	JB	RIGHT,OUTPUT_UP4
	JB	LEFT,OUTPUT_DOWN4
	SJMP	LEAVE_SETTINGS5A

OUTPUT_UP4:
	SETB	P_ALT
	LJMP	OUTPUT_UP

OUTPUT_DOWN4:
	SETB	P_ALT
	LJMP	OUTPUT_DOWN

LEAVE_SETTINGS5A:
	LCALL	MUTE_DAC

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DUAL

	MOV	A,INPSET
	SWAP	A
	ANL	A,#003H
	JZ	SET_OVER3
	MOV	COUNT1,A
SET_COUNT6:
	MOV	COUNT2,#18
SET_COUNT5:
	INC	DPTR
	DJNZ	COUNT2,SET_COUNT5
	DJNZ	COUNT1,SET_COUNT6
SET_OVER3:
	LCALL	LCD_TEXT

	JB	STEREO,OUTPUT_STEREO_ACTIVE_BRIDGE
	JB	ACTIVE,OUTPUT_STEREO_ACTIVE_BRIDGE

OUTPUT_DUAL:	
	MOV	A,INPSET		; Input routing: ch1->ch1 ch2->ch2
	ANL	A,#0F0H			;
	ORL	A,#009H			;
	MOV	INPSET,A		;

	MOV	I2C_TX,#049H		; low byte for DSP opcode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	LJMP	OUTPUT_END3

OUTPUT_STEREO_ACTIVE_BRIDGE:		; Stereo, active or bridge mode
	MOV	MOD2,MOD1

	MOV	SPPRESET2,SPPRESET1

	MOV	A,SPOPT
	ANL	A,#00FH
	MOV	B,A
	SWAP	A
	ADD	A,B
	MOV	SPOPT,A

	MOV	C,HCORR1
	MOV	HCORR2,C

	SETB	CHAN2
	LCALL	PRESET_MUTE
	LCALL	DSP_LOAD_PRESET

	SETB	DLINK

	MOV	C,D_FINE1		; TEMP
	MOV	D_FINE,C		; TEMP
	MOV	D_LOW,D_LOW1
	MOV	D_MID,D_MID1
	MOV	D_HI,D_HI1

	MOV	C,D_FINE1		; TEMP
	MOV	D_FINE2,C		; TEMP
	MOV	D_LOW2,D_LOW1
	MOV	D_MID2,D_MID1
	MOV	D_HI2,D_HI1

	MOV	C,D1
	MOV	D2,C

	JB	D2,SET_DELAY1
	MOV	I2C_TX,#017H		; Get opcode for DSP delay data ch2
	LCALL	DSP_BYPASS_DELAY
	SJMP	SET_DELAY3
SET_DELAY1:
	LCALL	DSP_LOAD_DELAY2
SET_DELAY3:

	SETB	EQLINK
	LCALL	COPY_EQ

	MOV	C,EQ1
	MOV	EQ2,C

	MOV	I2C_TX,#02AH		; DSP opcode
	JB	EQ2,EQON5
	MOV	I2C_TX,#028H		; DSP opcode
EQON5:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	LCALL	SETUP_EQ

	MOV	C,MUTE1
	MOV	MUTE2,C

	MOV	I2C_TX,#019H		; low byte for DSP opcode
	JB	MUTE2,MUTE8
	MOV	I2C_TX,#021H		; low byte for DSP opcode
MUTE8:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	MOV	G_LOW,G_LOW1
	MOV	G_HI,G_HI1

	MOV	G_LOW2,G_LOW1
	MOV	G_HI2,G_HI1

	MOV	DSP_OPCODE,#032H	; DSP opcode for CH2 output gain data
	LCALL	DSP_LOAD_GAIN

	JB	ACTIVE,OUTPUT_ACTIVE_BRIDGE

OUTPUT_STEREO:
	MOV	A,INPSET		; Input routing: ch1->ch1 ch2->ch2
	ANL	A,#0F0H			;
	ORL	A,#009H			;
	MOV	INPSET,A		;

	MOV	I2C_TX,#048H		; DSP opcode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	SJMP	OUTPUT_END3

OUTPUT_ACTIVE_BRIDGE:
	MOV	A,INPSET
	ANL	A,#0F0H
	ORL	A,#005H
	MOV	INPSET,A

	JB	STEREO,OUTPUT_BRIDGE	

OUTPUT_ACTIVE:
	MOV	I2C_TX,#047H		; low byte for DSP opcode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	LJMP	OUTPUT_END3

OUTPUT_BRIDGE:
	MOV	I2C_TX,#046H		; low byte for DSP opcode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

OUTPUT_END3:
	LCALL	CHECK_ADC_STACKED
	LCALL	DSP_ENABLE_INT

	MOV	DPTR,#03A4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOFF
	JB	EQLINK,LINK_EQ_DELAY4
	JB	DLINK,LINK_DELAY4
	SJMP	NO_LINK4

LINK_EQ_DELAY4:
	MOV	DPTR,#EQL
	JNB	DLINK,NO_LINK4
	MOV	DPTR,#EQDLYL
	SJMP	NO_LINK4
LINK_DELAY4:
	MOV	DPTR,#DLYL
NO_LINK4:
	LCALL	LCD_TEXT

	LCALL	WRITE_SETTINGS	
	LJMP	SETTINGS_5A

OUTPUT_UP:
	MOV	A,INPSET
	SWAP	A
	ANL	A,#03H
	CJNE	A,#03H,OUTPUT_UP1
	LJMP	SELECT_SETTINGS_5
OUTPUT_UP1:
	CJNE	A,#01H,OUTPUT_UP2
	MOV	A,INPSET
	ADD	A,#16
	MOV	INPSET,A
OUTPUT_UP2:
	MOV	A,INPSET
	ADD	A,#16
	MOV	INPSET,A
	LJMP	SELECT_SETTINGS_5

OUTPUT_DOWN:
	MOV	A,INPSET
	SWAP	A
	ANL	A,#03H
	JNZ	OUTPUT_DOWN1
	LJMP	SELECT_SETTINGS_5
OUTPUT_DOWN1:
	CJNE	A,#03H,OUTPUT_DOWN2
	MOV	A,INPSET
	CLR	C
	SUBB	A,#16
	MOV	INPSET,A
OUTPUT_DOWN2:
	MOV	A,INPSET
	CLR	C
	SUBB	A,#16
	MOV	INPSET,A
	LJMP	SELECT_SETTINGS_5

SETTINGS_6:
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	STEREO,CURSOR_8
	JB	ACTIVE,CURSOR_8
	JB	ALOCK,CURSOR_8
	MOV	DPTR,#CURSOR
CURSOR_8:
	LCALL	LCD_TEXT
SETTINGS_6A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETTINGS_WAIT6:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETTINGS_WAIT6
	CLR	ENC
	JB	RIGHT,SETTINGS_6A
	JB	PUS,SELECT_SETTINGS_6

JUMP_OFF_SETTINGS_6:
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LJMP	SETTINGS_5

SELECT_SETTINGS_6:
	JB	ALOCK,SETTINGS_6A
	JB	ACTIVE,SETTINGS_6A
	JB	STEREO,SETTINGS_6A

SELECT_SETTINGS_6A:
	MOV	DPTR,#03A4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOFF
	JB	EQLINK,LINK_EQ_DELAY1
	JB	DLINK,LINK_DELAY1
	SJMP	NO_LINK1

LINK_EQ_DELAY1:
	MOV	DPTR,#EQL
	JNB	DLINK,NO_LINK1
	MOV	DPTR,#EQDLYL
	SJMP	NO_LINK1
LINK_DELAY1:
	MOV	DPTR,#DLYL
NO_LINK1:
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

SETTINGS_WAIT6A:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETTINGS_WAIT6A
	CLR	ENC
	JB	RIGHT,LINK_UP
	JB	LEFT,LINK_DOWN
	SJMP	LINK_CONFIRM

LINK_UP:
	SETB	P_ALT
	MOV	A,INPSET
	ANL	A,#0C0H
	CJNE	A,#0C0H,LINK_UP1
	SJMP	SELECT_SETTINGS_6A
LINK_UP1:
	MOV	A,INPSET
	ADD	A,#040H
	MOV	INPSET,A
	SJMP	SELECT_SETTINGS_6A

LINK_DOWN:
	SETB	P_ALT
	MOV	A,INPSET
	ANL	A,#0C0H
	JNZ	LINK_DOWN1
	SJMP	SELECT_SETTINGS_6A
LINK_DOWN1:
	MOV	A,INPSET
	CLR	C
	SUBB	A,#040H
	MOV	INPSET,A
	SJMP	SELECT_SETTINGS_6A

LINK_CONFIRM:
	MOV	DPTR,#03A4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOFF
	JB	EQLINK,LINK_EQ_DELAY2
	JB	DLINK,LINK_DELAY2
	SJMP	NO_LINK2
LINK_EQ_DELAY2:
	MOV	DPTR,#EQL
	JNB	DLINK,NO_LINK2
	MOV	DPTR,#EQDLYL
	SJMP	NO_LINK2
LINK_DELAY2:
	MOV	DPTR,#DLYL
NO_LINK2:
	LCALL	LCD_TEXT

	JNB	DLINK,DLINK_OFF

	MOV	C,D_FINE1		; TEMP
	MOV	D_FINE2,C		; TEMP
	MOV	D_LOW2,D_LOW1
	MOV	D_MID2,D_MID1
	MOV	D_HI2,D_HI1

	MOV	C,D1
	MOV	D2,C

	MOV	DELH2,DELH1
	MOV	DELL2,DELL1

	JB	D2,SET_DELAY2
	MOV	I2C_TX,#017H		; Get opcode for DSP
	LCALL	DSP_BYPASS_DELAY
	SJMP	SET_DELAY4
SET_DELAY2:
	LCALL	DSP_LOAD_DELAY2
SET_DELAY4:
	LCALL	DSP_ENABLE_INT

DLINK_OFF:
	JNB	EQLINK,EQLINK_OFF

	MOV	C,EQ1
	MOV	EQ2,C

	MOV	I2C_TX,#02AH		; DSP opcode
	JB	EQ2,EQON7
	MOV	I2C_TX,#028H		; DSP opcode
EQON7:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	LCALL	COPY_EQ
	LCALL	SETUP_EQ

EQLINK_OFF:
	LCALL	WRITE_SETTINGS
	LJMP	SETTINGS_6A

;* ------------------------------------------------------------------------
;*  SETUP CHANNEL 1/2 MENU:
;* ------------------------------------------------------------------------
SETUP12_MENU:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	JNB	ALOCK,NO_LOCK3
	MOV	DPTR,#03F9H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK_ICON
	LCALL	LCD_ICON
NO_LOCK3:

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SETUP2
	JB	CHAN2,SETUP_OVER1
	MOV	DPTR,#SETUP1
SETUP_OVER1:
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MPRES
	LCALL	LCD_TEXT

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#INPUT
	LCALL	LCD_TEXT

	MOV	A,INPSET
	JNB	CHAN2,INPUT3
	RR	A
	RR	A
INPUT3:
	ANL	A,#03H

	MOV	DPTR,#022AH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#INP1
	CJNE	A,#002H,INPUT1
	MOV	DPTR,#INP2
	SJMP	INPUT2
INPUT1:
	CJNE	A,#003H,INPUT2
	MOV	DPTR,#INP12
INPUT2:
	LCALL	LCD_TEXT

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MPAREQ
	JNB	CHAN2,SETUP_OVER3
	JNB	EQLINK,SETUP_OVER3	
	MOV	DPTR,#EQLNK
SETUP_OVER3:
	LCALL	LCD_TEXT

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	JNB	CHAN2,SETUP_OVER7
	JB	DLINK,SETUP_OVER8	
SETUP_OVER7:

	MOV	DPTR,#MDELAY
	LCALL	LCD_TEXT

	MOV	C,D_FINE2		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW2
	MOV	D_MID,D_MID2
	MOV	D_HI,D_HI2
	JB	CHAN2,SETUP5
	MOV	C,D_FINE1		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW1
	MOV	D_MID,D_MID1
	MOV	D_HI,D_HI1
SETUP5:
	MOV	DPTR,#032AH		; Start address in LCD memory
	JB	CHAN2,SETUP_OVER5
	JNB	D1,SETUP_OVER2
	LCALL	DELAY_DATA
	SJMP	SETUP_1
SETUP_OVER5:
	JNB	D2,SETUP_OVER2
	LCALL	DELAY_DATA
	SJMP	SETUP_1
SETUP_OVER2:	
	INC	0A2H			; Switch data pointers

	MOV	DPTR,#OFF2
	JNB	DABS,DELAY_ON11
	MOV	DPTR,#DOFF
	JNB	DUNIT,DELAY_ON11
	MOV	DPTR,#DOFFM
DELAY_ON11:

	LCALL	LCD_TEXT
	SJMP	SETUP_1

SETUP_OVER8:
	MOV	DPTR,#DLLNK
	LCALL	LCD_TEXT

SETUP_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
SETUP_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETUP_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETUP_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_SETUP_1
	JB	LEFT,SETUP_1A

SELECT_SETUP_1:
	LJMP	SETUP_MENU

JUMP_OFF_SETUP_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

SETUP_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
SETUP_2A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETUP_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETUP_WAIT2
	CLR	ENC
	JNB	PUS,JUMP_OFF_SETUP_2

SELECT_SETUP_2:
	LJMP	SPEAKER_SETUP

JUMP_OFF_SETUP_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,SETUP_3
	LJMP	SETUP_1

SETUP_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	ALOCK,CURSOR_10
	JNB	STEREO,CURSOR_25
	JNB	ACTIVE,CURSOR_10
CURSOR_25:
	MOV	DPTR,#CURSOR
CURSOR_10:
	LCALL	LCD_TEXT
SETUP_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETUP_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETUP_WAIT3
	CLR	ENC
	JNB	PUS,JUMP_OFF_SETUP_3

	JB	ALOCK,SETUP_3A
	JNB	STEREO,SELECT_SETUP_3
	JB	ACTIVE,SELECT_SETUP_3
	SJMP	SETUP_3A

JUMP_OFF_SETUP_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,SETUP_4B
	LJMP	SETUP_2
SETUP_4B:
	LJMP	SETUP_4

SELECT_SETUP_3:
	MOV	A,INPSET
	JNB	CHAN2,INPUT4
	RR	A
	RR	A
INPUT4:
	ANL	A,#03H

	MOV	DPTR,#022AH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#INP1
	CJNE	A,#002H,INPUT5
	MOV	DPTR,#INP2
	SJMP	INPUT6
INPUT5:
	CJNE	A,#003H,INPUT6
	MOV	DPTR,#INP12
INPUT6:
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SELECT_SETUP3A:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SELECT_SETUP3A
	CLR	ENC
	MOV	A,INPSET
	JNB	CHAN2,INPUT7
	RR	A
	RR	A
INPUT7:
	ANL	A,#03H

	JB	RIGHT,INPUT_UP
	JB	PUS,INPUT_CONF
	LJMP	INPUT_DOWN

INPUT_CONF:
	MOV	DPTR,#022AH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#INP1
	CJNE	A,#002H,INPUT8
	MOV	DPTR,#INP2
	SJMP	INPUT9
INPUT8:
	CJNE	A,#003H,INPUT9
	MOV	DPTR,#INP12
INPUT9:
	LCALL	LCD_TEXT

	LCALL	MUTE_DAC

	MOV	A,INPSET
	ANL	A,#03H

	MOV	I2C_TX,#040H		; DSP opcode
	CJNE	A,#002H,SET_INPUT5
	MOV	I2C_TX,#041H		; DSP opcode
	SJMP	SET_INPUT6
SET_INPUT5:
	CJNE	A,#003H,SET_INPUT6
	MOV	I2C_TX,#042H		; DSP opcode
SET_INPUT6:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	MOV	A,INPSET
	RR	A
	RR	A
	ANL	A,#03H

	MOV	I2C_TX,#044H		; DSP opcode
	CJNE	A,#002H,SET_INPUT7
	MOV	I2C_TX,#043H		; DSP opcode
	SJMP	SET_INPUT8
SET_INPUT7:
	CJNE	A,#003H,SET_INPUT8
	MOV	I2C_TX,#045H		; DSP opcode
SET_INPUT8:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	LCALL	CHECK_ADC_STACKED
	LCALL	WRITE_SETTINGS
	CLR	DAC_MUTE
	LJMP	SETUP_3A

INPUT_UP:
	CJNE	A,#03H,INPUT_UP1
	LJMP	SELECT_SETUP3A
INPUT_UP1:
	INC	A
	SJMP	INPUT_END

INPUT_DOWN:
	CJNE	A,#01H,INPUT_DOWN1
	LJMP	SELECT_SETUP3A
INPUT_DOWN1:
	DEC	A

INPUT_END:
	SETB	P_ALT
	JB	CHAN2,INPUT_END2
	MOV	B,A
	MOV	A,INPSET
	ANL	A,#0FCH
	ADD	A,B
	MOV	INPSET,A
	MOV	A,B
	JB	ACTIVE,INPUT_END2
	LJMP	SELECT_SETUP_3
INPUT_END2:
	RL	A
	RL	A
	MOV	B,A
	MOV	A,INPSET
	ANL	A,#0F3H
	ADD	A,B
	MOV	INPSET,A
	LJMP	SELECT_SETUP_3

SETUP_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	JNB	CHAN2,CURSOR_11
	JNB	EQLINK,CURSOR_11
	MOV	DPTR,#CURSOR2
CURSOR_11:
	LCALL	LCD_TEXT
SETUP_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETUP_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETUP_WAIT4
	CLR	ENC
	JNB	PUS,JUMP_OFF_SETUP_4

SELECT_SETUP_4:
	JNB	CHAN2,SETUP_OVER4
	JB	EQLINK,SETUP_4A	
SETUP_OVER4:
	LJMP	PARAMETRIC_EQ

JUMP_OFF_SETUP_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,SETUP_5
	LJMP	SETUP_3

SETUP_5:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	JB	ALOCK,CURSOR_13
	JNB	CHAN2,CURSOR_12
	JNB	DLINK,CURSOR_12
CURSOR_13:
	MOV	DPTR,#CURSOR2
CURSOR_12:
	LCALL	LCD_TEXT
SETUP_5A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SETUP_WAIT5:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SETUP_WAIT5
	CLR	ENC
	JB	LEFT,JUMP_OFF_SETUP_5
	JB	RIGHT,SETUP_5A

SELECT_SETUP_5:
	JB	ALOCK,SETUP_5A
	JNB	CHAN2,SETUP_OVER6
	JB	DLINK,SETUP_5A	
SETUP_OVER6:
	LJMP	DELAY_MENU

JUMP_OFF_SETUP_5:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LJMP	SETUP_4

;* ------------------------------------------------------------------------
;*  PRESET MENU:
;* ------------------------------------------------------------------------

PRESET_MENU:
	MOV	TEMP,PRESET
	CLR	PSWAP

	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PRESM
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PRES
	LCALL	LCD_TEXT

	MOV	A,PRESET

	MOV	DPTR,#01B6H		; Start address in LCD memory
	LCALL	PRESETNAME1

	MOV	DPTR,#0236H		; Start address in LCD memory
	LCALL	PRESETNAME2

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#RECALL
	LCALL	LCD_TEXT

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#STORE
	LCALL	LCD_TEXT

	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CNAME
	LCALL	LCD_TEXT

PRESET_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
PRESET_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

PRESET_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,PRESET_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_PRESET_1
	JB	LEFT,PRESET_1A

SELECT_PRESET_1:
	LJMP	SETUP_MENU

JUMP_OFF_PRESET_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

PRESET_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
CURSOR_22:
	LCALL	LCD_TEXT
PRESET_2A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

PRESET_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,PRESET_WAIT2
	CLR	ENC
	JB	PUS,SELECT_PRESET_2

	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	JB	LEFT,JUMP_OFF_PRESET_2
	SJMP	PRESET_3

SELECT_PRESET_2:
	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#RECALL
	LCALL	LCD_TEXT

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#STORE
	LCALL	LCD_TEXT

	CLR	PSWAP			; Disable preset swapping

	LJMP	CHANGE_PRESET

JUMP_OFF_PRESET_2:
	LJMP	PRESET_1	

PRESET_3:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH		; Refresh LCD display data	

PRESET_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,PRESET_WAIT3
	CLR	ENC
	JNB	PUS,JUMP_OFF_PRESET_3

SELECT_PRESET_3:
	CLR	P_ALT

	JB	PSWAP,PRESET_SWAP
	LJMP	RECALL_PRESET
PRESET_SWAP:
	LJMP	SWAP_PRESET

JUMP_OFF_PRESET_3:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	JB	RIGHT,PRESET_4
	LJMP	PRESET_2

PRESET_4:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	MOV	A,TEMP
	JZ	CURSOR_14
	MOV	DPTR,#CURSOR
CURSOR_14:
	LCALL	LCD_TEXT
PRESET_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

PRESET_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,PRESET_WAIT4
	CLR	ENC
	JNB	PUS,JUMP_OFF_PRESET_4

SELECT_PRESET_4:
	MOV	A,TEMP
	JZ	PRESET_4A
	CLR	PSWAP			; Disable preset swapping
	LJMP	STORE_PRESET

JUMP_OFF_PRESET_4:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	JB	RIGHT,PRESET_5
	LJMP	PRESET_3

PRESET_5:
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	MOV	A,TEMP
	JZ	CURSOR_15
	CLR	C
	SUBB	A,PRESET
	JNZ	CURSOR_15
	MOV	DPTR,#CURSOR
CURSOR_15:
	LCALL	LCD_TEXT
PRESET_5A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

PRESET_WAIT5:	
	LCALL	ENCODER_CHECK
	JNB	ENC,PRESET_WAIT5
	CLR	ENC
	JB	LEFT,JUMP_OFF_PRESET_5
	JB	RIGHT,PRESET_5A

SELECT_PRESET_5:
	MOV	A,TEMP
	JZ	PRESET_5A
	CLR	C
	SUBB	A,PRESET
	JNZ	PRESET_5A

	LJMP	PRESET_NAME_MENU

JUMP_OFF_PRESET_5:
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	LJMP	PRESET_4

CHANGE_PRESET:
	MOV	A,TEMP
	SETB	INV

	MOV	DPTR,#01B6H		; Start address in LCD memory
	LCALL	PRESETNAME1

	MOV	DPTR,#0236H		; Start address in LCD memory
	LCALL	PRESETNAME2
	LCALL	LCD_REFRESH		; Refresh LCD display data

	CLR	INV

CHANGE_PRESET_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,CHANGE_PRESET_WAIT
	CLR	ENC
	MOV	A,TEMP
	JB	LEFT,PRESET_DOWN
	JB	RIGHT,PRESET_UP
	SJMP	PRESET_CHANGE

PRESET_DOWN:
	JZ	PRESET_DOWN1
	DEC	TEMP
	SJMP	CHANGE_PRESET
PRESET_DOWN1:
	MOV	TEMP,#99
	SJMP	CHANGE_PRESET

PRESET_UP:
	CJNE	A,#99,PRESET_UP1
	MOV	TEMP,#0
	SJMP	CHANGE_PRESET
PRESET_UP1:
	INC	TEMP
	SJMP	CHANGE_PRESET


PRESET_CHANGE:
	MOV	DPTR,#01B6H		; Start address in LCD memory
	LCALL	PRESETNAME1

	MOV	DPTR,#0236H		; Start address in LCD memory
	LCALL	PRESETNAME2

	MOV	DPTR,#02AAH		; Start address in LCD memory
	MOV	A,#'?'
	LCALL	LCD_CHAR

	MOV	A,TEMP
	JZ	OVER10

	MOV	DPTR,#0324H		; Start address in LCD memory
	MOV	A,#'?'
	LCALL	LCD_CHAR
OVER10:
	LJMP	PRESET_2

RECALL_PRESET:
	MOV	DPTR,#02AAH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ED
	LCALL	LCD_TEXT

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#STORE
	LCALL	LCD_TEXT

	SETB	PSWAP			; Enable preset swapping
	LCALL	LCD_REFRESH		; Refresh LCD display data

	MOV	PPRESET,PRESET
	MOV	PRESET,TEMP

	LCALL	PRESET_ADDRESS		; Calculate address location of preset in FLASH

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	LCALL	FLASH_OPCODE		;

	MOV	R1,#FLAGS2

SETTINGS_LOOP3:
	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	MOV	@R1,A
	INC	R1
	CJNE	R1,#LIGHT,SETTINGS_LOOP3

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LCALL	SETUP_DSP
	LCALL	WRITE_SETTINGS

	MOV	R7,#0			; Wait for 1sec
TEXT_WAIT:
	MOV	R5,#9
	LCALL	LWAIT
	LCALL	ENCODER_CHECK
	JB	ENC,OVER_WAIT
	DJNZ	R7,TEXT_WAIT
OVER_WAIT:

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#RECALLP
	LCALL	LCD_TEXT
LOCK2:
	LJMP	PRESET_3

SWAP_PRESET:
	MOV	B,PRESET
	MOV	PRESET,PPRESET
	MOV	PPRESET,B

	MOV	TEMP,PRESET

	MOV	A,PRESET
	MOV	DPTR,#01B6H		; Start address in LCD memory
	LCALL	PRESETNAME1

	MOV	DPTR,#0236H		; Start address in LCD memory
	LCALL	PRESETNAME2

	LCALL	LCD_REFRESH		; Refresh LCD display data

	LCALL	PRESET_ADDRESS		; Calculate address location of preset in FLASH

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	LCALL	FLASH_OPCODE		;

	MOV	R1,#FLAGS2

SETTINGS_LOOP4:
	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	MOV	@R1,A
	INC	R1
	CJNE	R1,#LIGHT,SETTINGS_LOOP4

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LCALL	SETUP_DSP
	LCALL	WRITE_SETTINGS

	LJMP	PRESET_WAIT3

STORE_PRESET:
	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CONFIRM
	LCALL	LCD_TEXT

PRESET_CONF_NO:
	MOV	DPTR,#0336H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#NO
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

PRESET_CONF_NO_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,PRESET_CONF_NO_WAIT
	CLR	ENC
	JB	RIGHT,PRESET_CONF_YES
	JB	LEFT,PRESET_CONF_NO_WAIT

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#STORE
	LCALL	LCD_TEXT

	MOV	DPTR,#0324H		; Start address in LCD memory
	MOV	A,#'?'
	LCALL	LCD_CHAR

	LJMP	PRESET_4

PRESET_CONF_YES:
	MOV	DPTR,#0336H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#YES
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

PRESET_CONF_YES_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,PRESET_CONF_YES_WAIT
	CLR	ENC
	JB	LEFT,PRESET_CONF_NO
	JB	RIGHT,PRESET_CONF_YES_WAIT

PRESET_CONFIRMED:
	CLR	P_ALT
	MOV	PRESET,TEMP
	LCALL	PRESET_ADDRESS

	MOV	OPCODE,#053H		; Opcode for page to buffer1
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	LCALL	FLASH_OPCODE		;

	MOV	R1,#FLAGS2

SETTINGS_LOOP5:
	MOV	A,@R1
	INC	R1
	LCALL	SPI_TX			; 
	CJNE	R1,#LIGHT,SETTINGS_LOOP5

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY


	MOV	OPCODE,#083H		; Opcode for buffer1 to page
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#STORED
	LCALL	LCD_TEXT

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#RECALL
	LCALL	LCD_TEXT

	LCALL	WRITE_SETTINGS

	LJMP	PRESET_4


PRESET_ADDRESS:
	MOV	OPCODE1,#008H		; Start at page512

	MOV	A,PRESET

	ANL	A,#0F8H
	MOV	OPCODE2,A

	MOV	A,PRESET

	CLR	C
	SUBB	A,OPCODE2
	MOV	B,A

	MOV	A,OPCODE2
	RR	A
	MOV	OPCODE2,A

	MOV	A,#66
	MUL	AB
	ADD	A,#21
	MOV	OPCODE3,A

	MOV	A,OPCODE2
	ADDC	A,#0
	ADD	A,B
	MOV	OPCODE2,A

	RET


;* ------------------------------------------------------------------------
;*  OPTIONS MENU:
;* ------------------------------------------------------------------------

OPTIONS_MENU:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	JNB	ALOCK,NO_LOCK9
	MOV	DPTR,#03F9H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK_ICON
	LCALL	LCD_ICON
NO_LOCK9:

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#OPT
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DISPLAY
	LCALL	LCD_TEXT

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#INFO
	LCALL	LCD_TEXT

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MUTE
	LCALL	LCD_TEXT

	MOV	DPTR,#02AAH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#M_OFF

	JB	PUMUTE,MUTE6		; Mute on power up or preset change
	JNB	PRMUTE,MUTE13
	MOV	DPTR,#PRCH
	SJMP	MUTE13
MUTE6:					; Mute on power up or preset change
	MOV	DPTR,#PWRUP
	JNB	PRMUTE,MUTE13
	MOV	DPTR,#PWR_PRES

MUTE13:
	LCALL	LCD_TEXT

;	MOV	DPTR,#0306H		; Start address in LCD memory
;	INC	0A2H			; Switch data pointers
;	MOV	DPTR,#GAINR
;	JB	GAINREL,GAINREL1
;	MOV	DPTR,#GAINA
;GAINREL1:
;	LCALL	LCD_TEXT

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK
	LCALL	LCD_TEXT


OPTIONS_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
OPTIONS_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

OPTIONS_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,OPTIONS_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_OPTIONS_1
	JB	LEFT,OPTIONS_1A

SELECT_OPTIONS_1:
	LJMP	MAINMENU

JUMP_OFF_OPTIONS_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	SJMP	OPTIONS_2

OPTIONS_2:
	SETB	DIS
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data	

OPTIONS_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,OPTIONS_WAIT2
	CLR	ENC
	JNB	PUS,JUMP_OFF_OPTIONS_2

SELECT_OPTIONS_2:
	CLR	DIS
	LJMP	DISPLAY_MENU	

JUMP_OFF_OPTIONS_2:
	CLR	DIS
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,OPTIONS_3
	LJMP	OPTIONS_1

OPTIONS_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data	

OPTIONS_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,OPTIONS_WAIT3
	CLR	ENC
	JNB	PUS,JUMP_OFF_OPTIONS_3

SELECT_OPTIONS_3:
	LJMP	INFO_MENU

JUMP_OFF_OPTIONS_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,OPTIONS_4
	LJMP	OPTIONS_2

OPTIONS_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	ALOCK,CURSOR_16
	MOV	DPTR,#CURSOR
CURSOR_16:
	LCALL	LCD_TEXT
OPTIONS_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

OPTIONS_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,OPTIONS_WAIT4
	CLR	ENC
	JNB	PUS,JUMP_OFF_OPTIONS_4

SELECT_OPTIONS_4:
	JB	ALOCK,OPTIONS_4A

	JB	PUMUTE,MUTE15
	SETB	PUMUTE

	SJMP	MUTE16
MUTE15:
	CLR	PUMUTE
	CPL	PRMUTE
MUTE16:

	MOV	DPTR,#02AAH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#M_OFF

	JB	PUMUTE,MUTE12		; Mute on power up or preset change
	JNB	PRMUTE,MUTE14
	MOV	DPTR,#PRCH
	SJMP	MUTE14
MUTE12:					; Mute on power up or preset change
	MOV	DPTR,#PWRUP
	JNB	PRMUTE,MUTE14
	MOV	DPTR,#PWR_PRES

MUTE14:
	LCALL	LCD_TEXT

	LCALL	WRITE_SETTINGS
	SJMP	OPTIONS_4A

JUMP_OFF_OPTIONS_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,OPTIONS_5
	LJMP	OPTIONS_3

;//////////////////////////////Gain relative/absolute setting

;OPTIONS_5:
;	MOV	DPTR,#0300H		; Start address in LCD memory
;	INC	0A2H			; Switch data pointers
;	MOV	DPTR,#CURSOR
;	LCALL	LCD_TEXT
;OPTIONS_5A:
;	LCALL	LCD_REFRESH		; Refresh LCD display data	
;
;OPTIONS_WAIT5:	
;	LCALL	ENCODER_CHECK
;	JNB	ENC,OPTIONS_WAIT5
;	CLR	ENC
;	JNB	PUS,JUMP_OFF_OPTIONS_5
;
;SELECT_OPTIONS_5:
;	CPL	GAINREL
;
;	MOV	DPTR,#0306H		; Start address in LCD memory
;	INC	0A2H			; Switch data pointers
;	MOV	DPTR,#GAINR
;	JB	GAINREL,GAINREL2
;	MOV	DPTR,#GAINA
;GAINREL2:
;	LCALL	LCD_TEXT
;
;	LCALL	WRITE_SETTINGS
;	SJMP	OPTIONS_5A


;JUMP_OFF_OPTIONS_5:
;	MOV	DPTR,#0300H		; Start address in LCD memory
;	INC	0A2H			; Switch data pointers
;	MOV	DPTR,#SPACE
;	LCALL	LCD_TEXT
;	JB	RIGHT,OPTIONS_6
;	LJMP	OPTIONS_4

;////////////////////////////////////////end gain setting

OPTIONS_5:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
OPTIONS_5A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

OPTIONS_WAIT5:	
	LCALL	ENCODER_CHECK
	JNB	ENC,OPTIONS_WAIT5
	CLR	ENC
	JB	LEFT,JUMP_OFF_OPTIONS_5
	JB	RIGHT,OPTIONS_5A

SELECT_OPTIONS_5:
	SJMP	LOCK_MENU

JUMP_OFF_OPTIONS_5:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JMP	OPTIONS_4


;* ------------------------------------------------------------------------
;*  LOCK MENU:
;* ------------------------------------------------------------------------
LOCK_MENU:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	JNB	PLOCK,NO_LOCK5
	MOV	DPTR,#03F9H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK_ICON
	LCALL	LCD_ICON
NO_LOCK5:

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MLOCK
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	JB	ALOCK,LOCK_OVER2
	JB	PLOCK,LOCK_OVER2
	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCKA
	LCALL	LCD_TEXT

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCKP
	LCALL	LCD_TEXT

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#NCODE
	LCALL	LCD_TEXT
	SJMP	LOCK_1
LOCK_OVER2:

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#UNLOCK
	LCALL	LCD_TEXT

LOCK_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
LOCK_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

LOCK_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LOCK_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_LOCK_1
	JB	LEFT,LOCK_1A

SELECT_LOCK_1:
	LJMP	OPTIONS_MENU

JUMP_OFF_LOCK_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

LOCK_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
LOCK_2A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

LOCK_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LOCK_WAIT2
	CLR	ENC
	JB	PUS,SELECT_LOCK_2
	JB	LEFT,JUMP_OFF_LOCK_2
	JB	PLOCK,LOCK_2A
	SJMP	JUMP_OFF_LOCK_2

SELECT_LOCK_2:
	JNB	PLOCK,GO_LOCK1
	LJMP	GO_UNLOCK
GO_LOCK1:
	LJMP	GO_LOCK_ALL

JUMP_OFF_LOCK_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,LOCK_3
	LJMP	LOCK_1


LOCK_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
LOCK_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

LOCK_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LOCK_WAIT3
	CLR	ENC
	JB	PUS,SELECT_LOCK_3

JUMP_OFF_LOCK_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,LOCK_4
	LJMP	LOCK_2

SELECT_LOCK_3:
	LJMP	GO_LOCK

LOCK_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
LOCK_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

LOCK_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LOCK_WAIT4
	CLR	ENC
	JB	LEFT,JUMP_OFF_LOCK_4
	JB	PUS,SELECT_LOCK_4
	SJMP	LOCK_4A

JUMP_OFF_LOCK_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LJMP	LOCK_3

SELECT_LOCK_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#OPIN
	LCALL	LCD_TEXT

	LCALL	GET_CODE

	MOV	A,FREQ
	CJNE	A,PIN12,PIN_WRONG4
	MOV	A,QF
	CJNE	A,PIN34,PIN_WRONG4
	SJMP	LOCK_OVER11

PIN_WRONG4:
	MOV	A,FREQ
	CJNE	A,#023H,PIN_WRONG5
	MOV	A,QF
	CJNE	A,#010H,PIN_WRONG5


LOCK_OVER11:
	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#NPIN
	LCALL	LCD_TEXT

	LCALL	GET_CODE

	MOV	PIN12,FREQ
	MOV	PIN34,QF

	LCALL	WRITE_SETTINGS
	LJMP	LOCK_MENU
PIN_WRONG5:
	LCALL	PIN_WRONG
	LJMP	LOCK_MENU


GO_UNLOCK:
	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PIN
	LCALL	LCD_TEXT

	LCALL	GET_CODE

	MOV	A,FREQ
	CJNE	A,PIN12,PIN_WRONG1
	MOV	A,QF
	CJNE	A,PIN34,PIN_WRONG1

	CLR	ALOCK
	CLR	PLOCK

	LCALL	WRITE_SETTINGS
	LJMP	LOCK_MENU

PIN_WRONG1:
	MOV	A,FREQ
	CJNE	A,#023H,PIN_WRONG2
	MOV	A,QF
	CJNE	A,#010H,PIN_WRONG2

	CLR	ALOCK
	CLR	PLOCK

	MOV	PIN12,#0
	MOV	PIN34,#0

	LCALL	WRITE_SETTINGS
	RET

PIN_WRONG2:
	LCALL	PIN_WRONG
	RET

GO_LOCK_ALL:
	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PIN
	LCALL	LCD_TEXT

	LCALL	GET_CODE

	MOV	A,FREQ
	CJNE	A,PIN12,PIN_WRONG6
	MOV	A,QF
	CJNE	A,PIN34,PIN_WRONG6

	SETB	PLOCK
	SETB	ALOCK
	LCALL	WRITE_SETTINGS
	JB	PLOCK,PIN_WRONG7
	LJMP	LOCK_2A
PIN_WRONG7:
	LJMP	LOCK_MENU
PIN_WRONG6:
	LCALL	PIN_WRONG
	JB	PLOCK,PIN_WRONG8
	LJMP	LOCK_2A
PIN_WRONG8:
	LJMP	LOCK_MENU

GO_LOCK:
	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PIN
	LCALL	LCD_TEXT

	LCALL	GET_CODE

	MOV	A,FREQ
	CJNE	A,PIN12,PIN_WRONG3
	MOV	A,QF
	CJNE	A,PIN34,PIN_WRONG3

	SETB	PLOCK
	LCALL	WRITE_SETTINGS
	LJMP	LOCK_MENU
PIN_WRONG3:
	LCALL	PIN_WRONG
	LJMP	LOCK_MENU


PIN_WRONG:
	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#WPIN
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

	MOV	R7,#10			; Wait for 1sec
PIN_ERROR_WAIT:
	LCALL	RESET_WDT
	MOV	R5,#0
	LCALL	LWAIT
	DJNZ	R7,PIN_ERROR_WAIT

	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#WPIN2
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

	RET


;* ------------------------------------------------------------------------
;*  PRESET NAME MENU:
;* ------------------------------------------------------------------------
PRESET_NAME_MENU:

	MOV	DPTR,#01B6H		; Start address in LCD memory	
	MOV	CCNT,#72
UNDERSCORE1:
	MOVX	A,@DPTR			; Move data from LCD ERAM
	ORL	A,#080H
	MOVX	@DPTR,A			; Move data to LCD ERAM
	INC	DPTR
	DJNZ	CCNT,UNDERSCORE1

	MOV	DPTR,#0236H		; Start address in LCD memory	
	MOV	CCNT,#54
UNDERSCORE2:
	MOVX	A,@DPTR			; Move data from LCD ERAM
	ORL	A,#080H
	MOVX	@DPTR,A			; Move data to LCD ERAM
	INC	DPTR
	DJNZ	CCNT,UNDERSCORE2

	MOV	OPCODE,#055H		; Opcode for page to buffer2
	MOV	OPCODE1,#008H		; Start at page512

	MOV	A,PRESET
	ANL	A,#0F8H
	RR	A
	MOV	OPCODE2,A

	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

EDIT_NAME:
	MOV	CCNT,#0			; Start with first character

EDIT_NAME_LOOP:
	MOV	OPCODE,#0D6H		; Opcode for buffer2 read

	MOV	OPCODE1,#008H		; Start at page512

	MOV	A,PRESET
	ANL	A,#0F8H
	MOV	OPCODE2,A

	MOV	A,PRESET
	CLR	C
	SUBB	A,OPCODE2
	MOV	B,A

	MOV	A,OPCODE2
	RR	A
	MOV	OPCODE2,A

	MOV	A,#66
	MUL	AB
	ADD	A,CCNT
	MOV	OPCODE3,A

	MOV	A,OPCODE2
	ADDC	A,#0
	ADD	A,B
	MOV	OPCODE2,A

	LCALL	FLASH_OPCODE		;
	LCALL	SPI_RX			; Get byte from FLASH

	MOV	DNCHAR,SPIRDAT		; Received character
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	INC	CCNT

NAME_BACK:
	MOV	B,CCNT			; Get character count

	MOV	DPTR,#01B0H		; Start address in LCD memory
	MOV	A,CCNT
	CLR	C
	SUBB	A,#13
	JC	FIRST_LINE1
	MOV	DPTR,#01E8H		; Start address in LCD memory
FIRST_LINE1:

INC_DPTR1:
	INC	DPTR
	INC	DPTR
	INC	DPTR
	INC	DPTR
	INC	DPTR
	INC	DPTR
	DJNZ	B,INC_DPTR1

	MOV	A,DNCHAR
	SETB	INV
	LCALL	LCD_CHAR
	LCALL	LCD_REFRESH

WAIT_NAME1:
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT_NAME1
	CLR	ENC
	JB	PUS,CHAR_CONFIRM
	JB	RIGHT,CHAR_UP8
	LJMP	CHAR_DOWN

CHAR_UP8:
	LJMP	CHAR_UP

CHAR_CONFIRM:
	MOV	B,CCNT			; Get character count

	MOV	DPTR,#01B0H		; Start address in LCD memory
	MOV	A,CCNT
	CLR	C
	SUBB	A,#13
	JC	FIRST_LINE2
	MOV	DPTR,#01E8H		; Start address in LCD memory
FIRST_LINE2:

INC_DPTR2:
	INC	DPTR
	INC	DPTR
	INC	DPTR
	INC	DPTR
	INC	DPTR
	INC	DPTR
	DJNZ	B,INC_DPTR2

	MOV	A,DNCHAR
	CLR	INV
	LCALL	LCD_CHAR

	MOV	R0,#6
UNDERSCORE3:	
	DEC	DPL
	MOVX	A,@DPTR			; Move data from LCD ERAM
	ORL	A,#080H
	MOVX	@DPTR,A			; Move data to LCD ERAM
	DJNZ	R0,UNDERSCORE3

	LCALL	LCD_REFRESH

	DEC	CCNT

	MOV	OPCODE,#087H		; Opcode for buffer2 write

	MOV	A,PRESET
	ANL	A,#0F8H
	MOV	OPCODE2,A

	MOV	A,PRESET
	CLR	C
	SUBB	A,OPCODE2
	MOV	B,A

	MOV	A,#66
	MUL	AB
	MOV	OPCODE2,B
	ADD	A,CCNT

	MOV	OPCODE3,A

	MOV	A,OPCODE2
	ADDC	A,#0
	MOV	OPCODE2,A

	INC	CCNT

	LCALL	FLASH_OPCODE		;

	MOV	A,DNCHAR		; Write byte to FLASH
	LCALL	SPI_TX			; 

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,CCNT
	CJNE	A,#21,CONT_NAME_LOOP	; Enter 21 characters
	SJMP	END_NAME_LOOP

CONT_NAME_LOOP:
	LJMP	EDIT_NAME_LOOP

END_NAME_LOOP:
	MOV	OPCODE,#086H		; Write buffer2 to page12

	MOV	OPCODE1,#008H		; Start at page512

	MOV	A,PRESET
	ANL	A,#0F8H
	MOV	OPCODE2,A

	MOV	A,PRESET
	CLR	C
	SUBB	A,OPCODE2
	MOV	B,A

	MOV	A,OPCODE2
	RR	A
	MOV	OPCODE2,A

	MOV	A,#66
	MUL	AB
	MOV	OPCODE3,A

	MOV	A,OPCODE2
	ADD	A,B
	MOV	OPCODE2,A

	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LJMP	PRESET_MENU

CHAR_DOWN:
	LJMP	CHAR_DOWN0

CHAR_UP:
	INC	DNCHAR
	MOV	A,DNCHAR

	CJNE	A,#33,CHAR_UP1
	MOV	DNCHAR,#48
CHAR_UP1:

	CJNE	A,#58,CHAR_UP2
	MOV	DNCHAR,#65
CHAR_UP2:

	CJNE	A,#91,CHAR_UP3
	MOV	DNCHAR,#97
CHAR_UP3:

	CJNE	A,#123,CHAR_UP4
	MOV	DNCHAR,#33
CHAR_UP4:

	CJNE	A,#34,CHAR_UP5
	MOV	DNCHAR,#38
CHAR_UP5:

	CJNE	A,#48,CHAR_UP6
	MOV	DNCHAR,#58
CHAR_UP6:

	CJNE	A,#64,CHAR_UP7
	MOV	DNCHAR,#32
CHAR_UP7:

	LJMP	NAME_BACK


CHAR_DOWN0:
	DEC	DNCHAR
	MOV	A,DNCHAR

	CJNE	A,#57,CHAR_DOWN1
	MOV	DNCHAR,#47
CHAR_DOWN1:

	CJNE	A,#37,CHAR_DOWN2
	MOV	DNCHAR,#33
CHAR_DOWN2:

	CJNE	A,#32,CHAR_DOWN3
	MOV	DNCHAR,#122
CHAR_DOWN3:

	CJNE	A,#96,CHAR_DOWN4
	MOV	DNCHAR,#90
CHAR_DOWN4:

	CJNE	A,#64,CHAR_DOWN5
	MOV	DNCHAR,#57
CHAR_DOWN5:

	CJNE	A,#47,CHAR_DOWN6
	MOV	DNCHAR,#32
CHAR_DOWN6:

	CJNE	A,#31,CHAR_DOWN7
	MOV	DNCHAR,#63
CHAR_DOWN7:

	LJMP	NAME_BACK


;* ------------------------------------------------------------------------
;*  INFO MENU:
;* ------------------------------------------------------------------------
INFO_MENU:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#INFOM
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOG
	LCALL	LCD_TEXT

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SETC
	LCALL	LCD_TEXT

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#FIRM
	LCALL	LCD_TEXT

	MOV	A,#FIRMWARE
	SWAP	A
	ANL	A,#0FH
	MOV	DPTR,#02C2H		; Start address in LCD memory
	LCALL	LCD_NUMBER

	MOV	A,#FIRMWARE
	ANL	A,#0FH
	MOV	DPTR,#02CEH		; Start address in LCD memory
	LCALL	LCD_NUMBER

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PRESVER
	LCALL	LCD_TEXT

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#008H		; Start at PAGE525
	MOV	OPCODE2,#034H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get data from FLASH
	MOV	A,SPIRDAT		; Move received data to A
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	INC	0A2H			; Switch data pointers
	DEC	DPL

	MOV	B,#0

PVER_LOOP1:
	CLR	C
	SUBB	A,#100
	INC	B
	JNC	PVER_LOOP1

	DEC	B
	ADD	A,#100
	MOV	SPIRDAT,A

	MOV	A,B
	LCALL	LCD_NUMBER

	MOV	A,SPIRDAT
	MOV	B,#0

PVER_LOOP2:
	CLR	C
	SUBB	A,#10
	INC	B
	JNC	PVER_LOOP2

	DEC	B
	ADD	A,#10
	MOV	SPIRDAT,A

	MOV	A,B
	LCALL	LCD_NUMBER

	MOV	A,SPIRDAT
	LCALL	LCD_NUMBER

	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SN
	LCALL	LCD_TEXT

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#00H		; Start at PAGE18
	MOV	OPCODE2,#048H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	DPTR,#03BCH		; Start address in LCD memory
	MOV	R0,#8
SN_LOOP:
	LCALL	SPI_RX			; Get data from FLASH
	MOV	A,SPIRDAT		; Move received data to A
	LCALL	LCD_CHAR
	DJNZ	R0,SN_LOOP

	LCALL	SPI_RX			; Get data from FLASH
	MOV	A,SPIRDAT		; Move received data to A
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get data from FLASH
	MOV	A,SPIRDAT		; Move received data to A
	SWAP	A
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	MOV	A,SPIRDAT		; Move received data to A
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LCALL	DISP_TIME

INFO_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
INFO_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data

INFO_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DISP_TIME1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_INFO_1	
	JB	LEFT,INFO_1A
	JB	PUS,SELECT_INFO_1

DISP_TIME1:
	JNB	LOG_REF,INFO_WAIT1
	LCALL	DISP_TIME
	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	CLR	LOG_REF
	SJMP	INFO_WAIT1

SELECT_INFO_1:
	CLR	INF
	LJMP	OPTIONS_MENU

JUMP_OFF_INFO_1:
	CLR	INF
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

INFO_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data	

INFO_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DISP_TIME2
	CLR	ENC
	JNB	PUS,JUMP_OFF_INFO_2
	SJMP	SELECT_INFO_2
		
DISP_TIME2:
	JNB	LOG_REF,INFO_WAIT2
	LCALL	DISP_TIME
	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	CLR	LOG_REF
	SJMP	INFO_WAIT2

SELECT_INFO_2:
	LJMP	LOG_MENU

JUMP_OFF_INFO_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,INFO_3
	SJMP	INFO_1

INFO_3:
	SETB	INF
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	LCALL	LCD_TEXT

	JB	ALOCK,CURSOR_17
	MOV	DPTR,#0266H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ST
	LCALL	LCD_TEXT
CURSOR_17:

INFO_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

INFO_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DISP_TIME3
	CLR	ENC
	JB	LEFT,JUMP_OFF_INFO_3
	JB	RIGHT,INFO_3A
	SJMP	SELECT_INFO_3

DISP_TIME3:
	JNB	LOG_REF,INFO_WAIT3
	LCALL	DISP_TIME
	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	CLR	LOG_REF
	SJMP	INFO_WAIT3

SELECT_INFO_3:
	JB	ALOCK,INFO_3A
	LCALL	SET_CLOCK
	LCALL	CHECK_DST
	LJMP	INFO_MENU

JUMP_OFF_INFO_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	MOV	DPTR,#0266H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ST0
	LCALL	LCD_TEXT

	LJMP	INFO_2

; Display clock:
DISP_TIME:
;	LCALL	CHECK_SUMMERTIME
	JB	DST_EUR,DST_OVER4
	JB	DST_USA,DST_OVER4
	SJMP	DST_OVER3

DST_OVER4:
	MOV	DPTR,#0260H		; Start address in LCD memory
	MOV	A,#'S'
	JB	STIME,STIME4
	MOV	A,#'W'
STIME4:
	LCALL	LCD_CHAR
DST_OVER3:

	LCALL	DISPLAY_CLOCK
	RET

;* ------------------------------------------------------------------------
;*  LOG MENU:
;* ------------------------------------------------------------------------
LOG_MENU:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOGM
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT
		
	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#STARTS
	LCALL	LCD_TEXT

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ONTIME
	LCALL	LCD_TEXT

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SIGNAL
	LCALL	LCD_TEXT
	
	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H
	MOV	DPTR,#LLEN
	JB	LENABLE, LOG_MENU_CONT
	MOV	DPTR,#LLDI

LOG_MENU_CONT:
	LCALL LCD_TEXT
	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LLOG
	LCALL	LCD_TEXT

; Display starts:
	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#004H		; Start at PAGE256
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get page address high byte
	MOV	PGADDH,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get page address low byte
	MOV	PGADDL,SPIRDAT		; Move received data

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,PGADDH		; Start at PAGE??
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#002H		; 3rd byte
	LCALL	FLASH_OPCODE		;

	MOV	DPTR,#01BCH		; Start address in LCD memory

	MOV	COUNT1,#6
SKIP_ZERO:
	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	DJNZ	COUNT1,CONT_SKIP
	SJMP	OVER_ZEROS
CONT_SKIP:
	JZ	SKIP_ZERO

OVER_ZEROS:
	INC	COUNT1

STARTS_LOOP:
	LCALL	LCD_NUMBER
	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	DJNZ	COUNT1,STARTS_LOOP

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LCALL	ON_TIME

	LCALL	LCD_REFRESH		; Refresh LCD display data

LOG_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	CLR	LOG_REF

LOG_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,ON_TIME1
	CLR	ENC
	LCALL	LCD_REFRESH		; Refresh LCD display data
	JB	RIGHT,JUMP_OFF_LOG1	
	JB	LEFT,LOG_WAIT1
	JB	PUS,SELECT_LOG_1

ON_TIME1:
	JNB	LOG_REF,LOG_WAIT1
	LCALL	ON_TIME
	SJMP	LOG_1

SELECT_LOG_1:
	LJMP	INFO_MENU

JUMP_OFF_LOG1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	
LOG_2:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	CLR	LOG_REF

LOG_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,ON_TIME2
	CLR	ENC
	LCALL	LCD_REFRESH		; Refresh LCD display data
	JB	RIGHT,JUMP_OFF_LOG2	
	JB	LEFT,JUMP_OFF_LOG2
	JB	PUS,SELECT_LOG_2

ON_TIME2:
	JNB	LOG_REF,LOG_WAIT2
	LCALL	ON_TIME
	SJMP	LOG_2

SELECT_LOG_2:
	CPL	LENABLE			;Enable / disable limitlog

	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H
	MOV	DPTR,#BLANKLINE
	LCALL	LCD_TEXT

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H
	MOV	DPTR,#LLEN
	JB	LENABLE, SELECT_LOG_2_CONT
	MOV	DPTR,#LLDI
	
SELECT_LOG_2_CONT:	
	LCALL	LCD_TEXT
	SJMP	LOG_2

JUMP_OFF_LOG2:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	JB	RIGHT, LOG_3
	JMP	LOG_1

LOG_3:
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	CLR	LOG_REF

LOG_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,ON_TIME3
	CLR	ENC
	LCALL	LCD_REFRESH		; Refresh LCD display data
	JB	RIGHT,LOG_3	
	JB	LEFT,JUMP_OFF_LOG3
	JB	PUS,SELECT_LOG_3

ON_TIME3:
	JNB	LOG_REF,LOG_WAIT3
	LCALL	ON_TIME
	SJMP	LOG_3

SELECT_LOG_3:
	LJMP	LIMITLOG_MENU

JUMP_OFF_LOG3:
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	JMP	LOG_2

LCD_TIME:
	MOV	COUNT1,#6
SKIP_ZERO1:
	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	DJNZ	COUNT1,CONT_SKIP1
	SJMP	OVER_ZEROS1
CONT_SKIP1:
	JZ	SKIP_ZERO1

OVER_ZEROS1:
	LCALL	LCD_NUMBER
	MOV	A,COUNT1
	JZ	OVER_HOURS

HOURS_LOOP:

	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	LCALL	LCD_NUMBER
	DJNZ	COUNT1,HOURS_LOOP

OVER_HOURS:

	MOV	A,#'h'
	LCALL	LCD_CHAR

	MOV	COUNT1,#2
DISPLAY_MIN:
	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	LCALL	LCD_NUMBER
	DJNZ	COUNT1,DISPLAY_MIN

	MOV	A,#'m'
	LCALL	LCD_CHAR

	RET
ON_TIME:
	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#004H		; Start at PAGE256
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get ID page address high byte
	MOV	PGADDH,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get ID page address low byte
	MOV	PGADDL,SPIRDAT		; Move received data

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,PGADDH		; Start at PAGE??
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#008H		; 9th byte
	LCALL	FLASH_OPCODE		;

	MOV	DPTR,#023CH		; Start address in LCD memory
	LCALL	LCD_TIME		; Display on time

	MOV	DPTR,#02BCH		; Start address in LCD memory
	LCALL	LCD_TIME		; Display signal presend time

ON_TIME_CONT:
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	RET


;* ------------------------------------------------------------------------
;*  LIMITLOG MENU:
;* ------------------------------------------------------------------------
LIMITLOG_MENU:
	LCALL	COPY_LOG2		; Copy log page to buffer1

	MOV	CCNT,PGADDH		; Save page address
	MOV	DNCHAR,PGADDL		;

LIMITLOG_MENU_LOOP:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LLOGM
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT
	
	MOV	DPTR,#0186H		; DOES NOT REALLY BELONG HERE!!!
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SELP
	LCALL	LCD_TEXT

;	MOV	DPTR,#0206H		; Start address in LCD memory
;	INC	0A2H			; Switch data pointers
;	MOV	DPTR,#SELP
;	LCALL	LCD_TEXT

	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOG_ICON1
	LCALL	LCD_ICON
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOG_ICON2
	LCALL	LCD_ICON
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOG_ICON3
	LCALL	LCD_ICON



	LCALL	DISPLAY_PAGE_INFO
	LCALL	DISPLAY_PAGE_GRAPH

LLOG_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
LLOG_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

LLOG_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LLOG_WAIT1_2
	CLR	ENC
	JB	RIGHT,JUMP_OFF_LLOG_1
	JB	LEFT,LLOG_1A

SELECT_LLOG_1:
	LJMP	LOG_MENU	

LLOG_WAIT1_2:
	JNB	LOG_REF,LLOG_WAIT1	
	LCALL	DISPLAY_PAGE_GRAPH
	CLR	LOG_REF
	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	SJMP	LLOG_WAIT1

JUMP_OFF_LLOG_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

LLOG_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data	

LLOG_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LLOG_WAIT2_2
	CLR	ENC
	JB	PUS,SELECT_LLOG_2
	LCALL	LCD_REFRESH		; Refresh LCD display data
	LJMP	JUMP_OFF_LLOG_2

LLOG_WAIT2_2:
	JNB	LOG_REF,LLOG_WAIT2	
	LCALL	DISPLAY_PAGE_GRAPH
	CLR	LOG_REF
	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	SJMP	LLOG_WAIT2

SELECT_LLOG_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SELP
	SETB	INV
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH		; Refresh LCD display data

LLOG_WAIT2_3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LLOG_WAIT2_4
	CLR	ENC
	JB	LEFT,PR_PAGE
	JB	RIGHT,NXT_PAGE

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SELP
	LCALL	LCD_TEXT

	SJMP	LLOG_2

LLOG_WAIT2_4:
	JNB	LOG_REF,LLOG_WAIT2_3	
	LCALL	DISPLAY_PAGE_GRAPH
	CLR	LOG_REF
	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	SJMP	LLOG_WAIT2_3


PR_PAGE:
	MOV	A,DNCHAR		; Decrease page address by 4 (1 page)
	CLR	C			;
	SUBB	A,#004H			;
	MOV	DNCHAR,A		;
	MOV	A,CCNT			;
	SUBB	A,#000H			;
	MOV	CCNT,A			;

	CJNE	A,#010H,NO_PAGE_LIMIT6	; Count pages until 1025 (4100/4), then start again at page 8191
	MOV	A,DNCHAR
	CJNE	A,#00H,NO_PAGE_LIMIT6
	MOV	CCNT,#07FH		; Start all over at page 8191
	MOV	DNCHAR,#0FCH		;
NO_PAGE_LIMIT6:

	LCALL	DISPLAY_PAGE_INFO
	LCALL	DISPLAY_PAGE_GRAPH
	LCALL	LCD_REFRESH
	SJMP	LLOG_WAIT2_3

NXT_PAGE:
	MOV	A,DNCHAR		; Increase page address by 4 (1 page)
	ADD	A,#004H			;
	MOV	DNCHAR,A		;
	MOV	A,CCNT			;
	ADDC	A,#000H			;
	MOV	CCNT,A			;

	JNB	ACC.7,NO_PAGE_LIMIT5	; Count pages until 8192 (32768/4), then start again at page 1025

	MOV	CCNT,#010H		; Start all over at page 1025
	MOV	DNCHAR,#004H		;
NO_PAGE_LIMIT5:

	LCALL	DISPLAY_PAGE_INFO
	LCALL	DISPLAY_PAGE_GRAPH
	LCALL	LCD_REFRESH
	SJMP	LLOG_WAIT2_3

JUMP_OFF_LLOG_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,LLOG_3
	LJMP	LLOG_1


LLOG_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
LLOG_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

LLOG_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LLOG_WAIT3_2
	CLR	ENC
	JB	LEFT,JUMP_OFF_LLOG_3
	JB	PUS,SELECT_LLOG_3
	SJMP	LLOG_3A

LLOG_WAIT3_2:
	JNB	LOG_REF,LLOG_WAIT3	
	LCALL	DISPLAY_PAGE_GRAPH
	CLR	LOG_REF
	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change
	SJMP	LLOG_WAIT3

JUMP_OFF_LLOG_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LJMP	LLOG_2

SELECT_LLOG_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PAGE_INFO
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CH1M
	LCALL	LCD_TEXT

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CH2M
	LCALL	LCD_TEXT

	MOV	SEC_IN_PAGE,#0

ARROW_LOOP:
	MOV	A,SEC_IN_PAGE

	ADD	A,#088H
	MOV	DPL,A
	MOV	DPH,#03H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ARROW_ICON
	LCALL	LCD_ARROW_ICON

	MOV	PGADDH,CCNT
	MOV	PGADDL,DNCHAR

	LCALL	COPY_LOG2A		; Copy log page to buffer1

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; Start at byte0
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get count
	MOV	GRAPH2,SPIRDAT		; Move received data to GRAPH2

	LCALL	SPI_RX			; Get firmware code of this page
	MOV	A,SPIRDAT		; Move received data to A

	MOV	DPTR,#010CH		; Start address in LCD memory

	MOV	GRAPH3,#0

PVER_LOOP5:
	CLR	C
	SUBB	A,#100
	INC	GRAPH3
	JNC	PVER_LOOP5

	DEC	GRAPH3
	ADD	A,#100
	MOV	SPIRDAT,A

	MOV	A,GRAPH3
	LCALL	LCD_NUMBER

	MOV	A,SPIRDAT
	MOV	GRAPH3,#0

PVER_LOOP6:
	CLR	C
	SUBB	A,#10
	INC	GRAPH3
	JNC	PVER_LOOP6

	DEC	GRAPH3
	ADD	A,#10
	MOV	SPIRDAT,A

	MOV	A,GRAPH3
	LCALL	LCD_NUMBER

	MOV	A,SPIRDAT
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get year code of this page
	MOV	GRAPH3,SPIRDAT		; Move received data to GRAPH3

	MOV	DPTR,#0148H		; Start address in LCD memory
	MOV	A,GRAPH3
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER
	MOV	A,GRAPH3
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	DEC	GRAPH2

	MOV	A,SEC_IN_PAGE
	MOV	B,#8
	MUL	AB

	ADD	A,#03H
	MOV	OPCODE3,A

	MOV	A,B
	ADDC	A,#0
	MOV	OPCODE2,A

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; Start at byte..
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get month code of this page
	MOV	GRAPH3,SPIRDAT		; Move received data to GRAPH3

	MOV	DPTR,#0124H		; Start address in LCD memory (USA)
	JB	DT_FRM,CLK_OVER8
	MOV	DPTR,#0136H		; Start address in LCD memory (Eur)
CLK_OVER8:
	MOV	A,GRAPH3
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER
	MOV	A,GRAPH3
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get date code of this page
	MOV	GRAPH3,SPIRDAT		; Move received data to GRAPH3

	MOV	DPTR,#0136H		; Start address in LCD memory (USA)
	JB	DT_FRM,CLK_OVER9
	MOV	DPTR,#0124H		; Start address in LCD memory (Eur)
CLK_OVER9:
	MOV	A,GRAPH3
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	MOV	A,GRAPH3
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get hour code of this page
	MOV	GRAPH3,SPIRDAT		; Move received data to GRAPH3

	MOV	DPTR,#015AH		; Start address in LCD memory
	MOV	A,GRAPH3
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	MOV	A,GRAPH3
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get minutes code of this page
	MOV	GRAPH3,SPIRDAT		; Move received data to GRAPH3

	MOV	DPTR,#016CH		; Start address in LCD memory
	MOV	A,GRAPH3
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	MOV	A,GRAPH3
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get model1
	MOV	A,SPIRDAT		; Move received data to A
	MOV	GRAPH3,#0
	MOV	GRAPH4,#0
	JZ	CH1_LINEAR
MODEL_LOOP1:
	MOV	A,GRAPH4
	ADD	A,#1
	DA	A
	MOV	GRAPH4,A

	MOV	A,GRAPH3
	ADDC	A,#0
	MOV	GRAPH3,A

	DJNZ	SPIRDAT,MODEL_LOOP1
CH1_LINEAR:

	MOV	DPTR,#01BCH		; Start address in LCD memory
	MOV	A,GRAPH3
	LCALL	LCD_NUMBER

	MOV	A,GRAPH4
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	MOV	A,GRAPH4
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get model2
	MOV	A,SPIRDAT		; Move received data to A
	MOV	GRAPH3,#0
	MOV	GRAPH4,#0
	JZ	CH2_LINEAR
MODEL_LOOP2:
	MOV	A,GRAPH4
	ADD	A,#1
	DA	A
	MOV	GRAPH4,A

	MOV	A,GRAPH3
	ADDC	A,#0
	MOV	GRAPH3,A

	DJNZ	SPIRDAT,MODEL_LOOP2
CH2_LINEAR:

	MOV	DPTR,#023CH		; Start address in LCD memory
	MOV	A,GRAPH3
	LCALL	LCD_NUMBER

	MOV	A,GRAPH4
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	MOV	A,GRAPH4
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get limit1
	MOV	GRAPH4,SPIRDAT		; Move received data to GRAPH4
	LCALL	SPI_RX			; Get limit2
	MOV	GRAPH3,SPIRDAT		; Move received data to GRAPH3

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	DPTR,#LOG_LOOKUP
	MOV	GRAPH1,#00H		; Reset dB counter

LOG_LOOKUP_LOOP2:
	CLR	A
	MOVC	A,@A+DPTR		; Log value in A
	INC	DPTR	
	CLR	C
	SUBB	A,GRAPH4
	JC	STOP_LOG_LOOKUP_LOOP2
	JZ	STOP_LOG_LOOKUP_LOOP2

	MOV	A,GRAPH1
	ADD	A,#01H
	DA	A
	MOV	GRAPH1,A

	SJMP	LOG_LOOKUP_LOOP2
STOP_LOG_LOOKUP_LOOP2:

	MOV	A,GRAPH1
	MOV	DPTR,#01D4H		; Start address in LCD memory
	MOV	B,#'-'
	CJNE	A,#020H,LIM_UNDER20DB1
	MOV	B,#'>'
LIM_UNDER20DB1:
	MOV	A,B
	LCALL	LCD_CHAR

	MOV	DPTR,#01DAH		; Start address in LCD memory
	MOV	A,GRAPH1
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	MOV	DPTR,#01E0H		; Start address in LCD memory
	MOV	A,GRAPH1
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	MOV	DPTR,#LOG_LOOKUP
	MOV	GRAPH1,#0

LOG_LOOKUP_LOOP3:
	CLR	A
	MOVC	A,@A+DPTR		; Log value in A
	INC	DPTR	
	CLR	C
	SUBB	A,GRAPH3
	JC	STOP_LOG_LOOKUP_LOOP3
	JZ	STOP_LOG_LOOKUP_LOOP3

	MOV	A,GRAPH1
	ADD	A,#01H
	DA	A
	MOV	GRAPH1,A

	SJMP	LOG_LOOKUP_LOOP3
STOP_LOG_LOOKUP_LOOP3:

	MOV	A,GRAPH1
	MOV	DPTR,#0254H		; Start address in LCD memory
	MOV	B,#'-'
	CJNE	A,#020H,LIM_UNDER20DB2
	MOV	B,#'>'
LIM_UNDER20DB2:
	MOV	A,B
	LCALL	LCD_CHAR

	MOV	DPTR,#025AH		; Start address in LCD memory
	MOV	A,GRAPH1
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	MOV	DPTR,#0260H		; Start address in LCD memory
	MOV	A,GRAPH1
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	LCD_REFRESH_NO_BACK	; Refresh LCD display data with no backlight change

LLOG_WAIT3_3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LLOG_WAIT3_4
	CLR	ENC
	LCALL	LCD_REFRESH		; Refresh LCD display data
	JB	LEFT,ARROW_LEFT
	JB	RIGHT,ARROW_RIGHT

	LJMP	LIMITLOG_MENU_LOOP

LLOG_WAIT3_4:
	JNB	LOG_REF,LLOG_WAIT3_3	
	LCALL	DISPLAY_PAGE_GRAPH
	CLR	LOG_REF
	LJMP	ARROW_LOOP

ARROW_LEFT:
	MOV	A,SEC_IN_PAGE
	JZ	ARROW_LEFT1
	DEC	SEC_IN_PAGE
	LJMP	ARROW_LOOP
ARROW_LEFT1:
	ADD	A,#088H
	MOV	DPL,A
	MOV	DPH,#03H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ARROW_ICON_BLANK
	LCALL	LCD_ARROW_ICON

	MOV	SEC_IN_PAGE,GRAPH2
	LJMP	ARROW_LOOP

ARROW_RIGHT:
	MOV	A,SEC_IN_PAGE
	CJNE	A,GRAPH2,ARROW_RIGHT1

	ADD	A,#088H
	MOV	DPL,A
	MOV	DPH,#03H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ARROW_ICON_BLANK
	LCALL	LCD_ARROW_ICON

	MOV	SEC_IN_PAGE,#0
	LJMP	ARROW_LOOP
ARROW_RIGHT1:
	INC	SEC_IN_PAGE
	LJMP	ARROW_LOOP


DISPLAY_PAGE_INFO:
	MOV	PGADDH,CCNT
	MOV	PGADDL,DNCHAR
	LCALL	COPY_LOG2A		; Copy log page to buffer1

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; Start at byte0
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get counter
	MOV	COUNT1,SPIRDAT		; Move received data to COUNT1

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers

	MOV	A,COUNT1
	MOV	B,COUNT1		; Save COUNT1
	JNZ	NO_EMPTY_PAGE1
	MOV	DPTR,#E_PAGE
	LCALL	LCD_TEXT
	LJMP	PAGE_INFO_END

NO_EMPTY_PAGE1:
	MOV	DPTR,#PAGE_INFO
	LCALL	LCD_TEXT

	MOV	COUNT1,B		; restore COUNT1

	LCALL	SPI_RX			; Get preset version code of this page
	MOV	A,SPIRDAT		; Move received data to A

	MOV	DPTR,#020CH		; Start address in LCD memory

	MOV	COUNT2,#0

PVER_LOOP3:
	CLR	C
	SUBB	A,#100
	INC	COUNT2
	JNC	PVER_LOOP3

	DEC	COUNT2
	ADD	A,#100
	MOV	SPIRDAT,A

	MOV	A,COUNT2
	LCALL	LCD_NUMBER

	MOV	A,SPIRDAT
	MOV	COUNT2,#0

PVER_LOOP4:
	CLR	C
	SUBB	A,#10
	INC	COUNT2
	JNC	PVER_LOOP4

	DEC	COUNT2
	ADD	A,#10
	MOV	SPIRDAT,A

	MOV	A,COUNT2
	LCALL	LCD_NUMBER

	MOV	A,SPIRDAT
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get year code of this page
	MOV	COUNT2,SPIRDAT		; Move received data to COUNT2

	MOV	DPTR,#0248H		; Start address in LCD memory
	MOV	A,COUNT2
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER
	MOV	A,COUNT2
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get month code of this page
	MOV	COUNT2,SPIRDAT		; Move received data to COUNT2

	MOV	DPTR,#0224H		; Start address in LCD memory (USA)
	JB	DT_FRM,CLK_OVER6
	MOV	DPTR,#0236H		; Start address in LCD memory (Eur)
CLK_OVER6:
	MOV	A,COUNT2
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER
	MOV	A,COUNT2
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get date code of this page
	MOV	COUNT2,SPIRDAT		; Move received data to COUNT2

	MOV	DPTR,#0236H		; Start address in LCD memory (USA)
	JB	DT_FRM,CLK_OVER7
	MOV	DPTR,#0224H		; Start address in LCD memory (Eur)
CLK_OVER7:
	MOV	A,COUNT2
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER
	MOV	A,COUNT2
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get hour code of this page
	MOV	COUNT2,SPIRDAT		; Move received data to COUNT2

	MOV	DPTR,#025AH		; Start address in LCD memory
	MOV	A,COUNT2
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER
	MOV	A,COUNT2
	ANL	A,#00FH
	LCALL	LCD_NUMBER

	LCALL	SPI_RX			; Get minutes code of this page
	MOV	COUNT2,SPIRDAT		; Move received data to COUNT2

	MOV	DPTR,#026CH		; Start address in LCD memory
	MOV	A,COUNT2
	SWAP	A
	ANL	A,#00FH
	LCALL	LCD_NUMBER
	MOV	A,COUNT2
	ANL	A,#00FH
	LCALL	LCD_NUMBER

PAGE_INFO_END:
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	RET


DISPLAY_PAGE_GRAPH:
	LCALL	LCD_LOGGRAPH_CLEAR

	MOV	PGADDH,CCNT
	MOV	PGADDL,DNCHAR
	LCALL	COPY_LOG2A		; Copy log page to buffer1

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; Start at byte0
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get counter
	MOV	COUNT1,SPIRDAT		; Move received data to COUNT1

	MOV	A,COUNT1
	MOV	B,COUNT1		; Save COUNT1
	JNZ	NO_EMPTY_PAGE2
	LJMP	PAGE_END
NO_EMPTY_PAGE2:

	MOV	COUNT1,B		; restore COUNT1

	LCALL	SPI_RX			; Discard firmware code of this page
	LCALL	SPI_RX			; Discard year code of this page
	LCALL	SPI_RX			; Discard month code of this page
	LCALL	SPI_RX			; Discard date code of this page
	LCALL	SPI_RX			; Discard hour code of this page
	LCALL	SPI_RX			; Discard minutes code of this page

	MOV	DPTR,#028BH		; Start address in LCD ERAM
	PUSH	DPL
	PUSH	DPH

LOG_GRAPH_LOOP:
	LCALL	SPI_RX			; Discard model info
	LCALL	SPI_RX			;

	LCALL	SPI_RX			; Get ch1 limit data
	MOV	COUNT2,SPIRDAT		; Move received data to COUNT2

	LCALL	SPI_RX			; Get ch2 limit data
	MOV	A,SPIRDAT		; Move received data to A

	CLR	C			; Display largest limiting value (smallest number)
	SUBB	A,COUNT2		;
	JNC	NO_SWAP			;
	MOV	COUNT2,SPIRDAT		;
NO_SWAP:

	MOV	GRAPH3,#0
	MOV	GRAPH2,#0
	MOV	GRAPH1,#004H
	MOV	DPTR,#LOG_LOOKUP

LOG_LOOKUP_LOOP:
	CLR	A
	MOVC	A,@A+DPTR		; Log value in A
	INC	DPTR	
	CLR	C
	SUBB	A,COUNT2
	JC	STOP_LOG_LOOKUP_LOOP
	JZ	STOP_LOG_LOOKUP_LOOP

	MOV	A,GRAPH1
	CLR	C
	RRC	A
	ORL	A,#04H
	MOV	GRAPH1,A

	MOV	A,GRAPH2
	RRC	A
	MOV	GRAPH2,A

	MOV	A,GRAPH3
	RRC	A
	MOV	GRAPH3,A

	JB	ACC.3,STOP_LOG_LOOKUP_LOOP	; Stop at 15dB
	SJMP	LOG_LOOKUP_LOOP

STOP_LOG_LOOKUP_LOOP:
	POP	DPH
	POP	DPL
	PUSH	DPL
	PUSH	DPH

	MOV	R7,#03H				; Graph is 3 lines on LCD
	MOV	R0,#GRAPH3

LOG_DISPLAY_GRAPH:
	MOV	A,@R0
	MOVX	@DPTR,A				; Move data to LCD ERAM

	INC	R0				; Next graph byte

	MOV	A,DPL				; Move DPTR to next line
	ADD	A,#080H				;
	MOV	DPL,A				;
	MOV	A,DPH				;
	ADDC	A,#00H				;
	MOV	DPH,A				;

	DJNZ	R7,LOG_DISPLAY_GRAPH

	POP	DPH
	POP	DPL
	INC	DPTR				;
	PUSH	DPL
	PUSH	DPH

	LCALL	SPI_RX			; Discard month
	LCALL	SPI_RX			; Discard date
	LCALL	SPI_RX			; Discard hour
	LCALL	SPI_RX			; Discard minute

	DJNZ	COUNT1,LOG_GRAPH_LOOP1
	SJMP	PAGE_END1
LOG_GRAPH_LOOP1:
	LJMP	LOG_GRAPH_LOOP

PAGE_END1:
	POP	DPH
	POP	DPL

PAGE_END:
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY


	RET

;* ------------------------------------------------------------------------
;*  DISPLAY MENU:
;* ------------------------------------------------------------------------
DISPLAY_MENU:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DISPL
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CONTRAST
	LCALL	LCD_TEXT

	MOV	A,CONTR
	MOV	DPTR,#01C2H		; Start address in LCD memory
	LCALL	LCD_NUMBER

	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACKL
	LCALL	LCD_TEXT

	MOV	DPTR,#0242H		; Start address in LCD memory
	MOV	A,LIGHT
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BTIME
	LCALL	LCD_TEXT

	MOV	DPTR,#02C2H		; Start address in LCD memory
	MOV	A,LIGHT
	SWAP	A
	ANL	A,#0FH
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#OFF
	JZ	NO_TIMEOUT
	MOV	DPTR,#TENS
NO_TIMEOUT:
	LCALL	LCD_TEXT

DISPLAY_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
DISPLAY_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

DISPLAY_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DISPLAY_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_DISPLAY_1
	JB	LEFT,DISPLAY_1A

SELECT_DISPLAY_1:
	LJMP	OPTIONS_MENU

JUMP_OFF_DISPLAY_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	SJMP	DISPLAY_2

DISPLAY_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
DISPLAY_2A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

DISPLAY_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DISPLAY_WAIT2
	CLR	ENC
	JNB	PUS,JUMP_OFF_DISPLAY_2

SELECT_DISPLAY_2:
	MOV	A,CONTR
	SETB	INV
	MOV	DPTR,#01C2H		; Start address in LCD memory
	LCALL	LCD_NUMBER
SELECT_DISPLAY_2A:
	LCALL	LCD_REFRESH		; Refresh LCD display data
	
DISPLAY_WAIT2A:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DISPLAY_WAIT2A
	CLR	ENC
	JB	RIGHT,CONTR_UP
	JB	LEFT,CONTR_DOWN

	MOV	A,CONTR
	CLR	INV
	MOV	DPTR,#01C2H		; Start address in LCD memory
	LCALL	LCD_NUMBER
	LCALL	WRITE_SETTINGS
	SJMP	DISPLAY_2A

CONTR_UP:
	MOV	A,CONTR
	CJNE	A,#09H,CONTR_UP1
	SJMP	DISPLAY_WAIT2A
CONTR_UP1:
	INC	CONTR
	LCALL	LCD_CONTRAST
	SJMP	SELECT_DISPLAY_2

CONTR_DOWN:
	MOV	A,CONTR
	JZ	SELECT_DISPLAY_2A
CONTR_DOWN1:
	DEC	CONTR
	LCALL	LCD_CONTRAST
	SJMP	SELECT_DISPLAY_2

JUMP_OFF_DISPLAY_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,DISPLAY_3
	LJMP	DISPLAY_1

DISPLAY_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
DISPLAY_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

DISPLAY_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DISPLAY_WAIT3
	CLR	ENC
	JNB	PUS,JUMP_OFF_DISPLAY_3

SELECT_DISPLAY_3:
	MOV	A,LIGHT
	ANL	A,#0FH
	SETB	INV
	MOV	DPTR,#0242H		; Start address in LCD memory
	LCALL	LCD_NUMBER
SELECT_DISPLAY_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data
	
DISPLAY_WAIT3A:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DISPLAY_WAIT3A
	CLR	ENC
	JB	RIGHT,LIGHT_UP
	JB	LEFT,LIGHT_DOWN

	MOV	A,LIGHT
	ANL	A,#0FH
	CLR	INV
	MOV	DPTR,#0242H		; Start address in LCD memory
	LCALL	LCD_NUMBER
	LCALL	WRITE_SETTINGS
	SJMP	DISPLAY_3A

LIGHT_UP:
	MOV	A,LIGHT
	ANL	A,#0FH
	CJNE	A,#09H,LIGHT_UP1
	SJMP	SELECT_DISPLAY_3A
LIGHT_UP1:
	INC	LIGHT
	LCALL	BACKLIGHT_INT
	SJMP	SELECT_DISPLAY_3

LIGHT_DOWN:
	MOV	A,LIGHT
	ANL	A,#0FH
	JZ	SELECT_DISPLAY_3A
LIGHT_DOWN1:
	DEC	LIGHT
	LCALL	BACKLIGHT_INT
	SJMP	SELECT_DISPLAY_3

JUMP_OFF_DISPLAY_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,DISPLAY_4
	LJMP	DISPLAY_2

DISPLAY_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
DISPLAY_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

DISPLAY_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DISPLAY_WAIT4
	CLR	ENC
	JB	LEFT,JUMP_OFF_DISPLAY_4
	JB	RIGHT,DISPLAY_4A

SELECT_DISPLAY_4:
	MOV	A,LIGHT
	SWAP	A
	ANL	A,#0FH
	JNZ	TIME2
	MOV	A,LIGHT
	ADD	A,#010H
	MOV	LIGHT,A
	SJMP	TIME3
TIME2:
	MOV	A,LIGHT
	ANL	A,#00FH
	MOV	LIGHT,A

TIME3:
	MOV	DPTR,#02C2H		; Start address in LCD memory
	MOV	A,LIGHT
	SWAP	A
	ANL	A,#0FH
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#OFF
	JZ	NO_TIMEOUT1
	MOV	DPTR,#TENS
NO_TIMEOUT1:
	LCALL	LCD_TEXT

	LCALL	WRITE_SETTINGS
	SJMP	DISPLAY_4A

JUMP_OFF_DISPLAY_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LJMP	DISPLAY_3

;* ------------------------------------------------------------------------
;*  PARAMETRIC EQUALIZER:
;* ------------------------------------------------------------------------

PARAMETRIC_EQ:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0200H		; Start address in LCD ERAM
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQ_ICON1
	LCALL	LCD_ICON

	MOV	DPTR,#0280H		; Start address in LCD ERAM
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQ_ICON2
	LCALL	LCD_ICON

	MOV	DPTR,#0300H		; Start address in LCD ERAM
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQ_ICON3
	LCALL	LCD_ICON

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PAREQ
	LCALL	LCD_TEXT

	MOV	DPTR,#0086H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	A,FLAGS0		; Start with 1st section
	ANL	A,#0CFH			;
	MOV	FLAGS0,A		;

	MOV	DSP_OPCODE,#022H	; DSP opcode for ch2 section1 data
	JB	CHAN2,EQ_OVER1
	MOV	DSP_OPCODE,#012H	; DSP opcode for ch1 section1 data
EQ_OVER1:

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SEC1
	LCALL	LCD_TEXT

	MOV	FREQ,FREQ5
	MOV	QF,QF5
	MOV	GAIN,GAIN5
	MOV	C,CH2S1
	MOV	BYP,C
	JB	CHAN2,EQ_OVER2
	MOV	FREQ,FREQ1
	MOV	QF,QF1
	MOV	GAIN,GAIN1
	MOV	C,CH1S1
	MOV	BYP,C
EQ_OVER2:
	LCALL	EQ_DATA			; Display eq data

	MOV	I2C_TX,#026H		; DSP opcode for eq graph ch2
	JB	CHAN2,EQ_OVER4
	MOV	I2C_TX,#011H		; DSP opcode for eq graph ch1
EQ_OVER4:
	LCALL	DSP_READ_GRAPH		; Read and display eq graph


EQ_1:
	MOV	DPTR,#0080H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
EQ_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data

EQ_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,EQ_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_EQ_1
	JB	LEFT,EQ_1A

SELECT_EQ_1:
	LJMP	SETUP12_MENU

JUMP_OFF_EQ_1:
	MOV	DPTR,#0080H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

EQ_2:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

EQ_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,EQ_WAIT2
	CLR	ENC
	JNB	PUS,JUMP_OFF_EQ_2

SELECT_EQ_2:
	LJMP	SELECT_SECTION

JUMP_OFF_EQ_2:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,EQ_3
	SJMP	EQ_1

EQ_3:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	ALOCK,CURSOR_18
	MOV	DPTR,#CURSOR
CURSOR_18:
	LCALL	LCD_TEXT
EQ_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data

EQ_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,EQ_WAIT3
	CLR	ENC
	JNB	PUS,JUMP_OFF_EQ_3

SELECT_EQ_3:
	JB	ALOCK,EQ_3A
	SETB	P_ALT
	CPL	BYP
	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BYPASS
	JB	BYP,EQ_OVER5
	MOV	DPTR,#ON
EQ_OVER5:
	LCALL	LCD_TEXT

	LCALL	DSP_LOAD_USER_EQ

	JB	CHAN2,EQ_OVER29
	JNB	EQLINK,EQ_OVER29

	LCALL	LINK_EQ

	MOV	A,DSP_OPCODE
	MOV	B,A
	ADD	A,#010H
	MOV	DSP_OPCODE,A
	LCALL	DSP_LOAD_USER_EQ
	MOV	DSP_OPCODE,B
EQ_OVER29:

	MOV	I2C_TX,#026H		; DSP opcode
	JB	CHAN2,EQ_OVER25
	MOV	I2C_TX,#011H		; DSP opcode
EQ_OVER25:
	LCALL	DSP_READ_GRAPH
	LCALL	SAVE_SECTION
	LCALL	WRITE_SETTINGS
	SJMP	EQ_3

JUMP_OFF_EQ_3:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,EQ_4
	LJMP	EQ_2

EQ_4:
	MOV	DPTR,#00C2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	ALOCK,CURSOR_19
	MOV	DPTR,#CURSOR
CURSOR_19:
	LCALL	LCD_TEXT
EQ_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data

EQ_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,EQ_WAIT4
	CLR	ENC
	JNB	PUS,JUMP_OFF_EQ_4

SELECT_EQ_4:
	JB	ALOCK,EQ_4A
	LCALL	SELECT_FREQ1
	LCALL	SAVE_SECTION
	LCALL	WRITE_SETTINGS
	SJMP	EQ_4

JUMP_OFF_EQ_4:
	MOV	DPTR,#00C2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,EQ_5
	LJMP	EQ_3

EQ_5:
	MOV	DPTR,#0142H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	ALOCK,CURSOR_20
	MOV	DPTR,#CURSOR
CURSOR_20:
	LCALL	LCD_TEXT
EQ_5A:
	LCALL	LCD_REFRESH		; Refresh LCD display data

EQ_WAIT5:	
	LCALL	ENCODER_CHECK
	JNB	ENC,EQ_WAIT5
	CLR	ENC
	JNB	PUS,JUMP_OFF_EQ_5

SELECT_EQ_5:
	JB	ALOCK,EQ_5A
	LCALL	SELECT_Q1
	LCALL	SAVE_SECTION
	LCALL	WRITE_SETTINGS
	SJMP	EQ_5

JUMP_OFF_EQ_5:
	MOV	DPTR,#0142H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,EQ_6
	LJMP	EQ_4

EQ_6:
	MOV	DPTR,#01C2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	ALOCK,CURSOR_21
	MOV	DPTR,#CURSOR
CURSOR_21:
	LCALL	LCD_TEXT
EQ_6A:
	LCALL	LCD_REFRESH		; Refresh LCD display data

EQ_WAIT6:	
	LCALL	ENCODER_CHECK
	JNB	ENC,EQ_WAIT6
	CLR	ENC
	JB	LEFT,JUMP_OFF_EQ_6
	JB	RIGHT,EQ_6A

SELECT_EQ_6:
	JB	ALOCK,EQ_6A
	LCALL	SELECT_GAIN1
	LCALL	SAVE_SECTION
	LCALL	WRITE_SETTINGS
	SJMP	EQ_6

JUMP_OFF_EQ_6:
	MOV	DPTR,#01C2H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LJMP	EQ_5

SELECT_SECTION:
	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	A,FLAGS0
	ANL	A,#030H
	MOV	DPTR,#SEC1
	JZ	EQ_OVER6
	CJNE	A,#010H,EQ_OVER61
	MOV	DPTR,#SEC2
	SJMP	EQ_OVER6
EQ_OVER61:
	CJNE	A,#020H,EQ_OVER62
	MOV	DPTR,#SEC3
	SJMP	EQ_OVER6
EQ_OVER62:
	MOV	DPTR,#SEC4
EQ_OVER6:
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

SELECT_SECTION_WAIT:
	LCALL	ENCODER_CHECK
	JNB	ENC,SELECT_SECTION_WAIT
	CLR	ENC
	JB	RIGHT,INC_SECTION
	JB	LEFT,DEC_SECTION

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	A,FLAGS0
	ANL	A,#030H
	MOV	DPTR,#SEC1
	JZ	EQ_OVER15
	CJNE	A,#010H,EQ_OVER151
	MOV	DPTR,#SEC2
	SJMP	EQ_OVER15
EQ_OVER151:
	CJNE	A,#020H,EQ_OVER152
	MOV	DPTR,#SEC3
	SJMP	EQ_OVER15
EQ_OVER152:
	MOV	DPTR,#SEC4
EQ_OVER15:
	LCALL	LCD_TEXT
	LJMP	EQ_2

INC_SECTION:
	MOV	A,FLAGS0
	ANL	A,#030H
	JZ	GOTO_SECT_2
	CJNE	A,#010H,INC_SECTION1
	SJMP	GOTO_SECT_3
INC_SECTION1:
	CJNE	A,#020H,INC_SECTION2
	SJMP	GOTO_SECT_4
INC_SECTION2:
	SJMP	SELECT_SECTION_WAIT

DEC_SECTION:
	MOV	A,FLAGS0
	ANL	A,#030H
	JZ	SELECT_SECTION_WAIT
	CJNE	A,#010H,DEC_SECTION1
	SJMP	GOTO_SECT_1
DEC_SECTION1:
	CJNE	A,#020H,DEC_SECTION2
	SJMP	GOTO_SECT_2
DEC_SECTION2:
	SJMP	GOTO_SECT_3


GOTO_SECT_1:
	LJMP	GOTO_SECT1
GOTO_SECT_2:
	LJMP	GOTO_SECT2
GOTO_SECT_3:
	LJMP	GOTO_SECT3
GOTO_SECT_4:
	LJMP	GOTO_SECT4

GOTO_SECT1:
	MOV	DSP_OPCODE,#022H	; DSP opcode for ch2 section1 data
	JB	CHAN2,EQ_OVER16
	MOV	DSP_OPCODE,#012H	; DSP opcode for ch1 section1 data
EQ_OVER16:

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SEC1
	SETB	INV
	LCALL	LCD_TEXT

	MOV	FREQ,FREQ5
	MOV	QF,QF5
	MOV	GAIN,GAIN5
	MOV	C,CH2S1
	MOV	BYP,C
	JB	CHAN2,EQ_OVER17
	MOV	FREQ,FREQ1
	MOV	QF,QF1
	MOV	GAIN,GAIN1
	MOV	C,CH1S1
	MOV	BYP,C
EQ_OVER17:
	LCALL	EQ_DATA

	MOV	A,FLAGS0		; Set to section1
	ANL	A,#0CFH			;
	MOV	FLAGS0,A		;
	LJMP	SELECT_SECTION_WAIT

GOTO_SECT2:
	MOV	DSP_OPCODE,#023H	; DSP opcode for ch2 section2 data
	JB	CHAN2,EQ_OVER18
	MOV	DSP_OPCODE,#013H	; DSP opcode for ch1 section2 data
EQ_OVER18:

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SEC2
	SETB	INV
	LCALL	LCD_TEXT

	MOV	FREQ,FREQ6
	MOV	QF,QF6
	MOV	GAIN,GAIN6
	MOV	C,CH2S2
	MOV	BYP,C
	JB	CHAN2,EQ_OVER19
	MOV	FREQ,FREQ2
	MOV	QF,QF2
	MOV	GAIN,GAIN2
	MOV	C,CH1S2
	MOV	BYP,C
EQ_OVER19:
	LCALL	EQ_DATA

	MOV	A,FLAGS0		; Set to section2
	ANL	A,#0CFH			;
	ORL	A,#010H			;
	MOV	FLAGS0,A		;
	LJMP	SELECT_SECTION_WAIT

GOTO_SECT3:
	MOV	DSP_OPCODE,#024H	; DSP opcode for ch2 section3 data
	JB	CHAN2,EQ_OVER20
	MOV	DSP_OPCODE,#014H	; DSP opcode for ch1 section3 data
EQ_OVER20:


	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SEC3
	SETB	INV
	LCALL	LCD_TEXT

	MOV	FREQ,FREQ7
	MOV	QF,QF7
	MOV	GAIN,GAIN7
	MOV	C,CH2S3
	MOV	BYP,C
	JB	CHAN2,EQ_OVER21
	MOV	FREQ,FREQ3
	MOV	QF,QF3
	MOV	GAIN,GAIN3
	MOV	C,CH1S3
	MOV	BYP,C
EQ_OVER21:
	LCALL	EQ_DATA

	MOV	A,FLAGS0		; Set to section3
	ANL	A,#0CFH			;
	ORL	A,#020H			;
	MOV	FLAGS0,A		;
	LJMP	SELECT_SECTION_WAIT

GOTO_SECT4:
	MOV	DSP_OPCODE,#025H	; DSP opcode for ch2 section4 data
	JB	CHAN2,EQ_OVER22
	MOV	DSP_OPCODE,#015H	; DSP opcode for ch1 section4 data
EQ_OVER22:


	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SEC4
	SETB	INV
	LCALL	LCD_TEXT

	MOV	FREQ,FREQ8
	MOV	QF,QF8
	MOV	GAIN,GAIN8
	MOV	C,CH2S4
	MOV	BYP,C
	JB	CHAN2,EQ_OVER23
	MOV	FREQ,FREQ4
	MOV	QF,QF4
	MOV	GAIN,GAIN4
	MOV	C,CH1S4
	MOV	BYP,C
EQ_OVER23:
	LCALL	EQ_DATA

	MOV	A,FLAGS0		; Set to section4
	ANL	A,#0CFH			;
	ORL	A,#030H			;
	MOV	FLAGS0,A		;
	LJMP	SELECT_SECTION_WAIT

SELECT_FREQ1:
	LCALL	DSP_LOAD_USER_EQ
	JB	CHAN2,EQ_OVER26
	JNB	EQLINK,EQ_OVER26
	
	LCALL	LINK_EQ

	MOV	A,DSP_OPCODE
	MOV	B,A
	ADD	A,#010H			; Add 10 to DSP opcode for ch2 data
	MOV	DSP_OPCODE,A
	LCALL	DSP_LOAD_USER_EQ
	MOV	DSP_OPCODE,B
EQ_OVER26:

	MOV	DPTR,#00C8H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#F
	LCALL	LCD_TEXT

	MOV	DPTR,#00D4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#FREQ_TABLE

	MOV	R7,#05H			; Multiply index by 5
MUL1:
	MOV	A,DPL
	ADD	A,FREQ
	MOV	DPL,A
	MOV	A,DPH
	ADDC	A,#00H
	MOV	DPH,A
	DJNZ	R7,MUL1

	SETB	INV
	LCALL	LCD_TEXT

	INC	0A2H			; Switch data pointers
	DEC	DPL
	INC	0A2H			; Switch data pointers

	MOV	DPTR,#HZ
	MOV	A,FREQ
	CLR	C
	SUBB	A,#68
	JC	UNIT_HZ2
	MOV	DPTR,#KHZ
UNIT_HZ2:
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH		; Refresh LCD display data

FREQ_ENTER_WAIT:
	MOV	R7,#50
FREQ_ENTER_WAIT1:
	LCALL	ENCODER_CHECK
	JNB	GRAPH,FREQ_ENTER_WAIT2
	MOV	R5,#1
	LCALL	LWAIT
	DJNZ	R7,FREQ_ENTER_WAIT2

	MOV	I2C_TX,#026H		; DSP opcode
	JB	CHAN2,OVER15
	MOV	I2C_TX,#011H		; DSP opcode
OVER15:
	LCALL	DSP_READ_GRAPH
	LCALL	LCD_REFRESH		; Refresh LCD display data
	CLR	GRAPH
	SJMP	FREQ_ENTER_WAIT1
FREQ_ENTER_WAIT2:
	JNB	ENC,FREQ_ENTER_WAIT1
	CLR	ENC
	SETB	GRAPH
	JB	LEFT,FREQ_DOWN
	JB	RIGHT,FREQ_UP

	LCALL	EQ_DATA

	MOV	I2C_TX,#026H		; DSP opcode
	JB	CHAN2,OVER18
	MOV	I2C_TX,#011H		; DSP opcode
OVER18:
	LCALL	DSP_READ_GRAPH
	LCALL	LCD_REFRESH		; Refresh LCD display data
	CLR	GRAPH

	RET

FREQ_UP:
	SETB	P_ALT
	MOV	A,FREQ
	CLR	C
	SUBB	A,#120
	JZ	FREQ_UP1
	INC	FREQ
FREQ_UP1:
	LJMP	SELECT_FREQ1

FREQ_DOWN:
	SETB	P_ALT
	MOV	A,FREQ
	JZ	FREQ_DOWN1
	DEC	FREQ
FREQ_DOWN1:
	LJMP	SELECT_FREQ1

SELECT_Q1:
	LCALL	DSP_LOAD_USER_EQ
	JB	CHAN2,EQ_OVER27
	JNB	EQLINK,EQ_OVER27
	
	LCALL	LINK_EQ

	MOV	A,DSP_OPCODE
	MOV	B,A
	ADD	A,#010H			; DSP opcode for ch1 section4 data
	MOV	DSP_OPCODE,A
	LCALL	DSP_LOAD_USER_EQ
	MOV	DSP_OPCODE,B
EQ_OVER27:

	MOV	DPTR,#0154H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#Q_TABLE

	MOV	R7,#04H			; Multiply index by 4
MUL3:
	MOV	A,DPL
	ADD	A,QF
	MOV	DPL,A
	MOV	A,DPH
	ADDC	A,#00H
	MOV	DPH,A
	DJNZ	R7,MUL3

	SETB	INV
	LCALL	LCD_TEXT	
	LCALL	LCD_REFRESH		; Refresh LCD display data

Q_ENTER_WAIT:
	MOV	R7,#50
Q_ENTER_WAIT1:
	LCALL	ENCODER_CHECK
	JNB	GRAPH,Q_ENTER_WAIT2
	MOV	R5,#1
	LCALL	LWAIT
	DJNZ	R7,Q_ENTER_WAIT2
	MOV	I2C_TX,#026H		; DSP opcode
	JB	CHAN2,OVER16
	MOV	I2C_TX,#011H		; DSP opcode
OVER16:
	LCALL	DSP_READ_GRAPH
	LCALL	LCD_REFRESH		; Refresh LCD display data
	CLR	GRAPH
	SJMP	Q_ENTER_WAIT1
Q_ENTER_WAIT2:
	JNB	ENC,Q_ENTER_WAIT1
	CLR	ENC
	SETB	GRAPH
	JB	LEFT,Q_DOWN
	JB	RIGHT,Q_UP
	
	LCALL	EQ_DATA

	MOV	I2C_TX,#026H		; DSP opcode
	JB	CHAN2,OVER19
	MOV	I2C_TX,#011H		; DSP opcode
OVER19:
	LCALL	DSP_READ_GRAPH
	LCALL	LCD_REFRESH		; Refresh LCD display data
	CLR	GRAPH

	RET

Q_UP:
	SETB	P_ALT
	MOV	A,QF
	CLR	C
	SUBB	A,#025H
	JZ	Q_UP1
	INC	QF
Q_UP1:
	LJMP	SELECT_Q1

Q_DOWN:
	SETB	P_ALT
	MOV	A,QF
	JZ	Q_DOWN1
	DEC	QF
Q_DOWN1:
	LJMP	SELECT_Q1

SELECT_GAIN1:
	LCALL	DSP_LOAD_USER_EQ
	JB	CHAN2,EQ_OVER28
	JNB	EQLINK,EQ_OVER28
	
	LCALL	LINK_EQ

	MOV	A,DSP_OPCODE
	MOV	B,A
	ADD	A,#010H			; DSP opcode for ch1 section4 data
	MOV	DSP_OPCODE,A
	LCALL	DSP_LOAD_USER_EQ
	MOV	DSP_OPCODE,B
EQ_OVER28:

	MOV	DPTR,#01C8H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#G
	LCALL	LCD_TEXT

	MOV	DPTR,#01D4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#GAIN_TABLE

	MOV	A,GAIN
	JZ	NOTCH2
	MOV	R7,#06H			; Multiply index by 6
MUL5:
	MOV	A,DPL
	ADD	A,GAIN
	MOV	DPL,A
	MOV	A,DPH
	ADDC	A,#00H
	MOV	DPH,A
	DJNZ	R7,MUL5
NOTCH2:
	SETB	INV
	LCALL	LCD_TEXT

	MOV	A,GAIN
	JZ	NOTCH3

	INC	0A2H			; Switch data pointers
	DEC	DPL
	INC	0A2H			; Switch data pointers

	MOV	DPTR,#DECIB2
	LCALL	LCD_TEXT
NOTCH3:
	LCALL	LCD_REFRESH		; Refresh LCD display data

GAIN_ENTER_WAIT:
	MOV	R7,#50
GAIN_ENTER_WAIT1:
	LCALL	ENCODER_CHECK
	JNB	GRAPH,GAIN_ENTER_WAIT2
	MOV	R5,#1
	LCALL	LWAIT
	DJNZ	R7,GAIN_ENTER_WAIT2
	MOV	I2C_TX,#026H		; DSP opcode
	JB	CHAN2,OVER17
	MOV	I2C_TX,#011H		; DSP opcode
OVER17:
	LCALL	DSP_READ_GRAPH
	LCALL	LCD_REFRESH		; Refresh LCD display data
	CLR	GRAPH
	SJMP	GAIN_ENTER_WAIT1
GAIN_ENTER_WAIT2:
	JNB	ENC,GAIN_ENTER_WAIT1
	CLR	ENC
	SETB	GRAPH
	JB	LEFT,GAIN_DOWN
	JB	RIGHT,GAIN_UP
	
	LCALL	EQ_DATA

	MOV	I2C_TX,#026H		; DSP opcode
	JB	CHAN2,OVER20
	MOV	I2C_TX,#011H		; DSP opcode
OVER20:
	LCALL	DSP_READ_GRAPH
	LCALL	LCD_REFRESH		; Refresh LCD display data
	CLR	GRAPH

	RET

GAIN_UP:
	SETB	P_ALT
	MOV	A,GAIN
	CLR	C
	SUBB	A,#65			; EQ max +12dB
;	SUBB	A,#81			; EQ max +19dB
	JZ	GAIN_UP1
	INC	GAIN
GAIN_UP1:
	LJMP	SELECT_GAIN1

GAIN_DOWN:
	SETB	P_ALT
	MOV	A,GAIN
	JZ	GAIN_DOWN1
	DEC	GAIN
GAIN_DOWN1:
	LJMP	SELECT_GAIN1

;* ------------------------------------------------------------------------
;*  Function  :LINK_EQ
;*  Purpose   :Copy eq data to ch2 variables when eqlinked
;*  Arguments :-
;*  Uses      :-
;*  Returns   :-
;* ------------------------------------------------------------------------
LINK_EQ:
	MOV	A,FLAGS0
	ANL	A,#030H
	JZ	LINK_SECT1
	CJNE	A,#010H,L_OVER1
	SJMP	LINK_SECT2
L_OVER1:
	CJNE	A,#020H,L_OVER2
	SJMP	LINK_SECT3
L_OVER2:
	SJMP	LINK_SECT4

LINK_SECT1:
	MOV	FREQ5,FREQ
	MOV	QF5,QF
	MOV	GAIN5,GAIN
	MOV	C,BYP
	MOV	CH2S1,C
	RET

LINK_SECT2:
	MOV	FREQ6,FREQ
	MOV	QF6,QF
	MOV	GAIN6,GAIN
	MOV	C,BYP
	MOV	CH2S2,C
	RET

LINK_SECT3:
	MOV	FREQ7,FREQ
	MOV	QF7,QF
	MOV	GAIN7,GAIN
	MOV	C,BYP
	MOV	CH2S3,C
	RET

LINK_SECT4:
	MOV	FREQ8,FREQ
	MOV	QF8,QF
	MOV	GAIN8,GAIN
	MOV	C,BYP
	MOV	CH2S4,C
	RET

;* ------------------------------------------------------------------------
;*  Function  :SAVE_SECTION
;*  Purpose   :save current eq section data
;*  Arguments :-
;*  Uses      :-
;*  Returns   :-
;* ------------------------------------------------------------------------

SAVE_SECTION:
	MOV	A,FLAGS0
	ANL	A,#030H
	JZ	SAVE_SECTION1
	CJNE	A,#010H,S_OVER1
	SJMP	SAVE_SECTION2
S_OVER1:
	CJNE	A,#020H,S_OVER2
	SJMP	SAVE_SECTION3
S_OVER2:
	SJMP	SAVE_SECTION4

SAVE_SECTION1:
	JNB	CHAN2,EQ_OVER7
	MOV	FREQ5,FREQ
	MOV	QF5,QF
	MOV	GAIN5,GAIN
	MOV	C,BYP
	MOV	CH2S1,C
	RET
EQ_OVER7:
	MOV	FREQ1,FREQ
	MOV	QF1,QF
	MOV	GAIN1,GAIN
	MOV	C,BYP
	MOV	CH1S1,C
	RET

SAVE_SECTION2:
	JNB	CHAN2,EQ_OVER9
	MOV	FREQ6,FREQ
	MOV	QF6,QF
	MOV	GAIN6,GAIN
	MOV	C,BYP
	MOV	CH2S2,C
	RET
EQ_OVER9:
	MOV	FREQ2,FREQ
	MOV	QF2,QF
	MOV	GAIN2,GAIN
	MOV	C,BYP
	MOV	CH1S2,C
	RET

SAVE_SECTION3:
	JNB	CHAN2,EQ_OVER11
	MOV	FREQ7,FREQ
	MOV	QF7,QF
	MOV	GAIN7,GAIN
	MOV	C,BYP
	MOV	CH2S3,C
	RET
EQ_OVER11:
	MOV	FREQ3,FREQ
	MOV	QF3,QF
	MOV	GAIN3,GAIN
	MOV	C,BYP
	MOV	CH1S3,C
	RET

SAVE_SECTION4:
	JNB	CHAN2,EQ_OVER13
	MOV	FREQ8,FREQ
	MOV	QF8,QF
	MOV	GAIN8,GAIN
	MOV	C,BYP
	MOV	CH2S4,C
	RET
EQ_OVER13:
	MOV	FREQ4,FREQ
	MOV	QF4,QF
	MOV	GAIN4,GAIN
	MOV	C,BYP
	MOV	CH1S4,C
	RET

;* ------------------------------------------------------------------------
;*  DELAY MENU:
;* ------------------------------------------------------------------------

DELAY_MENU:				; 
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DELAY2
	JB	CHAN2,DELAY_CH2_2
	MOV	DPTR,#DELAY1
DELAY_CH2_2:
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers

	MOV	DPTR,#DON
	MOV	C,D2
	JB	CHAN2,DELAY_ON4
	MOV	C,D1
DELAY_ON4:
	JC	DELAY_ON3
	MOV	DPTR,#DOFF2
	JNB	DABS,DELAY_ON3
	MOV	DPTR,#DOFF
	JNB	DUNIT,DELAY_ON3
	MOV	DPTR,#DOFFM
DELAY_ON3:
	LCALL	LCD_TEXT

	MOV	DPTR,#0206H		; Start address in LCD memory
	LCALL	DELAY_DATA

	MOV	DPTR,#0286H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#UNT
	LCALL	LCD_TEXT

	MOV	DPTR,#02AAH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#M1
	JB	DUNIT,UNIT8
	MOV	DPTR,#MS1
UNIT8:
	LCALL	LCD_TEXT

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ABS
	JB	DABS,DREL1
	MOV	DPTR,#REL
DREL1:
	LCALL	LCD_TEXT	


DELAY_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
DELAY_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

DELAY_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DELAY_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_DELAY_1
	JB	LEFT,DELAY_1A

SELECT_DELAY_1:
	LJMP	SETUP12_MENU

JUMP_OFF_DELAY_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

DELAY_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
DELAY_2A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

DELAY_WAIT2:	
	LCALL	DSP_ENABLE_INT
DELAY_WAIT2B:
	LCALL	ENCODER_CHECK
	JNB	ENC,DELAY_WAIT2B
	CLR	ENC
	JNB	PUS,JUMP_OFF_DELAY_2
	SJMP	SELECT_DELAY2

JUMP_OFF_DELAY_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,JMP_TO_DELAY_3
	LJMP	DELAY_1

JMP_TO_DELAY_3:
	LJMP	DELAY_3

SELECT_DELAY2:
	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DON

	MOV	C,D2
	JB	CHAN2,DELAY5
	MOV	C,D1
DELAY5:
	JC	DELAY_ON2
	MOV	DPTR,#DOFF2
	JNB	DABS,DELAY_ON2
	MOV	DPTR,#DOFF
	JNB	DUNIT,DELAY_ON2
	MOV	DPTR,#DOFFM
DELAY_ON2:
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

DELAY_WAIT2A:
	LCALL	ENCODER_CHECK
	JNB	ENC,DELAY_WAIT2A
	CLR	ENC
	JB	PUS,DELAY_ON_OFF_CONFIRM
	JB	RIGHT,DELAY_ON
	LJMP	DELAY_OFF

DELAY_ON_OFF_CONFIRM:
	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DON
	MOV	C,D2
	JB	CHAN2,DELAY6
	MOV	C,D1
DELAY6:
	JC	DELAY_ON1
	MOV	DPTR,#DOFF2
	JNB	DABS,DELAY_ON1
	MOV	DPTR,#DOFF
	JNB	DUNIT,DELAY_ON1
	MOV	DPTR,#DOFFM
DELAY_ON1:
	LCALL	LCD_TEXT

	JB	CHAN2,SET_DELAY_CH2

	MOV	C,D_FINE1		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW1
	MOV	D_MID,D_MID1
	MOV	D_HI,D_HI1
	LCALL	DSP_CALC_DELAY
	MOV	DELL1,GRAPH1
	MOV	DELH1,GRAPH2

	JNB	D1,DELAY9

	LCALL	DSP_LOAD_DELAY1

	JB	DLINK,SET_DELAY_CH2

	SJMP	END_CONFIRM_DELAY_ON_OFF
DELAY9:
	MOV	I2C_TX,#016H		; Get opcode for DSP
	LCALL	DSP_BYPASS_DELAY
	JB	DLINK,SET_DELAY_CH2

	SJMP	END_CONFIRM_DELAY_ON_OFF

SET_DELAY_CH2:
	MOV	C,D_FINE2		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW2
	MOV	D_MID,D_MID2
	MOV	D_HI,D_HI2
	LCALL	DSP_CALC_DELAY
	MOV	DELL2,GRAPH1
	MOV	DELH2,GRAPH2

	JNB	D2,DELAY10

	LCALL	DSP_LOAD_DELAY2
	SJMP	END_CONFIRM_DELAY_ON_OFF
DELAY10:
	MOV	I2C_TX,#017H		; Get opcode for DSP
	LCALL	DSP_BYPASS_DELAY

END_CONFIRM_DELAY_ON_OFF:
	LCALL	WRITE_SETTINGS
	LJMP	DELAY_2A

DELAY_ON:
	SETB	P_ALT
	JB	CHAN2,DELAY4
	SETB	D1
	JB	DLINK,DELAY4
	LJMP	SELECT_DELAY2
DELAY4:
	SETB	D2
	LJMP	SELECT_DELAY2

DELAY_OFF:
	SETB	P_ALT
	JB	CHAN2,DELAY3
	CLR	D1
	JB	DLINK,DELAY3
	LJMP	SELECT_DELAY2
DELAY3:
	CLR	D2
	LJMP	SELECT_DELAY2


DELAY_3:				;SET DELAY MENU ENTRY
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
DELAY_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data

DELAY_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DELAY_WAIT3
	CLR	ENC
	JB	PUS,SELECT_DELAY_3
	LJMP	JUMP_OFF_DELAY_3

SELECT_DELAY_3:
	JB	DUNIT,NO_CORR
	JB	D_FINE,NO_CORR
	MOV	A,D_LOW
	CJNE	A,#9,NO_CORR
	MOV	A,D_MID
	CJNE	A,#2,NO_CORR
	MOV	A,D_HI
	JNZ	NO_CORR

	SETB	D_FINE
	MOV	D_LOW,#0
	MOV	D_MID,#9
	MOV	D_HI,#2
NO_CORR:

	MOV	DPTR,#0206H		; Start address in LCD memory
	SETB	INV
	LCALL	DELAY_DATA
	LCALL	LCD_REFRESH		; Refresh LCD display data

DELAY_WAIT3A:
	LCALL	ENCODER_CHECK
	JNB	ENC,DELAY_WAIT3A
	CLR	ENC
	JB	PUS,DELAY_CONFIRM
	SETB	P_ALT
	LJMP	DELAY_CHANGE

DELAY_CONFIRM:
	MOV	DPTR,#0206H		; Start address in LCD memory
	LCALL	DELAY_DATA

	JB	CHAN2,DELAY_CH2

DELAY_CH1:
	MOV	C,D_FINE		;TEMP
	MOV	D_FINE1,C		;TEMP
	MOV	D_LOW1,D_LOW
	MOV	D_MID1,D_MID
	MOV	D_HI1,D_HI

	LCALL	DSP_CALC_DELAY
	MOV	DELL1,GRAPH1
	MOV	DELH1,GRAPH2

	JB	D1,DELAY_OVER1
	MOV	I2C_TX,#016H		; Get opcode for DSP
	LCALL	DSP_BYPASS_DELAY
	JB	DLINK,DELAY_CH2
	SJMP	DELAY_CONT
DELAY_OVER1:
	LCALL	DSP_LOAD_DELAY1
	JB	DLINK,DELAY_CH2
	SJMP	DELAY_CONT

DELAY_CH2:
	MOV	C,D_FINE		;TEMP
	MOV	D_FINE2,C		;TEMP
	MOV	D_LOW2,D_LOW
	MOV	D_MID2,D_MID
	MOV	D_HI2,D_HI

	LCALL	DSP_CALC_DELAY
	MOV	DELL2,GRAPH1
	MOV	DELH2,GRAPH2

	JB	D2,DELAY_OVER2
	MOV	I2C_TX,#017H		; Get opcode for DSP
	LCALL	DSP_BYPASS_DELAY
	SJMP	DELAY_CONT
DELAY_OVER2:
	LCALL	DSP_LOAD_DELAY2

DELAY_CONT:
	LCALL	WRITE_SETTINGS
	LCALL	DSP_ENABLE_INT
	LJMP	DELAY_3A

DELAY_CHANGE:
	JB	LEFT,DELAY_DOWN1

DELAY_UP1:
	MOV	COUNT1,#1
	JNB	ENC_FAST,SLOW_UP
	MOV	COUNT1,#10
SLOW_UP:
	LCALL	DELAY_UP
	DJNZ	COUNT1,SLOW_UP
	LJMP	SELECT_DELAY_3

DELAY_DOWN1:
	MOV	COUNT1,#1
	JNB	ENC_FAST,SLOW_DOWN
	MOV	COUNT1,#10
SLOW_DOWN:
	LCALL	DELAY_DOWN
	DJNZ	COUNT1,SLOW_DOWN
	LJMP	SELECT_DELAY_3

JUMP_OFF_DELAY_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,DELAY_4
	LJMP	DELAY_2

DELAY_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
DELAY_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data

DELAY_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DELAY_WAIT4
	CLR	ENC
	JB	PUS,SELECT_DELAY_4

JUMP_OFF_DELAY_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	LEFT,JUMP_OFF_DELAY_4_CONT
	LJMP	DELAY_5

JUMP_OFF_DELAY_4_CONT:
	LJMP	DELAY_3

SELECT_DELAY_4:
	CPL	DUNIT

	MOV	DPTR,#02AAH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#M1
	JB	DUNIT,UNIT4
	MOV	DPTR,#MS1
UNIT4:
	LCALL	LCD_TEXT

LEAVE_DELAY4A:
	MOV	GRAPH1,DELL1
	MOV	GRAPH2,DELH1

	LCALL	COMPUTE_DELAY
	MOV	C, D_FINE		;TEMP
	MOV	D_FINE1,C		;TEMP
	MOV	D_LOW1,D_LOW
	MOV	D_MID1,D_MID
	MOV	D_HI1,D_HI

	MOV	GRAPH1,DELL2
	MOV	GRAPH2,DELH2

	LCALL	COMPUTE_DELAY
	MOV	C, D_FINE		;TEMP
	MOV	D_FINE2,C		;TEMP
	MOV	D_LOW2,D_LOW
	MOV	D_MID2,D_MID
	MOV	D_HI2,D_HI

	JB	CHAN2,DELAY_OVER3
	MOV	C,D_FINE1		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW1
	MOV	D_MID,D_MID1
	MOV	D_HI,D_HI1

DELAY_OVER3:
	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DON
	MOV	C,D2
	JB	CHAN2,DELAY_ON5
	MOV	C,D1
DELAY_ON5:

	JC	DELAY_ON6
	MOV	DPTR,#DOFF2
	JNB	DABS,DELAY_ON6
	MOV	DPTR,#DOFF
	JNB	DUNIT,DELAY_ON6
	MOV	DPTR,#DOFFM
DELAY_ON6:
	LCALL	LCD_TEXT


	MOV	DPTR,#0206H		; Start address in LCD memory
	LCALL	DELAY_DATA
	LCALL	WRITE_SETTINGS	
	LJMP	DELAY_4A

DELAY_5:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
DELAY_5A:
	LCALL	LCD_REFRESH		; Refresh LCD display data

DELAY_WAIT5:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DELAY_WAIT5
	CLR	ENC
	JB	PUS,SELECT_DELAY_5

JUMP_OFF_DELAY_5:
	MOV	DPTR,#0300H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,DELAY_5
	LJMP	DELAY_4

SELECT_DELAY_5:
	CPL	DABS

	MOV	DPTR,#0306H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#REL
	JNB	DABS,DREL2
	MOV	DPTR,#ABS
DREL2:
	LCALL	LCD_TEXT

LEAVE_DELAY5A:
	MOV	GRAPH1,DELL1
	MOV	GRAPH2,DELH1

	LCALL	COMPUTE_DELAY
	MOV	C,D_FINE		;TEMP
	MOV	D_FINE1,C		;TEMP
	MOV	D_LOW1,D_LOW
	MOV	D_MID1,D_MID
	MOV	D_HI1,D_HI

	MOV	GRAPH1,DELL2
	MOV	GRAPH2,DELH2

	LCALL	COMPUTE_DELAY
	MOV	C,D_FINE		;TEMP
	MOV	D_FINE2,C		;TEMP
	MOV	D_LOW2,D_LOW
	MOV	D_MID2,D_MID
	MOV	D_HI2,D_HI

	JB	CHAN2,DELAY_OVER4
	MOV	C,D_FINE1		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW1
	MOV	D_MID,D_MID1
	MOV	D_HI,D_HI1

DELAY_OVER4:
	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DON
	MOV	C,D2
	JB	CHAN2,DELAY_ON7
	MOV	C,D1
DELAY_ON7:
	JC	DELAY_ON8
	MOV	DPTR,#DOFF2
	JNB	DABS,DELAY_ON8
	MOV	DPTR,#DOFF
	JNB	DUNIT,DELAY_ON8
	MOV	DPTR,#DOFFM
DELAY_ON8:
	LCALL	LCD_TEXT


	MOV	DPTR,#0206H		; Start address in LCD memory
	LCALL	DELAY_DATA
	LCALL	WRITE_SETTINGS	
	LJMP	DELAY_5A



DELAY_UP:
	JB	D_FINE,D_FINE_7

	JNB	DUNIT,UNIT_MS12
	MOV	A,D_LOW
	CJNE	A,#9,DO_DELAY_UP
	MOV	A,D_MID
	CJNE	A,#9,DO_DELAY_UP
	MOV	A,D_HI
	CJNE	A,#9,DO_DELAY_UP
	RET

UNIT_MS12:
	MOV	A,D_LOW
	CJNE	A,#4,DO_DELAY_UP
	MOV	A,D_MID
	CJNE	A,#9,DO_DELAY_UP
	MOV	A,D_HI
	CJNE	A,#2,DO_DELAY_UP
	RET

D_FINE_7:
	JNB	DUNIT,UNIT_MS14
	MOV	A,D_LOW
	CJNE	A,#9,DO_DELAY_UP
	MOV	A,D_MID
	CJNE	A,#9,DO_DELAY_UP
	MOV	A,D_HI
	CJNE	A,#9,DO_DELAY_UP

	MOV	D_LOW,#0
	MOV	D_MID,#0
	MOV	D_HI,#1
	CLR	D_FINE
	RET

UNIT_MS14:
	MOV	A,D_LOW
	CJNE	A,#4,DO_DELAY_UP
	MOV	A,D_MID
	CJNE	A,#9,DO_DELAY_UP
	MOV	A,D_HI
	CJNE	A,#2,DO_DELAY_UP

	MOV	D_LOW,#0
	MOV	D_MID,#3
	MOV	D_HI,#0
	CLR	D_FINE
	RET

DO_DELAY_UP:
	INC	D_LOW
	MOV	A,D_LOW
	CJNE	A,#10,END_DELAY_UP
	MOV	D_LOW,#0
	INC	D_MID
	MOV	A,D_MID
	CJNE	A,#10,END_DELAY_UP
	MOV	D_MID,#0
	INC	D_HI
END_DELAY_UP:
	RET

DELAY_DOWN:
	JB	D_FINE,D_FINE_6

	JNB	DUNIT,UNIT_MS9
	MOV	A,D_LOW
	JNZ	DO_DELAY_DOWN
	MOV	A,D_MID
	JNZ	DO_DELAY_DOWN
	MOV	A,D_HI
	CJNE	A,#1,DO_DELAY_DOWN

	MOV	D_LOW,#9
	MOV	D_MID,#9
	MOV	D_HI,#9
	SETB	D_FINE

	RET

UNIT_MS9:
	MOV	A,D_LOW
	JNZ	DO_DELAY_DOWN
	MOV	A,D_MID
	CJNE	A,#3,DO_DELAY_DOWN
	MOV	A,D_HI
	JNZ	DO_DELAY_DOWN

	MOV	D_LOW,#4
	MOV	D_MID,#9
	MOV	D_HI,#2
	SETB	D_FINE

	RET

D_FINE_6:
	JNB	DUNIT,UNIT_MS13

	MOV	A,D_LOW
	CJNE	A,#4,DO_DELAY_DOWN
	MOV	A,D_MID
	CJNE	A,#3,DO_DELAY_DOWN
	MOV	A,D_HI
	JNZ	DO_DELAY_DOWN
	RET

UNIT_MS13:
	MOV	A,D_LOW
	JNZ	DO_DELAY_DOWN
	MOV	A,D_MID
	CJNE	A,#1,DO_DELAY_DOWN
	MOV	A,D_HI
	JNZ	DO_DELAY_DOWN
	RET

DO_DELAY_DOWN:
	DEC	D_LOW
	MOV	A,D_LOW
	CJNE	A,#0FFH,END_DELAY_DOWN
	MOV	D_LOW,#9
	DEC	D_MID
	MOV	A,D_MID
	CJNE	A,#0FFH,END_DELAY_DOWN
	MOV	D_MID,#9
	DEC	D_HI
END_DELAY_DOWN:
	RET

;* ------------------------------------------------------------------------
;*  Function  :PRESETNAME
;*  Purpose   :-
;*  Arguments :A,DPTR
;*  Uses      :B,OPCODE,OPCODE1,OPCODE2,OPCODE3,CCNT
;*  Calls     :FLASH_OPCODE
;*	       SPI_RX
;*	       LCD_CHAR
;*  Returns   :-
;* ------------------------------------------------------------------------
PRESETNAME1:
	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#008H		; Start at page512

	MOV	B,A

	ANL	A,#0F8H
	MOV	OPCODE2,A

	MOV	A,B

	CLR	C
	SUBB	A,OPCODE2
	MOV	B,A

	MOV	A,OPCODE2
	RR	A
	MOV	OPCODE2,A

	MOV	A,#66
	MUL	AB
	MOV	OPCODE3,A

	MOV	A,OPCODE2
	ADD	A,B
	MOV	OPCODE2,A

	LCALL	FLASH_OPCODE		;

	MOV	CCNT,#12		; Set character count for first 12 characters
PRESETNAME_LOOP1:
	LCALL	SPI_RX			; Get data from FLASH
	MOV	A,SPIRDAT		; Move received data to A
	LCALL	LCD_CHAR
	DJNZ	CCNT,PRESETNAME_LOOP1

	RET

PRESETNAME2:
	MOV	CCNT,#9			; Set character count for last 9 characters
PRESETNAME_LOOP2:
	LCALL	SPI_RX			; Get data from FLASH
	MOV	A,SPIRDAT		; Move received data to A
	LCALL	LCD_CHAR
	DJNZ	CCNT,PRESETNAME_LOOP2


	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	RET


;* ------------------------------------------------------------------------
;*  Function  :SETUP_DSP
;*  Purpose   :-
;*  Arguments :-
;*  Uses      :A,R0,G_LOW,G_HI,DSP_OPCODE,I2C_TX,BYTECNTL,BYTECNTH,SLVADR,D_LOW,D_MID,D_HI,DELL1,DELH1,DELL2,DELH2,GRAPH1,GRAPH2
;*  Calls     :MUTE_DAC
;*	       DSP_LOAD_GAIN
;*	       SETUP_EQ
;*	       SENDDATA
;*	       CHECK_ADC_STACKED
;*	       DSP_LOAD_PRESET
;*	       DSP_CALC_DELAY
;*	       DSP_BYPASS_DELAY
;*	       DSP_LOAD_DELAY1
;*	       DSP_LOAD_DELAY2
;*	       DSP_ENABLE_INT
;*  Returns   :-
;* ------------------------------------------------------------------------
SETUP_DSP:
	LCALL	MUTE_DAC

; Load gain data to DSP:
	MOV	G_LOW,G_LOW1
	MOV	G_HI,G_HI1
	MOV	DSP_OPCODE,#031H	; DSP opcode for ch1 gain data
	LCALL	DSP_LOAD_GAIN

	MOV	G_LOW,G_LOW2
	MOV	G_HI,G_HI2
	MOV	DSP_OPCODE,#032H	; DSP opcode for ch2 gain data
	LCALL	DSP_LOAD_GAIN

; Load user eq data to DSP:
	LCALL	SETUP_EQ

; Bypass ch1 user eq:
	JB	EQ1,EQ3			; Jump if eq not bypassed
	MOV	I2C_TX,#027H		; DSP opcode for bypass ch1 user eq
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus
EQ3:

; Bypass ch2 user eq:
	JB	EQ2,EQ4			; Jump if eq not bypassed
	MOV	I2C_TX,#028H		; DSP opcode for bypass ch1 user eq
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus
EQ4:

; Set DSP in bridge mode:
	JNB	STEREO,NO_BRIDGE1
	JNB	ACTIVE,NO_BRIDGE1
	MOV	I2C_TX,#046H		; DSP opcode for bridge mode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus
NO_BRIDGE1:

; Set DSP in stereo mode:
	JB	ACTIVE,NO_STEREO
	JNB	STEREO,NO_STEREO
	MOV	I2C_TX,#048H		; DSP opcode for stereo mode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus
NO_STEREO:

; Set DSP in active mode:
	JNB	ACTIVE,NO_ACTIVE
	JB	STEREO,NO_ACTIVE
	MOV	I2C_TX,#047H		; DSP opcode for active mode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus
NO_ACTIVE:

; Set DSP in dual channel mode:
	JB	ACTIVE,NO_DUAL
	JB	STEREO,NO_DUAL
	MOV	I2C_TX,#049H		; DSP opcode for active mode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus
NO_DUAL:


; Load input routing settings for ch1 to DSP:
	MOV	A,INPSET
	ANL	A,#03H

	MOV	I2C_TX,#040H		; DSP opcode for ch1 input to ch1 amp
	CJNE	A,#002H,SET_INPUT1
	MOV	I2C_TX,#041H		; DSP opcode for ch2 input to ch1 amp
	SJMP	SET_INPUT2
SET_INPUT1:
	CJNE	A,#003H,SET_INPUT2
	MOV	I2C_TX,#042H		; DSP opcode for ch1+ch2 input to ch1 amp
SET_INPUT2:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus


; Load input routing settings for ch2 to DSP:
	MOV	A,INPSET
	RR	A
	RR	A
	ANL	A,#03H

	MOV	I2C_TX,#044H		; DSP opcode for ch1 input to ch2 amp
	CJNE	A,#002H,SET_INPUT3
	MOV	I2C_TX,#043H		; DSP opcode for ch2 input to ch2 amp
	SJMP	SET_INPUT4
SET_INPUT3:
	CJNE	A,#003H,SET_INPUT4
	MOV	I2C_TX,#045H		; DSP opcode for ch1+ch2 input to ch2 amp
SET_INPUT4:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

; Set ADC in stacked mode:
	LCALL	CHECK_ADC_STACKED

; Load speaker preset data for ch1 to DSP:
	CLR	CHAN2
	LCALL	DSP_LOAD_PRESET

; Load speaker preset data for ch2 to DSP:
	SETB	CHAN2
	LCALL	DSP_LOAD_PRESET

; Calculate delay data for ch1:
	MOV	C,D_FINE1		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW1
	MOV	D_MID,D_MID1
	MOV	D_HI,D_HI1

	LCALL	DSP_CALC_DELAY
	MOV	DELL1,GRAPH1
	MOV	DELH1,GRAPH2

; Calculate delay data for ch2:
	MOV	C,D_FINE2		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW2
	MOV	D_MID,D_MID2
	MOV	D_HI,D_HI2

	LCALL	DSP_CALC_DELAY
	MOV	DELL2,GRAPH1
	MOV	DELH2,GRAPH2

; Load delay data for ch1 to DSP:
	MOV	I2C_TX,#016H		; DSP opcode for delay ch1
	LCALL	DSP_BYPASS_DELAY

	JNB	D1,NO_DELAY_CH1
	MOV	C,D_FINE1		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW1
	MOV	D_MID,D_MID1
	MOV	D_HI,D_HI1
	LCALL	DSP_LOAD_DELAY1	
NO_DELAY_CH1:

; Load delay data for ch2 to DSP:
	MOV	I2C_TX,#017H		; DSP opcode for delay ch2
	LCALL	DSP_BYPASS_DELAY

	JNB	D2,NO_DELAY_CH2
	MOV	C,D_FINE2		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW2
	MOV	D_MID,D_MID2
	MOV	D_HI,D_HI2
	LCALL	DSP_LOAD_DELAY2	
NO_DELAY_CH2:

; Load mute data for ch1 to DSP:
	MOV	I2C_TX,#020H		; DSP opcode for unmute ch1
	JNB	MUTE1,MUTE9
	MOV	I2C_TX,#018H		; DSP opcode for mute ch1
MUTE9:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

; Load mute data for ch2 to DSP:
	MOV	I2C_TX,#021H		; DSP opcode for unmute ch2
	JNB	MUTE2,MUTE10
	MOV	I2C_TX,#019H		; DSP opcode for mute ch2
MUTE10:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

; Enable interrupts from ADC in DSP:
	LCALL	DSP_ENABLE_INT

	RET

;* ------------------------------------------------------------------------
;*  Function  :GET_CODE
;*  Purpose   :Input code for lock function
;*  Arguments :-
;*  Uses      :A,DPTR,FREQ,QF
;*  Calls     :LCD_NUMBER
;*	       LCD_REFRESH
;*	       ENCODER_CHECK
;*  Returns   :FREQ,QF
;* ------------------------------------------------------------------------
GET_CODE:
	MOV	FREQ,#0
	MOV	QF,#0

	MOV	DPTR,#03C8H		; Start address in LCD memory
	CLR	A
	LCALL	LCD_NUMBER
	CLR	A
	LCALL	LCD_NUMBER
	CLR	A
	LCALL	LCD_NUMBER

PIN1:
	MOV	DPTR,#03C2H		; Start address in LCD memory
	MOV	A,FREQ
	SWAP	A
	ANL	A,#0FH
	SETB	INV
	LCALL	LCD_NUMBER
	LCALL	LCD_REFRESH		; Refresh LCD display data

WAIT_PIN1:
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT_PIN1
	CLR	ENC
	JB	RIGHT,PIN1_UP
	JB	LEFT,PIN1_DOWN

	MOV	DPTR,#03C2H		; Start address in LCD memory
	MOV	A,FREQ
	SWAP	A
	ANL	A,#0FH
	CLR	INV
	LCALL	LCD_NUMBER
	LJMP	PIN2

PIN1_UP:
	MOV	A,FREQ
	ANL	A,#0F0H
	CJNE	A,#090H,PIN1_UP1
	CLR	C
	SUBB	A,#090H
	MOV	FREQ,A
	SJMP	PIN1
PIN1_UP1:
	MOV	A,FREQ
	ADD	A,#010H
	MOV	FREQ,A
	SJMP	PIN1

PIN1_DOWN:
	MOV	A,FREQ
	ANL	A,#0F0H
	CJNE	A,#0,PIN1_DOWN1
	ADD	A,#090H
	MOV	FREQ,A
	SJMP	PIN1
PIN1_DOWN1:
	MOV	A,FREQ
	CLR	C
	SUBB	A,#010H
	MOV	FREQ,A
	SJMP	PIN1
		
PIN2:
	MOV	DPTR,#03C8H		; Start address in LCD memory
	MOV	A,FREQ
	ANL	A,#0FH
	SETB	INV
	LCALL	LCD_NUMBER
	LCALL	LCD_REFRESH		; Refresh LCD display data

WAIT_PIN2:
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT_PIN2
	CLR	ENC
	JB	RIGHT,PIN2_UP
	JB	LEFT,PIN2_DOWN

	MOV	DPTR,#03C8H		; Start address in LCD memory
	MOV	A,FREQ
	ANL	A,#0FH
	CLR	INV
	LCALL	LCD_NUMBER
	LJMP	PIN3

PIN2_UP:
	MOV	A,FREQ
	ANL	A,#0FH
	CJNE	A,#9,PIN2_UP1
	CLR	C
	SUBB	A,#009H
	MOV	FREQ,A
	SJMP	PIN2
PIN2_UP1:
	MOV	A,FREQ
	ADD	A,#001H
	MOV	FREQ,A
	SJMP	PIN2

PIN2_DOWN:
	MOV	A,FREQ
	ANL	A,#0FH
	CJNE	A,#0,PIN2_DOWN1
	ADD	A,#009H
	MOV	FREQ,A
	SJMP	PIN2
PIN2_DOWN1:
	MOV	A,FREQ
	CLR	C
	SUBB	A,#001H
	MOV	FREQ,A
	SJMP	PIN2

PIN3:
	MOV	DPTR,#03CEH		; Start address in LCD memory
	MOV	A,QF
	SWAP	A
	ANL	A,#0FH
	SETB	INV
	LCALL	LCD_NUMBER
	LCALL	LCD_REFRESH		; Refresh LCD display data

WAIT_PIN3:
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT_PIN3
	CLR	ENC
	JB	RIGHT,PIN3_UP
	JB	LEFT,PIN3_DOWN

	MOV	DPTR,#03CEH		; Start address in LCD memory
	MOV	A,QF
	SWAP	A
	ANL	A,#0FH
	CLR	INV
	LCALL	LCD_NUMBER
	LJMP	PIN4

PIN3_UP:
	MOV	A,QF
	ANL	A,#0F0H
	CJNE	A,#090H,PIN3_UP1
	SUBB	A,#090H
	MOV	QF,A
	SJMP	PIN3
PIN3_UP1:
	MOV	A,QF
	ADD	A,#010H
	MOV	QF,A
	SJMP	PIN3

PIN3_DOWN:
	MOV	A,QF
	ANL	A,#0F0H
	CJNE	A,#0,PIN3_DOWN1
	ADD	A,#090H
	MOV	QF,A
	SJMP	PIN3
PIN3_DOWN1:
	MOV	A,QF
	CLR	C
	SUBB	A,#010H
	MOV	QF,A
	SJMP	PIN3

PIN4:
	MOV	DPTR,#03D4H		; Start address in LCD memory
	MOV	A,QF
	ANL	A,#0FH
	SETB	INV
	LCALL	LCD_NUMBER
	LCALL	LCD_REFRESH		; Refresh LCD display data

WAIT_PIN4:
	LCALL	ENCODER_CHECK
	JNB	ENC,WAIT_PIN4
	CLR	ENC
	JB	RIGHT,PIN4_UP
	JB	LEFT,PIN4_DOWN

	CLR	INV
	LJMP	PIN_CONT

PIN4_UP:
	MOV	A,QF
	ANL	A,#0FH
	CJNE	A,#9,PIN4_UP1
	SUBB	A,#009H
	MOV	QF,A
	SJMP	PIN4
PIN4_UP1:
	MOV	A,QF
	ADD	A,#001H
	MOV	QF,A
	SJMP	PIN4

PIN4_DOWN:
	MOV	A,QF
	ANL	A,#0FH
	CJNE	A,#0,PIN4_DOWN1
	ADD	A,#009H
	MOV	QF,A
	SJMP	PIN4
PIN4_DOWN1:
	MOV	A,QF
	CLR	C
	SUBB	A,#001H
	MOV	QF,A
	SJMP	PIN4

PIN_CONT:
	RET

;* ------------------------------------------------------------------------
;*  Function  :COPY_EQ
;*  Purpose   :Copy user eq data from ch1 to ch2
;*  Arguments :FREQ1,QF1,GAIN1,FREQ2,QF2,GAIN2,FREQ3,QF3,GAIN3,FREQ4,QF4,GAIN4
;*  Uses      :-
;*  Calls     :-
;*  Returns   :FREQ5,QF5,GAIN5,FREQ6,QF6,GAIN6,FREQ7,QF7,GAIN7,FREQ8,QF8,GAIN8
;* ------------------------------------------------------------------------
COPY_EQ:
	MOV	FREQ5,FREQ1
	MOV	QF5,QF1
	MOV	GAIN5,GAIN1
	MOV	C,CH1S1
	MOV	CH2S1,C

	MOV	FREQ6,FREQ2
	MOV	QF6,QF2
	MOV	GAIN6,GAIN2
	MOV	C,CH1S2
	MOV	CH2S2,C

	MOV	FREQ7,FREQ3
	MOV	QF7,QF3
	MOV	GAIN7,GAIN3
	MOV	C,CH1S3
	MOV	CH2S3,C

	MOV	FREQ8,FREQ4
	MOV	QF8,QF4
	MOV	GAIN8,GAIN4
	MOV	C,CH1S4
	MOV	CH2S4,C

	RET

;* ------------------------------------------------------------------------
;*  Function  :SETUP_EQ
;*  Purpose   :Load all data to DSP for user parametric eq
;*  Arguments :-
;*  Uses      :FREQ,QF,GAIN,DSP_OPCODE
;*  Calls     :DSP_LOAD_USER_EQ
;*  Returns   :-
;* ------------------------------------------------------------------------
SETUP_EQ:
	MOV	FREQ,FREQ1
	MOV	QF,QF1
	MOV	GAIN,GAIN1
	MOV	C,CH1S1
	MOV	BYP,C

	MOV	DSP_OPCODE,#012H	; DSP opcode for section1 data
	LCALL	DSP_LOAD_USER_EQ
	JNB	EQLINK,EQLINK_NEXT1
	MOV	DSP_OPCODE,#022H	; DSP opcode for section1 data
	LCALL	DSP_LOAD_USER_EQ
EQLINK_NEXT1:

	MOV	FREQ,FREQ2
	MOV	QF,QF2
	MOV	GAIN,GAIN2
	MOV	C,CH1S2
	MOV	BYP,C

	MOV	DSP_OPCODE,#013H	; DSP opcode for section2 data
	LCALL	DSP_LOAD_USER_EQ
	JNB	EQLINK,EQLINK_NEXT2
	MOV	DSP_OPCODE,#023H	; DSP opcode for section1 data
	LCALL	DSP_LOAD_USER_EQ
EQLINK_NEXT2:

	MOV	FREQ,FREQ3
	MOV	QF,QF3
	MOV	GAIN,GAIN3
	MOV	C,CH1S3
	MOV	BYP,C

	MOV	DSP_OPCODE,#014H	; DSP opcode for section3 data
	LCALL	DSP_LOAD_USER_EQ
	JNB	EQLINK,EQLINK_NEXT3
	MOV	DSP_OPCODE,#024H	; DSP opcode for section1 data
	LCALL	DSP_LOAD_USER_EQ
EQLINK_NEXT3:

	MOV	FREQ,FREQ4
	MOV	QF,QF4
	MOV	GAIN,GAIN4
	MOV	C,CH1S4
	MOV	BYP,C

	MOV	DSP_OPCODE,#015H	; DSP opcode for section4 data
	LCALL	DSP_LOAD_USER_EQ
	JNB	EQLINK,EQLINK_NEXT4
	MOV	DSP_OPCODE,#025H	; DSP opcode for section1 data
	LCALL	DSP_LOAD_USER_EQ
EQLINK_NEXT4:

	JNB	EQLINK,EQLINK_NEXT5
	RET
EQLINK_NEXT5:
	MOV	FREQ,FREQ5
	MOV	QF,QF5
	MOV	GAIN,GAIN5
	MOV	C,CH2S1
	MOV	BYP,C

	MOV	DSP_OPCODE,#022H	; DSP opcode for section1 data
	LCALL	DSP_LOAD_USER_EQ

	MOV	FREQ,FREQ6
	MOV	QF,QF6
	MOV	GAIN,GAIN6
	MOV	C,CH2S2
	MOV	BYP,C

	MOV	DSP_OPCODE,#023H	; DSP opcode for section2 data
	LCALL	DSP_LOAD_USER_EQ

	MOV	FREQ,FREQ7
	MOV	QF,QF7
	MOV	GAIN,GAIN7
	MOV	C,CH2S3
	MOV	BYP,C

	MOV	DSP_OPCODE,#024H	; DSP opcode for section3 data
	LCALL	DSP_LOAD_USER_EQ

	MOV	FREQ,FREQ8
	MOV	QF,QF8
	MOV	GAIN,GAIN8
	MOV	C,CH2S4
	MOV	BYP,C

	MOV	DSP_OPCODE,#025H	; DSP opcode for section4 data
	LCALL	DSP_LOAD_USER_EQ

	RET	


;* ------------------------------------------------------------------------
;*  Function  :SPEAKER_SETUP
;*  Purpose   :-
;*  Arguments :MOD1,MOD2,SPPRESET1,SPPRESET2,SPOPT,HCORR1,HCORR2,D_LOW1,D_MID1,D_HI1,D_LOW2,D_MID2,D_HI2,G_LOW1,G_HI1,G_LOW2,G_HI2,INPSET
;*  Uses      :A,B,2x DPTR,R0,COUNT1,COUNT2,I2C_TX,BYTECNTL,BYTECNTH,SLVADR,TEMP,OPCODE,OPCODE1,OPCODE2,OPCODE3,D_LOW,D_MID,D_HI,G_LOW,G_HI
;*  Calls     :LCD_CLEAR
;*	       LCD_ICON
;*	       LCD_TEXT
;*	       LCD_REFRESH
;*	       ENCODER_CHECK
;*	       LOW_CORRECTION
;*	       HIGH_CORRECTION
;*	       SP_TO_DSP
;*	       WRITE_SETTINGS
;*	       MUTE_DAC
;*	       SENDDATA
;*	       SP_TEST_ACTIVE
;*	       FLASH_OPCODE
;*	       SPI_RX
;*	       PRESET_MUTE
;*	       DSP_LOAD_PRESET
;*	       DSP_BYPASS_DELAY
;*	       DSP_LOAD_DELAY2
;*	       COPY_EQ
;*	       SETUP_EQ
;*	       DSP_LOAD_GAIN
;*	       DSP_ENABLE_INT
;*  Returns   :MOD1,MOD2,SPPRESET1,SPPRESET2,SPOPT,HCORR1,HCORR2,D_LOW1,D_MID1,D_HI1,D_LOW2,D_MID2,D_HI2,G_LOW1,G_HI1,G_LOW2,G_HI2,INPSET
;* ------------------------------------------------------------------------
SPEAKER_SETUP:
	CLR	GRAPH			; Temporarily use this bit
SPEAKER_SETUP1:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	JNB	PLOCK,NO_LOCK4
	MOV	DPTR,#03F9H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK_ICON
	LCALL	LCD_ICON
NO_LOCK4:

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPSET2
	JB	CHAN2,SP_SET_NEXT8
	MOV	DPTR,#SPSET1
SP_SET_NEXT8:
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LIN

	MOV	COUNT1,MOD2
	JB	CHAN2,SP_SET_NEXT3
	MOV	COUNT1,MOD1
SP_SET_NEXT3:
	MOV	A,COUNT1
	JZ	SP_SET_NEXT2
SP_SET_NEXT1A:
	MOV	COUNT2,#21
SP_SET_NEXT1:
	INC	DPTR
	DJNZ	COUNT2,SP_SET_NEXT1
	DJNZ	COUNT1,SP_SET_NEXT1A
SP_SET_NEXT2:
	LCALL	LCD_TEXT

	INC	0A2H			; Switch data pointers
	MOV	DPTR,#01BCH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	LCALL	LCD_TEXT

	JNB	PRMUTE,NO_PRMUTE1
	JNB	GRAPH,NO_PRMUTE1
	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#UMUTE
	LCALL	LCD_TEXT
NO_PRMUTE1:

	MOV	A,SPPRESET1
	JNB	CHAN2,CHAN2_3
	MOV	A,SPPRESET2
CHAN2_3:
	JB	ACC.0,L_CORR1
	JB	ACC.1,H_CORR1
	LJMP	SP_SETUP_MENU

H_CORR1:				; Only high correction
	MOV	DPTR,#0206H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE1
	MOV	DPTR,#0286H		; Start address in LCD memory
NO_UNMUTE1:
	INC	0A2H			; Switch data pointers
	MOV	C,HCORR1
	JNB	CHAN2,CHAN2_8
	MOV	C,HCORR2
CHAN2_8:

	MOV	DPTR,#FLOWN
	JNC	FLOWN1
	MOV	DPTR,#STACKED
FLOWN1:
	LCALL	LCD_TEXT
	LJMP	SP_SETUP_MENU

L_CORR1:
	JB	ACC.1,LH_CORR1
					; Only low correction
	MOV	DPTR,#0206H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE2
	MOV	DPTR,#0286H		; Start address in LCD memory
NO_UNMUTE2:
	INC	0A2H			; Switch data pointers

	SWAP	A
	ANL	A,#0FH

	CJNE	A,#0,NO_TYPE0_1
	MOV	DPTR,#ARRAYLEN0
	SJMP	TYPE_END1
NO_TYPE0_1:
	CJNE	A,#1,NO_TYPE1_1
	MOV	DPTR,#ARRAYLEN1
	SJMP	TYPE_END1
NO_TYPE1_1:
	CJNE	A,#2,NO_TYPE2_1
	MOV	DPTR,#ARRAYLEN2
	SJMP	TYPE_END1
NO_TYPE2_1:
	CJNE	A,#3,NO_TYPE3_1
	MOV	DPTR,#ARRAYLEN3
	SJMP	TYPE_END1
NO_TYPE3_1:
	CJNE	A,#4,NO_TYPE4_1
	MOV	DPTR,#ARRAYLEN4
	SJMP	TYPE_END1
NO_TYPE4_1:
	CJNE	A,#5,NO_TYPE5_1
	MOV	DPTR,#ARRAYLEN5
	SJMP	TYPE_END1
NO_TYPE5_1:
	CJNE	A,#6,NO_TYPE6_1
	MOV	DPTR,#ARRAYLEN6
	SJMP	TYPE_END1
NO_TYPE6_1:
	CJNE	A,#7,NO_TYPE7_1
	MOV	DPTR,#ARRAYLEN7
	SJMP	TYPE_END1
NO_TYPE7_1:
TYPE_END1:
	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_9
	SWAP	A
CHAN2_9:
	ANL	A,#00FH
	JZ	ARRAY3_1

	MOV	COUNT1,A
INC_PTR2:
	MOV	COUNT2,#14
INC_PTR1:
	INC	DPTR
	DJNZ	COUNT2,INC_PTR1
	DJNZ	COUNT1,INC_PTR2

ARRAY3_1:
	LCALL	LCD_TEXT
	JMP	SP_SETUP_MENU		

LH_CORR1:				; Low and high correction
	MOV	DPTR,#0206H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE3
	MOV	DPTR,#0286H		; Start address in LCD memory
NO_UNMUTE3:
	INC	0A2H			; Switch data pointers

	SWAP	A
	ANL	A,#0FH

	CJNE	A,#0,NO_TYPE0_2
	MOV	DPTR,#ARRAYLEN0
	JMP	TYPE_END2
NO_TYPE0_2:
	CJNE	A,#1,NO_TYPE1_2
	MOV	DPTR,#ARRAYLEN1
	JMP	TYPE_END2
NO_TYPE1_2:
	CJNE	A,#2,NO_TYPE2_2
	MOV	DPTR,#ARRAYLEN2
	JMP	TYPE_END2
NO_TYPE2_2:
	CJNE	A,#3,NO_TYPE3_2
	MOV	DPTR,#ARRAYLEN3
	JMP	TYPE_END2
NO_TYPE3_2:
	CJNE	A,#4,NO_TYPE4_2
	MOV	DPTR,#ARRAYLEN4
	JMP	TYPE_END2
NO_TYPE4_2:
	CJNE	A,#5,NO_TYPE5_2
	MOV	DPTR,#ARRAYLEN5
	JMP	TYPE_END2
NO_TYPE5_2:
	CJNE	A,#6,NO_TYPE6_2
	MOV	DPTR,#ARRAYLEN6
	JMP	TYPE_END2
NO_TYPE6_2:
	CJNE	A,#7,NO_TYPE7_2
	MOV	DPTR,#ARRAYLEN7
	JMP	TYPE_END2
NO_TYPE7_2:
TYPE_END2:
	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_11
	SWAP	A
CHAN2_11:
	ANL	A,#00FH
	JZ	ARRAY3_2

	MOV	COUNT1,A
INC_PTR4:
	MOV	COUNT2,#14
INC_PTR3:
	INC	DPTR
	DJNZ	COUNT2,INC_PTR3
	DJNZ	COUNT1,INC_PTR4

ARRAY3_2:
	LCALL	LCD_TEXT

	MOV	DPTR,#0286H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE4
	MOV	DPTR,#0306H		; Start address in LCD memory
NO_UNMUTE4:
	INC	0A2H			; Switch data pointers

	MOV	C,HCORR1
	JNB	CHAN2,CHAN2_12
	MOV	C,HCORR2
CHAN2_12:
	MOV	DPTR,#FLOWN
	JNC	FLOWN2
	MOV	DPTR,#STACKED
FLOWN2:
	LCALL	LCD_TEXT

SP_SETUP_MENU:
	JNB	GRAPH,SP_SETUP_1
	LJMP	SP_SETUP_5

SP_SETUP_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
SP_SETUP_1A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SP_SETUP_WAIT1:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SP_SETUP_WAIT1
	CLR	ENC
	JB	RIGHT,JUMP_OFF_SP_SETUP_1
	JB	LEFT,SP_SETUP_1A

SELECT_SP_SETUP_1:
	LJMP	SETUP12_MENU

JUMP_OFF_SP_SETUP_1:
	MOV	DPTR,#0100H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

SP_SETUP_2:
	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	PLOCK,CURSOR_9
	MOV	DPTR,#CURSOR
CURSOR_9:
	LCALL	LCD_TEXT

	JB	PLOCK,SP_SETUP_2A
	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PTCH
	LCALL	LCD_TEXT
SP_SETUP_2A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SP_SETUP_WAIT2:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SP_SETUP_WAIT2
	CLR	ENC
	JB	LEFT,CONT_JUMP_OFF_2
	JB	RIGHT,JUMP_OFF_SP_SETUP_2

SELECT_SP_SETUP_2:
	JB	PLOCK,SP_SETUP_2A
	LJMP	SP_SELECT

JUMP_OFF_SP_SETUP_2:
	MOV	A,SPPRESET1
	JNB	CHAN2,CHAN2_4
	MOV	A,SPPRESET2
CHAN2_4:
	JB	ACC.0,CONT_JUMP_OFF_2
	JB	ACC.1,CONT_JUMP_OFF_2
	JNB	GRAPH,SP_SETUP_2A

	JB	PLOCK,NO_LINE3
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BLANKLINE
	LCALL	LCD_TEXT
NO_LINE3:

	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	LJMP	SP_SETUP_5
CONT_JUMP_OFF_2:

	JB	PLOCK,NO_LINE4
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BLANKLINE
	LCALL	LCD_TEXT
NO_LINE4:

	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT

	JB	RIGHT,CONT_JUMP_OFF_2A
	LJMP	SP_SETUP_1
CONT_JUMP_OFF_2A:
	JNB	GRAPH,SP_SETUP_3	
	LJMP	SP_SETUP_5

SP_SETUP_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE5
	MOV	DPTR,#0280H		; Start address in LCD memory
NO_UNMUTE5:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	ALOCK,CURSOR_23
	MOV	DPTR,#CURSOR
CURSOR_23:
	LCALL	LCD_TEXT
SP_SETUP_3A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SP_SETUP_WAIT3:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SP_SETUP_WAIT3
	CLR	ENC
	JB	LEFT,CONT_JUMP_OFF_3
	JB	RIGHT,JUMP_OFF_SP_SETUP_3

SELECT_SP_SETUP_3:
	JB	ALOCK,SP_SETUP_3A
	MOV	A,SPPRESET1
	JNB	CHAN2,CHAN2_10
	MOV	A,SPPRESET2
CHAN2_10:
	JNB	ACC.0,HIGH_CORR1

	LCALL	LOW_CORRECTION
	LCALL	SP_TO_DSP
	LCALL	WRITE_SETTINGS
	SJMP	SP_SETUP_WAIT3

HIGH_CORR1:
	LCALL	HIGH_CORRECTION
	LCALL	SP_TO_DSP
	LCALL	WRITE_SETTINGS
	SJMP	SP_SETUP_WAIT3

JUMP_OFF_SP_SETUP_3:
	MOV	A,SPPRESET1
	JNB	CHAN2,CHAN2_5
	MOV	A,SPPRESET2
CHAN2_5:
	JNB	ACC.0,SP_SETUP_3A
	JNB	ACC.1,SP_SETUP_3A
CONT_JUMP_OFF_3:
	MOV	DPTR,#0200H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE6
	MOV	DPTR,#0280H		; Start address in LCD memory
NO_UNMUTE6:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,SP_SETUP_4
	JB	GRAPH,SP_SETUP_5
	LJMP	SP_SETUP_2

SP_SETUP_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE7
	MOV	DPTR,#0300H		; Start address in LCD memory
NO_UNMUTE7:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR2
	JB	ALOCK,CURSOR_24
	MOV	DPTR,#CURSOR
CURSOR_24:
	LCALL	LCD_TEXT
SP_SETUP_4A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SP_SETUP_WAIT4:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SP_SETUP_WAIT4
	CLR	ENC
	JB	LEFT,JUMP_OFF_SP_SETUP_4
	JB	RIGHT,SP_SETUP_4A

SELECT_SP_SETUP_4:
	JB	ALOCK,SP_SETUP_4A
	LCALL	HIGH_CORRECTION
	LCALL	SP_TO_DSP
	LCALL	WRITE_SETTINGS
	SJMP	SP_SETUP_WAIT4

JUMP_OFF_SP_SETUP_4:
	MOV	DPTR,#0280H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE8
	MOV	DPTR,#0300H		; Start address in LCD memory
NO_UNMUTE8:
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	LJMP	SP_SETUP_3

SP_SETUP_5:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT
SP_SETUP_5A:
	LCALL	LCD_REFRESH		; Refresh LCD display data	

SP_SETUP_WAIT5:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SP_SETUP_WAIT5
	CLR	ENC
	JB	LEFT,JUMP_OFF_SP_SETUP_5
	JB	PUS,SELECT_SP_SETUP_5

	MOV	A,SPPRESET1
	JNB	CHAN2,CHAN2_39
	MOV	A,SPPRESET2
CHAN2_39:
	JB	ACC.0,JUMP_OFF_SP_SETUP_5
	JB	ACC.1,JUMP_OFF_SP_SETUP_5
	SJMP	SP_SETUP_5A

SELECT_SP_SETUP_5:
	CLR	GRAPH
	LCALL	MUTE_DAC

	JB	CHAN2,UNMUTE_CH2

	CLR	MUTE1
	MOV	I2C_TX,#020H		; DSP opcode for unmute ch1
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	JB	ACTIVE,UNMUTE_CH2
	JB	STEREO,UNMUTE_CH2

	LCALL	WRITE_SETTINGS
	CLR	DAC_MUTE		; Unmute DA converter
	LJMP	SPEAKER_SETUP1

UNMUTE_CH2:
	CLR	MUTE2
	MOV	I2C_TX,#021H		; DSP opcode for unmute ch2
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	LCALL	WRITE_SETTINGS
	CLR	DAC_MUTE		; Unmute DA converter
	LJMP	SPEAKER_SETUP1

JUMP_OFF_SP_SETUP_5:
	MOV	DPTR,#0200H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPACE
	LCALL	LCD_TEXT
	JB	RIGHT,SP_SETUP_3B
	LJMP	SP_SETUP_2
SP_SETUP_3B:
	LJMP	SP_SETUP_3

SP_SELECT:
	MOV	TEMP,MOD2
	JB	CHAN2,SP_SEL_CH2
	MOV	TEMP,MOD1
SP_SEL_CH2:

SP_SELECT_LOOP:
	LCALL	LCD_CLEAR		; Clear LCD data RAM

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SPSET2
	JB	CHAN2,SP_SET_NEXT16
	MOV	DPTR,#SPSET1
SP_SET_NEXT16:
	LCALL	LCD_TEXT

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BACK
	LCALL	LCD_TEXT

	MOV	DPTR,#0180H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CURSOR
	LCALL	LCD_TEXT

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LIN

	MOV	COUNT1,TEMP
	MOV	A,COUNT1
	JZ	SP_SET_NEXT15
SP_SET_NEXT14A:
	MOV	COUNT2,#21
SP_SET_NEXT14:
	INC	DPTR
	DJNZ	COUNT2,SP_SET_NEXT14
	DJNZ	COUNT1,SP_SET_NEXT14A
SP_SET_NEXT15:
	SETB	INV
	LCALL	LCD_TEXT

	INC	0A2H			; Switch data pointers
	MOV	DPTR,#01BCH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	SETB	INV
	LCALL	LCD_TEXT

	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#TURN
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH		; Refresh LCD display data

SP_SELECT_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SP_SELECT_WAIT
	CLR	ENC
	JB	RIGHT,SP_SELECT_UP
	JB	PUS,SP_SELECT_BACK

SP_SELECT_DOWN:
	MOV	A,TEMP
	JNZ	SP_SELECT_DOWN1
	MOV	TEMP,#LAST_MODEL
	LCALL	SP_TEST_ACTIVE
	JNZ	SP_SELECT_DOWN
	LJMP	SP_SELECT_LOOP
SP_SELECT_DOWN1:
	DEC	TEMP
	LCALL	SP_TEST_ACTIVE
	JNZ	SP_SELECT_DOWN
	LJMP	SP_SELECT_LOOP

SP_SELECT_UP:
	MOV	A,TEMP
	CJNE	A,#LAST_MODEL,SP_SELECT_UP1
	MOV	TEMP,#0
	LCALL	SP_TEST_ACTIVE
	JNZ	SP_SELECT_UP
	LJMP	SP_SELECT_LOOP
SP_SELECT_UP1:
	INC	TEMP
	LCALL	SP_TEST_ACTIVE
	JNZ	SP_SELECT_UP
	LJMP	SP_SELECT_LOOP


SP_TEST_ACTIVE:
	JB	CHAN2,SP_TEST_ACTIVE1
	CLR	A
	RET

SP_TEST_ACTIVE1:
	MOV	A,TEMP

	MOV	OPCODE3,#000H		;
	JNB	ACC.0,FIRST_PRESET_IN_PAGE1
	MOV	OPCODE3,#084H		; Move to second preset in page
FIRST_PRESET_IN_PAGE1:

	ANL	A,#0FEH			; Clear bit0

	ADD	A,#01CH			; First preset in page 526 (/2)
	MOV	OPCODE2,A		;
					;
	MOV	A,#004H			;
	ADDC	A,#0			;
	MOV	OPCODE1,A		;

	CLR	C
	MOV	A,OPCODE3
	RLC	A
	MOV	OPCODE3,A

	MOV	A,OPCODE2
	RLC	A
	MOV	OPCODE2,A

	MOV	A,OPCODE1
	RLC	A
	MOV	OPCODE1,A

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get preset options data byte from FLASH
	MOV	A,SPIRDAT		; 

	ANL	A,#004H

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	RET


SP_SELECT_BACK:
	MOV	DPTR,#0380H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BLANKLINE
	LCALL	LCD_TEXT

	MOV	DPTR,#0386H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CONFIRM
	LCALL	LCD_TEXT

CONF_NO:
	MOV	DPTR,#03B6H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#NO
	SETB	INV
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH		; Refresh LCD display data

SP_SELECT_CONF_NO_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SP_SELECT_CONF_NO_WAIT
	CLR	ENC
	JB	RIGHT,CONF_YES
	JB	LEFT,SP_SELECT_CONF_NO_WAIT
	LJMP	SPEAKER_SETUP1

CONF_YES:
	MOV	DPTR,#03B6H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#YES
	SETB	INV
	LCALL	LCD_TEXT

	LCALL	LCD_REFRESH		; Refresh LCD display data

SP_SELECT_CONF_YES_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,SP_SELECT_CONF_YES_WAIT
	CLR	ENC
	JB	LEFT,CONF_NO
	JB	RIGHT,SP_SELECT_CONF_YES_WAIT

CONFIRMED:
	SETB	P_ALT
	JNB	PRMUTE,NO_PRMUTE2
	SETB	GRAPH
NO_PRMUTE2:

	LCALL	PRESET_MUTE
	JB	CHAN2,SP_CONF2
	MOV	MOD1,TEMP
	SJMP	SP_CONF1
SP_CONF2:
	MOV	MOD2,TEMP

SP_CONF1:
	LCALL	SP_TO_DSP
	LCALL	WRITE_SETTINGS
	LJMP	SPEAKER_SETUP1

SP_TO_DSP:
	LCALL	DSP_LOAD_PRESET		; Set x-over and limiters for selected speaker

COPY_SPEAKER_BIQ:
	MOV	A,SPPRESET1
	JNB	CHAN2,SP_CH21
	MOV	A,SPPRESET2
SP_CH21:
	JB	ACC.2,ACTIVE_SPEAKER
	LJMP	NO_ACTIVE_SPEAKER

ACTIVE_SPEAKER:
; Switch to active mode:
	SETB	ACTIVE
	CLR	STEREO

	MOV	A,ACT_2ND
	MOV	MOD2,A

	MOV	SPPRESET2,SPPRESET1

	MOV	A,SPOPT
	ANL	A,#00FH
	MOV	B,A
	SWAP	A
	ADD	A,B
	MOV	SPOPT,A

	MOV	C,HCORR1
	MOV	HCORR2,C

	SETB	CHAN2
	LCALL	DSP_LOAD_PRESET		; Set x-over and limiters for selected speaker
	CLR	CHAN2

	SETB	DLINK

	MOV	C,D_FINE1		;TEMP
	MOV	D_FINE,C		;TEMP
	MOV	D_LOW,D_LOW1
	MOV	D_MID,D_MID1
	MOV	D_HI,D_HI1

	MOV	C,D_FINE2		;TEMP
	MOV	D_FINE1,C		;TEMP
	MOV	D_LOW2,D_LOW1
	MOV	D_MID2,D_MID1
	MOV	D_HI2,D_HI1

	MOV	C,D1
	MOV	D2,C

	JB	D1,SET_DELAY6
	MOV	I2C_TX,#017H		; Get opcode for DSP
	LCALL	DSP_BYPASS_DELAY
	SJMP	SET_DELAY5
SET_DELAY6:
	LCALL	DSP_LOAD_DELAY2
SET_DELAY5:

	SETB	EQLINK
	LCALL	COPY_EQ

	MOV	C,EQ1
	MOV	EQ2,C

	MOV	I2C_TX,#02AH		; DSP opcode
	JB	EQ2,EQON9
	MOV	I2C_TX,#028H		; DSP opcode
EQON9:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	LCALL	SETUP_EQ

	MOV	C,MUTE1
	MOV	MUTE2,C

	MOV	I2C_TX,#019H		; low byte for DSP opcode
	JB	MUTE2,MUTE11
	MOV	I2C_TX,#021H		; low byte for DSP opcode
MUTE11:
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	MOV	G_LOW,G_LOW1
	MOV	G_HI,G_HI1

	MOV	G_LOW2,G_LOW1
	MOV	G_HI2,G_HI1

	MOV	DSP_OPCODE,#032H	; DSP opcode for CH2 output gain data
	LCALL	DSP_LOAD_GAIN

	MOV	I2C_TX,#047H		; low byte for DSP opcode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	MOV	A,INPSET
	ANL	A,#0F0H
	ORL	A,#005H
	MOV	INPSET,A

	LCALL	CHECK_ADC_STACKED

	LCALL	DSP_ENABLE_INT
	RET

NO_ACTIVE_SPEAKER:
	JB	CHAN2,SP_CH26
	JB	STEREO,COPY_SPEAKER_BIQ2 ; copy ch1 to ch2 in stereo or bridge mode
SP_CH26:
	JNB	ACTIVE,NO_ACTIVE_MODE
	JB	STEREO,NO_ACTIVE_MODE

; If in active mode, switch to dual channel mode:

	CLR	ACTIVE

	MOV	A,INPSET
	ANL	A,#0F0H
	ORL	A,#009H
	MOV	INPSET,A

	PUSH	DPL
	PUSH	DPH

	MOV	I2C_TX,#049H		; low byte for DSP opcode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	POP	DPH
	POP	DPL
	JB	CHAN2,COPY_SPEAKER_BIQ1

COPY_SPEAKER_BIQ2:
	MOV	MOD2,MOD1

	MOV	SPPRESET2,SPPRESET1

	MOV	A,SPOPT
	ANL	A,#00FH
	MOV	B,A
	SWAP	A
	ADD	A,B
	MOV	SPOPT,A

	MOV	C,HCORR1
	MOV	HCORR2,C

	SETB	CHAN2
;	LCALL	PRESET_MUTE
	LCALL	DSP_LOAD_PRESET		; Set x-over and limiters for selected speaker
	CLR	CHAN2

	LCALL	CHECK_ADC_STACKED

NO_ACTIVE_MODE:
	LCALL	DSP_ENABLE_INT
	RET

COPY_SPEAKER_BIQ1:
	MOV	MOD1,MOD2

	MOV	SPPRESET1,SPPRESET2

	MOV	A,SPOPT
	ANL	A,#0F0H
	MOV	B,A
	SWAP	A
	ADD	A,B
	MOV	SPOPT,A

	MOV	C,HCORR2
	MOV	HCORR1,C

	CLR	CHAN2
;	LCALL	PRESET_MUTE
	LCALL	DSP_LOAD_PRESET		; Set x-over and limiters for selected speaker
	SETB	CHAN2

	LCALL	CHECK_ADC_STACKED

	LCALL	DSP_ENABLE_INT
	RET

LOW_CORRECTION:
	MOV	DPTR,#0206H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE9
	MOV	DPTR,#0286H		; Start address in LCD memory
NO_UNMUTE9:
	INC	0A2H			; Switch data pointers

	MOV	A,SPPRESET1
	JNB	CHAN2,CHAN2_6
	MOV	A,SPPRESET2
CHAN2_6:
	SWAP	A
	ANL	A,#0FH

	CJNE	A,#0,NO_TYPE0_3
	MOV	DPTR,#ARRAYLEN0
	JMP	TYPE_END3
NO_TYPE0_3:
	CJNE	A,#1,NO_TYPE1_3
	MOV	DPTR,#ARRAYLEN1
	JMP	TYPE_END3
NO_TYPE1_3:
	CJNE	A,#2,NO_TYPE2_3
	MOV	DPTR,#ARRAYLEN2
	JMP	TYPE_END3
NO_TYPE2_3:
	CJNE	A,#3,NO_TYPE3_3
	MOV	DPTR,#ARRAYLEN3
	JMP	TYPE_END3
NO_TYPE3_3:
	CJNE	A,#4,NO_TYPE4_3
	MOV	DPTR,#ARRAYLEN4
	JMP	TYPE_END3
NO_TYPE4_3:
	CJNE	A,#5,NO_TYPE5_3
	MOV	DPTR,#ARRAYLEN5
	JMP	TYPE_END3
NO_TYPE5_3:
	CJNE	A,#6,NO_TYPE6_3
	MOV	DPTR,#ARRAYLEN6
	JMP	TYPE_END3
NO_TYPE6_3:
	CJNE	A,#7,NO_TYPE7_3
	MOV	DPTR,#ARRAYLEN7
	JMP	TYPE_END3
NO_TYPE7_3:
TYPE_END3:

	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_13
	SWAP	A
CHAN2_13:
	ANL	A,#00FH
	JZ	ARRAY3_3

	MOV	COUNT1,A
INC_PTR6:
	MOV	COUNT2,#14
INC_PTR5:
	INC	DPTR
	DJNZ	COUNT2,INC_PTR5
	DJNZ	COUNT1,INC_PTR6

ARRAY3_3:
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data	

LOW_CORR_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,LOW_CORR_WAIT
	CLR	ENC

	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_14
	SWAP	A
CHAN2_14:
	ANL	A,#00FH
	JB	LEFT,LOW_CORR_DOWN
	JB	RIGHT,LOW_CORR_UP

	MOV	DPTR,#0206H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE10
	MOV	DPTR,#0286H		; Start address in LCD memory
NO_UNMUTE10:
	INC	0A2H			; Switch data pointers

	MOV	B,A

	MOV	A,SPPRESET1
	JNB	CHAN2,CHAN2_7
	MOV	A,SPPRESET2
CHAN2_7:
	SWAP	A
	ANL	A,#0FH

	CJNE	A,#0,NO_TYPE0_4
	MOV	DPTR,#ARRAYLEN0
	JMP	TYPE_END4
NO_TYPE0_4:
	CJNE	A,#1,NO_TYPE1_4
	MOV	DPTR,#ARRAYLEN1
	JMP	TYPE_END4
NO_TYPE1_4:
	CJNE	A,#2,NO_TYPE2_4
	MOV	DPTR,#ARRAYLEN2
	JMP	TYPE_END4
NO_TYPE2_4:
	CJNE	A,#3,NO_TYPE3_4
	MOV	DPTR,#ARRAYLEN3
	JMP	TYPE_END4
NO_TYPE3_4:
	CJNE	A,#4,NO_TYPE4_4
	MOV	DPTR,#ARRAYLEN4
	JMP	TYPE_END4
NO_TYPE4_4:
	CJNE	A,#5,NO_TYPE5_4
	MOV	DPTR,#ARRAYLEN5
	JMP	TYPE_END4
NO_TYPE5_4:
	CJNE	A,#6,NO_TYPE6_4
	MOV	DPTR,#ARRAYLEN6
	JMP	TYPE_END4
NO_TYPE6_4:
	CJNE	A,#7,NO_TYPE7_4
	MOV	DPTR,#ARRAYLEN7
	JMP	TYPE_END4
NO_TYPE7_4:
TYPE_END4:

	MOV	A,B
	JZ	ARRAY3_4

	MOV	COUNT1,A
INC_PTR8:
	MOV	COUNT2,#14
INC_PTR7:
	INC	DPTR
	DJNZ	COUNT2,INC_PTR7
	DJNZ	COUNT1,INC_PTR8

ARRAY3_4:
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data
	
	RET

LOW_CORR_DOWN:
	JZ	LOW_CORR_DOWN_CONT
	SETB	P_ALT
	DEC	A
	SJMP	LOW_CORRECTION_END

LOW_CORR_DOWN_CONT:
	LJMP	LOW_CORR_WAIT

LOW_CORR_UP:
	MOV	B,A
	CLR	A
	MOVC	A,@A+DPTR		; ASCII value in A
	CJNE	A,#'|',LOW_CORR_UP1
	MOV	A,B
	LJMP	LOW_CORR_WAIT
LOW_CORR_UP1:
	MOV	A,B
	SETB	P_ALT
	INC	A

LOW_CORRECTION_END:
	MOV	B,A
	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_15
	SWAP	A
CHAN2_15:
	ANL	A,#0F0H
	ADD	A,B
	JNB	CHAN2,CHAN2_17
	SWAP	A
CHAN2_17:
	MOV	SPOPT,A

	JNB	ACTIVE,LOW_CORRECTION1
	JB	STEREO,LOW_CORRECTION1
	MOV	A,SPPRESET1
	JNB	ACC.2,LOW_CORRECTION1

	JB	CHAN2,CHAN2_31
	MOV	A,SPOPT
	ANL	A,#00FH
	MOV	B,A
	SWAP	A
	ADD	A,B
	MOV	SPOPT,A
	SJMP	LOW_CORRECTION1
CHAN2_31:
	MOV	A,SPOPT
	ANL	A,#0F0H
	MOV	B,A
	SWAP	A
	ADD	A,B
	MOV	SPOPT,A
LOW_CORRECTION1:
	LJMP	LOW_CORRECTION

HIGH_CORRECTION:
	MOV	A,SPPRESET1
	JNB	CHAN2,CHAN2_16
	MOV	A,SPPRESET2
CHAN2_16:
	MOV	DPTR,#0206H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE11
	MOV	DPTR,#0286H		; Start address in LCD memory
NO_UNMUTE11:
	JNB	ACC.0,HI_CORR1
	MOV	DPTR,#0286H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE12
	MOV	DPTR,#0306H		; Start address in LCD memory
NO_UNMUTE12:
HI_CORR1:
	INC	0A2H			; Switch data pointers

	MOV	C,HCORR1
	JNB	CHAN2,CHAN2_18
	MOV	C,HCORR2
CHAN2_18:
	MOV	DPTR,#FLOWN
	JNC	FLOWN3
	MOV	DPTR,#STACKED
FLOWN3:
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

HIGH_CORR_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,HIGH_CORR_WAIT
	CLR	ENC
	JB	LEFT,HIGH_CORR_DOWN
	JB	RIGHT,HIGH_CORR_UP

	MOV	A,SPPRESET1
	JNB	CHAN2,CHAN2_19
	MOV	A,SPPRESET2
CHAN2_19:
	MOV	DPTR,#0206H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE13
	MOV	DPTR,#0286H		; Start address in LCD memory
NO_UNMUTE13:
	JNB	ACC.0,HI_CORR2
	MOV	DPTR,#0286H		; Start address in LCD memory
	JNB	GRAPH,NO_UNMUTE14
	MOV	DPTR,#0306H		; Start address in LCD memory
NO_UNMUTE14:
HI_CORR2:
	INC	0A2H			; Switch data pointers

	MOV	C,HCORR1
	JNB	CHAN2,CHAN2_30
	MOV	C,HCORR2
CHAN2_30:
	MOV	DPTR,#FLOWN
	JNC	FLOWN4
	MOV	DPTR,#STACKED
FLOWN4:
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

	RET


HIGH_CORR_DOWN:
	SETB	P_ALT
	JB	CHAN2,CHAN2_20
	CLR	HCORR1
	SJMP	HIGH_CORR_END
CHAN2_20:
	CLR	HCORR2
	SJMP	HIGH_CORR_END

HIGH_CORR_UP:
	SETB	P_ALT
	JB	CHAN2,CHAN2_21
	SETB	HCORR1
	SJMP	HIGH_CORR_END
CHAN2_21:
	SETB	HCORR2

HIGH_CORR_END:
	JNB	ACTIVE,HIGH_CORRECTION1
	JB	STEREO,HIGH_CORRECTION1
	MOV	A,SPPRESET1
	JNB	ACC.2,HIGH_CORRECTION1

	JB	CHAN2,CHAN2_32
	MOV	C,HCORR1
	MOV	HCORR2,C
	SJMP	HIGH_CORRECTION1
CHAN2_32:
	MOV	C,HCORR2
	MOV	HCORR1,C

HIGH_CORRECTION1:
	LJMP	HIGH_CORRECTION

;* ------------------------------------------------------------------------
;*  Function  :ENTER_GAIN
;*  Purpose   :Enter gain data of 1 channel on LCD
;*  Arguments :G_LOW,G_HI
;*  Uses      :A,DSP_OPCODE,
;*  Calls     :GAIN_DATA
;*	       LCD_REFRESH
;*	       DSP_LOAD_GAIN
;*	       ENCODER_CHECK
;*  Returns   :G_LOW,G_HI
;* ------------------------------------------------------------------------
ENTER_GAIN:
	SETB	INV
	LCALL	GAIN_DATA		; Display gain on LCD
	LCALL	LCD_REFRESH		; Refresh LCD display data

	MOV	DSP_OPCODE,#032H	; DSP opcode for CH2 output gain data
	JB	CHAN2,SET_GAIN_CH2
	MOV	DSP_OPCODE,#031H	; DSP opcode for CH1 output gain data
SET_GAIN_CH2:
	LCALL	DSP_LOAD_GAIN

	JB	CHAN2,GAIN_WAIT
	JB	STEREO,GAIN_LINK
	JB	ACTIVE,GAIN_LINK	
	SJMP	GAIN_WAIT
GAIN_LINK:
	MOV	DSP_OPCODE,#032H	; DSP opcode for CH2 output gain data
	LCALL	DSP_LOAD_GAIN

GAIN_WAIT:
	LCALL	ENCODER_CHECK
	JNB	ENC,GAIN_WAIT
	CLR	ENC
	JB	LEFT,GAIN_DOWN2
	JB	RIGHT,GAIN_UP2

	LCALL	GAIN_DATA		; Display gain on LCD
	LCALL	LCD_REFRESH		; Refresh LCD display data

	RET

GAIN_UP2:
	DEC	G_LOW
	MOV	A,G_LOW
	CJNE	A,#003,GAIN_OVER3
	SJMP	GAIN_OVER4
GAIN_OVER3:
	CJNE	A,#0FFH,GAIN_OVER2
	MOV	G_LOW,#09H
	DEC	G_HI
	LJMP	END_GAIN

GAIN_OVER4:
	MOV	A,G_HI
	CJNE	A,#000,GAIN_OVER2
	MOV	G_LOW,#04H
GAIN_OVER2:
	LJMP	END_GAIN


GAIN_DOWN2:
	INC	G_LOW
	MOV	A,G_LOW
	CJNE	A,#0AH,GAIN_OVER1

	MOV	G_LOW,#00H
	INC	G_HI
GAIN_OVER1:
	MOV	A,G_HI
	CJNE	A,#07H,END_GAIN_DOWN
	MOV	A,G_LOW
	JZ	END_GAIN_DOWN 
	DEC	A
	JZ	END_GAIN_DOWN
	DEC	A
	JZ	END_GAIN_DOWN

	MOV	G_LOW,#02H
	MOV	G_HI,#07H
END_GAIN_DOWN:

END_GAIN:
	SETB	P_ALT

	PUSH	DPL
	PUSH	DPH

	MOV	A,PRESET
	JZ	OVER_ALT3

	MOV	DPTR,#0078H		; Start address in LCD memory
	SETB	INV
	MOV	A,#'*'
	LCALL	LCD_CHAR
	CLR	INV
OVER_ALT3:

	POP	DPH
	POP	DPL

	LJMP	ENTER_GAIN

;* ------------------------------------------------------------------------
;*  Function  :GAIN_DATA
;*  Purpose   :Display gain data of 1 channel on LCD
;*  Arguments :G_HI,G_LOW,GAINREL
;*  Uses      :A
;*  Calls     :LCD_CHAR
;*	       LCD_NUMBER
;*	       LCD_TEXT
;*  Returns   :-
;* ------------------------------------------------------------------------
GAIN_DATA:
	PUSH	DPL
	PUSH	DPH

;	JNB	GAINREL,GAIN_DATAR	;WAS ABSOLUTE
;	LJMP	GAIN_DATAR	;WAS RELATIVE!!!

GAIN_DATAR:
	MOV	A,G_HI
	JZ	GAIN_NEXT2
	CJNE	A,#1,MINUS
	MOV	A,G_LOW
	JZ	NO_MINUS

MINUS:
	MOV	A,#'-'
	LCALL	LCD_CHAR

NO_MINUS:
	MOV	A,G_HI
	DEC	A
	JZ	GAIN_NEXT1
	LCALL	LCD_NUMBER
GAIN_NEXT1:

	MOV	A,G_LOW
	LCALL	LCD_NUMBER
	SJMP	GAIN_NEXT3

GAIN_NEXT2:
	MOV	A,#'+'
	LCALL	LCD_CHAR

	MOV	A,#10
	CLR	C
	SUBB	A,G_LOW
	CJNE	A,#10,GAIN_NEXT4
	MOV	A,#1
	LCALL	LCD_NUMBER
	CLR	A
	LCALL	LCD_NUMBER
	SJMP	GAIN_NEXT3
GAIN_NEXT4:
	LCALL	LCD_NUMBER


GAIN_NEXT3:
	CLR	INV
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DECIBR
	LCALL	LCD_TEXT
	INC	0A2H			; Switch data pointers


	POP	DPH
	POP	DPL

	RET

;* ------------------------------------------------------------------------
;*  Function  :DELAY_DATA
;*  Purpose   :Display delay data of 1 channel on LCD
;*  Arguments :2x DPTR,D_HI,D_MID,D_LOW,DUNIT,DABS,D_FINE
;*  Uses      :A,GRAPH1,GRAPH2,GRAPH3
;*  Calls     :LCD_NUMBER
;*	       LCD_CHAR
;*	       LCD_TEXT
;*  Returns   :-
;* ------------------------------------------------------------------------

DELAY_DATA:
	MOV	GRAPH3,D_HI
	MOV	GRAPH2,D_MID
	MOV	GRAPH1,D_LOW

	JB	DUNIT,DELAY_METERS

	JB	DABS,DELAY_NEXT6
	JB	D_FINE,DELAY_NEXT5
	MOV	A,GRAPH1
	DEC	A
	MOV	GRAPH1,A
	CJNE	A,#0FFH,DELAY_NEXT6
	MOV	GRAPH1,#9
	MOV	A,GRAPH2
	DEC	A
	MOV	GRAPH2,A
	CJNE	A,#0FFH,DELAY_NEXT6
	MOV	GRAPH2,#9
	MOV	A,GRAPH3
	DEC	A
	MOV	GRAPH3,A
	SJMP	DELAY_NEXT6
DELAY_NEXT5:
	MOV	A,GRAPH2
	DEC	A
	MOV	GRAPH2,A
	CJNE	A,#0FFH,DELAY_NEXT6
	MOV	GRAPH2,#9
	MOV	A,GRAPH3
	DEC	A
	MOV	GRAPH3,A
DELAY_NEXT6:
	
	MOV	A,GRAPH3
	JZ	DELAY_NEXT1
	LCALL	LCD_NUMBER
	MOV	A,GRAPH2
	SJMP	DELAY_NEXT3
DELAY_NEXT1:

	MOV	A,GRAPH2
	JB	D_FINE,DELAY_NEXT3
	JZ	DELAY_NEXT2
DELAY_NEXT3:
	LCALL	LCD_NUMBER
DELAY_NEXT2:

	JNB	D_FINE,D_FINE8
	MOV	A,#'.'
	LCALL	LCD_CHAR
D_FINE8:

	MOV	A,GRAPH1
	LCALL	LCD_NUMBER

	CLR	INV
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MS
	LCALL	LCD_TEXT
	INC	0A2H			; Switch data pointers

	RET

DELAY_METERS:
	JB	DABS,DELAY_NEXT8
	JB	D_FINE,DELAY_NEXT7
	MOV	A,GRAPH1
	CLR	C
	SUBB	A,#3
	MOV	GRAPH1,A
	JNC	DELAY_NEXT8
	ADD	A,#10
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	DEC	A
	MOV	GRAPH2,A
	CJNE	A,#0FFH,DELAY_NEXT8
	MOV	GRAPH2,#9
	MOV	A,GRAPH3
	DEC	A
	MOV	GRAPH3,A
	SJMP	DELAY_NEXT8
DELAY_NEXT7:
	MOV	A,GRAPH1
	CLR	C
	SUBB	A,#4
	MOV	GRAPH1,A
	JNC	DELAY_NEXT9
	ADD	A,#10
	MOV	GRAPH1,A
DELAY_NEXT9:

	MOV	A,GRAPH2
	SUBB	A,#3
	MOV	GRAPH2,A
	JNC	DELAY_NEXT8
	ADD	A,#10
	MOV	GRAPH2,A
	MOV	A,GRAPH3
	DEC	A
	MOV	GRAPH3,A
DELAY_NEXT8:

	MOV	A,GRAPH3
	JB	D_FINE,D_FINE3
	JZ	DELAY_NEXT4
D_FINE3:
	LCALL	LCD_NUMBER
DELAY_NEXT4:

	JNB	D_FINE,D_FINE4
	MOV	A,#'.'
	LCALL	LCD_CHAR
D_FINE4:

	MOV	A,GRAPH2
	LCALL	LCD_NUMBER

	JB	D_FINE,D_FINE7
	MOV	A,#'.'
	LCALL	LCD_CHAR
D_FINE7:

	MOV	A,GRAPH1
	LCALL	LCD_NUMBER

	CLR	INV
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#M
	LCALL	LCD_TEXT
	INC	0A2H			; Switch data pointers


	RET

;* ------------------------------------------------------------------------
;*  Function  :EQ_DATA
;*  Purpose   :Display data for one parametric section
;*  Arguments :FREQ,Q,GAIN
;*  Uses      :A,2x DPTR,R7
;*  Calls     :LCD_TEXT
;*	       LCD_REFRESH
;*  Returns   :-
;* ------------------------------------------------------------------------
EQ_DATA:

	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#BYPASS
	JB	BYP,EQ_OVER3
	MOV	DPTR,#ON
EQ_OVER3:
	LCALL	LCD_TEXT

	MOV	DPTR,#00C8H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#F
	LCALL	LCD_TEXT

	MOV	DPTR,#0148H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#Q
	LCALL	LCD_TEXT

	MOV	DPTR,#01C8H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#G
	LCALL	LCD_TEXT

	MOV	DPTR,#00D4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#FREQ_TABLE

	MOV	R7,#05H			; Multiply index by 5
MUL7:
	MOV	A,DPL
	ADD	A,FREQ
	MOV	DPL,A
	MOV	A,DPH
	ADDC	A,#00H
	MOV	DPH,A
	DJNZ	R7,MUL7

	LCALL	LCD_TEXT

	INC	0A2H			; Switch data pointers
	DEC	DPL
	INC	0A2H			; Switch data pointers	

	MOV	DPTR,#HZ
	MOV	A,FREQ
	CLR	C
	SUBB	A,#68
	JC	UNIT_HZ1
	MOV	DPTR,#KHZ
UNIT_HZ1:
	LCALL	LCD_TEXT


	MOV	DPTR,#0154H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#Q_TABLE

	MOV	R7,#04H			; Multiply index by 4
MUL8:
	MOV	A,DPL
	ADD	A,QF
	MOV	DPL,A
	MOV	A,DPH
	ADDC	A,#00H
	MOV	DPH,A
	DJNZ	R7,MUL8

	LCALL	LCD_TEXT	

	MOV	DPTR,#01D4H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#GAIN_TABLE

	MOV	A,GAIN
	JNZ	NO_NOTCH
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data
	RET
	       
NO_NOTCH:
	MOV	R7,#06H			; Multiply index by 6
MUL9:
	MOV	A,DPL
	ADD	A,GAIN
	MOV	DPL,A
	MOV	A,DPH
	ADDC	A,#00H
	MOV	DPH,A
	DJNZ	R7,MUL9

	LCALL	LCD_TEXT

	MOV	A,GAIN
	JZ	NOTCH1

	INC	0A2H			; Switch data pointers
	DEC	DPL
	INC	0A2H			; Switch data pointers

	MOV	DPTR,#DECIB2
	LCALL	LCD_TEXT
NOTCH1:
	LCALL	LCD_REFRESH		; Refresh LCD display data

	RET

;* ------------------------------------------------------------------------
;*  Function  :BACKLIGHT_INT
;*  Purpose   :Set backlight intensity
;*  Arguments :LIGHT
;*  Uses      :A,DPTR,R4
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
BACKLIGHT_INT:
	MOV	A,LIGHT
	ANL	A,#0FH
	JZ	BACKLIGHT_OFF
	CLR	BCKLGHT1
	CLR	BCKLGHT2
	CLR	BCKLGHT3
	CLR	BCKLGHT4
	MOV	R4,A
	MOV	DPTR,#LIGHT_TABLE
BACKL_COUNT:
	INC	DPTR
	DJNZ	R4,BACKL_COUNT
	CLR	A
	MOVC	A,@A+DPTR		; Get data byte from DATA memory

	MOV	0F1H,A			; Set LED output in LEDCON
	RET

BACKLIGHT_OFF:
	SETB	BCKLGHT1
	SETB	BCKLGHT2
	SETB	BCKLGHT3
	SETB	BCKLGHT4
	RET

;* ------------------------------------------------------------------------
;*  Function  :LCD_CONTRAST
;*  Purpose   :Set LCD contrast
;*  Arguments :-
;*  Uses      :A,DPTR,R3
;*  Calls     :LCD_SEND_BYTE
;*  Returns   :-
;* ------------------------------------------------------------------------
LCD_CONTRAST:
	MOV	A,#081H			;
	LCALL	LCD_SEND_BYTE		; LCD electronic volume register set

	MOV	DPTR,#CONTR_TABLE
	MOV	A,CONTR
	JZ	CONTR_OVER
	MOV	R3,CONTR
CONTR_COUNT:
	INC	DPTR
	DJNZ	R3,CONTR_COUNT
CONTR_OVER:
	CLR	A
	MOVC	A,@A+DPTR		; Get data byte from DATA memory
	LCALL	LCD_SEND_BYTE		; LCD electronic volume register set

	RET


;* ------------------------------------------------------------------------
;*  Function  :INIT_LCD
;*  Purpose   :Initialise LCD controller
;*  Arguments :-
;*  Uses      :A
;*  Calls     :LCD_SEND_BYTE
;*  Returns   :-
;* ------------------------------------------------------------------------
INIT_LCD:
	SETB	LCD_CS			; LCD chip select

	MOV	A,#0E2H			;
	LCALL	LCD_SEND_BYTE		; LCD reset

	MOV	A,#0A2H			;
	LCALL	LCD_SEND_BYTE		; LCD bias set

;	MOV	A,#0A0H			; Display normal
	MOV	A,#0A1H			; Display upside down
	LCALL	LCD_SEND_BYTE		; LCD ADC select

;	MOV	A,#0C8H			; Display normal
	MOV	A,#0C0H			; Display upside down
	LCALL	LCD_SEND_BYTE		; LCD common output mode select

	MOV	A,#027H			;
	LCALL	LCD_SEND_BYTE		; LCD V0 voltage regulator resistor ratio set

	LCALL	LCD_CONTRAST		; LCD electronic volume register set

	MOV	A,#02FH			;
	LCALL	LCD_SEND_BYTE		; LCD power control set

	MOV	A,#0F8H			;
	LCALL	LCD_SEND_BYTE		; LCD booster ratio set

	MOV	A,#001H			;
	LCALL	LCD_SEND_BYTE		; LCD booster ratio set

	MOV	A,#040H			;
	LCALL	LCD_SEND_BYTE		; LCD Display start line set

	MOV	A,#0AFH			;
	LCALL	LCD_SEND_BYTE		; LCD Display on

	RET

;* ------------------------------------------------------------------------
;*  Function  :INIT_ADC
;*  Purpose   :Initialise AD & DA converters
;*  Arguments :-
;*  Uses      :R5
;*  Calls     :LWAIT
;*  Returns   :-
;* ------------------------------------------------------------------------
INIT_ADC:

	CLR	CNV_RST			; ADC/DAC reset	
	MOV	R5,#1
	LCALL	LWAIT
	SETB	CNV_RST			; release ADC/DAC reset

	MOV	R5,#00H			; Wait for ADC to complete reset and provide stable clocks
	LCALL	LWAIT			;
	LCALL	LWAIT			;
	LCALL	LWAIT			;
	LCALL	LWAIT			;

	RET

;* ------------------------------------------------------------------------
;*  Function  :INIT_DSP
;*  Purpose   :Initialise DSP
;*  Arguments :-
;*  Uses      :R1
;*  Calls     :LWAIT
;*  Returns   :-
;* ------------------------------------------------------------------------
INIT_DSP:
	CLR	DSP_RST			; DSP reset	
	MOV	R5,#1
	LCALL	LWAIT
	SETB	DSP_RST			; release DSP reset
	MOV	R5,#1
	LCALL	LWAIT
	RET

;* ------------------------------------------------------------------------
;*  Function  :INIT_SPI
;*  Purpose   :Initialise SPI interface
;*  Arguments :-
;*  Uses      :-
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
INIT_SPI:
;	MOV	0C3H,#0B2H		; Init SPCON
	MOV	0C3H,#031H		; Init SPCON
	ORL	0B1H,#004H		; Enable SPI interrupt in IEN1
	ORL	0B3H,#004H		; Set SPI interrupt priority in IPH1
	ORL	0B2H,#004H		; Set SPI interrupt priority in IPL1
	CLR	SPITXC			; Clear flag
	ORL	0C3H,#040H		; Enable SPI
	RET		

;* ------------------------------------------------------------------------
;*  Function  :DSP_READ_GRAPH
;*  Purpose   :Read parametric eq graph data from dsp and display on LCD
;*  Arguments :I2C_TX
;*  Uses      :A,2x DPTR,R0,R6,R7,BYTECNTL,BYTECNTLH,SLVADR,GRAPH1,GRAPH2,GRAPH3,GRAPH4
;*  Calls     :LCD_EQGRAPH_CLEAR
;*	       LCD_ICON
;*	       SENDDATA
;*	       GOMASTER
;*	       RCVBYTE
;*	       SENDSTOP
;*  Returns   :-
;* ------------------------------------------------------------------------
DSP_READ_GRAPH:
	LCALL	LCD_EQGRAPH_CLEAR

	MOV	DPTR,#0380H		; Start address in LCD ERAM
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQ_ICON4
	LCALL	LCD_ICON

	MOV	DPTR,#03A0H		; Start address in LCD ERAM
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQ_ICON5
	LCALL	LCD_ICON

	MOV	DPTR,#03CBH		; Start address in LCD ERAM
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQ_ICON6
	LCALL	LCD_ICON

	MOV	DPTR,#03EEH		; Start address in LCD ERAM
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#EQ_ICON7
	LCALL	LCD_ICON

	MOV	DPTR,#028AH		; Start address in LCD ERAM
	MOV	R6,#59
	MOV	A,#020H
X_AXIS:					; Plot X-axis
	MOVX	@DPTR,A
	INC	DPTR
	INC	DPTR
	NOP
	DJNZ	R6,X_AXIS

	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	INC	SLVADR			; Set slave address for reading
	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JNB	NOACK,CONT2		; Check for slave not responding
	LJMP	EXIT3
CONT2:
	MOV	DPTR,#020AH		; Start address in LCD ERAM
	PUSH	DPL
	PUSH	DPH

	MOV	BYTECNTL,#076H		; Set counters to receive 118 bytes
	MOV	BYTECNTH,#01H		; 

GRAPH_FROM_DSP_LOOP:
	LCALL	RCVBYTE			; Receive low data byte from DSP
	DEC	A			; Graph index in a

	MOV	GRAPH1,#00H		; Reset graph bytes
	MOV	GRAPH2,#00H
	MOV	GRAPH3,#020H
	MOV	GRAPH4,#00H

	MOV	R7,A
	CLR	C
	SUBB	A,#12
	JZ	OVER1
	JC	LOOP_DOWN
	MOV	R7,A

BIT_LOOP_UP:				; Shift graph column data R7 times up
	CLR	C
	MOV	A,GRAPH3
	JB	CHAN2,EQ_CH21
	JNB	EQ1,EQ_BYP1
	SJMP	EQ_NO_BYP1
EQ_CH21:
	JNB	EQ2,EQ_BYP1
EQ_NO_BYP1:
	ADD	A,#040H
EQ_BYP1:
	RRC	A
	MOV	GRAPH3,A

	MOV	A,GRAPH4
	RRC	A
	MOV	GRAPH4,A

	DJNZ	R7,BIT_LOOP_UP
	SJMP	OVER1

LOOP_DOWN:
	MOV	A,#12
	CLR	C
	SUBB	A,R7
	MOV	R7,A

BIT_LOOP_DOWN:				; Shift graph column data R7 times down
	CLR	C
	MOV	A,GRAPH3

	JB	CHAN2,EQ_CH22
	JNB	EQ1,EQ_BYP2
	SJMP	EQ_NO_BYP2
EQ_CH22:
	JNB	EQ2,EQ_BYP2
EQ_NO_BYP2:
	ADD	A,#010H
EQ_BYP2:
	RLC	A
	MOV	GRAPH3,A

	MOV	A,GRAPH2
	RLC	A
	MOV	GRAPH2,A

	MOV	A,GRAPH1
	RLC	A
	MOV	GRAPH1,A

	DJNZ	R7,BIT_LOOP_DOWN

OVER1:

	MOV	R7,#04H				; Graph is 4 lines on LCD
	MOV	R0,#GRAPH4

EQ_DISPLAY_GRAPH:
	MOVX	A,@DPTR
	ORL	A,@R0
	MOVX	@DPTR,A				; Move data to LCD ERAM

	INC	R0				; Next graph byte

	MOV	A,DPL				; Move DPTR to next line
	ADD	A,#080H				;
	MOV	DPL,A				;
	MOV	A,DPH				;
	ADDC	A,#00H				;
	MOV	DPH,A				;

	DJNZ	R7,EQ_DISPLAY_GRAPH

	POP	DPH
	POP	DPL
	INC	DPTR				;
	PUSH	DPL
	PUSH	DPH

	DJNZ	BYTECNTL,GRAPH_FROM_DSP_LOOP1
	DJNZ	BYTECNTH,GRAPH_FROM_DSP_LOOP1

	POP	DPH
	POP	DPL

EXIT3:	LCALL	SENDSTOP			; Done, send an I2C stop condition

	JNB	ALOCK,NO_LOCK6
	MOV	DPTR,#03F9H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#LOCK_ICON
	LCALL	LCD_ICON
NO_LOCK6:
	RET

GRAPH_FROM_DSP_LOOP1:
	LJMP	GRAPH_FROM_DSP_LOOP

;* ------------------------------------------------------------------------
;*  Function  :READ_SETTINGS
;*  Purpose   :Read settings from FLASH memory at startup
;*  Arguments :-
;*  Uses      :A,2x DPTR,R1,OPCODE,OPCODE1,OPCODE2,OPCODE3
;*  Calls     :FLASH_OPCODE
;*	       SPI_RX
;*	       LCD_CLEAR
;*	       LCD_TEXT
;*	       LCD_REFRESH
;*  Returns   :-
;* ------------------------------------------------------------------------
READ_SETTINGS:
	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#00H		; Start at PAGE19
	MOV	OPCODE2,#04CH		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get ID page address high byte
	MOV	PGADDH,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get ID page address low byte
	MOV	PGADDL,SPIRDAT		; Move received data

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,PGADDH		; Start at PAGE??
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get ID code from FLASH
	MOV	A,SPIRDAT		; Move received data to A
	CJNE	A,#FIRMWARE,READ_SETTINGS1

	LCALL	SPI_RX			; Discard burncounters
	LCALL	SPI_RX			; 

	MOV	R1,#FLAGS5

SETTINGS_LOOP2:
	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	MOV	@R1,A
	INC	R1
	CJNE	R1,#PGADDL,SETTINGS_LOOP2

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LJMP	START1

READ_SETTINGS1:

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LCALL	LCD_CLEAR		; Clear LCD data RAM
	MOV	DPTR,#0184H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#PRESERROR
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

	SJMP	$

;* ------------------------------------------------------------------------
;*  Function  :WRITE_SETTINGS
;*  Purpose   :Write settings to FLASH memory
;*  Arguments :#FIRMWARE
;*  Uses      :A,R1,OPCODE,OPCODE1,OPCODE2,OPCODE3,PGADDL,PGADDH
;*  Calls     :FLASH_OPCODE
;*	       SPI_RX
;*	       SPI_TX
;*  Returns   :BURNCL,BURNCH,PGADDL,PGADDH
;* ------------------------------------------------------------------------
WRITE_SETTINGS:
	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#00H		; Start at PAGE19
	MOV	OPCODE2,#04CH		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get page address high byte
	MOV	PGADDH,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get page address low byte
	MOV	PGADDL,SPIRDAT		; Move received data

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,PGADDH		; Start at PAGE...
	MOV	OPCODE2,PGADDL		;
;	MOV	OPCODE3,#004H		; 
	MOV	OPCODE3,#001H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get page address high byte
	MOV	BURNCH,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get page address low byte
	MOV	BURNCL,SPIRDAT		; Move received data

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,BURNCL		; Increase burncounter by 1
	ADD	A,#001H			;
	MOV	BURNCL,A		;
	MOV	A,BURNCH		;
	ADDC	A,#000H			;
	MOV	BURNCH,A		;

	JNC	NO_BURN_LIMIT		; Count burncycles until 65535, then advance to next page

	MOV	A,PGADDL		; Increase page address by 4 (1 page)
	ADD	A,#004H			;
	MOV	PGADDL,A		;
	MOV	A,PGADDH		;
	ADDC	A,#000H			;
	MOV	PGADDH,A		;
	JNB	ACC.2,NO_PAGE_LIMIT	; Count pages until 256 (1024/4), then start again at page 20

	MOV	PGADDH,#000H		; Start all over at page 20
	MOV	PGADDL,#050H		;
NO_PAGE_LIMIT:
					; Store new page address in page19:
	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#000H		; 
	LCALL	FLASH_OPCODE		;

	MOV	A,PGADDH
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	A,PGADDL
	LCALL	SPI_TX			; Write byte to FLASH

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page19
	MOV	OPCODE1,#00H		; Page address
	MOV	OPCODE2,#04CH		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

NO_BURN_LIMIT:
	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte0 in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	A,#FIRMWARE		; Write ID code to FLASH
	LCALL	SPI_TX			; 

	MOV	R1,#BURNCH

SETTINGS_LOOP:
	MOV	A,@R1
	LCALL	SPI_TX			; 
	INC	R1
	CJNE	R1,#PGADDL,SETTINGS_LOOP

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page??
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	RET

;* ------------------------------------------------------------------------
;*  Function  :COPY_LOG1,COPY_LOG2
;*  Purpose   :Copy log page to FLASH buffer1
;*  Arguments :-
;*  Uses      :OPCODE,OPCODE1,OPCODE2,OPCODE3
;*  Calls     :FLASH_OPCODE
;*	       SPI_RX
;*  Returns   :-
;* ------------------------------------------------------------------------
COPY_LOG1:
	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#004H		; Start at PAGE256
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 

	SJMP	OVER_LOG2

COPY_LOG2:
	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#010H		; Start at PAGE1024
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 

OVER_LOG2:
	LCALL	FLASH_OPCODE		;
	LCALL	SPI_RX			; Get log page address high byte
	MOV	PGADDH,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get log page address low byte
	MOV	PGADDL,SPIRDAT		; Move received data

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

; Move log page to buffer1
COPY_LOG2A:
	MOV	OPCODE,#053H		; Opcode for page to buffer1
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#0		; 
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	RET


;* ------------------------------------------------------------------------
;*  Function  :STORE_LOG1
;*  Purpose   :Store log in buffer1 to FLASH page
;*  Arguments :PGADDL,PGADDH
;*  Uses      :A,OPCODE,OPCODE1,OPCODE2,OPCODE3
;*  Calls     :FLASH_OPCODE
;*	       SPI_RX
;*	       SPI_TX
;*  Returns   :BURNCL,BURNCH,PGADDL,PGADDH
;* ------------------------------------------------------------------------

STORE_LOG1:
	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; Start at 1st byte
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get burncounter high byte
	MOV	BURNCH,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get burncounter low byte
	MOV	BURNCL,SPIRDAT		; Move received data

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,BURNCL		; Increase burncounter by 1
	ADD	A,#001H			;
	MOV	BURNCL,A		;
	MOV	A,BURNCH		;
	ADDC	A,#000H			;
	MOV	BURNCH,A		;

	JNC	NO_BURN_LIMIT2		; Count burncycles until 65535, then advance to next page

	MOV	A,PGADDL		; Increase page address by 4 (1 page)
	ADD	A,#004H			;
	MOV	PGADDL,A		;
	MOV	A,PGADDH		;
	ADDC	A,#000H			;
	MOV	PGADDH,A		;
	JNB	ACC.3,NO_PAGE_LIMIT2	; Count pages until 512 (2048/4), then start again at page 257

	MOV	PGADDH,#004H		; Start all over at page 257
	MOV	PGADDL,#004H		;
NO_PAGE_LIMIT2:

	SETB	NXT_PG

NO_BURN_LIMIT2:
	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte0 in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	A,BURNCH
	LCALL	SPI_TX			; Write byte to FLASH
	MOV	A,BURNCL
	LCALL	SPI_TX			; Write byte to FLASH

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	JB	NXT_PG,ADVANCE_PAGE
	RET

ADVANCE_PAGE:

	CLR	NXT_PG

					; Store new page address in page256:
	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	A,PGADDH
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	A,PGADDL
	LCALL	SPI_TX			; Write byte to FLASH

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page256
	MOV	OPCODE1,#004H		; Page address
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	RET

;* ------------------------------------------------------------------------
;*  Function  :INC_TIME
;*  Purpose   :Increase timecounter in log in buffer1 of flash memory
;*  Arguments :COUNT1,COUNT2
;*  Uses      :A,OPCODE,OPCODE1,OPCODE2,OPCODE3
;*  Calls     :FLASH_OPCODE
;*	       SPI_RX
;*	       SPI_TX
;*  Returns   :-
;* ------------------------------------------------------------------------

INC_TIME:
	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Starts at .. byte
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	ADD	A,#1
	CJNE	A,#10,INC_HOURS_END

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Start at .. byte in buffer
	LCALL	FLASH_OPCODE		;

	CLR	A
	LCALL	SPI_TX			; Write byte to FLASH

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	DEC	COUNT1

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Starts at .. byte
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	ADD	A,#1
	CJNE	A,#6,INC_HOURS_END

INC_HOURS1:

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Start at .. byte in buffer
	LCALL	FLASH_OPCODE		;

	CLR	A
	LCALL	SPI_TX			; Write byte to FLASH

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	DEC	COUNT1

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Starts at .. byte
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	ADD	A,#1
	CJNE	A,#10,INC_HOURS_END
	MOV	A,COUNT1

	CJNE	A,COUNT2,INC_HOURS1
	CLR	A

INC_HOURS_END:

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Start at .. byte in buffer
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_TX			; Write byte to FLASH

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	RET

;* ------------------------------------------------------------------------
;*  Function  :INC_STARTS
;*  Purpose   :increase starts counter in log
;*  Arguments :-
;*  Uses      :A,COUNT1,OPCODE,OPCODE1,OPCODE2,OPCODE3
;*  Calls     :COPY_LOG1
;*	       FLASH_OPCODE
;*	       SPI_RX
;*	       SPI_TX
;*	       STORE_LOG1
;*  Returns   :-
;* ------------------------------------------------------------------------
INC_STARTS:
	LCALL	COPY_LOG1

; Increase starts counter:

	MOV	COUNT1,#7

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Start at ... byte
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	ADD	A,#1
	CJNE	A,#10,INC_STARTS_END

	CLR	A

INC_STARTS1:

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Start at ... byte in buffer
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_TX			; 

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	DEC	COUNT1

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Start at ... byte
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; 
	MOV	A,SPIRDAT		; Move received data to A

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	ADD	A,#1
	CJNE	A,#10,INC_STARTS_END
	MOV	A,COUNT1

	CJNE	A,#3,INC_STARTS1

	CLR	A
INC_STARTS_END:

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,COUNT1		; Start at ... byte in buffer
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_TX			; 

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LCALL	STORE_LOG1

	RET


;* ------------------------------------------------------------------------
;*  Function  :DSP_ENABLE_INT
;*  Purpose   :Enable dsp interrupts
;*  Arguments :-
;*  Uses      :R0,I2C_TX,BYTECNTL,BYTECNTH,SLVADR
;*  Calls     :SENDDATA
;*  Returns   :-
;* ------------------------------------------------------------------------
DSP_ENABLE_INT:
	MOV	I2C_TX,#037H		; Get opcode for DSP enable interrupts

	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 

        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	CLR	DAC_MUTE		; Unmute DA converter

	RET


;* ------------------------------------------------------------------------
;*  Function  :PRESET_MUTE
;*  Purpose   :
;*  Arguments :-
;*  Uses      :R0,I2C_TX,BYTECNTL,BYTECNTH,SLVADR
;*  Calls     :SENDDATA
;*  Returns   :-
;* ------------------------------------------------------------------------
PRESET_MUTE:
	JNB	PRMUTE,NO_PRESET_MUTE

	JB	STEREO,MUTE_CHAN1
	JB	ACTIVE,MUTE_CHAN1

	JB	CHAN2,MUTE_CHAN2

MUTE_CHAN1:
	SETB	MUTE1
; Load mute data for ch1 to DSP:
	MOV	I2C_TX,#018H		; DSP opcode for mute ch1
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	JB	STEREO,MUTE_CHAN2
	JB	ACTIVE,MUTE_CHAN2

	RET

MUTE_CHAN2:
	SETB	MUTE2
; Load mute data for ch2 to DSP:
	MOV	I2C_TX,#019H		; DSP opcode for mute ch2
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

NO_PRESET_MUTE:
	RET

;* ------------------------------------------------------------------------
;*  Function  :DSP_LOAD_GAIN
;*  Purpose   :load gain data to DSP
;*  Arguments :-
;*  Uses      :A,R0,R5,SLVADR,BYTECNTL
;*  Calls     :LWAIT
;*	       GOMASTER
;*	       SENDBYTE
;*	       SENDSTOP
;*  Returns   :-
;* ------------------------------------------------------------------------
DSP_LOAD_GAIN:

	MOV	R5,#10
	LCALL	LWAIT

        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	LCALL	GOMASTER		; Acquire bus and send slave address.
	JB	NOACK,EXIT10		; Check for slave not responding.

	MOV	A,DSP_OPCODE		; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT10		; Check for slave not responding

	MOV	BYTECNTL,#02H		; send 2 bytes
	MOV	R0,#G_HI		; 
GAINLOOP2:
	MOV	A,@R0			; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	INC	R0			; Advance buffer pointer
	JB	NOACK,EXIT10		; Check for slave not responding
	DJNZ	BYTECNTL,GAINLOOP2	; All bytes send?

EXIT10:	LCALL	SENDSTOP		; Done, send an I2C stop.

	RET

;* ------------------------------------------------------------------------
;*  Function  :COMPUTE_DELAY
;*  Purpose   :compute delay data to other units
;*  Arguments :GRAPH1,GRAPH2
;*  Uses      :A,B,COUNT1
;*  Calls     :DELAY_UP
;*  Returns   :D_LOW,D_MID,D_HI
;* ------------------------------------------------------------------------
COMPUTE_DELAY:

	MOV	D_HI,#0
	MOV	D_MID,#0
	MOV	D_LOW,#0

	MOV	B,#48			; 96/2
	JNB	DUNIT,UNIT_MS10
	MOV	B,#14			; 28/2
UNIT_MS10:

	MOV	A,GRAPH1		; Add half count for rounding
	ADD	A,B			;
	MOV	GRAPH1,A		;
	MOV	A,GRAPH2		;
	ADDC	A,#0			;
	MOV	GRAPH2,A		;

	MOV	B,#000H

	MOV	COUNT1,#96		; 96 samples for 1ms
	JNB	DUNIT,UNIT9
	MOV	COUNT1,#113		; 28.25 samples for 0.1m = 113/4 samples

	CLR	C			; Shift 2 bits left
	MOV	A,GRAPH1
	RLC	A
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	RLC	A
	MOV	GRAPH2,A
	MOV	A,B
	RLC	A
	MOV	B,A

	CLR	C
	MOV	A,GRAPH1
	RLC	A
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	RLC	A
	MOV	GRAPH2,A
	MOV	A,B
	RLC	A
	MOV	B,A
UNIT9:

COUNTDOWN_LOOP1:
	CLR	C
	MOV	A,GRAPH1
	SUBB	A,COUNT1
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	SUBB	A,#0
	MOV	GRAPH2,A
	MOV	A,B
	SUBB	A,#0
	MOV	B,A
	JC	EXIT_COUNTDOWN1
	LCALL	DELAY_UP
	SJMP	COUNTDOWN_LOOP1

EXIT_COUNTDOWN1:

	RET



;* ------------------------------------------------------------------------
;*  Function  :DSP_BYPASS_DELAY
;*  Purpose   :-
;*  Arguments :-
;*  Uses      :A,SLVADR
;*  Calls     :MUTE_DAC
;*	       GOMASTER
;*	       SENDBYTE
;*	       SENDSTOP
;*  Returns   :-
;* ------------------------------------------------------------------------
DSP_BYPASS_DELAY:
	LCALL	MUTE_DAC

        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address

	LCALL	GOMASTER		; Acquire bus and send slave address.
	JB	NOACK,EXIT13		; Check for slave not responding.
	
	MOV	A,I2C_TX		; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT13		; Check for slave not responding

	MOV	A,#0			; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT13		; Check for slave not responding

	MOV	A,#0			; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT13		; Check for slave not responding

	MOV	A,#1			; Low byte is 1
	LCALL	SENDBYTE		; Send next data byte

EXIT13:	LCALL	SENDSTOP		; Done, send an I2C stop.

	RET

;* ------------------------------------------------------------------------
;*  Function  :DSP_CALC_DELAY
;*  Purpose   :Calculate delay data for DSP
;*  Arguments :D_LOW, D_MID, D_HI
;*  Uses      :A,B,GRAPH1,GRAPH2,COUNT1,COUNT2
;*  Calls     :-
;*  Returns   :GRAPH1,GRAPH2
;* ------------------------------------------------------------------------
DSP_CALC_DELAY:
	MOV	GRAPH2,#000H
	MOV	GRAPH1,#000H
	MOV	B,#000H

	MOV	COUNT2,#96
	JNB	DUNIT,UNIT_MS1
	MOV	COUNT2,#113
UNIT_MS1:
DELAY_COUNT1A:
	MOV	COUNT1,#100
DELAY_COUNT1:
	MOV	A,GRAPH1
	ADD	A,D_HI
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	ADDC	A,#0
	MOV	GRAPH2,A
	MOV	A,B
	ADDC	A,#0
	MOV	B,A
	DJNZ	COUNT1,DELAY_COUNT1
	DJNZ	COUNT2,DELAY_COUNT1A

	MOV	COUNT2,#96
	JNB	DUNIT,UNIT_MS2
	MOV	COUNT2,#113
UNIT_MS2:
DELAY_COUNT2A:
	MOV	COUNT1,#10
DELAY_COUNT2:
	MOV	A,GRAPH1
	ADD	A,D_MID
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	ADDC	A,#0
	MOV	GRAPH2,A
	MOV	A,B
	ADDC	A,#0
	MOV	B,A
	DJNZ	COUNT1,DELAY_COUNT2
	DJNZ	COUNT2,DELAY_COUNT2A

	MOV	COUNT1,#96
	JNB	DUNIT,UNIT_MS3
	MOV	COUNT1,#113
UNIT_MS3:
DELAY_COUNT3:
	MOV	A,GRAPH1
	ADD	A,D_LOW
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	ADDC	A,#0
	MOV	GRAPH2,A
	MOV	A,B
	ADDC	A,#0
	MOV	B,A
	DJNZ	COUNT1,DELAY_COUNT3

	JNB	DUNIT,UNIT_MS4

	MOV	A,GRAPH1		; Add 2 for rounding
	ADD	A,#2
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	ADDC	A,#0
	MOV	GRAPH2,A
	MOV	A,B
	ADDC	A,#0
	MOV	B,A

	CLR	C			; Divide by 4
	MOV	A,B
	RRC	A
	MOV	B,A
	MOV	A,GRAPH2
	RRC	A
	MOV	GRAPH2,A
	MOV	A,GRAPH1
	RRC	A
	MOV	GRAPH1,A

	CLR	C
	MOV	A,B
	RRC	A
	MOV	B,A
	MOV	A,GRAPH2
	RRC	A
	MOV	GRAPH2,A
	MOV	A,GRAPH1
	RRC	A
	MOV	GRAPH1,A
UNIT_MS4:

	RET

;* ------------------------------------------------------------------------
;*  Function  :DSP_LOAD_DELAY1/2
;*  Purpose   :load delay data to DSP
;*  Arguments :DELL1,DELH1,DELL2,DELH2
;*  Uses      :A,R0,I2C_TX,SLVADR,GRAPH1,GRAPH2,GRAPH3,GRAPH4,BYTECNTL
;*  Calls     :MUTE_DAC
;*	       GOMASTER
;*	       SENDBYTE
;*	       SENDSTOP
;*  Returns   :-
;* ------------------------------------------------------------------------
DSP_LOAD_DELAY1:
	LCALL	MUTE_DAC

	MOV	I2C_TX,#016H		; DSP opcode
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address

	LCALL	GOMASTER		; Acquire bus and send slave address.
	JB	NOACK,EXIT9		; Check for slave not responding.
	
	MOV	A,I2C_TX		; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT9		; Check for slave not responding

	MOV	GRAPH3,DELL1
	MOV	GRAPH4,DELH1

	MOV	GRAPH1,DELL1
	MOV	GRAPH2,DELH1

	JNB	D_FINE,D_FINE5
	MOV	GRAPH1,#0
	MOV	GRAPH2,#0

	MOV	A,GRAPH3		; Add 4 for rounding
	ADD	A,#4			
	MOV	GRAPH3,A		
	MOV	A,GRAPH4
	ADDC	A,#0
	MOV	GRAPH4,A

DIV_10_1:				; Divide by 10 for fine mode
	MOV	A,GRAPH3	
	CLR	C
	SUBB	A,#10
	MOV	GRAPH3,A

	MOV	A,GRAPH4
	SUBB	A,#0
	MOV	GRAPH4,A

	JC	END_DIV_10_1
	
	MOV	A,GRAPH1
	ADD	A,#1
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	ADDC	A,#0
	MOV	GRAPH2,A

	SJMP	DIV_10_1
END_DIV_10_1:
D_FINE5:

	CLR	C			; Subtract 1ms-1 sample for AD-DA latency
	MOV	A,GRAPH1
	SUBB	A,#95
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	SUBB	A,#0
	MOV	GRAPH2,A

	JNC	DELAY7
	MOV	GRAPH1,#1
	MOV	GRAPH2,#0
	SJMP	DELAY8
DELAY7:
	JNZ	DELAY8
	MOV	A,GRAPH1
	JNZ	DELAY8
	MOV	GRAPH1,#1
DELAY8:

	MOV	A,#0
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT9		; Check for slave not responding

	MOV	BYTECNTL,#02H		; send 2 bytes
	MOV	R0,#GRAPH2

DELAYLOOP2:
	MOV	A,@R0			; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	INC	R0			; Advance buffer pointer
	JB	NOACK,EXIT9		; Check for slave not responding
	DJNZ	BYTECNTL,DELAYLOOP2	; All bytes send?

EXIT9:	LCALL	SENDSTOP		; Done, send an I2C stop.

	RET

DSP_LOAD_DELAY2:
	LCALL	MUTE_DAC

	MOV	I2C_TX,#017H		; DSP opcode

        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 

	LCALL	GOMASTER		; Acquire bus and send slave address.
	JB	NOACK,EXIT11		; Check for slave not responding.
	
	MOV	A,I2C_TX		; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT11		; Check for slave not responding

	MOV	GRAPH3,DELL2
	MOV	GRAPH4,DELH2

	MOV	GRAPH1,DELL2
	MOV	GRAPH2,DELH2

	JNB	D_FINE,D_FINE6
	MOV	GRAPH1,#0
	MOV	GRAPH2,#0

	MOV	A,GRAPH3		; Add 4 for rounding
	ADD	A,#4			
	MOV	GRAPH3,A		
	MOV	A,GRAPH4
	ADDC	A,#0
	MOV	GRAPH4,A

DIV_10_2:
	MOV	A,GRAPH3
	CLR	C
	SUBB	A,#10
	MOV	GRAPH3,A

	MOV	A,GRAPH4
	SUBB	A,#0
	MOV	GRAPH4,A

	JC	END_DIV_10_2
	
	MOV	A,GRAPH1
	ADD	A,#1
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	ADDC	A,#0
	MOV	GRAPH2,A

	SJMP	DIV_10_2

END_DIV_10_2:
D_FINE6:

	CLR	C			; Subtract 1ms-1 sample for AD-DA latency
	MOV	A,GRAPH1
	SUBB	A,#95
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	SUBB	A,#0
	MOV	GRAPH2,A

	JNC	DELAY11
	MOV	GRAPH1,#1
	MOV	GRAPH2,#0
	SJMP	DELAY12
DELAY11:
	JNZ	DELAY12
	MOV	A,GRAPH1
	JNZ	DELAY12
	MOV	GRAPH1,#1
DELAY12:

	MOV	A,#0
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT11		; Check for slave not responding

	MOV	BYTECNTL,#02H		; send 2 bytes
	MOV	R0,#GRAPH2

DELAYLOOP4:
	MOV	A,@R0			; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	INC	R0			; Advance buffer pointer
	JB	NOACK,EXIT11		; Check for slave not responding
	DJNZ	BYTECNTL,DELAYLOOP4	; All bytes send?

EXIT11:	LCALL	SENDSTOP		; Done, send an I2C stop.

	RET

;* ------------------------------------------------------------------------
;*  Function  :DSP_LOAD_USER_EQ
;*  Purpose   :load 1 section of user eq data to DSP
;*  Arguments :-
;*  Uses      :A,R0,R5,I2C_TX+2,BYTECNTL,SLVADR
;*  Calls     :LWAIT
;*	       GOMASTER
;*	       SENDBYTE
;*	       SENDSTOP
;*  Returns   :-
;* ------------------------------------------------------------------------
DSP_LOAD_USER_EQ:
	MOV	R5,#10
	LCALL	LWAIT

	MOV	I2C_TX+2,DSP_OPCODE	; DSP opcode

	MOV	BYTECNTL,#03H		; send 3 bytes
        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX+2		; 

	LCALL	GOMASTER		; Acquire bus and send slave address.
	JB	NOACK,EXIT7		; Check for slave not responding.
	
SDLOOP1:
	MOV	A,@R0			; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	INC	R0			; Advance buffer pointer
	JB	NOACK,EXIT7		; Check for slave not responding
	DJNZ	BYTECNTL,SDLOOP1	; All bytes send?

	MOV	A,#41
	JB	BYP,SECT_BYP
	MOV	A,@R0			; Get data byte from DATA memory
SECT_BYP:

	LCALL	SENDBYTE		; Send 4th data byte
EXIT7:	LCALL	SENDSTOP		; Done, send an I2C stop.

	RET


;* ------------------------------------------------------------------------
;*  Function  :DSP_LOAD_PRESET
;*  Purpose   :load speaker preset data to DSP
;*  Arguments :MOD1,MOD2
;*  Uses      :A,B,DPTR,OPCODE,OPCODE1,OPCODE2,OPCODE3,SLVADR,BYTECNTL,COUNT1
;*  Calls     :MUTE_DAC
;*	       FLASH_OPCODE
;*	       SPI_RX
;*	       GOMASTER
;*	       SENDBYTE
;*	       SENDSTOP
;*  Returns   :SPPRESET1,SPPRESET2,SPOPT,ACT_2ND
;* ------------------------------------------------------------------------
DSP_LOAD_PRESET:
	LCALL	MUTE_DAC

	MOV	A,MOD2
	MOV	I2C_TX,#034H		; DSP opcode
	JB	CHAN2,CHAN2_28
	MOV	A,MOD1
	MOV	I2C_TX,#033H		; DSP opcode
CHAN2_28:

	MOV	OPCODE3,#000H		;
	JNB	ACC.0,FIRST_PRESET_IN_PAGE
	MOV	OPCODE3,#084H		; Move to second preset in page
FIRST_PRESET_IN_PAGE:

	ANL	A,#0FEH			; Clear bit0

	ADD	A,#01CH			; First preset in page 526 (/2)
	MOV	OPCODE2,A		;
					;
	MOV	A,#004H			;
	ADDC	A,#0			;
	MOV	OPCODE1,A		;

	CLR	C
	MOV	A,OPCODE3
	RLC	A
	MOV	OPCODE3,A

	MOV	A,OPCODE2
	RLC	A
	MOV	OPCODE2,A

	MOV	A,OPCODE1
	RLC	A
	MOV	OPCODE1,A

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get preset options data byte from FLASH
	MOV	A,SPIRDAT		; 

	JNB	CHAN2,CHAN2_1
	MOV	SPPRESET2,A		; 
	SJMP	CHAN2_2
CHAN2_1:
	MOV	SPPRESET1,A		; 
CHAN2_2:

	JB	ACC.0,LOW_EQ
	LJMP	NO_LOW_EQ
LOW_EQ:

	SWAP	A
	ANL	A,#0FH

	CJNE	A,#0,NO_ARRAY_TYPE0	; Type0=Lr14=8 different lenghts

	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_34
	SWAP	A
CHAN2_34:
	MOV	B,A

	ANL	A,#00FH
	CLR	C
	SUBB	A,#8
	JNC	ARRAY_LEN0
	LJMP	ARRAY_LEN_OK
ARRAY_LEN0:

	MOV	A,B
	ANL	A,#0F0H
	ORL	A,#007H

	JNB	CHAN2,CHAN2_33
	SWAP	A
CHAN2_33:
	MOV	SPOPT,A
	LJMP	ARRAY_LEN_OK
NO_ARRAY_TYPE0:


	CJNE	A,#1,NO_ARRAY_TYPE1	; Type1=Lr16=8 different lenghts

	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_22
	SWAP	A
CHAN2_22:
	MOV	B,A

	ANL	A,#00FH
	CLR	C
	SUBB	A,#8
	JNC	ARRAY_LEN1
	LJMP	ARRAY_LEN_OK
ARRAY_LEN1:

	MOV	A,B
	ANL	A,#0F0H
	ORL	A,#007H

	JNB	CHAN2,CHAN2_23
	SWAP	A
CHAN2_23:
	MOV	SPOPT,A
	LJMP	ARRAY_LEN_OK
NO_ARRAY_TYPE1:

	CJNE	A,#2,NO_ARRAY_TYPE2	; Type2=Lr30=12 different lenghts

	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_24
	SWAP	A
CHAN2_24:
	MOV	B,A

	ANL	A,#00FH
	CLR	C
	SUBB	A,#12
	JNC	ARRAY_LEN2
	LJMP	ARRAY_LEN_OK
ARRAY_LEN2:

	MOV	A,B
	ANL	A,#0F0H
	ORL	A,#00BH

	JNB	CHAN2,CHAN2_25
	SWAP	A
CHAN2_25:
	MOV	SPOPT,A
	LJMP	ARRAY_LEN_OK
NO_ARRAY_TYPE2:

	CJNE	A,#3,NO_ARRAY_TYPE3	; Type3=QR18,QR36=16 different lenghts

	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_26
	SWAP	A
CHAN2_26:
	MOV	B,A

	ANL	A,#00FH
	CLR	C
	SUBB	A,#16
	JNC	ARRAY_LEN3
	LJMP	ARRAY_LEN_OK
ARRAY_LEN3:

	MOV	A,B
	ANL	A,#0F0H
	ORL	A,#00FH

	JNB	CHAN2,CHAN2_27
	SWAP	A
CHAN2_27:
	MOV	SPOPT,A
	LJMP	ARRAY_LEN_OK
NO_ARRAY_TYPE3:


	CJNE	A,#4,NO_ARRAY_TYPE4	; Type4=VR8=7 different eq's

	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_35
	SWAP	A
CHAN2_35:
	MOV	B,A

	ANL	A,#00FH
	CLR	C
	SUBB	A,#7
	JNC	ARRAY_LEN4
	LJMP	ARRAY_LEN_OK
ARRAY_LEN4:

	MOV	A,B
	ANL	A,#0F0H
	ORL	A,#006H

	JNB	CHAN2,CHAN2_36
	SWAP	A
CHAN2_36:
	MOV	SPOPT,A
	LJMP	ARRAY_LEN_OK
NO_ARRAY_TYPE4:

	CJNE	A,#5,NO_ARRAY_TYPE5	; Type5=VR12=7 different eq's

	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_38
	SWAP	A
CHAN2_38:
	MOV	B,A

	ANL	A,#00FH
	CLR	C
	SUBB	A,#7
	JNC	ARRAY_LEN5
	LJMP	ARRAY_LEN_OK
ARRAY_LEN5:

	MOV	A,B
	ANL	A,#0F0H
	ORL	A,#006H

	JNB	CHAN2,CHAN2_37
	SWAP	A
CHAN2_37:
	MOV	SPOPT,A
	LJMP	ARRAY_LEN_OK
NO_ARRAY_TYPE5:

	CJNE	A,#6,NO_ARRAY_TYPE6	; Type6=BF362=3 different eq's

	MOV	A,SPOPT
	JNB	CHAN2,CHAN2_40
	SWAP	A
CHAN2_40:
	MOV	B,A

	ANL	A,#00FH
	CLR	C
	SUBB	A,#3
	JNC	ARRAY_LEN6
	LJMP	ARRAY_LEN_OK
ARRAY_LEN6:

	MOV	A,B
	ANL	A,#0F0H
	ORL	A,#002H

	JNB	CHAN2,CHAN2_41
	SWAP	A
CHAN2_41:
	MOV	SPOPT,A
	LJMP	ARRAY_LEN_OK
NO_ARRAY_TYPE6:

;	CJNE	A,#7,NO_ARRAY_TYPE7	; Type7=LR7
;	MOV	A,SPOPT
;	JNB	CHAN2,CHAN2_42
;	SWAP	A
;CHAN2_42:
;	MOV	B,A
;
;	ANL	A,#00FH
;	CLR	C
;	SUBB	A,#3
;	JNC	ARRAY_LEN7
;	LJMP	ARRAY_LEN_OK
;ARRAY_LEN6:
;
;	MOV	A,B
;	ANL	A,#0F0H
;	ORL	A,#002H
;
;	JNB	CHAN2,CHAN2_43
;	SWAP	A
;CHAN2_43:
;	MOV	SPOPT,A
;	LJMP	ARRAY_LEN_OK
;NO_ARRAY_TYPE7:

ARRAY_LEN_OK:
NO_LOW_EQ:

	LCALL	SPI_RX			; 
	MOV	ACT_2ND,SPIRDAT		; 

        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address

	LCALL	GOMASTER		; Acquire bus and send slave address.
	JNB	NOACK,SPEQLOOP1		; Check for slave not responding.
	LJMP	EXIT8

SPEQLOOP1:
	MOV	A,I2C_TX		; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	JNB	NOACK,EQ_CONT1		; Check for slave not responding
	LJMP	EXIT8
EQ_CONT1:
					; send a total of 33 bytes
	MOV	BYTECNTL,#3		; send 3 bytes for section5
SPEQLOOP2:
	LCALL	SPI_RX			; Get data byte from FLASH
	MOV	A,SPIRDAT		; 
	LCALL	SENDBYTE		; Send next data byte
	JNB	NOACK,EQ_CONT2		; Check for slave not responding
	LJMP	EXIT8
EQ_CONT2:
	DJNZ	BYTECNTL,SPEQLOOP2	; All bytes send?

	MOV	A,SPPRESET1
	JNB	CHAN2,NO_CH21
	MOV	A,SPPRESET2
NO_CH21:
	JNB	ACC.0,NO_EQ_SWAP1

	SWAP	A
	ANL	A,#0FH

	CJNE	A,#00H,NO_TYPE0
	MOV	DPTR,#LOW_EQ_TYPE0
	SJMP	END_TYPE_LOW_EQ
NO_TYPE0:
	CJNE	A,#01H,NO_TYPE1
	MOV	DPTR,#LOW_EQ_TYPE1
	SJMP	END_TYPE_LOW_EQ
NO_TYPE1:
	CJNE	A,#02H,NO_TYPE2
	MOV	DPTR,#LOW_EQ_TYPE2
	SJMP	END_TYPE_LOW_EQ
NO_TYPE2:
	CJNE	A,#03H,NO_TYPE3
	MOV	DPTR,#LOW_EQ_TYPE3
	SJMP	END_TYPE_LOW_EQ
NO_TYPE3:
	CJNE	A,#04H,NO_TYPE4
	MOV	DPTR,#LOW_EQ_TYPE4
	SJMP	END_TYPE_LOW_EQ
NO_TYPE4:
	CJNE	A,#05H,NO_TYPE5
	MOV	DPTR,#LOW_EQ_TYPE5
	SJMP	END_TYPE_LOW_EQ
NO_TYPE5:
	CJNE	A,#06H,NO_TYPE6
	MOV	DPTR,#LOW_EQ_TYPE6
	SJMP	END_TYPE_LOW_EQ
NO_TYPE6:
	CJNE	A,#07H,NO_TYPE7
	MOV	DPTR,#LOW_EQ_TYPE7
	SJMP	END_TYPE_LOW_EQ
NO_TYPE7:
	MOV	DPTR,#LOW_EQ_TYPE0

END_TYPE_LOW_EQ:
	MOV	A,SPOPT			; Get speaker options
	JNB	CHAN2,EQ_CHAN2_1
	SWAP	A
EQ_CHAN2_1:
	ANL	A,#00FH
	JZ	NO_EQ_SWAP1


	DEC	A
	JZ	PTR_OK1
	MOV	COUNT1,A
EQ_PTR1:
	INC	DPTR
	INC	DPTR
	INC	DPTR
	DJNZ	COUNT1,EQ_PTR1
PTR_OK1:

	MOV	BYTECNTL,#3		; send 3 bytes for substituted section6
SPEQLOOP3:
	CLR	A
	MOVC	A,@A+DPTR		; Get data byte from DATA memory
	INC	DPTR
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT8		; Check for slave not responding
	DJNZ	BYTECNTL,SPEQLOOP3	; All bytes send?

	LCALL	SPI_RX			; Get data byte from FLASH
	LCALL	SPI_RX			; Get data byte from FLASH
	LCALL	SPI_RX			; Get data byte from FLASH

	MOV	BYTECNTL,#9		; send 9 bytes for section7-9
	SJMP	EQ_SWAPED1

NO_EQ_SWAP1:
	MOV	BYTECNTL,#12		; send 12 bytes for section6-9
EQ_SWAPED1:

SPEQLOOP5:
	LCALL	SPI_RX			; Get data byte from FLASH
	MOV	A,SPIRDAT		; 
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT8		; Check for slave not responding
	DJNZ	BYTECNTL,SPEQLOOP5	; All bytes send?


	MOV	A,SPPRESET1
	JNB	CHAN2,NO_CH22
	MOV	A,SPPRESET2
NO_CH22:
	JNB	ACC.1,NO_EQ_SWAP2

	MOV	C,HCORR1
	JNB	CHAN2,CHAN2_29
	MOV	C,HCORR2
CHAN2_29:
	JNC	NO_EQ_SWAP2

	MOV	DPTR,#HIGH_EQ

	MOV	BYTECNTL,#3		; send 3 bytes for substituted section10
SPEQLOOP6:
	CLR	A
	MOVC	A,@A+DPTR		; Get data byte from DATA memory
	INC	DPTR
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT8		; Check for slave not responding
	DJNZ	BYTECNTL,SPEQLOOP6	; All bytes send?

	LCALL	SPI_RX			; Get data byte from FLASH
	LCALL	SPI_RX			; Get data byte from FLASH
	LCALL	SPI_RX			; Get data byte from FLASH

	MOV	BYTECNTL,#9		; send 9 bytes for section11-13
	SJMP	EQ_SWAPED2

NO_EQ_SWAP2:
	MOV	BYTECNTL,#12		; send 12 bytes for section10-13

EQ_SWAPED2:

SPEQLOOP8:
	LCALL	SPI_RX			; Get data byte from FLASH
	MOV	A,SPIRDAT		; 
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,EXIT8		; Check for slave not responding
	DJNZ	BYTECNTL,SPEQLOOP8	; All bytes send?



	MOV	BYTECNTL,#234		; send 234 bytes
SPSPLOOP2:
	LCALL	SPI_RX			; Get data byte from FLASH
	MOV	A,SPIRDAT		; 
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,SP_EXIT1		; Check for slave not responding
	DJNZ	BYTECNTL,SPSPLOOP2	; All bytes send?
EXIT8:
SP_EXIT1:
	LCALL	SENDSTOP		; Done, send an I2C stop.

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	RET

;* ------------------------------------------------------------------------
;*  Function  :DSP_LOAD_PROGRAM
;*  Purpose   :Bootstrap DSP program memory from FLASH memory
;*  Arguments :-
;*  Uses      :A,SLVADR,BYTECNTL,BYTECNTH,OPCODE,OPCODE1,OPCODE2,OPCODE3
;*  Calls     :GOMASTER
;*	       FLASH_OPCODE
;*	       SPI_RX
;*	       SENDBYTE
;*	       SENDSTOP
;*  Returns   :-
;* ------------------------------------------------------------------------
DSP_LOAD_PROGRAM:

        MOV	SLVADR,#DSP_ADR		; Get DSP slave address

	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,EXIT6		; Check for slave not responding

	MOV	BYTECNTH,#024H		; Number of bytes high byte 3K+2 24 bit words
	MOV	BYTECNTL,#006H		; Number of bytes low byte
	INC	BYTECNTH

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#00H		; Start at address0
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

DSP_BOOT_LOOP:
	LCALL	SPI_RX			; Get byte from FLASH
	MOV	A,SPIRDAT		; Move received data to A

	LCALL	SENDBYTE		; Send data byte to I2C bus
	JB	NOACK,EXIT5		; Check for slave not responding
	DJNZ	BYTECNTL,DSP_BOOT_LOOP	; All bytes send?
	DJNZ	BYTECNTH,DSP_BOOT_LOOP	; All bytes send?
EXIT5:
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY
EXIT6:
	LCALL	SENDSTOP		; Done, send an I2C stop condition
	RET

;* ------------------------------------------------------------------------
;*  Function  :SPI_TX
;*  Purpose   :Transmit byte to SPI
;*  Arguments :A = byte to be send
;*  Uses      :-
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
SPI_TX:
	MOV	0C5H,A			; Move byte to SPDAT
	JNB	SPITXC,$		; Wait for end of transmission
	CLR	SPITXC			; Clear flag
	RET

;* ------------------------------------------------------------------------
;*  Function  :SPI_RX
;*  Purpose   :Receive byte from SPI
;*  Arguments :-
;*  Uses      :-
;*  Calls     :-
;*  Returns   :SPIRDAT = Received data
;* ------------------------------------------------------------------------
SPI_RX:
	MOV	0C5H,#00H		; Send data to SPDAT to generate SCK signal
	JNB	SPITXC,$		; Wait for end of transmission
	CLR	SPITXC			; Clear flag
	MOV	SPIRDAT,SPISDAT		; Data is put in SPISDAT by SPI interrupt routine
	RET

;* ------------------------------------------------------------------------
;*  Function  :FLASH_OPCODE
;*  Purpose   :Enable FLASH memory and send opcode + dont't care bits
;*  Arguments :OPCODE:	084H Buffer1 write 
;*			087H Buffer2 write 
;*			083H Buffer1 to page with erase 
;*			086H Buffer2 to page with erase 
;*			0D4H Buffer1 read 
;*			0D6H Buffer2 read 
;*			053H Page to buffer1 transfer 
;*			055H Page to buffer2 transfer 
;*			0E8H Continuous array read 
;*  Uses      :R0,R7
;*  Calls     :SPI_TX
;*  Returns   :-
;* ------------------------------------------------------------------------
FLASH_OPCODE:
	PUSH	ACC

	MOV	R0,#OPCODE		; Pointer to FLASH opcode
	MOV	A,@R0
	MOV	R7,#004H		; Most opcodes are 4 bytes

	CJNE	A,#053H,NO_OP_53
	MOV	R7,#003H		; Send 3 byte opcode
NO_OP_53:
	CJNE	A,#055H,NO_OP_55
	MOV	R7,#003H		; Send 3 byte opcode
NO_OP_55:
	CJNE	A,#083H,NO_OP_83
	MOV	R7,#003H		; Send 3 byte opcode
NO_OP_83:
	CJNE	A,#086H,NO_OP_86
	MOV	R7,#003H		; Send 3 byte opcode
NO_OP_86:

	CLR	FLASH_CS		; Enable FLASH	

OPCODE_LOOP:
	MOV	A,@R0			; Get opcode
	INC	R0

	LCALL	SPI_TX

	DJNZ	R7,OPCODE_LOOP

; Now send don't care bits:

	MOV	A,OPCODE		; Move opcode to A
	MOV	R7,#001H		; Most opcodes need 1 byte of don't cares

	CJNE	A,#0E8H,NO_OP_E8
	MOV	R7,#004H		; Send 4 bytes of don't cares
NO_OP_E8:
	CJNE	A,#0D2H,NO_OP_D2
	MOV	R7,#004H		; Send 4 bytes of don't cares
NO_OP_D2:
	CJNE	A,#084H,NO_OP_84
	POP	ACC
	RET				; No don't care bits
NO_OP_84:
	CJNE	A,#087H,NO_OP_87
	POP	ACC
	RET				; No don't care bits
NO_OP_87:

DC_LOOP:
	CLR	A
	LCALL	SPI_TX			; 
	DJNZ	R7,DC_LOOP
	POP	ACC
	RET

;* ------------------------------------------------------------------------
;*  Function  :ENCODER_CHECK
;*  Purpose   :reads encoder movement and updates Log amd Limitlog
;*  Arguments :PGADDL,PGADDH
;*  Uses      :A,B,R0,R1,R4,R5,SECS,I2C_TX,I2C_TX+1,BYTECNTL,BYTECNTH,SLVADR,BTOCNT,COUNT1,COUNT2,
;*	       GRAPH1,GRAPH2,GRAPH3,GRAPH4,OPCODE,OPCODE1,OPCODE2,OPCODE3
;*  Calls     :RESET_WDT
;*	       LCD_BLANK
;*	       LCD_REFRESH_NO_BACK
;*	       CHECK_DST
;*	       LWAIT
;*	       JMF_MENU
;*	       TEST_MENU
;*	       MUTE_DAC
;*	       SENDDATA
;*	       LCD_TEXT
;*	       LCD_REFRESH
;*	       WRITE_SETTINGS
;*	       COPY_LOG1
;*	       INC_TIME
;*	       GOMASTER
;*	       RCVBYTE
;*	       SENDSTOP
;*	       STORE_LOG1
;*	       FLASH_OPCODE
;*	       SPI_RX
;*	       SPI_TX
;*	       COPY_LOG2
;*	       GET_RTC_DATA
;*  Returns   :PGADDL,PGADDH,LEFT,RIGHT,PUS,ENC
;* ------------------------------------------------------------------------
ENCODER_CHECK:
	LCALL	RESET_WDT

	JNB	DBLANK,ENCODER_CONT4
	LCALL	LCD_BLANK
ENCODER_CONT4:

	JB	RTC_IRP,ENCODER_CONT1	; 
	JB	RTC_IRQ,ENCODER_CONT1

	LCALL	LCD_REFRESH_NO_BACK

	SETB	RTC_IRP

	INC	SECS
	MOV	A,SECS
	
	CJNE	A,#60,FAST_WATCHDOG	;WAS 60 SECS!!!
	MOV	SECS,#0
	SETB	LOG_REF
	JB	S_CLK,NO_CHECK_DST
	LCALL	CHECK_DST
NO_CHECK_DST:
	JNB	AMP_ON,ENCODER_CONT1
	LJMP	UPDATE_LOG

FAST_WATCHDOG:
; DSP fast watchdog command:
;	MOV	I2C_TX,#052H		; DSP fast watchdog command
;
;	MOV	BYTECNTL,#01H		; send 1 byte
;	MOV	BYTECNTH,#00H		; 
;
;	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
;	MOV	R0,#I2C_TX		; 
;	LCALL	SENDDATA		; Send DSP opcode on I2C bus
;
;	MOV	BYTECNTL,#01H		; Number of bytes
;	MOV	BYTECNTH,#01H
;
;	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
;	INC	SLVADR			; Set slave address for reading
;	LCALL	GOMASTER		; Acquire I2C bus and send slave address
;	JB	NOACK,$			; Check for slave not responding
;
;	LCALL	RCVBYTE			; Receive next data byte from DSP
;	CJNE	A,#FIRMWARE,$		; Watchdog check
;
;	LCALL	SENDSTOP		; Done, send an I2C stop condition

ENCODER_CONT1:
	JNB	RTC_IRQ,ENCODER_CONT2
	CLR	RTC_IRP
ENCODER_CONT2:

	JNB	ENC,GO_ENCODER
	LJMP	END_ENCODER		; Encoder action still pending

GO_ENCODER:
	CLR	LEFT
	CLR	RIGHT
	CLR	PUS

	JB	ENC_SW,NO_PUS3		; Jump if encoder is not pushed
	MOV	R5,#10
	LCALL	LWAIT
	JB	ENC_SW,NO_PUS3		; Still pushed?
	SJMP	PUS_WAIT
NO_PUS3:
	LJMP	NO_PUS

PUS_WAIT:
	MOV	R4,#00H
PUS_WAIT2:
	LCALL	RESET_WDT
	SETB	PUS
	SETB	ENC
	JNB	ENC_SW,PUS_WAIT1
	LJMP	PUS_OVER1
PUS_WAIT1:
	MOV	R5,#10
	LCALL	LWAIT
	DJNZ	R4,PUS_WAIT2

	LCALL	RESET_WDT

	MOV	A,FLAGS0
	ANL	A,#030H
	CJNE	A,#030H,MUTE_ALL

	JNB	INF,NO_JMF

	LCALL	JMF_MENU
	CLR	LEFT
	CLR	RIGHT
	SETB	PUS
	SETB	ENC

	LJMP	PUS_OVER1
NO_JMF:
	JNB	DIS,MUTE_ALL

	LCALL	TEST_MENU
	CLR	LEFT
	CLR	RIGHT
	SETB	PUS
	SETB	ENC

	SJMP	PUS_OVER1
MUTE_ALL:
	PUSH	DPL
	PUSH	DPH

	LCALL	MUTE_DAC

	SETB	MUTE1
	SETB	MUTE2

; Load mute data for ch1 to DSP:
	MOV	I2C_TX,#018H		; DSP opcode for mute ch1
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

; Load mute data for ch2 to DSP:
	MOV	I2C_TX,#019H		; DSP opcode for mute ch2
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 
	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	CLR	DAC_MUTE		; Unmute DA converter

	JNB	MAIN,NO_TEXT
; Mute ON/OFF channel1:
	MOV	DPTR,#0207H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MT
	SETB	INV
	LCALL	LCD_TEXT

	JB	ACTIVE,NO_TEXT_CH2
	JB	STEREO,NO_TEXT_CH2

; Mute ON/OFF channel2:
	MOV	DPTR,#0249H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#MT
	SETB	INV
	LCALL	LCD_TEXT

NO_TEXT_CH2:
	LCALL	LCD_REFRESH
NO_TEXT:
	CLR	PUS
	CLR	ENC

	LCALL	WRITE_SETTINGS

	POP	DPH
	POP	DPL

END_MUTE_ALL:
WAIT_PUS:
	LCALL	RESET_WDT
	JNB	ENC_SW,WAIT_PUS
	MOV	R5,#10
	LCALL	LWAIT
	JNB	ENC_SW,WAIT_PUS

	SJMP	END_ENCODER

PUS_OVER1:
	MOV	R5,#10
	LCALL	LWAIT
	JB	ENC_SW,END_ENCODER1
	LJMP	PUS_WAIT1

NO_PUS:
	JB	ENC_A,NO_TURN

	JNB	ENC_B,TURN_LEFT

TURN_RIGHT:
	LCALL	RESET_WDT
	JB	ENC_SW,NO_PUS2
	LJMP	PUS_WAIT	
NO_PUS2:
	JNB	ENC_A,TURN_RIGHT
	JB	ENC_B,NO_TURN

	SETB	RIGHT
	SETB	ENC
	CLR	ENC_FAST
	MOV	A,ENC_TIM
	JZ	END_ENCODER1
	SETB	ENC_FAST
	SJMP	END_ENCODER1

TURN_LEFT:
	LCALL	RESET_WDT
	JB	ENC_SW,NO_PUS1
	LJMP	PUS_WAIT
NO_PUS1:	
	JNB	ENC_B,TURN_LEFT
	JB	ENC_A,NO_TURN

	SETB	LEFT
	SETB	ENC
	CLR	ENC_FAST
	MOV	A,ENC_TIM
	JZ	END_ENCODER1
	SETB	ENC_FAST
	SJMP	END_ENCODER1

NO_TURN:
	MOV	A,ENC_TIM
	JZ	END_ENCODER_NOTURN
	DEC	ENC_TIM

END_ENCODER_NOTURN:
	RET

END_ENCODER1:
	MOV	A,LIGHT
	ANL	A,#0FH
	JZ	BACKLIGHT_OFF1
	MOV	BTOCNT,#0CBH
BACKLIGHT_OFF1:

END_ENCODER:
	MOV	ENC_TIM,#0FFH
	RET



UPDATE_LOG:
	LCALL	COPY_LOG1		; Copy log page to buffer

; Increase on time with 1 minute:
	JNB	LOG_1ST,LOG_CONT1
	MOV	COUNT2,#8		; Address range of on time in log page 
	MOV	COUNT1,#15		;

	LCALL	INC_TIME
LOG_CONT1:
	MOV	GRAPH4,#07FH		;
	MOV	GRAPH3,#07FH		;
	MOV	GRAPH2,#0		;
	MOV	GRAPH1,#0		;
	JB	LENABLE,LOG_CONT2	;NEWWWW
; Get log data/watchdog from dsp
	MOV	I2C_TX,#01H		; Get opcode for DSP log/watchdog read

	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 

	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	MOV	BYTECNTL,#04H		; Number of bytes
	MOV	BYTECNTH,#01H

	MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	INC	SLVADR			; Set slave address for reading
	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,$			; Check for slave not responding

	LCALL	RCVBYTE			; Receive next data byte from DSP
;	CJNE	A,#FIRMWARE,$		; Watchdog check
	CJNE	A,#014H,$		; Watchdog check

	MOV	R1,#GRAPH4		; Temporarily use these variabeles

WD_LOOP1:
	LCALL	RCVBYTE			; Receive next data byte from DSP
	MOV	@R1,A
	INC	R1
	DJNZ	BYTECNTL,WD_LOOP1	; All bytes received?

	LCALL	SENDSTOP		; Done, send an I2C stop condition

	JB	LOG_1ST,LOG_CONT2	; Don't use first log samples
	MOV	GRAPH4,#07FH		;
	MOV	GRAPH3,#07FH		;
	MOV	GRAPH2,#0		;
	MOV	GRAPH1,#0		;
LOG_CONT2:

	JNB	LOG_1ST,NO_LOG1
	
	MOV	A,GRAPH2		; Check ch1 signal present
	CLR	C			;
	SUBB	A,#024H			; Threshold for -40dBu
	JNC	INC_SIGNAL_TIME		;

	MOV	A,GRAPH1		; Check ch2 signal present
	CLR	C			;
	SUBB	A,#024H			; Threshold for -40dBu
	JNC	INC_SIGNAL_TIME		;

NO_LOG1:
	LCALL	STORE_LOG1
	JB	LOG_1ST,GOTO_LOG2

	MOV	SECS,#10		; New log request after 10 seconds	;was 10 seconds!!!
	SETB	LOG_1ST
	LJMP	ENCODER_CONT1

INC_SIGNAL_TIME:
; Increase signal time with 1 minute:
	MOV	COUNT2,#16		; Address range of signal time in log page 
	MOV	COUNT1,#23		;

	LCALL	INC_TIME

	MOV	A,GRAPH4		; Check ch1 limiter
	CLR	C			;
	SUBB	A,#07EH			; Threshold for ..dB
	JC	INC_LIMIT_TIME		;

	MOV	A,GRAPH3		; Check ch2 limiter
	CLR	C			;
	SUBB	A,#07EH			; Threshold for ..dB
	JC	INC_LIMIT_TIME		;

	LCALL	STORE_LOG1
	SJMP	GOTO_LOG2

INC_LIMIT_TIME:
; Increase limit time with 1 minute:
	MOV	COUNT2,#24		; Address range of limit time in log page 
	MOV	COUNT1,#31		;

	LCALL	INC_TIME

	LCALL	STORE_LOG1

GOTO_LOG2:
	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#008H		; Start at PAGE525
	MOV	OPCODE2,#034H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get data from FLASH
	MOV	GRAPH1,SPIRDAT		; Preset version code in GRAPH1

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LCALL	COPY_LOG2		; Copy limitlog page to buffer1

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; Start at byte0
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get counter
	MOV	COUNT1,SPIRDAT		; Move received data to COUNT1

	LCALL	SPI_RX			; Get preset version code of this page
	MOV	GRAPH2,SPIRDAT		; Move received data to GRAPH2

	LCALL	SPI_RX			; Get year code of this page
	MOV	COUNT2,SPIRDAT		; Move received data to COUNT2

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

; Get year from RTC:				
	MOV	I2C_TX,#00H		; YR adress in RTC
	MOV	I2C_TX+1,#035H		; 
	LCALL	GET_RTC_DATA

	MOV	A,COUNT2		; Get year code of this page
	CJNE	A,I2C_TX,NEW_YEAR	; Compare to actual year
	SJMP	SAME_YEAR
NEW_YEAR:
	MOV	COUNT1,#0		; Start new page in new year
SAME_YEAR:

	MOV	A,GRAPH2		; Get preset version code of this page
	CJNE	A,GRAPH1,NEW_FIRM	; Compare to actual preset version code
	SJMP	SAME_FIRM
NEW_FIRM:
	MOV	COUNT1,#0		; Start new page when preset version changed
SAME_FIRM:

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; Start at byte0
	LCALL	FLASH_OPCODE		;

	MOV	A,COUNT1		; Increment counter
	INC	A			;
	MOV	B,A
	LCALL	SPI_TX			; Write byte to FLASH
		
	CJNE	A,#1,NO_INIT_NEW_PAGE

INIT_NEW_PAGE:
	MOV	A,GRAPH1		; Preset version
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	A,I2C_TX		; Year
	LCALL	SPI_TX			; Write byte to FLASH

NO_INIT_NEW_PAGE:
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,COUNT1		; Calculate next free address
	RL	A			; Address=count*8+3
	RL	A
	CLR	C
	RLC	A
	MOV	OPCODE3,A

	CLR	A
	RLC	A
	MOV	OPCODE2,A

	MOV	A,OPCODE3
	ADD	A,#3
	MOV	OPCODE3,A

	MOV	A,OPCODE2
	ADDC	A,#0
	MOV	OPCODE2,A

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte...
	LCALL	FLASH_OPCODE		;

	MOV	I2C_TX,#00H		; DT adress in RTC
	MOV	I2C_TX+1,#033H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX+1		; Get month
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	A,I2C_TX		; Get date
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	I2C_TX,#00H		; MN adress in RTC
	MOV	I2C_TX+1,#031H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX+1		; Get hour
	ANL	A,#07FH			; Set MIL bit to 0
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	A,I2C_TX		; Get minutes
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	A,MOD1			; Get speaker model for ch1
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	A,MOD2			; Get speaker model for ch2
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	A,GRAPH4		; Get limit data for ch1
	LCALL	SPI_TX			; Write byte to FLASH

	MOV	A,GRAPH3		; Get limit data for ch2
	LCALL	SPI_TX			; Write byte to FLASH

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,B
	CJNE	A,#60,NO_PAGE_FULL
	SJMP	PAGE_FULL
NO_PAGE_FULL:

	LJMP	ENCODER_CONT1

PAGE_FULL:
	MOV	A,PGADDL		; Increase page address by 4 (1 page)
	ADD	A,#004H			;
	MOV	PGADDL,A		;
	MOV	A,PGADDH		;
	ADDC	A,#000H			;
	MOV	PGADDH,A		;
	JNB	ACC.7,NO_PAGE_LIMIT3	; Count pages until 8192 (32768/4), then start again at page 1025

	MOV	PGADDH,#010H		; Start all over at page 1025
	MOV	PGADDL,#004H		;
NO_PAGE_LIMIT3:

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; Start at byte0
	LCALL	FLASH_OPCODE		;

	MOV	A,PGADDH		; 
	LCALL	SPI_TX			; Write byte to FLASH
	MOV	A,PGADDL		; 
	LCALL	SPI_TX			; Write byte to FLASH

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page1024
	MOV	OPCODE1,#010H		; Page address
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	LJMP	ENCODER_CONT1

;* ------------------------------------------------------------------------
;*  Function  :RESET_WDT
;*  Purpose   :Resets or starts watchdog timer
;*  Arguments :-
;*  Uses      :-
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
RESET_WDT:

	MOV	0A6H,#01EH
	MOV	0A6H,#0E1H

	RET

;* ------------------------------------------------------------------------
;*  Function  :SCLHIGH
;*  Purpose   :sends SCL pin high and waits for any clock stretching peripherals.
;*  Arguments :-
;*  Uses      :-
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
SCLHIGH:
	SETB    SCLPIN			; Set SCL from our end.
	JNB     SCLPIN,$		; Wait for pin to actually go high.
	RET

;* ------------------------------------------------------------------------
;*  Function  :SENDSTOP
;*  Purpose   :sends an I2C stop, releasing the bus.
;*  Arguments :-
;*  Uses      :-
;*  Returns   :-
;* ------------------------------------------------------------------------
SENDSTOP:
	CLR	SDAPIN			; Get SDA ready for stop.
	LCALL	SCLHIGH			; Set SCL for stop.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	SETB	SDAPIN			; Send I2C stop.

	RET				; Bus should now be released.

;* ------------------------------------------------------------------------
;*  Function  :SENDBYTE
;*  Purpose   :sends one byte of data to an I2C slave device.
;*  Arguments :A, byte to be send
;*  Uses      :C
;*  Returns   :-
;* ------------------------------------------------------------------------
SENDBYTE:  
	MOV	BITCNT,#8		; Set bit count.

SBLOOP:	RLC	A			; Send one data bit.
	MOV	SDAPIN,C		; Put data bit on pin.
	LCALL	SCLHIGH			; Send clock.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	CLR	SCLPIN
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	DJNZ	BITCNT,SBLOOP		; Repeat until all bits send.

	SETB	SDAPIN			; Release data line for acknowledge.
	NOP
	LCALL	SCLHIGH			; Send clock for acknowledge.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	JNB	SDAPIN,EXIT1		; Check for valid acknowledge bit.
	SETB	NOACK			; Set status for no acknowledge.
EXIT1:	CLR	SCLPIN			; Finish acknowledge bit.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	RET

;* ------------------------------------------------------------------------
;*  Function  :GOMASTER
;*  Purpose   :sends an I2C start condition and slave address.
;*  Arguments :SLVADR = slave address.
;*  Uses      :A
;*  Returns   :-
;* ------------------------------------------------------------------------
GOMASTER:  
	CLR	NOACK			; Clear error status flags.

	JNB	SCLPIN,$		; Wait for bus clear.
	JNB	SDAPIN,$		;

	CLR	SDAPIN			; Begin I2C start.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	CLR	SCLPIN
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP			; Complete I2C start.
	MOV	A,SLVADR		; Get slave address.

	MOV	BITCNT,#8		; Set bit count.

SBLOOP1:
	RLC	A			; Send one data bit.
	MOV	SDAPIN,C		; Put data bit on pin.
	LCALL	SCLHIGH			; Send clock.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	CLR	SCLPIN
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	DJNZ	BITCNT,SBLOOP1		; Repeat until all bits send.

	SETB	SDAPIN			; Release data line for acknowledge.
	NOP
	LCALL	SCLHIGH			; Send clock for acknowledge.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	JNB	SDAPIN,EXIT20		; Check for valid acknowledge bit.
	SETB	NOACK			; Set status for no acknowledge.
EXIT20:	CLR	SCLPIN			; Finish acknowledge bit.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
FAULT:	RET


;* ------------------------------------------------------------------------
;*  Function  :SENDDATA
;*  Purpose   :sends one or more bytes of data to an I2C slave device.
;*  Arguments :BYTECNT = count of bytes to be send.
;*            :SLVADR  = slave address.
;*            :@R0     = data to be send
;*  Uses      :A
;*  Returns   :-
;* ------------------------------------------------------------------------
SENDDATA:  
	MOV	R5,#10
	LCALL	LWAIT

	MOV	A,BYTECNTL
	JZ	CONT4			; Don't increase high byte if low byte is 0
	INC	BYTECNTH
CONT4:
	LCALL	GOMASTER		; Acquire bus and send slave address.
	JB	NOACK,EXIT		; Check for slave not responding.
	
SDLOOP:
	MOV	A,@R0			; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	INC	R0			; Advance buffer pointer
	JB	NOACK,EXIT		; Check for slave not responding
	DJNZ	BYTECNTL,SDLOOP		; All bytes send?
	DJNZ	BYTECNTH,SDLOOP		; All bytes send?

EXIT:	LCALL	SENDSTOP		; Done, send an I2C stop.
	RET

;* ------------------------------------------------------------------------
;*  Function  :SENDDATA_NOSTOP
;*  Purpose   :sends one or more bytes of data to an I2C slave device, but don't send a STOP bit
;*  Arguments :BYTECNT = count of bytes to be send.
;*            :SLVADR  = slave address.
;*            :@R0     = data to be send
;*  Uses      :A
;*  Returns   :-
;* ------------------------------------------------------------------------
SENDDATA_NOSTOP:  
	MOV	A,BYTECNTL
	JZ	CONT5			; Don't increase high byte if low byte is 0
	INC	BYTECNTH
CONT5:
	LCALL	GOMASTER		; Acquire bus and send slave address.
	JB	NOACK,EXIT		; Check for slave not responding.
	
SDLOOP2:
	MOV	A,@R0			; Get data byte from DATA memory
	LCALL	SENDBYTE		; Send next data byte
	INC	R0			; Advance buffer pointer
	JB	NOACK,EXIT12		; Check for slave not responding
	DJNZ	BYTECNTL,SDLOOP2	; All bytes send?
	DJNZ	BYTECNTH,SDLOOP2	; All bytes send?
	LCALL	SCLHIGH			; 
EXIT12:	
	RET

;* ------------------------------------------------------------------------
;*  Function  :RCVBYTE
;*  Purpose   :receives one byte of data from an I2C slave device.
;*  Arguments :-
;*  Uses      :C
;*  Returns   :A = data byte received.
;* ------------------------------------------------------------------------
RCVBYTE:	
	JB	DSP_HREQ,$		; Wait for HREQ assertion
RCVBYTE_RTC:

	MOV	BITCNT,#08H		; Set bit count.
RBLOOP:	LCALL	SCLHIGH			; Read one data bit.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	MOV	C,SDAPIN		; Get data bit from pin.
	RLC	A			; Rotate bit into result byte.
	CLR	SCLPIN
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	DJNZ	BITCNT,RBLOOP		; Repeat until all bits received.

	PUSH	ACC			; Save A
	MOV	A,BYTECNTL		;
	CJNE	A,#01H,RBACK		; Check for last byte of frame.
	MOV	A,BYTECNTH		;
	CJNE	A,#01H,RBACK		;
	SETB	SDAPIN			; Send no acknowledge on last byte.
	SJMP	RBACLK

RBACK:	CLR	SDAPIN			; Send acknowledge bit.
RBACLK:	LCALL	SCLHIGH			; Send acknowledge clock.
	POP	ACC			; Retrieve A
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	CLR	SCLPIN
	SETB	SDAPIN			; Clear acknowledge bit.
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	RET

;* ------------------------------------------------------------------------
;*  Function  :RCVDATA
;*  Purpose   :receives one or more bytes of data from an I2C slave device.
;*  Arguments :BYTECNTL,BYTECNTH = count of bytes to be received.
;*            :SLVADR  = slave address.
;*            :R0      = start address of data to be received.
;*  Uses      :A,BYTECNTH
;*  Calls     :GOMASTER
;*	       RCVBYTE
;*	       SENDSTOP
;*  Returns   :@R0     = data received.
;* ------------------------------------------------------------------------
RCVDATA:
	MOV	A,BYTECNTL
	JZ	CONT3
	INC	BYTECNTH
CONT3:
	INC	SLVADR			; Set for READ of slave.
	LCALL	GOMASTER		; Acquire bus and send slave address.
	JB	NOACK,EXIT2		; Check for slave not responding.
RDLOOP1:
	LCALL	RCVBYTE			; Receive next data byte.
	MOV	@R0,A			; Save data byte in buffer.
	INC	R0			; Advance buffer pointer.
	DJNZ	BYTECNTL,RDLOOP1	; Repeat until all bytes received.
	DJNZ	BYTECNTH,RDLOOP1	; Repeat until all bytes received.

EXIT2:	LCALL	SENDSTOP		; Done, send an I2C stop.
	RET

;* ------------------------------------------------------------------------
;*  Function  :RCVDATA_RTC
;*  Purpose   :receives one or more bytes of data from an I2C slave device.
;*  Arguments :BYTECNTL,BYTECNTH = count of bytes to be received.
;*            :SLVADR  = slave address.
;*            :R0      = start address of data to be received.
;*  Uses      :A,BYTECNTH
;*  Calls     :GOMASTER
;*	       RCVBYTE_RTC
;*	       SENDSTOP
;*  Returns   :@R0     = data received.
;* ------------------------------------------------------------------------
RCVDATA_RTC:
	MOV	A,BYTECNTL
	JZ	CONT6
	INC	BYTECNTH
CONT6:
	INC	SLVADR			; Set for READ of slave.
	LCALL	GOMASTER		; Acquire bus and send slave address.
	JB	NOACK,EXIT14		; Check for slave not responding.
RDLOOP2:
	LCALL	RCVBYTE_RTC		; Receive next data byte.
	MOV	@R0,A			; Save data byte in buffer.
	INC	R0			; Advance buffer pointer.
	DJNZ	BYTECNTL,RDLOOP2	; Repeat until all bytes received.
	DJNZ	BYTECNTH,RDLOOP2	; Repeat until all bytes received.

EXIT14:	LCALL	SENDSTOP		; Done, send an I2C stop.
	RET

;* ------------------------------------------------------------------------
;*  Function  :INIT_RTC
;*  Purpose   :Initialise real time clock
;*  Arguments :-
;*  Uses      :A,R5,COUNT1
;*  Calls     :SET_WEL_RWEL
;*	       GOMASTER
;*	       SENDBYTE
;*	       SENDSTOP
;*	       LWAIT
;*  Returns   :-
;* ------------------------------------------------------------------------
INIT_RTC:
	LCALL	SET_WEL_RWEL

	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,RTC_EXIT0		; Check for slave not responding

	MOV	A,#0			; INT address high byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT0		; Check for slave not responding

	MOV	A,#011H			; INT address low byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT0		; Check for slave not responding

	MOV	A,#018H			; INT set FO1 FO0
	LCALL	SENDBYTE		; Send next data byte

RTC_EXIT0:
	LCALL	SENDSTOP		; Done, send an I2C stop condition

	MOV	R5,#50			; Wait 10ms for nonvolatile write cycle to complete
	LCALL	LWAIT			;

	LCALL	SET_WEL_RWEL

	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,RTC_EXIT6		; Check for slave not responding

	MOV	A,#0			; SC address high byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT6		; Check for slave not responding

	MOV	A,#030H			; SC address low byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT6		; Check for slave not responding

	MOV	COUNT1,#3
SC_MN_HR:
	MOV	A,#000H			; SC, MN and HR set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT6		; Check for slave not responding
	DJNZ	COUNT1,SC_MN_HR

	MOV	COUNT1,#3
DT_M0_YR:
	MOV	A,#001H			; DT, M0 and YR set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT6		; Check for slave not responding
	DJNZ	COUNT1,DT_M0_YR

	MOV	A,#000H			; DW set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT6		; Check for slave not responding

	MOV	A,#020H			; Y2K set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT6		; Check for slave not responding

RTC_EXIT6:
	LCALL	SENDSTOP		; Done, send an I2C stop condition

	MOV	R5,#50			; Wait 10ms for nonvolatile write cycle to complete
	LCALL	LWAIT			;

	RET

;* ------------------------------------------------------------------------
;*  Function  :CHECK_DST
;*  Purpose   :Check daylight saving time and adjust clock for it
;*  Arguments :-
;*  Uses      :A,B,R1,R5,R7,GRAPH1,GRAPH2,GRAPH3,GRAPH4,I2C_TX,I2C_TX+1
;*  Calls     :WRITE_SETTINGS
;*	       GET_RTC_DATA
;*	       SET_WEL_RWEL
;*	       GOMASTER
;*	       SENDBYTE
;*	       SENDSTOP
;*	       LWAIT
;*	       RESET_WDT
;*  Returns   :-
;* ------------------------------------------------------------------------
CHECK_DST:
	JB	DST_EUR,DO_CHECK
	JB	DST_USA,DO_CHECK

	CLR	S_CLK
	LCALL	WRITE_SETTINGS

	RET

DO_CHECK:
	MOV	GRAPH2,#007H		; Start at year 2000
	MOV	GRAPH1,#0D0H		;

	MOV	I2C_TX,#00H		; YR adress in RTC
	MOV	I2C_TX+1,#035H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX		; Add decades
	SWAP	A
	ANL	A,#00FH
	MOV	B,#10
	MUL	AB
	ADD	A,GRAPH1
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	ADDC	A,#0
	MOV	GRAPH2,A

	MOV	A,I2C_TX		; Add single years
	ANL	A,#00FH
	ADD	A,GRAPH1
	MOV	GRAPH1,A
	MOV	A,GRAPH2
	ADDC	A,#0
	MOV	GRAPH2,A

	MOV	GRAPH3,GRAPH1
	MOV	GRAPH4,GRAPH2
	MOV	GRAPH1,#0
	MOV	GRAPH2,#0

	MOV	R1,#5
SLOOP1:					; Years*5
	MOV	A,GRAPH1
	ADD	A,GRAPH3
	MOV	GRAPH1,A

	MOV	A,GRAPH2
	ADDC	A,GRAPH4
	MOV	GRAPH2,A
	
	DJNZ	R1,SLOOP1

	MOV	R1,#2
SLOOP2:					; Years/4
	MOV	A,GRAPH2
	CLR	C
	RRC	A
	MOV	GRAPH2,A

	MOV	A,GRAPH1
	RRC	A
	MOV	GRAPH1,A

	DJNZ	R1,SLOOP2

	MOV	A,GRAPH1		; Years-15 (valid for years 2000-2099)
	CLR	C
	SUBB	A,#15
	MOV	GRAPH1,A

	MOV	A,GRAPH2
	SUBB	A,#0
	MOV	GRAPH2,A

SLOOP3:					; MOD7
	MOV	A,GRAPH1
	CLR	C
	SUBB	A,#7
	MOV	GRAPH1,A

	MOV	A,GRAPH2
	SUBB	A,#0
	MOV	GRAPH2,A	
	JNC	SLOOP3
	
	MOV	A,GRAPH1
	ADD	A,#7
	MOV	GRAPH3,A		; Graph3 = 'f' = (FLOOR((5*yr)/4)-FLOOR(yr/100)+FLOOR(yr/400))MOD7


; Calculate start of summertime

	MOV	GRAPH4,#5
	JB	DST_EUR,DST_OVER5
	MOV	GRAPH4,#2
DST_OVER5:
	ADD	A,GRAPH4		; Calculate start of summertime = Sunday (31-(f+5)MOD7) march (Eur)/ Sunday (14-(f+2)MOD7) march (USA)

SLOOP4:					; MOD7
	SUBB	A,#7
	JNC	SLOOP4
	ADD	A,#7
	MOV	GRAPH1,A
	JZ	SOVER1

	MOV	A,#031H
	JB	DST_EUR,DST_OVER6
	MOV	A,#014H
DST_OVER6:

SLOOP5:	
	ADD	A,#099H
	DA	A
	DJNZ	GRAPH1,SLOOP5
	SJMP	SOVER2

SOVER1:
	MOV	A,#031H
	JB	DST_EUR,DST_OVER7
	MOV	A,#014H
DST_OVER7:

SOVER2:
	MOV	GRAPH1,A		; GRAPH1 = date code in march in this year on which summertime starts

; Calculate start of wintertime

	MOV	A,GRAPH3		; Graph3 = 'f' = (FLOOR((5*yr)/4)-FLOOR(yr/100)+FLOOR(yr/400))MOD7
	ADD	A,#2			; Calculate start of wintertime = Sunday (31-(f+2)MOD7) october (Eur) / Sunday (7-(f+2)MOD7) november (USA)

SLOOP6:					; MOD7
	SUBB	A,#7
	JNC	SLOOP6
	ADD	A,#7
	MOV	GRAPH2,A
	JZ	SOVER3

	MOV	A,#031H
	JB	DST_EUR,DST_OVER8
	MOV	A,#007H
DST_OVER8:

SLOOP7:	
	ADD	A,#099H
	DA	A
	DJNZ	GRAPH2,SLOOP7
	SJMP	SOVER4

SOVER3:
	MOV	A,#031H
	JB	DST_EUR,DST_OVER9
	MOV	A,#007H
DST_OVER9:
SOVER4:
	MOV	GRAPH2,A		; GRAPH2 = date code in october in this year on which wintertime starts

; Check for daylight savings

	MOV	I2C_TX,#00H		; MO adress in RTC
	MOV	I2C_TX+1,#034H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX		; A = current month code

	JNB	STIME,CHECK_SUMMER
	LJMP	CHECK_WINTER

CHECK_SUMMER:				; Now in wintertime. Change to summertime?
	CJNE	A,#011H,NO_SUMMER1
	LJMP	WINTER			; November, stay in wintertime
NO_SUMMER1:
	CJNE	A,#012H,NO_SUMMER2
	LJMP	WINTER			; December, stay in wintertime
NO_SUMMER2:
	CJNE	A,#001H,NO_SUMMER3
	LJMP	WINTER			; January, stay in wintertime
NO_SUMMER3:
	CJNE	A,#002H,NO_SUMMER4
	LJMP	WINTER			; February, stay in wintertime
NO_SUMMER4:

	CJNE	A,#003H,SUMMER1	
	SJMP	CHECK_START_SUMMER	; March, check...
SUMMER1:
	CJNE	A,#010H,SUMMER2
	LJMP	CHECK_END_SUMMER	; October, check...
SUMMER2:

SET_SUMMER:				; Months: 4,5,6,7,8,9 Goto summertime
	SETB	STIME			; Set to summertime

	JNB	S_CLK,ADJUST_TIME1	; Do not adjust clock when manually setting the time
	CLR	S_CLK			;
	CLR	CTIME			; Do not check time next time DDP is powered on
	LCALL	WRITE_SETTINGS
	RET				;

ADJUST_TIME1:
	SETB	CTIME			; Check time next time DDP is powered on

	MOV	I2C_TX,#00H		; HR address in RTC
	MOV	I2C_TX+1,#032H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX
	ANL	A,#07FH			; Mask MIL
	ADD	A,#1			; Add 1 hour
	DA	A
	CJNE	A,#024H,SOVER5
	CLR	A
SOVER5:
	ORL	A,#080H			; Set MIL
	MOV	GRAPH1,A

	LCALL	SET_WEL_RWEL

	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,RTC_EXIT7		; Check for slave not responding

	MOV	A,#0			; HR address high byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT7		; Check for slave not responding

	MOV	A,#032H			; HR address low byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT7		; Check for slave not responding

	MOV	A,GRAPH1		; HR set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT7		; Check for slave not responding

RTC_EXIT7:
	LCALL	SENDSTOP		; Done, send an I2C stop condition

	MOV	R7,#0			; Wait for 1.1sec
S_WAIT1:
	MOV	R5,#11
	LCALL	LWAIT
	LCALL	RESET_WDT
	DJNZ	R7,S_WAIT1

	CLR	S_CLK			;
	LCALL	WRITE_SETTINGS
	RET


CHECK_START_SUMMER:			; March, check...
	MOV	I2C_TX,#00H		; DT adress in RTC
	MOV	I2C_TX+1,#033H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX		; A = current date code
	CLR	C
	SUBB	A,GRAPH1		; GRAPH1 = date code in march in this year on which summertime starts
	JZ	ST_OVER1		; Date matches, check...
	JC	WINTER			; Date not yet reached. Stay in wintertime
	SJMP	SET_SUMMER		; Date has allready passed. Change to summertime

ST_OVER1:
	MOV	I2C_TX,#00H		; HR adress in RTC
	MOV	I2C_TX+1,#032H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX
	ANL	A,#07FH			; Mask MIL
	CLR	C
	SUBB	A,#002H
	JC	WINTER			; Stay in wintertime
	LJMP	SET_SUMMER		; 2:00 hrs or later. Change to summertime

CHECK_END_SUMMER:			; October, check...
	MOV	I2C_TX,#00H		; DT adress in RTC
	MOV	I2C_TX+1,#033H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX		; A = current date code
	CLR	C
	SUBB	A,GRAPH2		; GRAPH2 = date code in october in this year on which wintertime starts
	JZ	ST_OVER2		; Date matches, check...
	JNC	WINTER			; Date has allready passed. Stay in wintertime
	LJMP	SET_SUMMER		; Date not yet reached. Change to summertime

ST_OVER2:
	MOV	I2C_TX,#00H		; HR adress in RTC
	MOV	I2C_TX+1,#032H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX
	ANL	A,#07FH			; Mask MIL
	CLR	C
	SUBB	A,#002H
	JNC	WINTER			; 2:00 hrs or later. Stay in wintertime
	LJMP	SET_SUMMER		; Change to summertime

WINTER:					; Months: 11,12,1,2 Stay in wintertime
	CLR	S_CLK			;
	LCALL	WRITE_SETTINGS
	RET

CHECK_WINTER:				; Now in summertime. Change to wintertime?
	CJNE	A,#004H,NO_WINTER1
	LJMP	SUMMER			; April, stay in summertime
NO_WINTER1:
	CJNE	A,#005H,NO_WINTER2
	LJMP	SUMMER			; May, stay in summertime
NO_WINTER2:
	CJNE	A,#006H,NO_WINTER3
	LJMP	SUMMER			; June, stay in summertime
NO_WINTER3:
	CJNE	A,#007H,NO_WINTER4
	LJMP	SUMMER			; July, stay in summertime
NO_WINTER4:
	CJNE	A,#008H,NO_WINTER5
	LJMP	SUMMER			; August, stay in summertime
NO_WINTER5:
	CJNE	A,#009H,NO_WINTER6
	LJMP	SUMMER			; September, stay in summertime
NO_WINTER6:

	CJNE	A,#010H,WINTER1
	SJMP	CHECK_START_WINTER	; October, check...
WINTER1:
	CJNE	A,#003H,WINTER2
	LJMP	CHECK_END_WINTER	; March, check...
WINTER2:

SET_WINTER:				; Months: 11,12,1,2 Goto wintertime
	CLR	STIME			; Set  to wintertime

	JNB	S_CLK,ADJUST_TIME2	; Do not adjust clock when manually setting the time
	CLR	S_CLK			;
	CLR	CTIME			; Do not check time next time DDP is powered on
	LCALL	WRITE_SETTINGS
	RET				;

ADJUST_TIME2:
	SETB	CTIME			; Check time next time DDP is powered on

	MOV	I2C_TX,#00H		; HR adress in RTC
	MOV	I2C_TX+1,#032H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX
	ANL	A,#07FH			; Mask MIL
	ADD	A,#099H			; Subtract 1 hour
	DA	A
	CJNE	A,#099H,SOVER6
	MOV	A,#023H
SOVER6:
	ORL	A,#080H			; Set MIL
	MOV	GRAPH1,A

	LCALL	SET_WEL_RWEL

	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,RTC_EXIT8		; Check for slave not responding

	MOV	A,#0			; HR address high byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT8		; Check for slave not responding

	MOV	A,#032H			; HR address low byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT8		; Check for slave not responding

	MOV	A,GRAPH1		; HR set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT8		; Check for slave not responding

RTC_EXIT8:
	LCALL	SENDSTOP		; Done, send an I2C stop condition

	MOV	R7,#0			; Wait for 1.1sec
S_WAIT2:
	MOV	R5,#11
	LCALL	LWAIT
	LCALL	RESET_WDT
	DJNZ	R7,S_WAIT2

	CLR	S_CLK			;
	LCALL	WRITE_SETTINGS
	RET

CHECK_START_WINTER:			; October, check...
	MOV	I2C_TX,#00H		; DT adress in RTC
	MOV	I2C_TX+1,#033H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX		; A = current date code
	CLR	C
	SUBB	A,GRAPH2		; GRAPH2 = date code in october in this year on which wintertime starts
	JZ	ST_OVER3		; Date matches, check...
	JC	SUMMER			; Date not yet reached. Stay in summertime
	SJMP	SET_WINTER		; Date has allready passed. Change to wintertime

ST_OVER3:
	MOV	I2C_TX,#00H		; HR adress in RTC
	MOV	I2C_TX+1,#032H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX
	ANL	A,#07FH			; Mask MIL
	JB	S_CLK,ADJUST_TIME3	; Jump when manually setting the time

	CLR	C			; Normal clock running
	SUBB	A,#003H
	JC	SUMMER			; before 3:00 hrs. Stay in summertime
	LJMP	SET_WINTER		; 3:00 hrs or later. Change to wintertime

ADJUST_TIME3:
	CLR	C			; Manually setting the time
	SUBB	A,#002H
	JC	SUMMER			; Before 2:00. Stay in summertime
	LJMP	SET_WINTER		; 2:00 hrs or later. Change to wintertime

CHECK_END_WINTER:			; March, check...
	MOV	I2C_TX,#00H		; DT adress in RTC
	MOV	I2C_TX+1,#033H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX		; A = current date code
	CLR	C
	SUBB	A,GRAPH1		; GRAPH1 = date code in march in this year on which summertime starts
	JZ	ST_OVER4		; Date matches, check...
	JNC	SUMMER			; Date has allready passed. Stay in summertime
	LJMP	SET_WINTER		; Date not yet reached. Change to wintertime

ST_OVER4:
	MOV	I2C_TX,#00H		; HR adress in RTC
	MOV	I2C_TX+1,#032H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX
	ANL	A,#07FH			; Mask MIL
	CLR	C
	SUBB	A,#002H
	JC	SET_WINTER_1		; before 2:00 hrs. Change to wintertime

SUMMER:					; Months: 4,5,6,7,8,9 Stay in summertime
	CLR	S_CLK			;
	LCALL	WRITE_SETTINGS
	RET

SET_WINTER_1:
	LJMP	SET_WINTER

;* ------------------------------------------------------------------------
;*  Function  :SET_CLOCK/CHECK_CLOCK
;*  Purpose   :Enter clock data
;*  Arguments :-
;*  Uses      :A,DPTR,CCNT,I2C_TX,I2C_TX+1,D_HI,D_MID,D_LOW,G_HI,G_LOW,DNCHAR
;*  Calls     :LCD_CLEAR
;*	       LCD_TEXT
;*	       DISPLAY_CLOCK
;*	       LCD_REFRESH
;*	       ENCODER_CHECK
;*	       GET_RTC_DATA
;*	       ENTER_DATA
;*	       WRITE_SETTINGS
;*	       SET_WEL_RWEL
;*	       GOMASTER
;*	       SENDBYTE
;*	       SENDSTOP
;*  Returns   :-
;* ------------------------------------------------------------------------
CHECK_CLOCK:
	LCALL	LCD_CLEAR

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#CHK_STIME
	JB	STIME,SUMMERTIME
	MOV	DPTR,#CHK_WTIME
SUMMERTIME:
	LCALL	LCD_TEXT

	SJMP	SET_CLOCK2

SET_CLOCK:

; Enter daytime:
	LCALL	LCD_CLEAR

	MOV	DPTR,#0006H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#TIME
	LCALL	LCD_TEXT

SET_CLOCK2:
	SETB	S_CLK

	MOV	DPTR,#0106H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DST_ADJ
	LCALL	LCD_TEXT

; Display date format:
	MOV	DPTR,#0186H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DATEFORM
	LCALL	LCD_TEXT

	MOV	DPTR,#01CEH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DDMMYY
	JNB	DT_FRM,DFRM_OVER
	MOV	DPTR,#MMDDYY
DFRM_OVER:
	LCALL	LCD_TEXT

; Display clock:
	LCALL	DISPLAY_CLOCK

; Change Daylight saving mode:
SETCLOCK_1:
	MOV	DPTR,#014EH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#OFF
	JNB	DST_EUR,DS_OVER1
	MOV	DPTR,#EUR
	SJMP	DS_OVER2
DS_OVER1:
	JNB	DST_USA,DS_OVER2
	MOV	DPTR,#USA
DS_OVER2:
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

SETCLOCK_WAIT1:
	LCALL	ENCODER_CHECK
	JNB	ENC,SETCLOCK_WAIT1
	CLR	ENC
	JB	RIGHT,DST_UP
	JB	LEFT,DST_DOWN

	MOV	DPTR,#014EH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#OFF
	JNB	DST_EUR,DS_OVER3
	MOV	DPTR,#EUR
	SJMP	DS_OVER4
DS_OVER3:
	JNB	DST_USA,DS_OVER4
	MOV	DPTR,#USA
DS_OVER4:
	LCALL	LCD_TEXT

	SJMP	SETCLOCK_2

DST_UP:
	JB	DST_EUR,GOTO_DST_USA
	JB	DST_USA,SETCLOCK_WAIT1

GOTO_DST_EUR:
	SETB	DST_EUR
	CLR	DST_USA
	SJMP	SETCLOCK_1

GOTO_DST_USA:
	CLR	DST_EUR
	SETB	DST_USA
	SJMP	SETCLOCK_1

DST_DOWN:
	JB	DST_EUR,GOTO_DST_OFF
	JB	DST_USA,GOTO_DST_EUR
	SJMP	SETCLOCK_WAIT1

GOTO_DST_OFF:
	CLR	DST_EUR
	CLR	DST_USA
	SJMP	SETCLOCK_1

SETCLOCK_2:
	MOV	DPTR,#01CEH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DDMMYY
	JNB	DT_FRM,FRM_OVER1
	MOV	DPTR,#MMDDYY
FRM_OVER1:
	SETB	INV
	LCALL	LCD_TEXT
	LCALL	LCD_REFRESH		; Refresh LCD display data

SETCLOCK_WAIT2:
	LCALL	ENCODER_CHECK
	JNB	ENC,SETCLOCK_WAIT2
	CLR	ENC
	JB	RIGHT,DATEFORM_MMDDYY
	JB	LEFT,DATEFORM_DDMMYY

	MOV	DPTR,#01CEH		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#DDMMYY
	JNB	DT_FRM,FRM_OVER2
	MOV	DPTR,#MMDDYY
FRM_OVER2:
	LCALL	LCD_TEXT
	LCALL	DISPLAY_CLOCK

	SJMP	SETCLOCK_3

DATEFORM_MMDDYY:
	SETB	DT_FRM
	SJMP	SETCLOCK_2

DATEFORM_DDMMYY:
	CLR	DT_FRM
	SJMP	SETCLOCK_2

SETCLOCK_3:
	JNB	DT_FRM,SETCLOCK_3A
	LJMP	SETCLOCK_3B

; DD-MM'YY Mode:
SETCLOCK_3A:				; Get date
	MOV	DPTR,#0207H		; Start address in LCD memory

	MOV	CCNT,#031H

	MOV	I2C_TX,#00H		; DT adress in RTC
	MOV	I2C_TX+1,#033H		; 
	LCALL	GET_RTC_DATA

	MOV	DNCHAR,I2C_TX
	LCALL	ENTER_DATA		; Get date
	MOV	D_LOW,DNCHAR		; Temp. store date data in this variable

SETCLOCK_4A:				; Get month
	MOV	DPTR,#0219H		; Start address in LCD memory

	MOV	CCNT,#012H

	MOV	I2C_TX,#00H		; MO adress in RTC
	MOV	I2C_TX+1,#034H		; 
	LCALL	GET_RTC_DATA

	MOV	DNCHAR,I2C_TX
	LCALL	ENTER_DATA		; Get month
	MOV	G_HI,DNCHAR		; Temp. store month data in this variable

	MOV	A,G_HI			; Get month data
	CJNE	A,#001H,NO_JAN
	SJMP	END_MONTH
NO_JAN:
	CJNE	A,#002H,NO_FEB
	MOV	A,D_LOW			; Get date data
	CLR	C
	SUBB	A,#029H
	JC	END_MONTH
	SJMP	SETCLOCK_4A
NO_FEB:
	CJNE	A,#003H,NO_MAR
	SJMP	END_MONTH
NO_MAR:
	CJNE	A,#004H,NO_APR
	MOV	A,D_LOW			; Get date data
	CLR	C
	SUBB	A,#031H
	JC	END_MONTH
	SJMP	SETCLOCK_4A
NO_APR:
	CJNE	A,#005H,NO_MAY
	SJMP	END_MONTH
NO_MAY:
	CJNE	A,#006H,NO_JUN
	MOV	A,D_LOW			; Get date data
	CLR	C
	SUBB	A,#031H
	JC	END_MONTH
	SJMP	SETCLOCK_4A
NO_JUN:
	CJNE	A,#007H,NO_JUL
	SJMP	END_MONTH
NO_JUL:
	CJNE	A,#008H,NO_AUG
	SJMP	END_MONTH
NO_AUG:
	CJNE	A,#009H,NO_SEP
	MOV	A,D_LOW			; Get date data
	CLR	C
	SUBB	A,#031H
	JC	END_MONTH
	SJMP	SETCLOCK_4A
NO_SEP:
	CJNE	A,#010H,NO_OCT
	SJMP	END_MONTH
NO_OCT:
	CJNE	A,#011H,NO_NOV
	MOV	A,D_LOW			; Get date data
	CLR	C
	SUBB	A,#031H
	JC	END_MONTH
	SJMP	SETCLOCK_4A
NO_NOV:
	CJNE	A,#012H,NO_DEC
	SJMP	END_MONTH
NO_DEC:


END_MONTH:
	SJMP	SETCLOCK_5

; MM-DD'YY Mode:
SETCLOCK_3B:				; Get month
	MOV	DPTR,#0207H		; Start address in LCD memory
	MOV	CCNT,#012H

	MOV	I2C_TX,#00H		; MO adress in RTC
	MOV	I2C_TX+1,#034H		; 
	LCALL	GET_RTC_DATA

	MOV	DNCHAR,I2C_TX
	LCALL	ENTER_DATA		; Get month
	MOV	G_HI,DNCHAR		; Temp. store month data in this variable

SETCLOCK_4B:				; Get date
	MOV	DPTR,#0219H		; Start address in LCD memory

	MOV	CCNT,#031H
	MOV	A,G_HI
	CJNE	A,#2,NO_FEB1
	MOV	CCNT,#029H
NO_FEB1:
	MOV	A,G_HI
	CJNE	A,#4,NO_APR1
	MOV	CCNT,#030H
NO_APR1:
	MOV	A,G_HI
	CJNE	A,#6,NO_JUN1
	MOV	CCNT,#030H
NO_JUN1:
	MOV	A,G_HI
	CJNE	A,#9,NO_SEP1
	MOV	CCNT,#030H
NO_SEP1:
	MOV	A,G_HI
	CJNE	A,#11,NO_NOV1
	MOV	CCNT,#030H
NO_NOV1:

	MOV	I2C_TX,#00H		; DT adress in RTC
	MOV	I2C_TX+1,#033H		; 
	LCALL	GET_RTC_DATA

	MOV	DNCHAR,I2C_TX
	LCALL	ENTER_DATA		; Get date
	MOV	D_LOW,DNCHAR		; Temp. store date data in this variable


SETCLOCK_5:				; Get year
	MOV	DPTR,#022BH		; Start address in LCD memory

	MOV	CCNT,#099H

	MOV	I2C_TX,#00H		; YR adress in RTC
	MOV	I2C_TX+1,#035H		; 
	LCALL	GET_RTC_DATA

	MOV	DNCHAR,I2C_TX
	LCALL	ENTER_DATA		; Get year
	MOV	G_LOW,DNCHAR		; Temp. store year data in this variable

SETCLOCK_6:				; Get hour
	MOV	DPTR,#023DH		; Start address in LCD memory

	MOV	CCNT,#023H

	MOV	I2C_TX,#00H		; HR adress in RTC
	MOV	I2C_TX+1,#032H		; 
	LCALL	GET_RTC_DATA

	MOV	A,I2C_TX
	ANL	A,#07FH
	MOV	DNCHAR,A

	LCALL	ENTER_DATA		; Get hour

	MOV	A,DNCHAR		; HR set
	ORL	A,#080H			; Set MIL
	MOV	D_MID,A			; Temp. store hour data in this variable

SETCLOCK_7:				; Get minute
	MOV	DPTR,#024FH		; Start address in LCD memory

	MOV	CCNT,#059H

	MOV	I2C_TX,#00H		; MN adress in RTC
	MOV	I2C_TX+1,#031H		; 
	LCALL	GET_RTC_DATA

	MOV	DNCHAR,I2C_TX
	LCALL	ENTER_DATA		; Get minute
	MOV	D_HI,DNCHAR		; Temp. store minute data in this variable

	LCALL	WRITE_SETTINGS

;Write clock data to ISL12026:
	LCALL	SET_WEL_RWEL

	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	MOV	A,#0			; SC address high byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	MOV	A,#030H			; SC address low byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	CLR	A			; SC set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	MOV	A,D_HI			; MN set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	MOV	A,D_MID			; HR set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	MOV	A,D_LOW			; DT set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	MOV	A,G_HI			; M0 set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	MOV	A,G_LOW			; YR set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	CLR	A			; DW set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

	MOV	A,020H			; Y2K set
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT1		; Check for slave not responding

RTC_EXIT1:
	LCALL	SENDSTOP		; Done, send an I2C stop condition

	MOV	SECS,#59

	RET

;* ------------------------------------------------------------------------
;*  Function  :DISPLAY_CLOCK
;*  Purpose   :Display data from real time clock
;*  Arguments :-
;*  Uses      :A,2x DPTR,I2C_TX,I2C_TX+1
;*  Calls     :LCD_TEXT
;*	       GET_RTC_DATA
;*	       LCD_NUMBER
;*  Returns   :-
;* ------------------------------------------------------------------------
DISPLAY_CLOCK:
	MOV	DPTR,#0206H		; Start address in LCD memory
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#SETC
	LCALL	LCD_TEXT

	MOV	I2C_TX,#00H		; MO adress in RTC
	MOV	I2C_TX+1,#034H		; 
	LCALL	GET_RTC_DATA

	MOV	DPTR,#0206H		; Start address in LCD memory (USA)
	JB	DT_FRM,DISP_CLK_OVER1
	MOV	DPTR,#0218H		; Start address in LCD memory (Eur)
DISP_CLK_OVER1:
	MOV	A,I2C_TX		; Display month
	SWAP	A
	ANL	A,#0FH
	LCALL	LCD_NUMBER
	MOV	A,I2C_TX
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	MOV	DPTR,#022AH		; Start address in LCD memory
	MOV	A,I2C_TX+1		; Display year
	SWAP	A
	ANL	A,#0FH
	LCALL	LCD_NUMBER
	MOV	A,I2C_TX+1
	ANL	A,#0FH
	
	LCALL	LCD_NUMBER

	MOV	I2C_TX,#00H		; HR adress in RTC
	MOV	I2C_TX+1,#032H		; 
	LCALL	GET_RTC_DATA

	MOV	DPTR,#023CH		; Start address in LCD memory
	MOV	A,I2C_TX		; Display hour
	SWAP	A
	ANL	A,#07H
	LCALL	LCD_NUMBER
	
	MOV	A,I2C_TX
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	MOV	DPTR,#0218H		; Start address in LCD memory (USA)
	JB	DT_FRM,DISP_CLK_OVER4
	MOV	DPTR,#0206H		; Start address in LCD memory (Eur)
DISP_CLK_OVER4:
	MOV	A,I2C_TX+1		; Display date
	SWAP	A
	ANL	A,#0FH
	LCALL	LCD_NUMBER
	MOV	A,I2C_TX+1
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	MOV	I2C_TX,#00H		; MN adress in RTC
	MOV	I2C_TX+1,#031H		; 
	LCALL	GET_RTC_DATA

	MOV	DPTR,#024EH		; Start address in LCD memory
	MOV	A,I2C_TX
	SWAP	A
	ANL	A,#0FH
	LCALL	LCD_NUMBER
	MOV	A,I2C_TX
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	RET

;* ------------------------------------------------------------------------
;*  Function  :GET_RTC_DATA
;*  Purpose   :Get data from real time clock
;*  Arguments :I2C_TX,I2C_TX+1
;*  Uses      :R0,BYTECNTL,BYTECNTH,SLVADR
;*  Calls     :SENDDATA_NOSTOP
;*	       RCVDATA_RTC
;*  Returns   :-
;* ------------------------------------------------------------------------
GET_RTC_DATA:			

	MOV	BYTECNTL,#02H		; send 2 bytes
	MOV	BYTECNTH,#00H		; 

        MOV	SLVADR,#RTC_CCR		; Get RTC I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA_NOSTOP		;

	MOV	BYTECNTL,#02H		; Receive 2 bytes
	MOV	BYTECNTH,#00H		; 

        MOV	SLVADR,#RTC_CCR		; Get RTC I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	RCVDATA_RTC		;

	RET

;* ------------------------------------------------------------------------
;*  Function  :SET_WEL_RWEL
;*  Purpose   :Set WEL and RWEL bits in RS of real time clock
;*  Arguments :-
;*  Uses      :A,SLVADR
;*  Calls     :GOMASTER
;*	       SENDBYTE
;*	       SENDSTOP
;*  Returns   :-
;* ------------------------------------------------------------------------

SET_WEL_RWEL:
        MOV	SLVADR,#RTC_CCR		; Get RTC slave address

	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,RTC_EXIT		; Check for slave not responding

	MOV	A,#0			; SR address high byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT		; Check for slave not responding

	MOV	A,#03FH			; SR address low byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT		; Check for slave not responding

	MOV	A,#002H			; SR set WEL
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT		; Check for slave not responding

	LCALL	SENDSTOP		; Done, send an I2C stop condition

	LCALL	GOMASTER		; Acquire I2C bus and send slave address
	JB	NOACK,RTC_EXIT		; Check for slave not responding

	MOV	A,#0			; SR address high byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT		; Check for slave not responding

	MOV	A,#03FH			; SR address low byte
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT		; Check for slave not responding

	MOV	A,#006H			; SR set RWEL
	LCALL	SENDBYTE		; Send next data byte
	JB	NOACK,RTC_EXIT		; Check for slave not responding

RTC_EXIT:
	LCALL	SENDSTOP		; Done, send an I2C stop condition

	RET

;* ------------------------------------------------------------------------
;*  Function  :ENTER_DATA
;*  Purpose   :Nummerical data input from user
;*  Arguments :DNCHAR,CCNT
;*  Uses      :A,COUNT1
;*  Calls     :LCD_NUMBER
;*	       LCD_REFRESH
;*	       ENCODER_CHECK
;*  Returns   :A
;* ------------------------------------------------------------------------
ENTER_DATA:
	DEC	DPL
DATA_LOOP:
	MOV	A,DNCHAR
	SWAP	A
	ANL	A,#0FH
	SETB	INV
	LCALL	LCD_NUMBER

	MOV	A,DNCHAR
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	LCALL	LCD_REFRESH

	MOV	COUNT1,#12		; Reset LCD pointer
RST_DPTR:				;
	DEC	DPL			;
	DJNZ	COUNT1,RST_DPTR		;

DATA_WAIT:	
	LCALL	ENCODER_CHECK
	JNB	ENC,DATA_WAIT
	CLR	ENC
	JB	RIGHT,DATA_UP
	JB	LEFT,DATA_DOWN

	MOV	A,DNCHAR
	SWAP	A
	ANL	A,#0FH
	CLR	INV
	LCALL	LCD_NUMBER

	MOV	A,DNCHAR
	ANL	A,#0FH
	LCALL	LCD_NUMBER

	RET

DATA_UP:
	MOV	A,DNCHAR
	CJNE	A,CCNT,DATA_UP1
	MOV	DNCHAR,#0
	MOV	A,CCNT
	CJNE	A,#012H,DATA_UP2
	MOV	DNCHAR,#1
DATA_UP2:
	CJNE	A,#029H,DATA_UP3
	MOV	DNCHAR,#1
DATA_UP3:
	CJNE	A,#030H,DATA_UP4
	MOV	DNCHAR,#1
DATA_UP4:
	CJNE	A,#031H,DATA_UP5
	MOV	DNCHAR,#1
DATA_UP5:

	SJMP	DATA_LOOP
DATA_UP1:
	ADD	A,#01H
	DA	A
	MOV	DNCHAR,A
	SJMP	DATA_LOOP

DATA_DOWN:
	MOV	A,DNCHAR
	JNZ	DATA_DOWN1
	MOV	DNCHAR,CCNT
	SJMP	DATA_LOOP
DATA_DOWN1:
	ADD	A,#099H
	DA	A
	MOV	DNCHAR,A
	JNZ	DATA_LOOP
	MOV	A,CCNT
	CJNE	A,#012H,DATA_DOWN2
	MOV	DNCHAR,CCNT
DATA_DOWN2:
	CJNE	A,#029H,DATA_DOWN3
	MOV	DNCHAR,CCNT
DATA_DOWN3:
	CJNE	A,#030H,DATA_DOWN4
	MOV	DNCHAR,CCNT
DATA_DOWN4:
	CJNE	A,#031H,DATA_DOWN5
	MOV	DNCHAR,CCNT
DATA_DOWN5:
	LJMP	DATA_LOOP

;* ------------------------------------------------------------------------
;*  Function  :LCD_GRAPH
;*  Purpose   :Places graphics data in LCD ERAM space
;*  Arguments :2x DPTR
;*  Uses      :A,B,R5,R7
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------

LCD_GRAPH:
	INC	0A2H			; Switch data pointers
	PUSH	DPL
	PUSH	DPH
	INC	0A2H			; Switch data pointers

	CLR	A
	MOVC	A,@A+DPTR		; Number of bytes in 1 line
	MOV	R7,A
	MOV	B,A
	INC	DPTR

	CLR	A
	MOVC	A,@A+DPTR		; Number of lines
	MOV	R5,A
	INC	DPTR

GRAPH_LOOP:
	CLR	A
	MOVC	A,@A+DPTR		; ASCII value in A
	INC	DPTR
	INC	0A2H			; Switch data pointers
	MOVX	@DPTR,A
	INC	DPTR
	INC	0A2H			; Switch data pointers
	DJNZ	R7,GRAPH_LOOP

	INC	0A2H			; Switch data pointers	

	POP	DPH
	POP	DPL

	MOV	A,DPL
	ADD	A,#080H
	MOV	DPL,A

	MOV	A,DPH
	ADDC	A,#00H
	MOV	DPH,A

	PUSH	DPL
	PUSH	DPH

	INC	0A2H			; Switch data pointers

	MOV	R7,B

	DJNZ	R5,GRAPH_LOOP

	POP	DPH
	POP	DPL

	RET

;* ------------------------------------------------------------------------
;*  Function  :LCD_CHAR
;*  Purpose   :Places character in LCD ERAM space
;*  Arguments :A,2x DPTR
;*  Uses      :R7,CHAR,COUNT1,COUNT2
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
LCD_CHAR:
	MOV	CHAR,A			; Save A

	CLR	A			; Start with one pixel space
	JNB	INV,NO_INVERSE6
	CPL	A
	CPL	ACC.7
NO_INVERSE6:
	MOVX	@DPTR,A
	INC	DPTR

	MOV	A,CHAR
	CLR	C
	SUBB	A,#020H			; Table starts with ASCII code 032

	INC	0A2H			; Switch data pointers
	MOV	DPTR,#ASCII_TABLE

	JZ	SPACE1
	MOV	COUNT1,A
CHAR_LOOP2:
	MOV	COUNT2,#005H
CHAR_LOOP1:
	INC	DPTR
	DJNZ	COUNT2,CHAR_LOOP1
	DJNZ	COUNT1,CHAR_LOOP2

SPACE1:
	MOV	R7,#05H			; 5 bytes per character
CHAR_LOOP:
	CLR	A
	MOVC	A,@A+DPTR
	INC	DPTR

	INC	0A2H			; Switch data pointers
	JNB	INV,NO_INVERSE7
	CPL	A
	CPL	ACC.7
NO_INVERSE7:
	MOVX	@DPTR,A
	INC	DPTR
	INC	0A2H			; Switch data pointers
	DJNZ	R7,CHAR_LOOP

	INC	0A2H			; Switch data pointers
	RET

;* ------------------------------------------------------------------------
;*  Function  :LCD_NUMBER
;*  Purpose   :Places nummeric value in LCD ERAM space
;*  Arguments :DPTR,A
;*  Uses      :B,R7,CHAR
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
LCD_NUMBER:
	MOV	CHAR,A			; Save A

	CLR	A			; Start with one pixel space
	JNB	INV,NO_INVERSE4
	CPL	A
	CPL	ACC.7
NO_INVERSE4:
	MOVX	@DPTR,A
	INC	DPTR


	MOV	A,CHAR
	INC	0A2H			; Switch data pointers
	MOV	DPTR,#NUMB
	MOV	B,#05H
	MUL	AB

	MOV	CHAR,A

	MOV	R7,#05H			; 5 bytes per character
LOOP3:
	MOV	A,CHAR
	MOVC	A,@A+DPTR
	INC	DPTR

	INC	0A2H			; Switch data pointers
	JNB	INV,NO_INVERSE5
	CPL	A
	CPL	ACC.7
NO_INVERSE5:
	MOVX	@DPTR,A
	INC	DPTR
	INC	0A2H			; Switch data pointers
	DJNZ	R7,LOOP3
	INC	0A2H			; Switch data pointers

	RET

;* ------------------------------------------------------------------------
;*  Function  :LCD_ARROW_ICON
;*  Purpose   :Places icon in LCD ERAM space ORed with original data
;*  Arguments :2x DPTR
;*  Uses      :A,B,R7
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------

LCD_ARROW_ICON:
	CLR	A
	MOVC	A,@A+DPTR		; Pixel count in A
	INC	DPTR

	MOV	R7,A
ICON_LOOP:
	CLR	A
	MOVC	A,@A+DPTR		; pixel byte in A
	INC	DPTR
	INC	0A2H			; Switch data pointers
	MOV	B,A
	MOVX	A,@DPTR
	ANL	A,#007H
	ORL	A,B

	MOVX	@DPTR,A
	INC	DPTR
	INC	0A2H			; Switch data pointers
	DJNZ	R7,ICON_LOOP

	RET

;* ------------------------------------------------------------------------
;*  Function  :LCD_ICON
;*  Purpose   :Places icon in LCD ERAM space
;*  Arguments :2x DPTR
;*  Uses      :A,R7
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------

LCD_ICON:
	CLR	A
	MOVC	A,@A+DPTR		; Pixel count in A
	INC	DPTR

	MOV	R7,A
ICON_LOOP1:
	CLR	A
	MOVC	A,@A+DPTR		; pixel byte in A
	INC	DPTR
	INC	0A2H			; Switch data pointers
	MOVX	@DPTR,A
	INC	DPTR
	INC	0A2H			; Switch data pointers
	DJNZ	R7,ICON_LOOP1

	RET
;* ------------------------------------------------------------------------
;*  Function  :LCD_TEXT
;*  Purpose   :Places text in LCD ERAM space
;*  Arguments :2x DPTR
;*  Uses      :A,B,R7
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------

LCD_TEXT:
	MOV	B,#' '
LCD_TEXT1:
	JNB	LINE,NO_LINE1
	CLR	A
	MOVC	A,@A+DPTR		; ASCII value in A
	CJNE	A,#' ',NO_LINE2
	SJMP	LINE1
NO_LINE2:
	CJNE	A,#'|',NO_LINE1
LINE1:
	MOV	A,B
	CJNE	A,#' ',NO_LINE1
	MOV	B,#' '

	INC	0A2H			; Switch data pointers
	MOV	A,#040H
	MOVX	@DPTR,A			;
	INC	DPTR			;
	INC	0A2H			; Switch data pointers
	SJMP	TEXT_LOOP

NO_LINE1:
	CLR	A
	MOVC	A,@A+DPTR		; ASCII value in A
	MOV	B,A
	INC	0A2H			; Switch data pointers
	CLR	A			; Start with one pixel space
	JNB	INV,NO_INVERSE1
	CPL	A
	CPL	ACC.7
NO_INVERSE1:
	MOVX	@DPTR,A			;
	INC	DPTR			;
	INC	0A2H			; Switch data pointers

TEXT_LOOP:
	CLR	A
	MOVC	A,@A+DPTR		; ASCII value in A
	CJNE	A,#'|',NO_END

	INC	DPTR
	CLR	INV			; Clear flag
	CLR	LINE			; Clear flag
	RET

NO_END:
	INC	DPTR
	CLR	C
	SUBB	A,#32			; Table starts with ASCII code 032

	PUSH	DPL
	PUSH	DPH

	MOV	DPTR,#ASCII_TABLE

	JNZ	NO_SPACE_SIGN
	JNB	LINE,SPACE_SIGN
	MOV	A,#'_'
	CLR	C
	SUBB	A,#32	

NO_SPACE_SIGN:
	MOV	COUNT1,A
TEXT_LOOP1:
	MOV	A,DPL
	ADD	A,#5
	MOV	DPL,A
	MOV	A,DPH
	ADDC	A,#0
	MOV	DPH,A
	DJNZ	COUNT1,TEXT_LOOP1
SPACE_SIGN:

	MOV	R7,#05H			; 5 bytes per character
LOOP2:
	CLR	A
	MOVC	A,@A+DPTR
	INC	DPTR

	INC	0A2H			; Switch data pointers
	JNB	INV,NO_INVERSE2
	CPL	A
	CPL	ACC.7
NO_INVERSE2:
	MOVX	@DPTR,A
	INC	DPTR
	INC	0A2H			; Switch data pointers
	DJNZ	R7,LOOP2

	POP	DPH
	POP	DPL

	JMP	LCD_TEXT1

;* ------------------------------------------------------------------------
;*  Function  :LCD_REFRESH
;*  Purpose   :Copies ERAM space to LCD
;*  Arguments :-
;*  Uses      :A,R5,R7,LCD_PG
;*  Calls     :INIT_LCD
;*             BACKLIGHT_INT
;*             LCD_SEND_BYTE
;*             LCD_SEND_DATA
;*  Returns   :-
;* ------------------------------------------------------------------------

LCD_REFRESH:
	PUSH	DPL
	PUSH	DPH

	LCALL	INIT_LCD
	LCALL	BACKLIGHT_INT
	CLR	DBLANK			; Clear flag
	SJMP	LCD_OVER

LCD_REFRESH_NO_BACK:
	JB	DBLANK,NO_LCD		; Do not refresh when LCD is blanked

	PUSH	DPL
	PUSH	DPH

	LCALL	INIT_LCD

LCD_OVER:
	MOV	LCD_PG,#0B0H		; LCD first page address
	MOV	DPTR,#000H		; Pointer to ERAM
	MOV	R7,#008H		; 8 pages

PAGE_LOOP:
	MOV	A,LCD_PG		;
	LCALL	LCD_SEND_BYTE		; LCD Display page set

	MOV	A,#010H			;
	LCALL	LCD_SEND_BYTE		; LCD Display column set

	MOV	A,#004H			; Display upside down
;	MOV	A,#000H			; Display normal
	LCALL	LCD_SEND_BYTE		; LCD Display column set

	MOV	R5,#080H		; 128 columns
COLUMN_LOOP:
	MOVX	A,@DPTR
	INC	DPTR
	LCALL	LCD_SEND_DATA
	DJNZ	R5,COLUMN_LOOP

	INC	LCD_PG
	DJNZ	R7,PAGE_LOOP

	POP	DPH
	POP	DPL
NO_LCD:
	RET
;* ------------------------------------------------------------------------
;*  Function  :LCD_BLANK
;*  Purpose   :All 0s to LCD
;*  Arguments :-
;*  Uses      :A,R1,R2,LCD_PG
;*  Calls     :INIT_LCD
;*	       LCD_SEND_BYTE
;*	       LCD_SEND_DATA
;*  Returns   :-
;* ------------------------------------------------------------------------
LCD_BLANK:
	PUSH	DPL
	PUSH	DPH

	LCALL	INIT_LCD

	MOV	LCD_PG,#0B0H		; LCD first page address
	MOV	DPTR,#000H		; Pointer to ERAM
	MOV	R2,#008H		; 8 pages

PAGE_LOOP1:
	MOV	A,LCD_PG		;
	LCALL	LCD_SEND_BYTE		; LCD Display page set

	MOV	A,#010H			;
	LCALL	LCD_SEND_BYTE		; LCD Display column set

	MOV	A,#004H			; Display upside down
;	MOV	A,#000H			; Display normal

	LCALL	LCD_SEND_BYTE		; LCD Display column set

	MOV	R1,#080H		; 128 columns
COLUMN_LOOP1:
	CLR	A
	LCALL	LCD_SEND_DATA
	DJNZ	R1,COLUMN_LOOP1

	INC	LCD_PG
	DJNZ	R2,PAGE_LOOP1

	POP	DPH
	POP	DPL
	RET

;* ------------------------------------------------------------------------
;*  Function  :LCD_CLEAR
;*  Purpose   :Clears total display ERAM
;*  Arguments :-
;*  Uses      :A,DPTR,R5,R7
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
LCD_CLEAR:
	CLR	A
	MOV	DPTR,#00H
	MOV	R7,#008H		; 8 Pages
CLEAR_PG_LOOP:
	MOV	R5,#080H		; 128 Columns
CLEAR_COL_LOOP:
	MOVX	@DPTR,A
	INC	DPTR
	DJNZ	R5,CLEAR_COL_LOOP

	DJNZ	R7,CLEAR_PG_LOOP

	RET

;* ------------------------------------------------------------------------
;*  Function  :LCD_EQGRAPH_CLEAR/LCD_LOGGRAPH_CLEAR/LCD
;*  Purpose   :Clears part of display ERAM
;*  Arguments :-
;*  Uses      :A,DPTR,R5
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
LCD_EQGRAPH_CLEAR:
	CLR	A

	MOV	DPTR,#020AH
	MOV	R5,#076H		; 128-10 Columns
CLEAR_COL_LOOP0:
	MOVX	@DPTR,A
	INC	DPTR
	DJNZ	R5,CLEAR_COL_LOOP0

LCD_LOGGRAPH_CLEAR:
	CLR	A

	MOV	DPTR,#028AH
	MOV	R5,#076H		; 128-10 Columns
CLEAR_COL_LOOP1:
	MOVX	@DPTR,A
	INC	DPTR
	DJNZ	R5,CLEAR_COL_LOOP1

	MOV	DPTR,#030AH
	MOV	R5,#076H		; 128-10 Columns
CLEAR_COL_LOOP2:
	MOVX	@DPTR,A
	INC	DPTR
	DJNZ	R5,CLEAR_COL_LOOP2

	MOV	DPTR,#038AH
	MOV	R5,#076H		; 128-10 Columns
CLEAR_COL_LOOP3:
	MOVX	@DPTR,A
	INC	DPTR
	DJNZ	R5,CLEAR_COL_LOOP3

	RET	
;* ------------------------------------------------------------------------
;*  Function  :LCD_SEND_BYTE/LCD_SEND_DATA
;*  Purpose   :Send contol/data byte to LCD
;*  Arguments :A
;*  Uses      :R3
;*  Calls     :-	
;*  Returns   :-
;* ------------------------------------------------------------------------

LCD_SEND_BYTE:
	CLR	LCD_DCNTRL		; Byte is control data
	SJMP	LCD_BYTE

LCD_SEND_DATA:
	SETB	LCD_DCNTRL		; Byte is data

LCD_BYTE:
	CLR	LCD_CS			; LCD chip select
	MOV	R3,#08H
LCD_BYTE_LOOP:
	RLC	A	
	MOV	LCD_DATA,C		; Data to LCD	
	CLR	LCD_CLK			; Clock low
	SETB	LCD_CLK			; Clock LCD
	DJNZ	R3,LCD_BYTE_LOOP

	SETB	LCD_CS			; LCD chip select

	RET

;* ------------------------------------------------------------------------
;*  Function  :LWAIT
;*  Purpose   :Waits for R5 * 0.4ms
;*  Arguments :R5
;*  Uses      :R6
;*  Calls     :-
;*  Returns   :-
;* ------------------------------------------------------------------------
LWAIT:	
	MOV	R6,#0
	DJNZ	R6,$
	DJNZ	R6,$
	DJNZ	R5,LWAIT		;FOR R5 TIMES
	RET

;* ------------------------------------------------------------------------
;*  Function  :CHECK_ADC_STACKED
;*  Purpose   :Checks and sets or clears adc stacked mode
;*  Arguments :-
;*  Uses      :A,R0,I2C_TX,BYTECNTL,BYTECNTH,SLVADR
;*  Calls     :SENDDATA
;*  Returns   :ADSTACK
;* ------------------------------------------------------------------------
CHECK_ADC_STACKED:	
	JB	ACTIVE,SET_ADC_STACKED	; Jump if in active or bridge mode

	MOV	A,INPSET
	ANL	A,#0FH
	CLR	C
	SUBB	A,#05H
	JZ	SET_ADC_STACKED

NO_STACK:
	CLR	ADSTACK

	RET

SET_ADC_STACKED:
	MOV	A,INPSET
	ANL	A,#0FH
	CJNE	A,#005H,NO_STACK

	SETB	ADSTACK

	MOV	I2C_TX,#050H		; DSP opcode for set adc stacked mode
	MOV	BYTECNTL,#01H		; send 1 byte
	MOV	BYTECNTH,#00H		; 

        MOV	SLVADR,#DSP_ADR		; Get DSP I2C slave address
	MOV	R0,#I2C_TX		; 
	LCALL	SENDDATA		; Send DSP opcode on I2C bus

	RET

;* ------------------------------------------------------------------------
;*  Function  :MUTE_DAC
;*  Purpose   :Mute DA converter
;*  Arguments :-
;*  Uses      :R5
;*  Calls     :LWAIT
;*  Returns   :DAC_MUTE
;* ------------------------------------------------------------------------
MUTE_DAC:
	SETB	DAC_MUTE		; Mute DA converter
	MOV	R5,#50
	LCALL	LWAIT
	RET

;* ------------------------------------------------------------------------
;*  Function  :TIMERO
;*  Purpose   :Timer0 interrupt routine
;*  Arguments :-
;*  Uses      :A
;*  Calls     :-
;*  Returns   :BCKLGHT1-4,DBLANK
;* ------------------------------------------------------------------------
TIMER0:
	PUSH	PSW			; Save Program Status Word
	PUSH	ACC			; Save Accu

	MOV	A,LIGHT
	SWAP	A
	ANL	A,#0FH
	JZ	BLIGHT_ON

	DJNZ	BTOCNT,BLIGHT_ON1
	SETB	BCKLGHT1		; Backlight off
	SETB	BCKLGHT2		;
	SETB	BCKLGHT3		;
	SETB	BCKLGHT4		;
	SETB	DBLANK

BLIGHT_ON1:

	POP	ACC			; Retrieve Accu
	POP	PSW			; Retrieve Program Status Word
	RETI

BLIGHT_ON:
	DJNZ	BTOCNT,BLIGHT_ON2
	MOV	0F1H,#055H		; Set LED output in LEDCON to 4x2mA
BLIGHT_ON2:

	POP	ACC			; Retrieve Accu
	POP	PSW			; Retrieve Program Status Word
	RETI

;* ------------------------------------------------------------------------
;*  Function  :EXT-INTO
;*  Purpose   :INT0 interrupt routine
;*  Arguments :-
;*  Uses      :-
;*  Calls     :-
;*  Returns   :FLASH_CS,BCKLGHT1-4
;* ------------------------------------------------------------------------
EXT_INT0:
	SETB	FLASH_CS		; End current FLASH process

	SETB	BCKLGHT1		; Backlight off
	SETB	BCKLGHT2		;
	SETB	BCKLGHT3		;
	SETB	BCKLGHT4		;

	SJMP	$			; Stop

;* ------------------------------------------------------------------------
;*  End of code
;* ------------------------------------------------------------------------

ALCONS_LOGO:
	DB	01AH,07H	 		; Number of columns, number of lines
	DB	0F8H,0FCH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FEH,0FCH,0F8H
	DB	0FFH,0FFH,0FFH,0FFH,0FFH,0FFH,0FFH,03FH,00FH,007H,003H,003H,001H,001H,001H,081H,081H,001H,001H,001H,003H,003H,007H,00FH,03FH,0FFH
	DB	0FFH,0FFH,0FFH,0FFH,0FFH,0FFH,0C0H,0C0H,0C0H,0C0H,0C0H,0C0H,0C0H,0FEH,0FFH,0FFH,0FFH,0FFH,0FEH,000H,000H,000H,000H,000H,000H,000H
	DB	0FFH,0FFH,0FFH,0FFH,0FFH,0FFH,0FFH,07FH,03FH,01FH,01FH,00FH,00FH,00FH,007H,007H,003H,003H,081H,000H,000H,000H,000H,000H,000H,000H
	DB	0FFH,0FFH,0FFH,0FFH,0FFH,0FFH,001H,000H,000H,000H,000H,000H,000H,0FCH,0FEH,0FEH,0FEH,0FFH,0FFH,000H,000H,000H,000H,000H,000H,000H
	DB	01FH,03FH,07FH,07FH,07FH,07FH,000H,000H,000H,080H,000H,000H,000H,01FH,03FH,07FH,07FH,03FH,01FH,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,0E4H,092H,0FEH,000H,0FFH,000H,07CH,082H,064H,000H,07CH,082H,07CH,000H,0FEH,002H,0FCH,000H,04CH,092H,064H

INPUT1_ICON:
	DB	006H,07FH,07FH,07DH,041H,07FH,07FH
INPUT2_ICON:
	DB	006H,07FH,07FH,045H,051H,07FH,07FH
INPUT12_ICON:
	DB	006H,07FH,041H,07FH,045H,051H,07FH
DELAY_ICON:
	DB	005H,07FH,041H,05DH,063H,07FH 
DELAYLINK_ICON:
	DB	009H,07FH,041H,05DH,063H,07FH,05DH,06BH,077H,07FH
EQ_ICON:
	DB	009H,07FH,041H,055H,07FH,041H,05DH,041H,05FH,07FH
EQB_ICON:
	DB	00DH,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
EQLINK_ICON:
	DB	00DH,07FH,041H,055H,07FH,041H,05DH,041H,05FH,07FH,05DH,06BH,077H,07FH
LOCK_ICON:
	DB	007H,07FH,047H,041H,045H,041H,047H,07FH
L3_ICON:	
	DB	020H,020H,020H,020H,044H,065H,073H,069H,067H,06EH,065H,064H,020H,062H,079H,03AH,07CH
STEREO_ICON:
	DB	016H,07FH,051H,045H,07FH,07DH,041H,07DH,07FH,041H,055H,07FH,041H,075H,04BH,07FH,041H,055H,07FH,041H,05DH,041H,07FH
ACTIVE_ICON:
	DB	016H,000H,07FH,041H,075H,041H,07FH,041H,05DH,07FH,07DH,041H,07DH,07FH,041H,07FH,061H,05FH,061H,07FH,041H,055H,07FH
BRIDGE_ICON:
	DB	016H,07FH,041H,055H,06BH,07FH,041H,075H,04BH,07FH,041H,07FH,041H,05DH,063H,07FH,041H,05DH,045H,07FH,041H,055H,07FH
L2_ICON:	
	DB	020H,020H,020H,020H,020H,020H,053H,06FH,066H,074H,077H,061H,072H,065H,07CH
LOG_ICON1:
	DB	00AH,040H,040H,040H,000H,0F0H,000H,0D0H,070H,000H,040H
LOG_ICON2:
	DB	00AH,010H,010H,010H,000H,07DH,054H,075H,001H,000H,010H
LOG_ICON3:
	DB	00AH,000H,000H,000H,000H,01FH,011H,01FH,000H,000H,004H
L4_ICON:
	DB	020H,020H,04AH,065H,072H,06FH,065H,06EH,020H,046H,06FH,072H,074H,061H,06EH,069H,065H,072H,07CH
ARROW_ICON:
	DB	007H,000H,020H,010H,0F8H,010H,020H,000H
ARROW_ICON_BLANK:
	DB	007H,000H,000H,000H,000H,000H,000H,000H
L1_ICON:
	DB	020H,020H,020H,020H,048H,061H,072H,064H,077H,061H,072H,065H,020H,061H,06EH,064H,07CH
EQ_ICON1:
	DB	00AH,004H,08EH,004H,000H,0DFH,040H,05DH,017H,000H,082H
EQ_ICON2:
	DB	00AH,001H,003H,001H,000H,0F7H,095H,0F7H,000H,000H,020H
EQ_ICON3:
	DB	00AH,008H,008H,008H,000H,0BEH,02AH,0BAH,080H,000H,008H
EQ_ICON4:
	DB	00FH,002H,002H,002H,000H,00FH,000H,00EH,00BH,000H,0EAH,0BCH,000H,0F8H,088H,0F8H
EQ_ICON5:
	DB	009H,0F8H,000H,0F8H,088H,0F8H,004H,0F8H,088H,0F8H
EQ_ICON6:
	DB	005H,0F8H,004H,0F8H,020H,0D0H
EQ_ICON7:
	DB	009H,0F8H,000H,0F8H,088H,0F8H,004H,0F8H,020H,0D0H


LOG_LOOKUP:
	DB	079H	; Gain -0.5dB
	DB	06CH	; Gain -1.5dB
	DB	060H	; Gain -2.5dB
	DB	056H	; Gain -3.5dB
	DB	04CH	; Gain -4.5dB
	DB	044H	; Gain -5.5dB
	DB	03DH	; Gain -6.5dB
	DB	036H	; Gain -7.5dB
	DB	030H	; Gain -8.5dB
	DB	02BH	; Gain -9.5dB
	DB	026H	; Gain -10.5dB
	DB	022H	; Gain -11.5dB
	DB	01EH	; Gain -12.5dB
	DB	01BH	; Gain -13.5dB
	DB	018H	; Gain -14.5dB
	DB	015H	; Gain -15.5dB
	DB	013H	; Gain -16.5dB
	DB	011H	; Gain -17.5dB
	DB	00FH	; Gain -18.5dB
	DB	00EH	; Gain -19.5dB
	DB	000H	; Gain 0

ASCII_TABLE:
	DB	0x00, 0x00, 0x00, 0x00, 0x00 ; sp
	DB	0x00, 0x00, 0x2f, 0x00, 0x00 ; !

;	DB	0x00, 0x07, 0x00, 0x07, 0x00 ; "
	DB	0x00, 0x00, 0x05, 0x03, 0x00 ; '

	DB	0x00, 0x7F, 0x22, 0x14, 0x08 ; # Cursor2
;	DB	0x14, 0x7f, 0x14, 0x7f, 0x14 ; #
	DB	0x24, 0x2a, 0x7f, 0x2a, 0x12 ; $
	DB	0x44, 0x4e, 0x5f, 0x44, 0x7c ; % Pijltje 'back'
;	DB	0xc4, 0xc8, 0x10, 0x26, 0x46 ; %
	DB	0x36, 0x49, 0x55, 0x22, 0x50 ; &
	DB	0x00, 0x05, 0x03, 0x00, 0x00 ; '
	DB	0x00, 0x1c, 0x22, 0x41, 0x00 ; (
	DB	0x00, 0x41, 0x22, 0x1c, 0x00 ; )
	DB	0x14, 0x08, 0x3E, 0x08, 0x14 ; *
	DB	0x08, 0x08, 0x3E, 0x08, 0x08 ; +
	DB	0x00, 0x00, 0x50, 0x30, 0x00 ; ,
;	DB	0x10, 0x10, 0x10, 0x10, 0x10 ; -
	DB	0x08, 0x08, 0x08, 0x08, 0x00 ; -
	DB	0x00, 0x60, 0x60, 0x00, 0x00 ; .
	DB	0x20, 0x10, 0x08, 0x04, 0x02 ; /
NUMB:
	DB	0x3E, 0x51, 0x49, 0x45, 0x3E ; 0
	DB	0x00, 0x42, 0x7F, 0x40, 0x00 ; 1
	DB	0x42, 0x61, 0x51, 0x49, 0x46 ; 2
	DB	0x21, 0x41, 0x45, 0x4B, 0x31 ; 3
	DB	0x18, 0x14, 0x12, 0x7F, 0x10 ; 4
	DB	0x27, 0x45, 0x45, 0x45, 0x39 ; 5
	DB	0x3C, 0x4A, 0x49, 0x49, 0x30 ; 6
	DB	0x01, 0x71, 0x09, 0x05, 0x03 ; 7
	DB	0x36, 0x49, 0x49, 0x49, 0x36 ; 8
	DB	0x06, 0x49, 0x49, 0x29, 0x1E ; 9
	DB	0x00, 0x36, 0x36, 0x00, 0x00 ; :
	DB	0x00, 0x56, 0x36, 0x00, 0x00 ; ;
	DB	0x08, 0x14, 0x22, 0x41, 0x00 ; <
	DB	0x14, 0x14, 0x14, 0x14, 0x14 ; =
	DB	0x00, 0x41, 0x22, 0x14, 0x08 ; >
	DB	0x02, 0x01, 0x51, 0x09, 0x06 ; ?
;	DB	0x32, 0x49, 0x59, 0x51, 0x3E ; @
	DB	0x1c, 0x3e, 0x78, 0x3e, 0x1c ; @ -> cardioid
	DB	0x7E, 0x11, 0x11, 0x11, 0x7E ; A
	DB	0x7F, 0x49, 0x49, 0x49, 0x36 ; B
	DB	0x3E, 0x41, 0x41, 0x41, 0x22 ; C
	DB	0x7F, 0x41, 0x41, 0x22, 0x1C ; D
	DB	0x7F, 0x49, 0x49, 0x49, 0x41 ; E
	DB	0x7F, 0x09, 0x09, 0x09, 0x01 ; F
	DB	0x3E, 0x41, 0x49, 0x49, 0x7A ; G
	DB	0x7F, 0x08, 0x08, 0x08, 0x7F ; H
	DB	0x00, 0x41, 0x7F, 0x41, 0x00 ; I
	DB	0x20, 0x40, 0x41, 0x3F, 0x01 ; J
	DB	0x7F, 0x08, 0x14, 0x22, 0x41 ; K
	DB	0x7F, 0x40, 0x40, 0x40, 0x40 ; L
	DB	0x7F, 0x02, 0x0C, 0x02, 0x7F ; M
	DB	0x7F, 0x04, 0x08, 0x10, 0x7F ; N
	DB	0x3E, 0x41, 0x41, 0x41, 0x3E ; O
	DB	0x7F, 0x09, 0x09, 0x09, 0x06 ; P
	DB	0x3E, 0x41, 0x51, 0x21, 0x5E ; Q
	DB	0x7F, 0x09, 0x19, 0x29, 0x46 ; R
	DB	0x46, 0x49, 0x49, 0x49, 0x31 ; S
	DB	0x01, 0x01, 0x7F, 0x01, 0x01 ; T
	DB	0x3F, 0x40, 0x40, 0x40, 0x3F ; U
	DB	0x1F, 0x20, 0x40, 0x20, 0x1F ; V
	DB	0x3F, 0x40, 0x38, 0x40, 0x3F ; W
	DB	0x63, 0x14, 0x08, 0x14, 0x63 ; X
	DB	0x07, 0x08, 0x70, 0x08, 0x07 ; Y
	DB	0x61, 0x51, 0x49, 0x45, 0x43 ; Z
	DB	0x00, 0x7F, 0x41, 0x41, 0x00 ; [
	DB	0x55, 0x2A, 0x55, 0x2A, 0x55 ; 55
	DB	0x00, 0x41, 0x41, 0x7F, 0x00 ; ]
	DB	0x00, 0x7F, 0x3E, 0x1C, 0x08 ; ^ -> Cursor1

	DB	0x40, 0x40, 0x40, 0x40, 0x40 ; _


	DB	0x00, 0x01, 0x02, 0x04, 0x00 ; '
	DB	0x20, 0x54, 0x54, 0x54, 0x78 ; a
	DB	0x7F, 0x48, 0x44, 0x44, 0x38 ; b
	DB	0x38, 0x44, 0x44, 0x44, 0x20 ; c
	DB	0x38, 0x44, 0x44, 0x48, 0x7F ; d
	DB	0x38, 0x54, 0x54, 0x54, 0x18 ; e
	DB	0x08, 0x7E, 0x09, 0x01, 0x02 ; f
;	DB	0x0C, 0x52, 0x52, 0x52, 0x3E ; g
;	DB	0x18, 0xA4, 0xA4, 0xA4, 0x7C ; g
	DB	0x08, 0x54, 0x54, 0x54, 0x3C ; g
	DB	0x7F, 0x08, 0x04, 0x04, 0x78 ; h
	DB	0x00, 0x44, 0x7D, 0x40, 0x00 ; i
	DB	0x20, 0x40, 0x44, 0x3D, 0x00 ; j
	DB	0x7F, 0x10, 0x28, 0x44, 0x00 ; k
	DB	0x00, 0x41, 0x7F, 0x40, 0x00 ; l
	DB	0x7C, 0x04, 0x18, 0x04, 0x78 ; m
	DB	0x7C, 0x08, 0x04, 0x04, 0x78 ; n
	DB	0x38, 0x44, 0x44, 0x44, 0x38 ; o
	DB	0x7C, 0x14, 0x14, 0x14, 0x08 ; p
	DB	0x08, 0x14, 0x14, 0x18, 0x7C ; q
	DB	0x7C, 0x08, 0x04, 0x04, 0x08 ; r
	DB	0x48, 0x54, 0x54, 0x54, 0x20 ; s
	DB	0x04, 0x3F, 0x44, 0x40, 0x20 ; t
	DB	0x3C, 0x40, 0x40, 0x20, 0x7C ; u
	DB	0x1C, 0x20, 0x40, 0x20, 0x1C ; v
	DB	0x3C, 0x40, 0x30, 0x40, 0x3C ; w
	DB	0x44, 0x28, 0x10, 0x28, 0x44 ; x
	DB	0x0C, 0x50, 0x50, 0x50, 0x3C ; y
	DB	0x44, 0x64, 0x54, 0x4C, 0x44 ; z


BLANKLINE:
	DB	'                     |'

BOOTMODE: DB	'BOOTMODE|'

FIRMERROR: DB	'DSP Firmware error|'
PRESERROR: DB	'Preset version error|'

BOOT1:	DB	' ALCONS  DDP|'
BOOT2:	DB	' 24bit 96kHz|'
BOOT3:	DB	'  |'
BOOT4:	DB	'DIGITAL DRIVE|' 
BOOT5:	DB	'  PROCESSOR|'
BOOT6:	DB	'    V .|'

UMT:	DB	'Mute   |'
MT:	DB	' MUTE |'
EQON:	DB	'EQ on |'
EQOFF:	DB	'EQ off|'
SETT:	DB	'Setup|'
MOPT:	DB	'Options|'

TESTM:	DB	'TEST MENU|'
NORMAL:	DB	'Normal |'
STCKD:	DB	'Stacked|'
FIN:	DB	'Finish|'
READY:	DB	'Ready.|'

OPT:	DB	'OPTIONS|'
DISPLAY: DB	'Display|'
INFO:	DB	'Information|'
DEVICE:	DB	'Device name|'
MUTE:	DB	'Mute:|'
M_OFF:	DB	'off           |'
PWRUP:	DB	'power up      |'
PRCH:	DB	'preset change |'
PWR_PRES: DB	'pwrup+prst chg|'
LOCK:	DB	'Lock|'
GAINA:	DB	'Gain: absolute|'
GAINR:	DB	'Gain: relative|'

SETTM:	DB	'SETUP|'
SET1:	DB	'Setup channel1|'
SET2:	DB	'Setup channel2|'
DUAL:	DB	'Dual channel mode|'
STER:	DB	'Stereo mode      |'
TWOWAY:	DB	'2-way active mode|'
BRIDGE:	DB	'Bridged mono mode|'
PRESETS: DB	'User presets|'
LNK:	DB	'Link|'
LOFF:	DB	'off     |'
EQL:	DB	'EQ      |'
DLYL:	DB	'Delay   |'
EQDLYL:	DB	'EQ+Delay|'

SETUP1:	DB	'SETUP CHANNEL1|'
SETUP2:	DB	'SETUP CHANNEL2|'
MPRES:	DB	'Speaker Preset|'
INPUT:	DB	'Input|'
INP1:	DB	' 1 |'
INP2:	DB	' 2 |'
INP12:	DB	'1+2|'
MPAREQ:	DB	'Parametric EQ|'
EQLNK:	DB	'EQ ch1 linked|'
MDELAY:	DB	'Delay|'
DLLNK:	DB	'Delay ch1 linked|'

PRESM:	DB	'USER PRESETS|'
PRES:	DB	'Preset:|'
RECALL:	DB	'Recall         |'
RECALLP: DB	'Recall previous|'
STORE:	DB	'Store      |'
ED:	DB	'ed|'
STORED:	DB	'Stored     |'
CNAME:	DB	'Change name|'

SPSET1:	DB	'SPEAKER CHANNEL1|'
SPSET2:	DB	'SPEAKER CHANNEL2|'
PTCH:	DB	'Push to change|'
TURN:	DB	'Turn to select|'
UMUTE:	DB	'Unmute?|'
CONFIRM: DB	'Confirm |'
YES:	DB	'yes|'
NO:	DB	'no |'

ARRAYLEN0:			; Used for LR14
	DB	'Array of 3 |  '
	DB	'Array of 6 |  '
	DB	'Array of 9 |  '
	DB	'Array of 12|  '
	DB	'Array of 15|  '
	DB	'Array of 18|  '
	DB	'Array of 21|  '
	DB	'Array of 24|| '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '

ARRAYLEN1:			; Used for LR16
	DB	'Array of 3 |  '
	DB	'Array of 6 |  '
	DB	'Array of 9 |  '
	DB	'Array of 12|  '
	DB	'Array of 15|  '
	DB	'Array of 18|  '
	DB	'Array of 21|  '
	DB	'Array of 24|| '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '
	DB	'Array of 24|  '

;ARRAYLEN2:			; Used for LR30
;	DB	'Array of 2 |  '
;	DB	'Array of 4 |  '
;	DB	'Array of 6 |  '
;	DB	'Array of 8 |  '
;	DB	'Array of 10|  '
;	DB	'Array of 12|  '
;	DB	'Array of 14|  '
;	DB	'Array of 16|  '
;	DB	'Array of 18|  '
;	DB	'Array of 20|  '
;	DB	'Array of 22|  '
;	DB	'Array of 24|| '
;	DB	'Array of 24|  '
;	DB	'Array of 24|  '
;	DB	'Array of 24|  '
;	DB	'Array of 24|  '

ARRAYLEN2:			; Used for LR30/7
	DB	'Array of 3 |  '
	DB	'Array of 6 |  '
	DB	'Array of 9 |  '
	DB	'Array of 12|  '
	DB	'Array of 15|  '
	DB	'Array of 18|| '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '

ARRAYLEN3:			; Used for QR18,QR36
	DB	'Array of 0.5m|'
	DB	'Array of 1.0m|'
	DB	'Array of 1.5m|'
	DB	'Array of 2.0m|'
	DB	'Array of 2.5m|'
	DB	'Array of 3.0m|'
	DB	'Array of 3.5m|'
	DB	'Array of 4.0m|'
	DB	'Array of 4.5m|'
	DB	'Array of 5.0m|'
	DB	'Array of 5.5m|'
	DB	'Array of 6.0m|'
	DB	'Array of 7.0m|'
	DB	'Array of 8.0m|'
	DB	'Array of 9.0m|'
	DB	'Array of 10m ||'

ARRAYLEN4:			; Used for VR8
	DB	'Flat |        '
	DB	'LF +1|        '
	DB	'LF +2|        '
	DB	'LF +3|        '
	DB	'LF +4|        '
	DB	'LF +5|        '
	DB	'LF +6||       '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '

ARRAYLEN5:			; Used for VR12
	DB	'Flat |        '
	DB	'LF +1|        '
	DB	'LF +2|        '
	DB	'LF +3|        '
	DB	'LF +4|        '
	DB	'LF +5|        '
	DB	'LF +6||       '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '
	DB	'LF +6|        '

ARRAYLEN6:			; Used for BF362
	DB	'Sub  |        '
	DB	'Bass |        '
	DB	'Punch||       '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '
	DB	'Punch|        '

ARRAYLEN7:			; Used for LR7
	DB	'Array of 3 |  '
	DB	'Array of 6 |  '
	DB	'Array of 9 |  '
	DB	'Array of 12|  '
	DB	'Array of 15|  '
	DB	'Array of 18|| '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '
	DB	'Array of 18|  '


FLOWN:	DB	'Flown  |'
STACKED: DB	'Stacked|'

PAREQ:	DB	'PARAMETRIC EQUALISER|'
SEC1:	DB	'Section1|'
SEC2:	DB	'Section2|'
SEC3:	DB	'Section3|'
SEC4:	DB	'Section4|'
ON:	DB	'On    |'
BYPASS:	DB	'Bypass|'
F:	DB	'F=       |'
G:	DB	'G=       |'
Q:	DB	'Q=       |'
HZ:	DB	'Hz|'
KHZ:	DB	'kHz|'
DECIB:	DB	'dB  |'
DECIB2:	DB	'dB|'
DECIBR:	DB	'dBr |'

DELAY1:	DB	'DELAY CHANNEL1|'
DELAY2:	DB	'DELAY CHANNEL2|'
OFF:	DB	'Off|'
OFF2:	DB	'off|'
DOFF:	DB	'Off (1ms)  |'
DOFF2:	DB	'Off        |'
DOFFM:	DB	'Off (0.34m)|'
DON:	DB	'On         |'
MS:	DB	'ms  |'
M:	DB	'm   |'
MS1:	DB	'ms|'
M1:	DB	'm |'
UNT:	DB	'Unit:|'
ABS:	DB	'Absolute (+latency)|'
REL:	DB	'DDP relative       |'

WRITING: DB	'Writing FLASH Memory|'

MLOCK:	DB	'LOCK|'
LOCKA:	DB	'Lock all|'
LOCKP:	DB	'Lock presets|'
UNLOCK:	DB	'Unlock|'
NCODE:	DB	'Change code|'

PIN:	DB	'    Code? |'
OPIN:	DB	'Old code? |'
NPIN:	DB	'New code? |'
WPIN:	DB	'WRONG CODE!   |'
WPIN2:	DB	'           |'

DISPL:	DB	'DISPLAY|'
CONTRAST: DB	'Contrast|'
BACKL:	DB	'Backlight|'
BTIME:	DB	'Timeout|'
TENS:	DB	'10s|'

INFOM:	DB	'INFORMATION|'
LOG:	DB	'Log|'
LLOG:	DB	'Limit log|'
SETC:	DB	'  -  "     :|'
ST:	DB	'^Set|'
ST0:	DB	'    |'
FIRM:	DB	'Firmware:V . .0|'
PRESVER: DB	'Presets :|'
SN:	DB	'Serial  :|'

LLOGM:	DB	'LIMIT LOG|'
SELP:	DB	'Select page|'
LLEN:	DB	'Log disabled|'
LLDI:	DB	'Log enabled|'
PAGE_INFO: DB	'V      -  "     :|'
E_PAGE:	DB	'Empty page          |'
CH1M:	DB	'Ch1 model       dB|'
CH2M:	DB	'Ch2 model       dB  |'

TIME:	DB	'SET CLOCK|'
CHK_WTIME: DB	'CHECK WINTERTIME|'
CHK_STIME: DB	'CHECK SUMMERTIME|'
DST_ADJ: DB	'DST adjust :|'
EUR:	DB	'Eur|'
USA:	DB	'USA|'
DATEFORM: DB	'Date format:|'
DDMMYY:	DB	'dd-mm"yy|'
MMDDYY:	DB	'mm-dd"yy|'

LOGM:	DB	'LOG|'
STARTS:	DB	'Starts  :|'
ONTIME:	DB	'On time :|'
SIGNAL:	DB	'Signal  :|'
LIMIT:	DB	'Limit   :|'

ON2:	DB	'On |'
BACK:	DB	'Back %|'
CURSOR:	DB	'^|'
CURSOR2: DB	'#|'
SPACE:	DB	' |'

CONTR_TABLE:		; Lookup table for LCD contrast
	DB	023H
	DB	025H
	DB	027H
	DB	029H
	DB	02BH
	DB	02DH
	DB	02FH
	DB	031H
	DB	033H
	DB	035H

LIGHT_TABLE:		; Lookup table for LCD backlight
	DB	000H	; This one is not used
	DB	055H	; 8mA
	DB	05AH	; 12mA
	DB	0AAH	; 16mA
	DB	06BH	; 20mA
	DB	05FH	; 24mA
	DB	0AFH	; 28mA
	DB	07FH	; 32mA
	DB	0BFH	; 34mA
	DB	0FFH	; 40mA

FREQ_TABLE:		; Lookup tables for parametric equalizer:
	DB	'20.0|'
	DB	'20.9|'
	DB	'22.1|'
	DB	'23.4|'
	DB	'24.8|'
	DB	'26.3|'
	DB	'27.8|'
	DB	'29.5|'
	DB	'31.3|'
	DB	'33.1|'

	DB	'35.1|'
	DB	'37.2|'
	DB	'39.4|'
	DB	'41.7|'
	DB	'44.2|'
	DB	'46.8|'
	DB	'49.6|'
	DB	'52.6|'
	DB	'55.7|'	
	DB	'59.0|'	

	DB	'62.5|'	
	DB	'66.2|'
	DB	'70.2|'
	DB	'74.3|'
	DB	'78.8|'
	DB	'83.4|'
	DB	'88.4|'
	DB	'93.6|'
	DB	'99.2|'
	DB	'105| '

	DB	'111| '
	DB	'118| '
	DB	'125| '
	DB	'132| '
	DB	'140| '
	DB	'149| '
	DB	'158| '
	DB	'167| '
	DB	'177| '
	DB	'187| '

	DB	'198| '
	DB	'210| '
	DB	'223| '
	DB	'236| '
	DB	'250| '
	DB	'265| '
	DB	'281| '
	DB	'297| '
	DB	'315| '
	DB	'334| '

	DB	'354| '
	DB	'375| '
	DB	'397| '
	DB	'420| '
	DB	'445| '
	DB	'472| '
	DB	'500| '
	DB	'530| '
	DB	'561| '
	DB	'595| '

	DB	'630| '
	DB	'667| '
	DB	'707| '
	DB	'749| '
	DB	'794| '
	DB	'841| '
	DB	'891| '
	DB	'944| '
	DB	'1.00|'
	DB	'1.06|'

	DB	'1.12|'
	DB	'1.19|'
	DB	'1.26|'
	DB	'1.34|'
	DB	'1.41|'
	DB	'1.50|'
	DB	'1.59|'
	DB	'1.68|'
	DB	'1.78|'
	DB	'1.89|'

	DB	'2.00|'
	DB	'2.12|'
	DB	'2.25|'
	DB	'2.38|'
	DB	'2.52|'
	DB	'2.67|'
	DB	'2.83|'
	DB	'3.00|'
	DB	'3.18|'
	DB	'3.36|'

	DB	'3.56|'
	DB	'3.78|'
	DB	'4.00|'
	DB	'4.24|'
	DB	'4.49|'
	DB	'4.78|'
	DB	'5.04|'
	DB	'5.34|'
	DB	'5.66|'
	DB	'5.99|'

	DB	'6.35|'
	DB	'6.73|'
	DB	'7.13|'
	DB	'7.55|'
	DB	'8.00|'
	DB	'8.48|'
	DB	'8.98|'
	DB	'9.51|'
	DB	'10.1|'
	DB	'10.7|'

	DB	'11.3|'
	DB	'12.0|'
	DB	'12.7|'
	DB	'13.5|'
	DB	'14.3|'
	DB	'15.1|'
	DB	'16.0|'
	DB	'17.0|'
	DB	'18.0|'
	DB	'19.0|'

	DB	'20.0|'

Q_TABLE:
	DB	'0.3|'
	DB	'0.4|'
	DB	'0.5|'
	DB	'0.6|'
	DB	'0.7|'
	DB	'0.8|'
	DB	'0.9|'
	DB	'1.0|'
	DB	'1.1|'
	DB	'1.2|'

	DB	'1.3|'
	DB	'1.5|'
	DB	'1.6|'
	DB	'1.8|'
	DB	'2.0|'
	DB	'2.2|'
	DB	'2.4|'
	DB	'2.7|'
	DB	'3.0|'
	DB	'3.5|'

	DB	'4.0|'
	DB	'4.5|'
	DB	'5.0|'
	DB	'5.5|'
	DB	'6.0|'
	DB	'6.5|'
	DB	'7.0|'
	DB	'7.5|'
	DB	'8.0|'
	DB	'8.5|'

	DB	'9.0|'
	DB	'9.5|'
	DB	'10 |'
	DB	'11 |'
	DB	'12 |'
	DB	'13 |'
	DB	'14 |'
	DB	'15 |'

GAIN_TABLE:
	DB	'Notch|'
	DB	'-20.0|'
	DB	'-19.5|'
	DB	'-19.0|'
	DB	'-18.5|'
	DB	'-18.0|'
	DB	'-17.5|'
	DB	'-17.0|'
	DB	'-16.5|'
	DB	'-16.0|'

	DB	'-15.5|'
	DB	'-15.0|'
	DB	'-14.5|'
	DB	'-14.0|'
	DB	'-13.5|'
	DB	'-13.0|'
	DB	'-12.5|'
	DB	'-12.0|'
	DB	'-11.5|'
	DB	'-11.0|'

	DB	'-10.5|'
	DB	'-10.0|'
	DB	'-9.5| '
	DB	'-9.0| '
	DB	'-8.5| '
	DB	'-8.0| '
	DB	'-7.5| '
	DB	'-7.0| '
	DB	'-6.5| '
	DB	'-6.0| '

	DB	'-5.5| '
	DB	'-5.0| '
	DB	'-4.5| '
	DB	'-4.0| '
	DB	'-3.5| '
	DB	'-3.0| '
	DB	'-2.5| '
	DB	'-2.0| '
	DB	'-1.5| '
	DB	'-1.0| '

	DB	'-0.5| '
	DB	'0.0|  '
	DB	'+0.5| '
	DB	'+1.0| '
	DB	'+1.5| '
	DB	'+2.0| '
	DB	'+2.5| '
	DB	'+3.0| '
	DB	'+3.5| '
	DB	'+4.0| '

	DB	'+4.5| '
	DB	'+5.0| '
	DB	'+5.5| '
	DB	'+6.0| '
	DB	'+6.5| '
	DB	'+7.0| '
	DB	'+7.5| '
	DB	'+8.0| '
	DB	'+8.5| '
	DB	'+9.0| '

	DB	'+9.5| '
	DB	'+10.0|'
	DB	'+10.5|'
	DB	'+11.0|'
	DB	'+11.5|'
	DB	'+12.0|'
	DB	'+12.5|'
	DB	'+13.0|'
	DB	'+13.5|'
	DB	'+14.0|'

	DB	'+14.5|'
	DB	'+15.0|'
	DB	'+15.5|'
	DB	'+16.0|'
	DB	'+16.5|'
	DB	'+17.0|'
	DB	'+17.5|'
	DB	'+18.0|'
	DB	'+18.5|'
	DB	'+19.0|'

	DB	'+19.5|'
	DB	'+20.0|'

LIN:DB	'Linear   |          |'	; Model 0
	DB	'BF151    | 100Hz    |'	; Model 1
	DB	'BF151    | 80Hz     |'	; Model 2
	DB	'BF181    | 100Hz    |'	; Model 3
	DB	'BF181    | 80Hz     |'	; Model 4
	DB	'BF181    | 100Hz @  |'	; Model 5
	DB	'BF181    | 80Hz @   |'	; Model 6
	DB	'BF302    | 100Hz    |'	; Model 7
	DB	'BF302    | 80Hz     |'	; Model 8
	DB	'BF362    | 100Hz    |'	; Model 9
	DB	'BF362    | 80Hz     |'	; Model 10
	DB	'BF362    | 100Hz @  |'	; Model 9
	DB	'BF362    | 80Hz @   |'	; Model 10
	DB	'BC543    | 100Hz    |'	; Model 11
	DB	'BC543    | 80Hz     |'	; Model 12
	DB	'BQ211    | 100Hz    |'	; Model 15
	DB	'BQ211    | 80Hz     |'	; Model 16
	DB	'BQ211    | 100Hz @  |'	; Model 17
	DB	'BQ211    | 80Hz @   |'	; Model 18
	DB	'LR7-120  | Fullrange|'	; Model 19
	DB	'LR7-120  | 80Hz     |'	; Model 20
	DB	'LR7-120  | 160Hz    |'	; Model 21
	DB	'LR7-90	  | Fullrange|'	; Model 22
	DB	'LR7-90	  | 80Hz     |'	; Model 23
	DB	'LR7-90   | 160Hz    |'	; Model 24
	DB	'LR7B     | 160Hz    |'	; Model 25
	DB	'LR7B     | 80Hz     |'	; Model 26
	DB	'LR7B     | 80-160Hz |'	; Model 27
	DB	'LR14-120 | Fullrange|'	; Model 28
	DB	'LR14-120 | 80Hz     |'	; Model 29
	DB	'LR14-120 | 160Hz    |'	; Model 30
	DB	'LR14-90  | Fullrange|'	; Model 31
	DB	'LR14-90  | 80Hz     |'	; Model 32
	DB	'LR14-90  | 160Hz    |'	; Model 33
	DB	'LR14B    | 160Hz    |'	; Model 34
	DB	'LR14B    | 80Hz     |'	; Model 35
	DB	'LR14B    | 80-160Hz |'	; Model 36
	DB	'LR16 lf  | Fullrange|'	; Model 37
	DB	'LR16 lf  | 80Hz     |'	; Model 38
	DB	'LR16 lf  | 160Hz    |'	; Model 39
	DB	'LR16B    | 160Hz    |'	; Model 40
	DB	'LR16B    | 80Hz     |'	; Model 41
	DB	'LR16B    | 80-160Hz |'	; Model 42
	DB	'QB363    | 100Hz    |'	; Model 43
	DB	'QB363    | 80Hz     |'	; Model 44
	DB	'QM/QR    | Fullrange|'	; Model 45
	DB	'QM/QR    | 80Hz     |'	; Model 46
	DB	'QM/QR    | 100Hz    |'	; Model 47
	DB	'SR9      | Fullrange|'	; Model 48
	DB	'TS3/TS7  | Fullrange|'	; Model 49
	DB	'TS3/TS7  | 100Hz    |'	; Model 50
	DB	'VR8      | Fullrange|'	; Model 51
	DB	'VR8      | 80Hz     |'	; Model 52
	DB	'VR8      | 100Hz    |'	; Model 53
	DB	'VR12-90  | Fullrange|'	; Model 54
	DB	'VR12-90  | 80Hz     |'	; Model 55
	DB	'VR12-90  | 100Hz    |'	; Model 56
	DB	'VR12-60  | Fullrange|'	; Model 57
	DB	'VR12-60  | 80Hz     |'	; Model 58
	DB	'VR12-60  | 100Hz    |'	; Model 59
; End of selectable presets

	DB	'LR16 hf  |          |'	; Model 60
	DB	'LR16 hf  |          |'	; Model 61
	DB	'LR16 hf  |          |'	; Model 62
	DB	'BC543    | 100Hz @  |'	; Model 13
	DB	'BC543    | 80Hz @   |'	; Model 14
	

; Low eq for array length. Copy into section6
LOW_EQ_TYPE0:	 		; Type 0 used for LR14
	DB	23,38,41	; F=75Hz Q=0.15 G=0.0dB array*2
	DB	23,38,102	; F=75Hz Q=0.15 G=-1.8dB array*3
	DB	23,38,35	; F=75Hz Q=0.15 G=-3.0dB array*4
	DB	23,38,33	; F=75Hz Q=0.15 G=-4.0dB array*5
	DB	23,38,103	; F=75Hz Q=0.15 G=-4.8dB array*6
	DB	23,38,30	; F=75Hz Q=0.15 G=-5.5dB array*7
	DB	23,38,29	; F=75Hz Q=0.15 G=-6.0dB array*8
	DB	23,38,28	; F=75Hz Q=0.15 G=-6.5dB array*9
	DB	23,38,27	; F=75Hz Q=0.15 G=-7.0dB array*10
	DB	23,38,104	; F=75Hz Q=0.15 G=-7.4dB array*11
	DB	23,38,105	; F=75Hz Q=0.15 G=-7.8dB array*12
	DB	23,38,24	; F=75Hz Q=0.15 G=-8.5dB array*14
	DB	23,38,23	; F=75Hz Q=0.15 G=-9.0dB array*16
	DB	23,38,106	; F=75Hz Q=0.15 G=-9.6dB array*18
	DB	23,38,21	; F=75Hz Q=0.15 G=-10.0dB array*20


LOW_EQ_TYPE1:	 		; Type 1 used for LR16
	DB	23,38,41	; F=75Hz Q=0.15 G=0.0dB array*2
	DB	23,38,102	; F=75Hz Q=0.15 G=-1.8dB array*3
	DB	23,38,35	; F=75Hz Q=0.15 G=-3.0dB array*4
	DB	23,38,33	; F=75Hz Q=0.15 G=-4.0dB array*5
	DB	23,38,103	; F=75Hz Q=0.15 G=-4.8dB array*6
	DB	23,38,30	; F=75Hz Q=0.15 G=-5.5dB array*7
	DB	23,38,29	; F=75Hz Q=0.15 G=-6.0dB array*8
	DB	23,38,28	; F=75Hz Q=0.15 G=-6.5dB array*9
	DB	23,38,27	; F=75Hz Q=0.15 G=-7.0dB array*10
	DB	23,38,104	; F=75Hz Q=0.15 G=-7.4dB array*11
	DB	23,38,105	; F=75Hz Q=0.15 G=-7.8dB array*12
	DB	23,38,24	; F=75Hz Q=0.15 G=-8.5dB array*14
	DB	23,38,23	; F=75Hz Q=0.15 G=-9.0dB array*16
	DB	23,38,106	; F=75Hz Q=0.15 G=-9.6dB array*18
	DB	23,38,21	; F=75Hz Q=0.15 G=-10.0dB array*20

LOW_EQ_TYPE2:	 		; Type 2 used for LR30
	DB	23,38,35	; F=75Hz Q=0.15 G=-3.0dB array*2
	DB	23,38,103	; F=75Hz Q=0.15 G=-4.8dB array*3
	DB	23,38,29	; F=75Hz Q=0.15 G=-6.0dB array*4
	DB	23,38,27	; F=75Hz Q=0.15 G=-7.0dB array*5
	DB	23,38,105	; F=75Hz Q=0.15 G=-7.8dB array*6
	DB	23,38,24	; F=75Hz Q=0.15 G=-8.5dB array*7
	DB	23,38,23	; F=75Hz Q=0.15 G=-9.0dB array*8
	DB	23,38,22	; F=75Hz Q=0.15 G=-9.5dB array*9
	DB	23,38,21	; F=75Hz Q=0.15 G=-10.0dB array*10
	DB	23,38,107	; F=75Hz Q=0.15 G=-10.4dB array*11
	DB	23,38,108	; F=75Hz Q=0.15 G=-10.8dB array*12
	DB	23,38,18	; F=75Hz Q=0.15 G=-11.5dB array*14
	DB	23,38,17	; F=75Hz Q=0.15 G=-12.0dB array*16
	DB	23,38,109	; F=75Hz Q=0.15 G=-12.6dB array*18
	DB	23,38,15	; F=75Hz Q=0.15 G=-13.0dB array*20

LOW_EQ_TYPE3:	 		; Type 3 used for QR18/QR36
	DB	23,38,35	; F=75Hz Q=0.15 G=-3.0dB array*2
	DB	23,38,103	; F=75Hz Q=0.15 G=-4.8dB array*3
	DB	23,38,29	; F=75Hz Q=0.15 G=-6.0dB array*4
	DB	23,38,27	; F=75Hz Q=0.15 G=-7.0dB array*5
	DB	23,38,105	; F=75Hz Q=0.15 G=-7.8dB array*6
	DB	23,38,24	; F=75Hz Q=0.15 G=-8.5dB array*7
	DB	23,38,23	; F=75Hz Q=0.15 G=-9.0dB array*8
	DB	23,38,22	; F=75Hz Q=0.15 G=-9.5dB array*9
	DB	23,38,21	; F=75Hz Q=0.15 G=-10.0dB array*10
	DB	23,38,107	; F=75Hz Q=0.15 G=-10.4dB array*11
	DB	23,38,108	; F=75Hz Q=0.15 G=-10.8dB array*12
	DB	23,38,18	; F=75Hz Q=0.15 G=-11.5dB array*14
	DB	23,38,17	; F=75Hz Q=0.15 G=-12.0dB array*16
	DB	23,38,109	; F=75Hz Q=0.15 G=-12.6dB array*18
	DB	23,38,15	; F=75Hz Q=0.15 G=-13.0dB array*20

LOW_EQ_TYPE4:	 		; Type 4 used for VR8 LF Boost
	DB	16,2,43		; F=49.6Hz Q=0.5 G=+1.0dB 
	DB	16,2,45		; F=49.6Hz Q=0.5 G=+2.0dB 
	DB	16,2,47		; F=49.6Hz Q=0.5 G=+3.0dB 
	DB	16,2,49		; F=49.6Hz Q=0.5 G=+4.0dB 
	DB	16,2,51		; F=49.6Hz Q=0.5 G=+5.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 

LOW_EQ_TYPE5:	 		; Type 5 used for VR12 LF Boost
	DB	16,2,43		; F=49.6Hz Q=0.5 G=+1.0dB 
	DB	16,2,45		; F=49.6Hz Q=0.5 G=+2.0dB 
	DB	16,2,47		; F=49.6Hz Q=0.5 G=+3.0dB 
	DB	16,2,49		; F=49.6Hz Q=0.5 G=+4.0dB 
	DB	16,2,51		; F=49.6Hz Q=0.5 G=+5.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 
	DB	16,2,53		; F=49.6Hz Q=0.5 G=+6.0dB 

LOW_EQ_TYPE6:	 		; Type 6 used for BF181/BF362 sub/bass/punch switch
	DB	9,13,57		; F=33.1Hz Q=1.8 G=+8.0dB (bass)
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB (punch)
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB 
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB 
	DB	14,13,55	; F=44.2Hz Q=1.8 G=+7.0dB

LOW_EQ_TYPE7:	 		; Type 7 used for LR7
	DB	23,38,41	; F=75Hz Q=0.15 G=0.0dB array*2
	DB	23,38,102	; F=75Hz Q=0.15 G=-1.8dB array*3
	DB	23,38,35	; F=75Hz Q=0.15 G=-3.0dB array*4
	DB	23,38,33	; F=75Hz Q=0.15 G=-4.0dB array*5
	DB	23,38,103	; F=75Hz Q=0.15 G=-4.8dB array*6
	DB	23,38,30	; F=75Hz Q=0.15 G=-5.5dB array*7
	DB	23,38,29	; F=75Hz Q=0.15 G=-6.0dB array*8
	DB	23,38,28	; F=75Hz Q=0.15 G=-6.5dB array*9
	DB	23,38,27	; F=75Hz Q=0.15 G=-7.0dB array*10
	DB	23,38,104	; F=75Hz Q=0.15 G=-7.4dB array*11
	DB	23,38,105	; F=75Hz Q=0.15 G=-7.8dB array*12
	DB	23,38,24	; F=75Hz Q=0.15 G=-8.5dB array*14
	DB	23,38,23	; F=75Hz Q=0.15 G=-9.0dB array*16
	DB	23,38,106	; F=75Hz Q=0.15 G=-9.6dB array*18
	DB	23,38,21	; F=75Hz Q=0.15 G=-10.0dB array*20



HIGH_EQ: ; High eq for stacked array. Copy into section10
	DB	121,39,33	; F=30kHz Q=0.2 G=-4dB

	CSEG  	AT 7BFFH

	DB	002H

	END






