;* ------------------------------------------------------------------------
;*  Title     :	ALCONS AUDIO BV DDP Module
;*  Version   :	V1.7.1
;*  Presets   :	V003
;*  File      :	DDP_FLASH_V1.7.001.A51
;*		BC543 cardioid as complementary active speaker preset
;*  Includes  :	DSP firmware version 1.4; System presets version 003
;*  Author    :	R. Kuipers
;*  Project   :	-
;*  Purpose   :	-
;*  Created   :	22-4-2011
;*  Modified  :	-
;* ------------------------------------------------------------------------

;* 

;* ------------------------------------------------------------------------
;*  DataFlash Memory Map:
;*  Page 0-17	   : DSP program
;*  Page 18	   : Serial code
;*  Page 19	   : Settings page address (20-255)
;*  Page 20-255	   : Settings (one moving page)
;*  Page 256	   : Log page address (257-511)
;*  Page 257-511   : Log with starts and hours counters (one moving page)
;*  Page 512-524   : DDP user presets 
;*  Page 525	   : Speaker presets version code + boot status byte
;*  Page 526-1023  : Reserved for speaker presets
;*  Page 1024	   : Limitlog page address (1025-8191)
;*  Page 1025-8191 : Limitlog with speaker preset and limit data
;* ------------------------------------------------------------------------

NAME	SAMPLE

VERSION EQU	007H			; Preset version code (1-255)

FIRM_ID	EQU	017H			; Software ID-code

LAST_MODEL EQU	64			; Last speaker preset model code 
					; Including non-selectable presets
STACK	SEGMENT	IDATA

	RSEG  	STACK
	DS    	018H  			; Stack

BITCNT	DATA	018H			; I2C bit counter
BYTECNTL DATA	019H			; I2C byte counter low byte
BYTECNTH DATA	01AH			; I2C byte counter high byte
SLVADR	DATA	01BH			; I2C slave address

OPCODE	DATA	01CH			; FLASH opcode
OPCODE1	DATA	01DH			; FLASH opcode1
OPCODE2	DATA	01EH			; FLASH opcode2
OPCODE3	DATA	01FH			; FLASH opcode3

FLAGS0	DATA	020H			; Flags register
NOACK	BIT	FLAGS0.0		; I2C no acknowledge flag
BUSFAULT BIT	FLAGS0.1		; I2C bus fault flag
I2CBUSY	BIT	FLAGS0.2		; I2C busy flag
CHAN2	BIT	FLAGS0.3		; Channel1/2 adjustment flag
SECT_0	BIT	FLAGS0.4		; eq section1-4
SECT_1	BIT	FLAGS0.5		; 
S_CLK	BIT	FLAGS0.6		; Clock has just been set

FLAGS1	DATA	021H			; Flags register
LEFT	BIT	FLAGS1.0		; Encoder turn left flag
RIGHT	BIT	FLAGS1.1		; Encoder turn right flag
PUS	BIT	FLAGS1.2		; Encoder pushbutton flag
ENC	BIT	FLAGS1.3		; Encoder action
ENC_FAST BIT	FLAGS1.4		; Encoder turning fast
INV	BIT	FLAGS1.5		; Text inversed
GRAPH	BIT	FLAGS1.6		; parametric eq graph has changed
SPITXC	BIT	FLAGS1.7		; SPI transmit complete flag

FLAGS4	DATA	022H
LOG_1ST	BIT	FLAGS4.0		; First log sample has been read (log does not use first sample)
MAIN	BIT	FLAGS4.1		; DDP is in main menu
PSWAP	BIT	FLAGS4.2		; Preset swap active
BYP	BIT	FLAGS4.3		; Current section is bypassed
RTC_IRP	BIT	FLAGS4.4		; Real time clock interrupt pending
NXT_PG	BIT	FLAGS4.5		; Flag indicates settings or log page has moved
LOG_REF	BIT	FLAGS4.6		; Flag indicates log refresh
DBLANK	BIT	FLAGS4.7		; Flag indicates display blank due to timeout

BURNCH	DATA	023H			; Flash burncounter high byte
BURNCL	DATA	024H			; Flash burncounter low byte

FLAGS5	DATA	025H			; Settings flags register
STIME	BIT	FLAGS5.0		; Summertime
CTIME	BIT	FLAGS5.1		; Check time for summer/wintertime
DST_EUR	BIT	FLAGS5.2		; DST for europe
DST_USA	BIT	FLAGS5.3		; DST for USA
DT_FRM	BIT	FLAGS5.4		; Date format 0=dd-mm-yy; 1=mm-dd-yy

FLAGS2	DATA	026H			; Settings flags register
MUTE1	BIT	FLAGS2.0		; CH1 is muted
MUTE2	BIT	FLAGS2.1		; CH2 is muted
EQ1	BIT	FLAGS2.2		; CH1 eq on
EQ2	BIT	FLAGS2.3		; CH2 eq on
GAINREL	BIT	FLAGS2.4		; Gain indication relative
D1	BIT	FLAGS2.5		; Delay ch1 on
D2	BIT	FLAGS2.6		; Delay ch2 on
DUNIT	BIT	FLAGS2.7		; Delay in meters

FLAGS6	DATA	027H			; Settings flags register

FLAGS3	DATA	028H			; Settings flags register
PUMUTE	BIT	FLAGS3.0		; Mute on at power up
PLOCK	BIT	FLAGS3.1		; Preset lock active
ALOCK	BIT	FLAGS3.2		; All functions locked (except mute)
PRMUTE	BIT	FLAGS3.3		; Mute on after preset change
HCORR1	BIT	FLAGS3.4		; High correction active on ch1
HCORR2	BIT	FLAGS3.5		; High correction active on ch2
D_FINE	BIT	FLAGS3.6		; Delay in fine mode
P_ALT	BIT	FLAGS3.7		; Preset altered

EQFLAGS	DATA	029H			; Pareq flags register
CH1S1	BIT	EQFLAGS.0		; CH1 section1 bypass
CH1S2	BIT	EQFLAGS.1		; CH1 section2 bypass
CH1S3	BIT	EQFLAGS.2		; CH1 section3 bypass
CH1S4	BIT	EQFLAGS.3		; CH1 section4 bypass
CH2S1	BIT	EQFLAGS.4		; CH2 section1 bypass
CH2S2	BIT	EQFLAGS.5		; CH2 section2 bypass
CH2S3	BIT	EQFLAGS.6		; CH2 section3 bypass
CH2S4	BIT	EQFLAGS.7		; CH2 section4 bypass

INPSET	DATA	02AH			; Input settings bits 3..0 for input routing
					; Bits	1 0
					; 	0 0 Not used
					;	0 1 Channel1 input to channel1
					;	1 0 Channel2 input to channel1
					;	1 1 Channel1+2 input to channel1
					; Bits	3 2
					; 	0 0 Not used
					;	0 1 Channel1 input to channel2
					;	1 0 Channel2 input to channel2
					;	1 1 Channel1+2 input to channel2
STEREO	BIT	INPSET.4		; Bits	5 4
ACTIVE	BIT	INPSET.5		; 	0 0 Dual channel mode
					; 	1 0 2-way active mode 
					; 	0 1 Stereo mode
					; 	1 1 bridged mono mode
EQLINK	BIT	INPSET.6		; Channel2 eq is linked to ch1
DLINK	BIT	INPSET.7		; Channel2 delay is linked to ch1

LIMIT1	DATA	02BH			; LIMIT LOG ENABLE
LENABLE BIT	LIMIT1.0
DELAYF	DATA	02CH			; Extra data byte
D_FINE1	BIT	DELAYF.0
D_FINE2	BIT	DELAYF.1

;EXTRA1	DATA	02BH			; Extra data byte
;EXTRA2	DATA	02CH			; Extra data byte

FREQ1	DATA	02DH			; Frequency parametric eq section1
QF1	DATA	02EH			; Q-factor parametric eq section1
GAIN1	DATA	02FH			; gain parametric eq section1
FREQ2	DATA	030H			; Frequency parametric eq section2
QF2	DATA	031H			; Q-factor parametric eq section2
GAIN2	DATA	032H			; gain parametric eq section2
FREQ3	DATA	033H			; Frequency parametric eq section3
QF3	DATA	034H			; Q-factor parametric eq section3
GAIN3	DATA	035H			; gain parametric eq section3
FREQ4	DATA	036H			; Frequency parametric eq section4
QF4	DATA	037H			; Q-factor parametric eq section4
GAIN4	DATA	038H			; gain parametric eq section4

FREQ5	DATA	039H			; Frequency parametric eq section1
QF5	DATA	03AH			; Q-factor parametric eq section1
GAIN5	DATA	03BH			; gain parametric eq section1
FREQ6	DATA	03CH			; Frequency parametric eq section2
QF6	DATA	03DH			; Q-factor parametric eq section2
GAIN6	DATA	03EH			; gain parametric eq section2
FREQ7	DATA	03FH			; Frequency parametric eq section3
QF7	DATA	040H			; Q-factor parametric eq section3
GAIN7	DATA	041H			; gain parametric eq section3
FREQ8	DATA	042H			; Frequency parametric eq section4
QF8	DATA	043H			; Q-factor parametric eq section4
GAIN8	DATA	044H			; gain parametric eq section4

D_LOW1	DATA	045H
D_MID1	DATA	046H
D_HI1	DATA	047H
D_LOW2	DATA	048H
D_MID2	DATA	049H
D_HI2	DATA	04AH

G_LOW1	DATA	04BH
G_HI1	DATA	04CH
G_LOW2	DATA	04DH
G_HI2	DATA	04EH

MOD1	DATA	04FH			; Model count speaker type channel1
MOD2	DATA	050H			; Model count speaker type channel2

SPOPT	DATA	051H			; Speaker preset options
					; Bits	3-0: Array length ch1
					; Bits	7-4: Array length ch2

LIGHT	DATA	052H			; Backlight timeout/intensity data
CONTR	DATA	053H			; LCD contrast data

PIN12	DATA	054H
PIN34	DATA	055H

PRESET	DATA	056H			; DDP preset

PGADDL	DATA	057H			; FLASH page address low byte
PGADDH	DATA	058H			; FLASH page address high byte

PAGECNTH DATA	059H			; FLASH byte in page counter high byte
PAGECNTL DATA	05AH			; FLASH byte in page counter low byte

ENC_TIM	DATA	05BH			; Countdown timer for encoder speed detect

SPISDAT	DATA	05CH			; SPI serial data
SPIRDAT	DATA	05DH			; SPI received data


I2C_TX	DATA	05EH			; 3 bytes (24 bit word)
I2C_TX2	DATA	05FH			; 
I2C_TX3	DATA	060H			; 

FREQ	DATA	061H			; Index to frequency lookup table
QF	DATA	062H			; Index to Q-factor lookup table
GAIN	DATA	063H			; Index to gain lookup table

TEMP	DATA	064H			; Speaker model in speaker select menu, Preset number in preset menu
PPRESET	DATA	065H			; Previous preset

DSP_OPCODE DATA	066H

GRAPH4	DATA	067H			; graph bytes for LCD graphs
GRAPH3	DATA	068H			;
GRAPH2	DATA	069H			;
GRAPH1	DATA	06AH			;

DNCHAR	DATA	06BH
CCNT	DATA	06CH

SECS	DATA	06DH			; Seconds counter
SEC_IN_PAGE DATA 06EH

D_HI	DATA	06FH
D_MID	DATA	070H
D_LOW	DATA	071H

G_HI	DATA	072H
G_LOW	DATA	073H

COUNT1	DATA	074H
COUNT2	DATA	075H

BTOCNT	DATA	076H			; Backlight TimeOut counter

LCD_PG	DATA  	077H			; 1 Byte
CHAR	DATA  	078H			; 1 Byte

SPPRESET1 DATA	079H			; Extra menus for speaker preset channel1
					; Bit	0: Low correction option enable
					; Bit	1: High correction option enable
					; Bit	2: Active speaker
					; Bit	4-7: Low correction option text for array length

SPPRESET2 DATA	07AH			; Extra menus for speaker preset channel2
					; Bit	0: Low correction option enable
					; Bit	1: High correction option enable
					; Bit	2: Active speaker
					; Bit	4-7: Low correction option text for array length

ACT_2ND DATA	07BH			; Modelnumber of 2nd part of active speaker

DELH1	DATA	07CH
DELL1	DATA	07DH
DELH2	DATA	07EH
DELL2	DATA	07FH

SCLPIN	BIT	0C0H.0			; I2C clock line (P4.0)
SDAPIN	BIT	0C0H.1			; I2C data line (P4.1)

AMP_ON	BIT	P0.1
FLASH_BUSY BIT	P0.2
ADSTACK	BIT	P0.3
DAC_MUTE BIT	P0.7
	
IR_EYE	BIT	P1.0
FLASH_CS BIT	P1.1
ENC_SW	BIT	P1.2
ENC_B	BIT	P1.3
ENC_A	BIT	P1.4

LCD_DATA BIT	P2.0
LCD_CLK	BIT	P2.1
LCD_RST	BIT	P2.2			; Keep this bit allways high!!
LCD_CS	BIT	P2.3
LCD_DCNTRL BIT	P2.4
DSP_RST	BIT	P2.5
RTC_IRQ BIT	P2.6
DSP_HREQ BIT	P2.7

CNV_RST	BIT	P3.0
PFO	BIT	P3.2
BCKLGHT1 BIT	P3.3
BCKLGHT2 BIT	P3.5
BCKLGHT3 BIT	P3.6
BCKLGHT4 BIT	P3.7
	
;* ------------------------------------------------------------------------
;*  Interrupt vectors:
;* ------------------------------------------------------------------------

	CSEG  	AT 000H			; Reset vector
	USING	0  			; Register-Bank 0
	LJMP	7C16H			; Jump to 7C16H

	CSEG	AT 04BH			; SPI interrupt vector
	LJMP	7C00H			; Jump to 7C00H

;* ------------------------------------------------------------------------
;*  Main program starts here:
;* ------------------------------------------------------------------------

	CSEG  	AT 04EH			;

	DB	001H

NORMAL_OPERATION:
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	ORL	0BCH,#080H		; Set USBE
	ORL	0A3H,#001H		; Set PLLEN
	ORL	0BCH,#010H		; Set DETACH

	MOV	08FH,#00H		; Clock to X1 (/12) mode
	MOV	0AFH,#00H		; 

; Display boot screen:
	LCALL	LCD_CLEAR		; Clear LCD data RAM
	LCALL	LCD_BOOT
	LCALL	LCD_REFRESH		; Refresh LCD display data

; Write boot status byte:
	MOV	OPCODE,#053H		; Opcode for page to buffer1
	MOV	OPCODE1,#008H		; Page 525
	MOV	OPCODE2,#034H		;
	MOV	OPCODE3,#0		; 
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte1 in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#001H		; 
	LCALL	FLASH_OPCODE		;

	MOV	A,#001H			; Write boot status byte
	LCALL	SPI_TX			; 

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page
	MOV	OPCODE1,#008H		; Page 525
	MOV	OPCODE2,#034H		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY


GET_DEFAULTS:
	MOV	R1,#FLAGS2
	MOV	DPTR,#DEFAULTS

DEFAULTS_LOOP:
	CLR	A
	MOVC	A,@A+DPTR		; Get data byte from DATA memory
	MOV	@R1,A
	INC	R1
	INC	DPTR
	CJNE	R1,#PGADDL,DEFAULTS_LOOP

; Write settings
	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#008H		; Start at PAGE525
	MOV	OPCODE2,#034H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get data from FLASH
	MOV	GRAPH2,SPIRDAT		; Temporary use this byte. Get previous presets version
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#0E8H		; Opcode for continuous page reading
	MOV	OPCODE1,#00H		; Start at PAGE19
	MOV	OPCODE2,#04CH		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get page address high byte
	MOV	PGADDH,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get page address low byte
	MOV	PGADDL,SPIRDAT		; Move received data

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#053H		; Opcode for page to buffer1
	MOV	OPCODE1,PGADDH		; Start at PAGE...
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#000H		; 
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#0D4H		; Opcode for buffer1 read
	MOV	OPCODE1,#000H		; 
	MOV	OPCODE2,#000H		;
	MOV	OPCODE3,#000H		; Start at byte 0
	LCALL	FLASH_OPCODE		;

	LCALL	SPI_RX			; Get page address high byte
	MOV	GRAPH1,SPIRDAT		; Temporary use this byte. get previous firmware version
	LCALL	SPI_RX			; Get page address high byte
	MOV	BURNCH,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get page address low byte
	MOV	BURNCL,SPIRDAT		; Move received data
	LCALL	SPI_RX			; Get dayclock settings
	MOV	FLAGS5,SPIRDAT		; Move received data

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

; Update firmware code:
	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte0 in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	A,#FIRM_ID		; Write ID code to FLASH
	LCALL	SPI_TX			; 

	MOV	A,GRAPH1		; Get previous firmware version number
	CJNE	A,#010H,OVER_FIRM1
	SJMP	RESTORE_DEFAULTS
OVER_FIRM1:
	CJNE	A,#011H,OVER_FIRM2
	SJMP	RESTORE_DEFAULTS
OVER_FIRM2:
	CJNE	A,#012H,OVER_FIRM3
	SJMP	RESTORE_DEFAULTS
OVER_FIRM3:
	CJNE	A,#013H,OVER_FIRM4
	SJMP	RESTORE_DEFAULTS
OVER_FIRM4:
	CJNE	A,#014H,OVER_FIRM5
	SJMP	RESTORE_DEFAULTS
OVER_FIRM5:
	CJNE	A,#015H,OVER_FIRM6
	SJMP	RESTORE_DEFAULTS
OVER_FIRM6:
	CJNE	A,#016H,OVER_FIRM7
	SJMP	RESTORE_DEFAULTS
OVER_FIRM7:

RESTORE_DEFAULTS:
	MOV	R1,#BURNCH

SETTINGS_LOOP:
	MOV	A,@R1
	LCALL	SPI_TX			; 
	INC	R1
	CJNE	R1,#PGADDL,SETTINGS_LOOP

DONT_RESTORE_DEFAULTS:
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,GRAPH2		; Get previous presets version number
	CLR	C
	SUBB	A,#VERSION
	JZ	DONT_RESTORE_MODELS

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte2D in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#02DH		; 
	LCALL	FLASH_OPCODE		;

	CLR	A			; Write MOD1
	LCALL	SPI_TX			; 
	CLR	A			; Write MOD2
	LCALL	SPI_TX			; 
	CLR	A			; Write SPOPT
	LCALL	SPI_TX			; 

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

DONT_RESTORE_MODELS:

	MOV	OPCODE,#083H		; Write buffer1 to page??
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

; DDP user presets:
USER_PRESETS:
	MOV	A,GRAPH1		; Get previous firmware version number
	CJNE	A,#010H,OVER_PRES1
	SJMP	DEFINE_PRESETS
OVER_PRES1:
	CJNE	A,#011H,OVER_PRES2
	SJMP	DEFINE_PRESETS
OVER_PRES2:
	CJNE	A,#012H,OVER_PRES3
	SJMP	DEFINE_PRESETS
OVER_PRES3:
	CJNE	A,#013H,OVER_PRES4
	SJMP	DEFINE_PRESETS
OVER_PRES4:
	CJNE	A,#014H,OVER_PRES5
	SJMP	DONT_DEFINE_PRESETS
OVER_PRES5:
	CJNE	A,#015H,OVER_PRES6
	SJMP	DONT_DEFINE_PRESETS
OVER_PRES6:

DEFINE_PRESETS:
	MOV	PGADDH,#008H		; Start at page 512
	MOV	PGADDL,#000H		;
	MOV	DPTR,#PRES

	MOV	COUNT2,#13		; Fill 13 pages

PRESET_PAGE_LOOP:
	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	COUNT1,#8		; 8 presets per page

PRESET_LOOP:
	MOV	R1,#21

NAME_LOOP:
	CLR	A
	MOVC	A,@A+DPTR		; Get data byte from DATA memory
	LCALL	SPI_TX			; Write byte to FLASH
	INC	DPTR
	DJNZ	R1,NAME_LOOP

	MOV	R0,#FLAGS2
DATA_LOOP1:
	MOV	A,@R0			; Get data byte from DATA memory
	INC	R0
	LCALL	SPI_TX			; Write byte to FLASH
	CJNE	R0,#LIGHT,DATA_LOOP1

	CLR	A
	LCALL	SPI_TX			; Write dummy 66th byte to FLASH

	MOV	A,COUNT2
	CJNE	A,#1,CONT1
	MOV	A,COUNT1
	CJNE	A,#5,CONT1
	SJMP	END_PRESET_LOOP
CONT1:
	DJNZ	COUNT1,PRESET_LOOP

END_PRESET_LOOP:
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page...
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,PGADDL		; Advance page address to next page
	ADD	A,#04H			; 
	MOV	PGADDL,A		;
	MOV	A,PGADDH		;
	ADDC	A,#00H			;
	MOV	PGADDH,A		;

	DJNZ	COUNT2,PRESET_PAGE_LOOP	
DONT_DEFINE_PRESETS:

	MOV	A,GRAPH2		; Get previous presets version number
	CLR	C
	SUBB	A,#VERSION
	JNZ	RESTORE_PRES_MODELS
	LJMP	DONT_RESTORE_PRES_MODELS

RESTORE_PRES_MODELS:
	MOV	PGADDH,#008H		; Start at page 512
	MOV	PGADDL,#000H		;

	MOV	COUNT2,#13		; Adjust 13 pages

PRESET_PAGE_LOOP2:
	MOV	OPCODE,#053H		; Opcode for page to buffer1
	MOV	OPCODE1,PGADDH		; Page...
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	COUNT1,#8		; 8 presets per page

	MOV	GRAPH3,#00H		; First MOD1 at byte 3EH
	MOV	GRAPH4,#03EH		;

PRESET_LOOP3:
	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; 
	MOV	OPCODE2,GRAPH3		;
	MOV	OPCODE3,GRAPH4		; 
	LCALL	FLASH_OPCODE		;

	CLR	A
	LCALL	SPI_TX			; Write MOD1
	CLR	A
	LCALL	SPI_TX			; Write MOD2
	CLR	A
	LCALL	SPI_TX			; Write SPOPT

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,GRAPH4		; Advance to next preset in this page
	ADD	A,#66			;
	MOV	GRAPH4,A		;
	MOV	A,GRAPH3		;
	ADDC	A,#0			;
	MOV	GRAPH3,A		;

	MOV	A,COUNT2
	CJNE	A,#1,CONT2
	MOV	A,COUNT1
	CJNE	A,#5,CONT2
	SJMP	END_MOD_PRESET_LOOP
CONT2:
	DJNZ	COUNT1,PRESET_LOOP3

END_MOD_PRESET_LOOP:
	MOV	OPCODE,#083H		; Write buffer1 to page...
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,PGADDL		; Advance page address to next page
	ADD	A,#04H			; 
	MOV	PGADDL,A		;
	MOV	A,PGADDH		;
	ADDC	A,#00H			;
	MOV	PGADDH,A		;

	DJNZ	COUNT2,PRESET_PAGE_LOOP2

DONT_RESTORE_PRES_MODELS:

;Write speaker presets to FLASH
	MOV	OPCODE,#053H		; Opcode for page to buffer1
	MOV	OPCODE1,#008H		; Page 525
	MOV	OPCODE2,#034H		;
	MOV	OPCODE3,#0		; 
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte0 in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	A,#VERSION		; Write preset version code
	LCALL	SPI_TX			; 

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page 525
	MOV	OPCODE1,#008H		; Page address
	MOV	OPCODE2,#034H		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	PGADDH,#008H		; Start at page 526
	MOV	PGADDL,#038H		; 

	MOV	DPTR,#SP_PRESETS
	MOV	PRESET,#LAST_MODEL 
	INC	PRESET

LOOP:
	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte0 in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	COUNT1,#2		; 2 presets per page

PAGE_LOOP1:
	MOV	COUNT2,#255		; 255+8=263 bytes per preset
PRESET_LOOP1:
	CLR	A
	MOVC	A,@A+DPTR		; Get byte from memory
	INC	DPTR
	LCALL	SPI_TX			; 
	DJNZ	COUNT2,PRESET_LOOP1

	MOV	COUNT2,#8		; 8 bytes per preset left
PRESET_LOOP2:
	CLR	A
	MOVC	A,@A+DPTR		; Get byte from memory
	INC	DPTR
	LCALL	SPI_TX			; 
	DJNZ	COUNT2,PRESET_LOOP2

	CLR	A			; Write 264th byte
	LCALL	SPI_TX			; 

	DJNZ	PRESET,CONT_WRITING
	SJMP	END_WRITING
CONT_WRITING:
	DJNZ	COUNT1,PAGE_LOOP1

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,PGADDL		; Increase page address by 4 (1 page)
	ADD	A,#004H			;
	MOV	PGADDL,A		;
	MOV	A,PGADDH		;
	ADDC	A,#000H			;
	MOV	PGADDH,A		;

	JNB	ACC.4,LOOP

	SJMP	$

END_WRITING:
	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

; Store DSP program:
	MOV	PGADDH,#00H		; Start at page0 in FLASH
	MOV	PGADDL,#00H		;

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte0 in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	A,#00H			; Store number of words = $000C00
	LCALL	SPI_TX			; 
	MOV	A,#0CH			;
	LCALL	SPI_TX			; 
	MOV	A,#00H			;
	LCALL	SPI_TX			; 

	MOV	A,#00H			; Store DSP P start address = $000000
	LCALL	SPI_TX			; 
	MOV	A,#00H			;
	LCALL	SPI_TX			; 
	MOV	A,#00H			;
	LCALL	SPI_TX			; 

	MOV	PAGECNTH,#02H		; Count 528 bytes per page - 6 allready send
	MOV	PAGECNTL,#0AH		;
	INC	PAGECNTH

	MOV	DPTR,#DSP_PROG

	MOV	BYTECNTH,#024H		; Number of bytes high byte 3k 3 byte words
	MOV	BYTECNTL,#00H		; Number of bytes low byte
;	INC	BYTECNTH		; Don't increase high byte if low byte is 0
FLASH_LOOP:
	CLR	A
	MOVC	A,@A+DPTR		; Get byte from memory
	INC	DPTR
	LCALL	SPI_TX			; Write byte to FLASH

	DJNZ	PAGECNTL,NEXT_BYTE	; Buffer not yet full?
	DJNZ	PAGECNTH,NEXT_BYTE	; Buffer not yet full?

; Buffer is full. Write buffer to FLASH page and continue writing to buffer:

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	A,PGADDL		; Advance page address to next page
	ADD	A,#04H			; 
	MOV	PGADDL,A		;
	MOV	A,PGADDH		;
	ADDC	A,#00H			;
	MOV	PGADDH,A		;

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte0 in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#00H		; 
	LCALL	FLASH_OPCODE		;

	MOV	PAGECNTH,#02H		; Count 528 bytes per page
	MOV	PAGECNTL,#010H		;
	INC	PAGECNTH		;

NEXT_BYTE:
	DJNZ	BYTECNTL,FLASH_LOOP	; All bytes received?
	DJNZ	BYTECNTH,FLASH_LOOP	; All bytes received?

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page
	MOV	OPCODE1,PGADDH		; Page address
	MOV	OPCODE2,PGADDL		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	R4,#0			; Wait 5sec
WAIT_LOOP1:
	MOV	R5,#50
	LCALL	LWAIT
	DJNZ	R4,WAIT_LOOP1

; Write boot status byte:
	MOV	OPCODE,#053H		; Opcode for page to buffer1
	MOV	OPCODE1,#008H		; Page 525
	MOV	OPCODE2,#034H		;
	MOV	OPCODE3,#0		; 
	LCALL	FLASH_OPCODE		;

	SETB	FLASH_CS		; End current FLASH process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#084H		; Opcode for buffer1 write
	MOV	OPCODE1,#00H		; Start at byte1 in buffer
	MOV	OPCODE2,#00H		;
	MOV	OPCODE3,#001H		; 
	LCALL	FLASH_OPCODE		;

	MOV	A,#002H			; Write boot status byte
	LCALL	SPI_TX			; 

	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

	MOV	OPCODE,#083H		; Write buffer1 to page
	MOV	OPCODE1,#008H		; Page 525
	MOV	OPCODE2,#034H		;
	MOV	OPCODE3,#00H		;
	LCALL	FLASH_OPCODE		;
	SETB	FLASH_CS		; End current process
	JNB	FLASH_BUSY,$		; Wait for FLASH ^BUSY

; Bootmode:
	ANL	0BCH,#0EFH		; Clear DETACH
	ORL	0A2H,#020H		; Set ENBOOT
	LJMP	0F400H			; Jump to bootloader

;* ------------------------------------------------------------------------
;*  Function  :LWAIT
;*  Purpose   :Waits for R5 * 0.4ms
;*  Arguments :R5
;*  Uses      :R6
;*  Returns   :-
;* ------------------------------------------------------------------------
LWAIT:	
	MOV	R6,#0
	DJNZ	R6,$
	DJNZ	R5,LWAIT		;FOR R5 TIMES
	RET

;* ------------------------------------------------------------------------
;*  Function  :SPI_TX
;*  Purpose   :Transmit byte to SPI
;*  Arguments :A = byte to be send
;*  Uses      :-
;*  Returns   :-
;* ------------------------------------------------------------------------
SPI_TX:
	LJMP	7CEEH

;* ------------------------------------------------------------------------
;*  Function  :SPI_RX
;*  Purpose   :Receive byte from SPI
;*  Arguments :-
;*  Uses      :-
;*  Returns   :SPIRDAT = Received data
;* ------------------------------------------------------------------------
SPI_RX:
	LJMP	7CF6H

;* ------------------------------------------------------------------------
;*  Function  :FLASH_OPCODE
;*  Purpose   :Enable FLASH memory and send opcode + dont't care bits
;*  Arguments :OPCODE:	084H Buffer1 write 
;*			087H Buffer2 write 
;*			083H Buffer1 to page with erase 
;*			086H Buffer2 to page with erase 
;*			0D4H Buffer1 read 
;*			0D6H Buffer2 read 
;*			053H Page to buffer1 transfer 
;*			055H Page to buffer2 transfer 
;*			0E8H Continuous array read 
;*  Uses      :A,R0,R7
;*  Returns   :-
;* ------------------------------------------------------------------------
FLASH_OPCODE:
	LJMP	7D02H

;* ------------------------------------------------------------------------
;*  Function  :LCD_REFRESH
;*  Purpose   :Copies ERAM space to LCD
;*  Arguments :-
;*  Uses      :A,R5,R7
;*            :INIT_LCD : A,R3,DPTR
;*            :BACKLIGHT_INT : A,R4,DPTR
;*            :LCD_SEND_BYTE : R3
;*            :LCD_SEND_DATA : R3
;*  Returns   :-
;* ------------------------------------------------------------------------

LCD_REFRESH:
	LJMP	7D49H


;* ------------------------------------------------------------------------
;*  Function  :LCD_CLEAR
;*  Purpose   :Clears total display ERAM
;*  Arguments :-
;*  Uses      :A,DPTR,R5,R7
;*  Returns   :-
;* ------------------------------------------------------------------------
LCD_CLEAR:
	LJMP	7D7CH

;* ------------------------------------------------------------------------
;*  Function  :LCD_BOOT
;*  Purpose   :Places BOOTMODE text in LCD ERAM space
;*  Arguments :DPTR
;*  Uses      :A,R7
;*  Returns   :-
;* ------------------------------------------------------------------------

LCD_BOOT:
	LJMP	7D8BH

;* ------------------------------------------------------------------------
;*  End of code
;* ------------------------------------------------------------------------

PRES:	DB	'DigitalDriveProcessor'
	DB	'Preset 1             '
	DB	'Preset 2             '
	DB	'Preset 3             '
	DB	'Preset 4             '
	DB	'Preset 5             '
	DB	'Preset 6             '
	DB	'Preset 7             '
	DB	'Preset 8             '
	DB	'Preset 9             '
	DB	'Preset 10            '
	DB	'Preset 11            '
	DB	'Preset 12            '
	DB	'Preset 13            '
	DB	'Preset 14            '
	DB	'Preset 15            '
	DB	'Preset 16            '
	DB	'Preset 17            '
	DB	'Preset 18            '
	DB	'Preset 19            '
	DB	'Preset 20            '
	DB	'Preset 21            '
	DB	'Preset 22            '
	DB	'Preset 23            '
	DB	'Preset 24            '
	DB	'Preset 25            '
	DB	'Preset 26            '
	DB	'Preset 27            '
	DB	'Preset 28            '
	DB	'Preset 29            '
	DB	'Preset 30            '
	DB	'Preset 31            '
	DB	'Preset 32            '
	DB	'Preset 33            '
	DB	'Preset 34            '
	DB	'Preset 35            '
	DB	'Preset 36            '
	DB	'Preset 37            '
	DB	'Preset 38            '
	DB	'Preset 39            '
	DB	'Preset 40            '
	DB	'Preset 41            '
	DB	'Preset 42            '
	DB	'Preset 43            '
	DB	'Preset 44            '
	DB	'Preset 45            '
	DB	'Preset 46            '
	DB	'Preset 47            '
	DB	'Preset 48            '
	DB	'Preset 49            '
	DB	'Preset 50            '
	DB	'Preset 51            '
	DB	'Preset 52            '
	DB	'Preset 53            '
	DB	'Preset 54            '
	DB	'Preset 55            '
	DB	'Preset 56            '
	DB	'Preset 57            '
	DB	'Preset 58            '
	DB	'Preset 59            '
	DB	'Preset 60            '
	DB	'Preset 61            '
	DB	'Preset 62            '
	DB	'Preset 63            '
	DB	'Preset 64            '
	DB	'Preset 65            '
	DB	'Preset 66            '
	DB	'Preset 67            '
	DB	'Preset 68            '
	DB	'Preset 69            '
	DB	'Preset 70            '
	DB	'Preset 71            '
	DB	'Preset 72            '
	DB	'Preset 73            '
	DB	'Preset 74            '
	DB	'Preset 75            '
	DB	'Preset 76            '
	DB	'Preset 77            '
	DB	'Preset 78            '
	DB	'Preset 79            '
	DB	'Preset 80            '
	DB	'Preset 81            '
	DB	'Preset 82            '
	DB	'Preset 83            '
	DB	'Preset 84            '
	DB	'Preset 85            '
	DB	'Preset 86            '
	DB	'Preset 87            '
	DB	'Preset 88            '
	DB	'Preset 89            '
	DB	'Preset 90            '
	DB	'Preset 91            '
	DB	'Preset 92            '
	DB	'Preset 93            '
	DB	'Preset 94            '
	DB	'Preset 95            '
	DB	'Preset 96            '
	DB	'Preset 97            '
	DB	'Preset 98            '
	DB	'Preset 99            '

DEFAULTS:
;	DB	000H			; Byte01/--: BURNCH
;	DB	000H			; Byte02/--: BURNCL
;	DB	004H			; Byte03/--: FLAGS5
	DB	07FH			; Byte04/15: FLAGS2
	DB	000H			; Byte05/16: FLAGS6
	DB	048H			; Byte06/17: FLAGS3
	DB	000H			; Byte07/18: EQFLAGS
	DB	009H			; Byte08/19: INPSET
	DB	000H			; Byte09/1A: Extra1
	DB	003H			; Byte0A/1B: Extra2
	DB	020H			; Byte0B/1C: FREQ1
	DB	007H			; Byte0C/1D: QF1
	DB	029H			; Byte0D/1E: GAIN1
	DB	038H			; Byte0E/1F: FREQ2
	DB	007H			; Byte0F/20: QF2
	DB	029H			; Byte10/21: GAIN2
	DB	057H			; Byte11/22: FREQ3
	DB	007H			; Byte12/23: QF3
	DB	029H			; Byte13/24: GAIN3
	DB	068H			; Byte14/25: FREQ4
	DB	007H			; Byte15/26: QF4
	DB	029H			; Byte16/27: GAIN4
	DB	020H			; Byte17/28: FREQ5
	DB	007H			; Byte18/29: QF5
	DB	029H			; Byte19/2A: GAIN5
	DB	038H			; Byte1A/2B: FREQ6
	DB	007H			; Byte1B/2C: QF6
	DB	029H			; Byte1C/2D: GAIN6
	DB	057H			; Byte1D/2E: FREQ7
	DB	007H			; Byte1E/2F: QF7
	DB	029H			; Byte1F/30: GAIN7
	DB	068H			; Byte20/31: FREQ8
	DB	007H			; Byte21/32: QF8
	DB	029H			; Byte22/33: GAIN8
	DB	000H			; Byte23/34: D_LOW1
	DB	001H			; Byte24/35: D_MID1
	DB	000H			; Byte25/36: D_HI1
	DB	000H			; Byte26/37: D_LOW2
	DB	001H			; Byte27/38: D_MID2
	DB	000H			; Byte28/39: D_HI2
	DB	000H			; Byte29/3A: G_LOW1
	DB	001H			; Byte2A/3B: G_HI1
	DB	000H			; Byte2B/3C: G_LOW2
	DB	001H			; Byte2C/3D: G_HI2
	DB	000H			; Byte2D/3E: MOD1
	DB	000H			; Byte2E/3F: MOD2
	DB	000H			; Byte2F/40: SPOPT
	DB	005H			; Byte30/41: LIGHT
	DB	005H			; Byte31/42: CONTR
	DB	000H			; Byte32/43: PIN12
	DB	000H			; Byte33/44: PIN34
	DB	000H			; Byte34/45: PRESET
END_DEFAULTS:

DSP_PROG:
	DB	008H,0f4H,0bdH,01eH,000H,00eH,005H,0f4H,03aH,000H,040H,000H
	DB	005H,000H,0bbH,008H,0f4H,0bbH,000H,000H,042H,008H,0f4H,0b9H
	DB	010H,008H,031H,008H,0f4H,0b8H,010H,008H,015H,008H,0f4H,0beH
	DB	000H,000H,002H,007H,0f4H,03fH,000H,000H,000H,007H,0f4H,03eH
	DB	000H,000H,000H,007H,0f4H,036H,00cH,002H,000H,007H,0f4H,038H
	DB	00cH,002H,000H,007H,0f4H,034H,000H,000H,040H,007H,0f4H,035H
	DB	001H,07dH,000H,007H,0f4H,037H,041H,07dH,000H,007H,0f4H,039H
	DB	000H,000H,003H,007H,0f4H,03aH,000H,000H,000H,007H,0f4H,03bH
	DB	000H,000H,003H,007H,0f4H,03cH,000H,000H,000H,007H,0f4H,03fH
	DB	000H,008H,05aH,007H,0f4H,03eH,000H,008H,05aH,007H,0f4H,020H
	DB	000H,000H,000H,001H,035H,020H,001H,037H,020H,007H,0f4H,010H
	DB	000H,030H,000H,00aH,0f0H,080H,000H,000H,032H,000H,000H,000H
	DB	00bH,0f0H,080H,000H,004H,0c9H,006H,078H,0a0H,000H,000H,000H
	DB	007H,0f4H,011H,000H,001H,023H,008H,0f4H,084H,000H,000H,001H
	DB	008H,0f4H,088H,000H,000H,003H,060H,0f4H,013H,000H,000H,000H
	DB	006H,000H,0a8H,048H,058H,000H,038H,00cH,000H,039H,006H,000H
	DB	005H,0f4H,020H,0ffH,0ffH,0ffH,062H,0f4H,000H,010H,000H,000H
	DB	005H,001H,0a2H,063H,0f4H,000H,010H,000H,000H,005H,001H,0a3H
	DB	064H,0f4H,000H,000H,001H,040H,03cH,004H,000H,06cH,036H,000H
	DB	065H,0f4H,000H,000H,001H,000H,03dH,004H,000H,06dH,038H,000H
	DB	066H,0f4H,000H,000H,001H,0c0H,03eH,004H,000H,06eH,039H,000H
	DB	067H,0f4H,000H,000H,001H,080H,03fH,004H,000H,06fH,03aH,000H
	DB	044H,0f4H,000H,000H,002H,025H,04cH,03bH,000H,044H,0f4H,000H
	DB	07fH,0f0H,000H,044H,024H,000H,024H,004H,000H,04cH,03dH,000H
	DB	030H,024H,000H,044H,0f4H,000H,080H,000H,000H,044H,018H,000H
	DB	044H,01cH,000H,044H,010H,000H,044H,014H,000H,006H,006H,0a0H
	DB	04cH,058H,000H,044H,0f4H,000H,07fH,0ffH,0ffH,04cH,02aH,000H
	DB	04cH,02bH,000H,044H,0f4H,000H,0ffH,0ffH,0ffH,044H,070H,000H
	DB	000H,002H,05bH,044H,070H,000H,000H,002H,0b3H,044H,0f4H,000H
	DB	000H,00fH,0ffH,044H,070H,000H,000H,002H,058H,044H,070H,000H
	DB	000H,002H,0b0H,00aH,022H,086H,000H,001H,001H,05eH,0a4H,000H
	DB	05fH,0a6H,000H,04eH,0aaH,01dH,044H,0f4H,000H,0a5H,060H,042H
	DB	045H,0f4H,000H,0daH,09eH,01bH,05fH,028H,02eH,05eH,0a8H,05dH
	DB	002H,070H,058H,00aH,089H,001H,056H,0f0H,045H,000H,002H,03fH
	DB	00aH,0f0H,0afH,000H,000H,08bH,00aH,089H,021H,00cH,01dH,00aH
	DB	047H,0f4H,065H,07fH,0ffH,0ffH,00aH,0f0H,0a7H,000H,000H,091H
	DB	00aH,089H,021H,020H,000H,070H,020H,000H,00dH,002H,070H,008H
	DB	05eH,0a5H,000H,05fH,02aH,000H,05fH,0a7H,000H,04eH,0abH,01dH
	DB	030H,00dH,000H,05fH,029H,02eH,05eH,0a9H,05dH,002H,070H,058H
	DB	00aH,089H,000H,056H,0f0H,045H,000H,002H,097H,00aH,0f0H,0afH
	DB	000H,000H,0a2H,00aH,089H,020H,00cH,01dH,00aH,020H,000H,065H
	DB	00aH,0f0H,0a7H,000H,000H,0a7H,00aH,089H,020H,020H,000H,070H
	DB	020H,000H,00dH,002H,070H,008H,000H,000H,000H,05fH,02bH,000H
	DB	006H,004H,080H,000H,000H,0c8H,057H,0d8H,000H,044H,0f4H,00bH
	DB	000H,001H,000H,002H,0a0H,048H,048H,0d8H,000H,021H,0e4H,022H
	DB	000H,0feH,0b9H,006H,018H,0a0H,001H,080H,040H,025H,040H,000H
	DB	021H,00fH,000H,05eH,0d0H,0abH,044H,0f4H,003H,07fH,0ffH,0ffH
	DB	002H,0a0H,040H,01cH,0d0H,005H,002H,070H,008H,000H,0feH,0b9H
	DB	021H,0e4H,000H,006H,018H,0a0H,001H,080H,040H,045H,058H,000H
	DB	021H,00fH,000H,04eH,0d8H,03eH,020H,058H,000H,057H,058H,013H
	DB	000H,000H,000H,00aH,022H,085H,000H,000H,0d6H,048H,08bH,000H
	DB	049H,08cH,000H,020H,000H,01dH,048H,09aH,000H,049H,00bH,000H
	DB	049H,00cH,000H,049H,092H,000H,020H,000H,01dH,000H,000H,000H
	DB	049H,01aH,000H,049H,012H,000H,00aH,022H,087H,000H,001H,001H
	DB	030H,023H,000H,034H,025H,000H,05eH,0f0H,000H,000H,000H,0c7H
	DB	00aH,022H,0a8H,000H,000H,0edH,044H,0f4H,000H,000H,067H,09dH
	DB	057H,0f4H,045H,008H,0d3H,0dcH,00aH,0f0H,0a7H,000H,001H,001H
	DB	021H,0e6H,013H,00aH,022H,084H,000H,000H,0e8H,020H,000H,03eH
	DB	00aH,022H,028H,056H,060H,000H,046H,064H,000H,00aH,0f0H,080H
	DB	000H,000H,0faH,044H,0f4H,000H,004H,00cH,020H,056H,0f4H,045H
	DB	040H,000H,000H,00aH,0f0H,0a9H,000H,001H,001H,021H,0c4H,01bH
	DB	00aH,022H,084H,000H,000H,0f7H,020H,000H,036H,00aH,022H,008H
	DB	044H,060H,000H,057H,064H,000H,030H,071H,000H,034H,070H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,056H,060H,000H
	DB	057H,064H,000H,001H,091H,091H,000H,000H,079H,020H,000H,013H
	DB	004H,04cH,094H,00cH,01eH,0e0H,001H,040H,0c5H,000H,000H,052H
	DB	00aH,0f0H,0aaH,000H,004H,0afH,001H,041H,085H,00bH,0f0H,0aaH
	DB	000H,004H,0b7H,001H,050H,085H,00bH,0f0H,0aaH,000H,004H,0a1H
	DB	061H,0f4H,000H,000H,002H,0bdH,001H,051H,085H,00bH,0f0H,0aaH
	DB	000H,004H,018H,061H,0f4H,000H,000H,004H,095H,001H,066H,085H
	DB	00bH,0f0H,0aaH,000H,004H,018H,001H,052H,085H,00aH,0f0H,0a2H
	DB	000H,001H,025H,00bH,0f0H,080H,000H,004H,034H,060H,0f4H,000H
	DB	000H,002H,0bdH,061H,0f4H,000H,000H,002H,004H,00aH,0f0H,080H
	DB	000H,001H,044H,001H,053H,085H,00aH,0f0H,0a2H,000H,001H,030H
	DB	00bH,0f0H,080H,000H,004H,034H,060H,0f4H,000H,000H,003H,033H
	DB	061H,0f4H,000H,000H,002H,009H,00aH,0f0H,080H,000H,001H,044H
	DB	001H,054H,085H,00aH,0f0H,0a2H,000H,001H,03bH,00bH,0f0H,080H
	DB	000H,004H,034H,060H,0f4H,000H,000H,003H,0a9H,061H,0f4H,000H
	DB	000H,002H,00eH,00aH,0f0H,080H,000H,001H,044H,001H,055H,085H
	DB	00aH,0f0H,0a2H,000H,001H,048H,00bH,0f0H,080H,000H,004H,034H
	DB	060H,0f4H,000H,000H,004H,01fH,061H,0f4H,000H,000H,002H,013H
	DB	00bH,0f0H,080H,000H,003H,0efH,00bH,0f0H,080H,000H,003H,09aH
	DB	001H,056H,085H,00aH,0f0H,0a2H,000H,001H,04fH,00bH,0f0H,080H
	DB	000H,003H,037H,054H,070H,013H,000H,002H,0b6H,001H,057H,085H
	DB	00aH,0f0H,0a2H,000H,001H,056H,00bH,0f0H,080H,000H,003H,037H
	DB	054H,070H,013H,000H,002H,0b7H,001H,058H,085H,00aH,0f0H,0a2H
	DB	000H,001H,05dH,020H,000H,013H,000H,000H,000H,056H,070H,000H
	DB	000H,002H,042H,001H,059H,085H,00aH,0f0H,0a2H,000H,001H,064H
	DB	020H,000H,013H,000H,000H,000H,056H,070H,000H,000H,002H,09aH
	DB	001H,060H,085H,00aH,0f0H,0a2H,000H,001H,06bH,044H,0f4H,013H
	DB	041H,0d0H,0d6H,044H,070H,000H,000H,002H,042H,001H,061H,085H
	DB	00aH,0f0H,0a2H,000H,001H,072H,044H,0f4H,013H,044H,039H,00dH
	DB	044H,070H,000H,000H,002H,09aH,001H,062H,085H,00aH,0f0H,0a2H
	DB	000H,001H,07dH,00bH,0f0H,080H,000H,004H,034H,060H,0f4H,000H
	DB	000H,004H,095H,061H,0f4H,000H,000H,002H,05cH,00aH,0f0H,080H
	DB	000H,001H,09cH,001H,063H,085H,00aH,0f0H,0a2H,000H,001H,088H
	DB	00bH,0f0H,080H,000H,004H,034H,060H,0f4H,000H,000H,005H,00bH
	DB	061H,0f4H,000H,000H,002H,061H,00aH,0f0H,080H,000H,001H,09cH
	DB	001H,064H,085H,00aH,0f0H,0a2H,000H,001H,093H,00bH,0f0H,080H
	DB	000H,004H,034H,060H,0f4H,000H,000H,005H,081H,061H,0f4H,000H
	DB	000H,002H,066H,00aH,0f0H,080H,000H,001H,09cH,001H,065H,085H
	DB	00aH,0f0H,0a2H,000H,001H,0a0H,00bH,0f0H,080H,000H,004H,034H
	DB	060H,0f4H,000H,000H,005H,0f7H,061H,0f4H,000H,000H,002H,06bH
	DB	00bH,0f0H,080H,000H,003H,0efH,00bH,0f0H,080H,000H,003H,099H
	DB	001H,067H,085H,00aH,0f0H,0a2H,000H,001H,0aeH,00aH,022H,020H
	DB	060H,0f4H,013H,000H,002H,007H,006H,004H,080H,000H,001H,0adH
	DB	056H,058H,000H,020H,058H,000H,020H,058H,000H,020H,058H,000H
	DB	020H,058H,000H,000H,000H,000H,001H,068H,085H,00aH,0f0H,0a2H
	DB	000H,001H,0bcH,00aH,022H,021H,060H,0f4H,013H,000H,002H,05fH
	DB	006H,004H,080H,000H,001H,0bbH,056H,058H,000H,020H,058H,000H
	DB	020H,058H,000H,020H,058H,000H,020H,058H,000H,000H,000H,000H
	DB	001H,069H,085H,00aH,0f0H,0a2H,000H,001H,0c4H,00aH,022H,000H
	DB	061H,0f4H,013H,000H,002H,008H,00aH,0f0H,080H,000H,001H,0caH
	DB	001H,06aH,085H,00aH,0f0H,0a2H,000H,001H,0ceH,00aH,022H,001H
	DB	061H,0f4H,013H,000H,002H,060H,006H,004H,080H,000H,001H,0cdH
	DB	044H,0d1H,000H,044H,049H,000H,001H,071H,085H,00aH,0f0H,0a2H
	DB	000H,001H,0dcH,00bH,0f0H,080H,000H,003H,0deH,021H,0c5H,000H
	DB	045H,070H,000H,000H,002H,0b4H,00bH,0f0H,080H,000H,003H,058H
	DB	056H,070H,000H,000H,002H,041H,00bH,0f0H,080H,000H,003H,063H
	DB	001H,072H,085H,00aH,0f0H,0a2H,000H,001H,0eaH,00bH,0f0H,080H
	DB	000H,003H,0deH,021H,0c5H,000H,045H,070H,000H,000H,002H,0b5H
	DB	00bH,0f0H,080H,000H,003H,058H,056H,070H,000H,000H,002H,099H
	DB	00bH,0f0H,080H,000H,003H,076H,001H,073H,085H,00aH,0f0H,0a2H
	DB	000H,002H,042H,000H,003H,0f8H,061H,0f4H,000H,000H,002H,018H
	DB	006H,007H,080H,000H,001H,0f6H,00bH,0f0H,080H,000H,004H,034H
	DB	00bH,0f0H,080H,000H,003H,0a8H,000H,000H,000H,00bH,0f0H,080H
	DB	000H,004H,034H,00bH,0f0H,080H,000H,003H,0b1H,061H,0f4H,000H
	DB	000H,002H,045H,00bH,0f0H,080H,000H,004H,034H,00bH,0f0H,080H
	DB	000H,003H,0b1H,060H,0f4H,000H,000H,002H,03bH,061H,0f4H,000H
	DB	000H,002H,04bH,006H,006H,080H,000H,002H,009H,044H,0d8H,000H
	DB	044H,059H,000H,000H,000H,000H,060H,0f4H,000H,000H,002H,051H
	DB	031H,0c0H,000H,00bH,0f0H,080H,000H,003H,0c2H,030H,027H,000H
	DB	031H,0c8H,000H,00bH,0f0H,080H,000H,003H,0caH,020H,000H,013H
	DB	050H,0f0H,000H,000H,000H,059H,000H,000H,00aH,000H,000H,000H
	DB	050H,070H,000H,000H,000H,05dH,050H,0f0H,000H,000H,000H,060H
	DB	000H,000H,00aH,000H,000H,000H,050H,070H,000H,000H,000H,064H
	DB	00bH,0f0H,080H,000H,003H,063H,044H,0f0H,013H,000H,000H,068H
	DB	04cH,02eH,000H,044H,0f0H,000H,000H,000H,06aH,044H,070H,000H
	DB	000H,002H,05aH,044H,0f0H,000H,000H,000H,066H,04cH,030H,000H
	DB	044H,0f0H,000H,000H,000H,067H,04cH,032H,000H,057H,0f0H,000H
	DB	000H,000H,06fH,000H,000H,000H,057H,070H,03eH,000H,002H,043H
	DB	000H,000H,000H,057H,070H,000H,000H,002H,044H,044H,0f4H,000H
	DB	07fH,0ffH,0ffH,04cH,02aH,000H,061H,0f4H,000H,000H,001H,000H
	DB	006H,080H,0a0H,048H,059H,000H,056H,070H,000H,000H,002H,03fH
	DB	056H,070H,000H,000H,002H,04fH,001H,074H,085H,00aH,0f0H,0a2H
	DB	000H,002H,09aH,000H,003H,0f8H,061H,0f4H,000H,000H,002H,070H
	DB	006H,007H,080H,000H,002H,04eH,00bH,0f0H,080H,000H,004H,034H
	DB	00bH,0f0H,080H,000H,003H,0a8H,000H,000H,000H,00bH,0f0H,080H
	DB	000H,004H,034H,00bH,0f0H,080H,000H,003H,0b1H,061H,0f4H,000H
	DB	000H,002H,09dH,00bH,0f0H,080H,000H,004H,034H,00bH,0f0H,080H
	DB	000H,003H,0b1H,060H,0f4H,000H,000H,002H,093H,061H,0f4H,000H
	DB	000H,002H,0a3H,006H,006H,080H,000H,002H,061H,044H,0d8H,000H
	DB	044H,059H,000H,000H,000H,000H,060H,0f4H,000H,000H,002H,0a9H
	DB	031H,0c2H,000H,00bH,0f0H,080H,000H,003H,0c2H,030H,074H,000H
	DB	031H,0dbH,000H,00bH,0f0H,080H,000H,003H,0caH,020H,000H,013H
	DB	050H,0f0H,000H,000H,000H,0a6H,000H,000H,00aH,000H,000H,000H
	DB	050H,070H,000H,000H,000H,0aaH,050H,0f0H,000H,000H,000H,0adH
	DB	000H,000H,00aH,000H,000H,000H,050H,070H,000H,000H,000H,0b1H
	DB	00bH,0f0H,080H,000H,003H,076H,044H,0f0H,013H,000H,000H,0b5H
	DB	04cH,02fH,000H,044H,0f0H,000H,000H,000H,0b7H,044H,070H,000H
	DB	000H,002H,0b2H,044H,0f0H,000H,000H,000H,0b3H,04cH,031H,000H
	DB	044H,0f0H,000H,000H,000H,0b4H,04cH,033H,000H,057H,0f0H,000H
	DB	000H,000H,0bcH,000H,000H,000H,057H,070H,03eH,000H,002H,09bH
	DB	000H,000H,000H,057H,070H,000H,000H,002H,09cH,044H,0f4H,000H
	DB	07fH,0ffH,0ffH,04cH,02bH,000H,061H,0f4H,000H,000H,001H,080H
	DB	006H,080H,0a0H,048H,059H,000H,056H,070H,000H,000H,002H,097H
	DB	056H,070H,000H,000H,002H,0a7H,001H,077H,085H,00aH,0f0H,0a2H
	DB	000H,002H,0a1H,00bH,0f0H,080H,000H,003H,040H,000H,0fcH,0b8H
	DB	00aH,022H,026H,001H,040H,0c5H,000H,000H,040H,00aH,0f0H,0a2H
	DB	000H,002H,0aaH,044H,0f4H,013H,040H,000H,000H,00aH,022H,007H
	DB	044H,023H,000H,056H,025H,000H,001H,040H,0c5H,000H,000H,041H
	DB	00aH,0f0H,0a2H,000H,002H,0b3H,044H,0f4H,013H,040H,000H,000H
	DB	00aH,022H,007H,044H,025H,000H,056H,023H,000H,001H,040H,0c5H
	DB	000H,000H,042H,00aH,0f0H,0a2H,000H,002H,0bbH,024H,020H,013H
	DB	00aH,022H,007H,044H,023H,000H,044H,025H,000H,001H,040H,0c5H
	DB	000H,000H,043H,00aH,0f0H,0a2H,000H,002H,0c9H,057H,0f4H,013H
	DB	040H,000H,000H,00aH,022H,084H,000H,002H,0c4H,020H,000H,03eH
	DB	00aH,022H,007H,057H,070H,000H,000H,000H,070H,056H,070H,000H
	DB	000H,000H,071H,001H,040H,0c5H,000H,000H,044H,00aH,0f0H,0a2H
	DB	000H,002H,0d7H,057H,0f4H,013H,040H,000H,000H,00aH,022H,084H
	DB	000H,002H,0d2H,020H,000H,03eH,00aH,022H,007H,057H,070H,000H
	DB	000H,000H,071H,056H,070H,000H,000H,000H,070H,001H,040H,0c5H
	DB	000H,000H,045H,00aH,0f0H,0a2H,000H,002H,0e4H,02fH,020H,013H
	DB	00aH,022H,084H,000H,002H,0dfH,020H,000H,03eH,00aH,022H,007H
	DB	057H,070H,000H,000H,000H,071H,057H,070H,000H,000H,000H,070H
	DB	001H,040H,0c5H,000H,000H,050H,00aH,0f0H,0a2H,000H,002H,0f8H
	DB	044H,0f4H,013H,040H,000H,000H,00aH,022H,027H,00aH,022H,008H
	DB	044H,023H,000H,00aH,022H,084H,000H,002H,0f1H,044H,0f4H,000H
	DB	0c0H,000H,000H,044H,070H,000H,000H,000H,071H,056H,025H,000H
	DB	056H,070H,000H,000H,000H,070H,04cH,070H,000H,000H,000H,0c7H
	DB	001H,040H,0c5H,000H,000H,046H,00aH,0f0H,0a2H,000H,003H,00bH
	DB	00aH,022H,024H,00aH,022H,005H,00aH,022H,007H,044H,0f4H,013H
	DB	040H,000H,000H,044H,023H,000H,056H,025H,000H,044H,0f4H,000H
	DB	0c0H,000H,000H,044H,070H,000H,000H,000H,071H,056H,070H,000H
	DB	000H,000H,070H,00aH,0f0H,080H,000H,003H,032H,001H,040H,0c5H
	DB	000H,000H,047H,00aH,0f0H,0a2H,000H,003H,01cH,00aH,022H,004H
	DB	00aH,022H,005H,00aH,022H,007H,044H,0f4H,013H,040H,000H,000H
	DB	044H,023H,000H,056H,025H,000H,044H,070H,000H,000H,000H,071H
	DB	056H,070H,000H,000H,000H,070H,00aH,0f0H,080H,000H,003H,032H
	DB	001H,040H,0c5H,000H,000H,048H,00aH,0f0H,0a2H,000H,003H,023H
	DB	00aH,022H,025H,00aH,0f0H,080H,000H,003H,028H,001H,040H,0c5H
	DB	000H,000H,049H,00aH,0f0H,0a2H,000H,003H,036H,00aH,022H,005H
	DB	00aH,022H,004H,00aH,022H,007H,044H,0f4H,013H,040H,000H,000H
	DB	044H,023H,000H,056H,025H,000H,056H,070H,000H,000H,000H,071H
	DB	044H,070H,000H,000H,000H,070H,00bH,0f0H,080H,000H,003H,063H
	DB	00bH,0f0H,080H,000H,003H,076H,00cH,000H,079H,006H,003H,080H
	DB	000H,003H,03eH,000H,000H,000H,001H,091H,091H,000H,003H,03aH
	DB	004H,048H,094H,00cH,01dH,010H,000H,000H,000H,000H,000H,00cH
	DB	000H,003H,0f8H,044H,0f0H,000H,000H,002H,0b6H,056H,0f0H,000H
	DB	000H,000H,06eH,044H,0f0H,040H,000H,002H,0b7H,057H,0f0H,000H
	DB	000H,000H,0bbH,044H,0f4H,048H,000H,080H,000H,004H,0ceH,0a2H
	DB	005H,0f4H,023H,0ffH,0ffH,0ffH,063H,0f4H,013H,010H,000H,000H
	DB	006H,0c4H,020H,048H,05bH,000H,004H,0cfH,0a3H,062H,0f4H,000H
	DB	010H,000H,000H,063H,0f4H,000H,010H,000H,000H,000H,000H,00cH
	DB	047H,0f4H,000H,072H,014H,082H,056H,0f4H,000H,065H,0acH,08cH
	DB	006H,0c5H,000H,000H,003H,060H,021H,0c6H,000H,020H,000H,0b1H
	DB	000H,000H,000H,020H,000H,032H,000H,000H,00cH,045H,0f0H,000H
	DB	000H,002H,0b4H,056H,0f0H,000H,000H,000H,06cH,00bH,0f0H,080H
	DB	000H,003H,089H,05eH,017H,000H,056H,0f0H,000H,000H,000H,06dH
	DB	00bH,0f0H,080H,000H,003H,089H,05eH,01bH,000H,056H,0f0H,000H
	DB	000H,000H,06bH,00bH,0f0H,080H,000H,003H,089H,056H,070H,013H
	DB	000H,002H,059H,000H,000H,00cH,045H,0f0H,000H,000H,002H,0b5H
	DB	056H,0f0H,000H,000H,000H,0b9H,00bH,0f0H,080H,000H,003H,089H
	DB	05eH,00fH,000H,056H,0f0H,000H,000H,000H,0baH,00bH,0f0H,080H
	DB	000H,003H,089H,05eH,013H,000H,056H,0f0H,000H,000H,000H,0b8H
	DB	00bH,0f0H,080H,000H,003H,089H,056H,070H,013H,000H,002H,0b1H
	DB	000H,000H,00cH,020H,000H,003H,00aH,0f0H,0a2H,000H,003H,08dH
	DB	000H,000H,00cH,046H,0f4H,000H,047H,0cfH,026H,006H,0c5H,000H
	DB	000H,003H,094H,021H,0c4H,000H,020H,000H,0d1H,020H,000H,032H
	DB	000H,000H,000H,00aH,022H,084H,000H,003H,098H,020H,000H,022H
	DB	000H,000H,00cH,020H,000H,02bH,060H,0f4H,013H,000H,002H,000H
	DB	006H,003H,080H,000H,003H,0a0H,044H,0d8H,000H,044H,059H,000H
	DB	000H,000H,000H,018H,0a0H,000H,00aH,0cdH,020H,000H,003H,0a5H
	DB	021H,0c6H,000H,046H,059H,000H,056H,059H,013H,000H,000H,00cH
	DB	060H,0f4H,000H,000H,002H,000H,006H,004H,080H,000H,003H,0aeH
	DB	044H,0d8H,000H,044H,059H,000H,000H,000H,000H,020H,059H,000H
	DB	000H,000H,00cH,060H,0f4H,000H,000H,002H,000H,006H,002H,080H
	DB	000H,003H,0b7H,044H,0d8H,000H,044H,059H,000H,000H,000H,000H
	DB	044H,0f0H,000H,000H,002H,0bcH,044H,059H,000H,006H,002H,080H
	DB	000H,003H,0bfH,044H,0d8H,000H,044H,059H,000H,000H,000H,000H
	DB	020H,059H,000H,000H,000H,00cH,006H,007H,080H,000H,003H,0c6H
	DB	00dH,003H,037H,054H,058H,013H,000H,000H,000H,006H,002H,0a0H
	DB	048H,059H,000H,000H,000H,00cH,006H,036H,080H,000H,003H,0ceH
	DB	00dH,003H,037H,054H,058H,013H,000H,000H,000H,020H,058H,000H
	DB	006H,006H,080H,000H,003H,0d4H,00dH,003H,037H,054H,058H,013H
	DB	000H,000H,000H,020H,058H,000H,006H,00bH,080H,000H,003H,0daH
	DB	00dH,003H,037H,054H,058H,013H,000H,000H,000H,006H,013H,0a0H
	DB	048H,059H,000H,000H,000H,00cH,020H,000H,013H,001H,091H,091H
	DB	000H,003H,0dfH,004H,04cH,094H,00cH,01eH,0e0H,026H,050H,000H
	DB	021H,084H,000H,020H,000H,0d0H,020H,000H,01bH,001H,091H,091H
	DB	000H,003H,0e7H,004H,04dH,094H,00cH,01eH,0e1H,00cH,01dH,008H
	DB	021H,0a4H,011H,020H,000H,040H,000H,000H,00cH,046H,0f4H,000H
	DB	000H,014H,000H,047H,0f4H,000H,043H,0e4H,073H,006H,076H,080H
	DB	000H,004H,015H,044H,0f0H,098H,000H,002H,0b8H,020H,000H,0d1H
	DB	000H,000H,000H,021H,0c5H,08eH,056H,0f0H,02eH,000H,002H,0bbH
	DB	00cH,01cH,087H,00cH,01dH,004H,020H,000H,02aH,00cH,01cH,004H
	DB	020H,000H,06dH,00eH,013H,0feH,000H,0feH,0b9H,006H,018H,0a0H
	DB	001H,080H,068H,000H,000H,000H,021H,024H,000H,021H,0cfH,083H
	DB	000H,0feH,0b9H,021H,0c5H,019H,006H,018H,0a0H,001H,080H,068H
	DB	045H,0f0H,000H,000H,002H,003H,021H,024H,000H,02eH,004H,0b9H
	DB	020H,000H,0a3H,00cH,01dH,004H,020H,000H,03aH,056H,058H,000H
	DB	021H,0e6H,013H,000H,000H,000H,055H,0a2H,000H,000H,000H,00cH
	DB	006H,076H,080H,000H,004H,032H,00aH,071H,0c4H,000H,000H,0ecH
	DB	00aH,071H,0c5H,000H,000H,076H,044H,0d9H,0a1H,00aH,071H,0c5H
	DB	000H,001H,061H,021H,0c4H,0a9H,046H,0f4H,000H,001H,000H,000H
	DB	021H,0e5H,01bH,060H,0f4H,0a0H,000H,009H,0a3H,00cH,01dH,012H
	DB	020H,000H,058H,007H,0d8H,084H,020H,000H,045H,00eH,074H,028H
	DB	000H,000H,000H,001H,091H,08fH,000H,004H,02dH,055H,070H,013H
	DB	0ffH,0ffH,093H,000H,000H,000H,000H,000H,000H,000H,000H,00cH
	DB	020H,000H,01bH,001H,091H,091H,000H,004H,035H,004H,04dH,094H
	DB	00cH,01eH,0e1H,056H,0f4H,000H,000H,007H,009H,021H,0a4H,000H
	DB	006H,003H,0a0H,020H,000H,040H,001H,091H,091H,000H,004H,03eH
	DB	021H,090H,000H,020H,000H,01bH,004H,04dH,094H,00cH,01eH,0e1H
	DB	056H,0f4H,000H,000H,008H,077H,007H,0d8H,087H,007H,0d8H,084H
	DB	007H,0e0H,086H,021H,0a5H,01bH,044H,070H,060H,000H,002H,0baH
	DB	046H,070H,060H,000H,002H,0b8H,020H,000H,01bH,001H,091H,091H
	DB	000H,004H,04fH,004H,04dH,094H,00cH,01eH,0e1H,001H,040H,0cdH
	DB	000H,000H,0ffH,00aH,0f0H,0aaH,000H,004H,095H,021H,090H,000H
	DB	021H,0a4H,000H,057H,0f4H,000H,000H,008H,0c7H,047H,070H,048H
	DB	000H,002H,0b9H,020H,000H,048H,007H,0d8H,08eH,007H,0e0H,086H
	DB	021H,0b0H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	007H,0d8H,08fH,007H,0e0H,087H,057H,070H,00bH,000H,002H,003H
	DB	00aH,0f0H,0a1H,000H,004H,072H,001H,040H,0cdH,0fcH,000H,000H
	DB	00aH,0f0H,0aaH,000H,004H,072H,00cH,01dH,08bH,021H,0c4H,000H
	DB	021H,0e5H,000H,020H,000H,0a3H,020H,000H,0b9H,024H,008H,000H
	DB	057H,070H,000H,000H,002H,0bbH,021H,0cfH,000H,045H,0f0H,03aH
	DB	000H,002H,0b9H,027H,004H,0abH,020H,000H,0f7H,021H,0e4H,000H
	DB	021H,0cfH,026H,000H,0feH,0b9H,006H,018H,0a0H,001H,080H,040H
	DB	000H,000H,000H,021H,00eH,00bH,00aH,0f0H,0a1H,000H,004H,086H
	DB	020H,000H,036H,000H,000H,000H,056H,070H,022H,000H,002H,000H
	DB	024H,020H,036H,045H,0f0H,040H,000H,002H,0baH,024H,040H,000H
	DB	046H,0f0H,0a8H,000H,002H,000H,056H,070H,0ebH,000H,002H,001H
	DB	056H,070H,000H,000H,002H,0bcH,057H,070H,000H,000H,002H,002H
	DB	000H,000H,00cH,024H,040H,013H,044H,070H,000H,000H,002H,001H
	DB	056H,070H,000H,000H,002H,0bcH,056H,070H,000H,000H,002H,000H
	DB	056H,070H,000H,000H,002H,002H,056H,070H,000H,000H,002H,003H
	DB	000H,000H,00cH,030H,000H,013H,006H,000H,08cH,000H,004H,0adH
	DB	007H,0d8H,08dH,006H,003H,080H,000H,004H,0acH,000H,000H,000H
	DB	001H,091H,08fH,000H,004H,0a8H,004H,0cdH,093H,00cH,01eH,091H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,00cH,044H,0f4H,013H
	DB	014H,000H,000H,000H,000H,000H,001H,091H,08fH,000H,004H,0b2H
	DB	004H,0c4H,093H,000H,000H,000H,00cH,001H,001H,030H,02aH,000H
	DB	044H,0f4H,000H,014H,000H,000H,006H,005H,080H,000H,004H,0c1H
	DB	000H,000H,000H,001H,091H,08fH,000H,004H,0bdH,004H,0c4H,093H
	DB	04cH,0d8H,000H,000H,000H,000H,046H,0f4H,013H,07fH,0ffH,0ffH
	DB	04eH,02aH,000H,04eH,02bH,000H,05eH,02cH,000H,05eH,02dH,000H
	DB	000H,000H,00cH,040H,01dH,000H,052H,01fH,000H,041H,01eH,000H
	DB	05bH,01fH,000H,042H,020H,000H,043H,021H,000H,068H,034H,000H
	DB	069H,035H,000H,06cH,037H,000H,001H,0b3H,0a1H,000H,005H,0f0H
	DB	037H,002H,000H,035H,0c5H,000H,030H,023H,000H,000H,008H,0f8H
	DB	004H,046H,0c8H,0e5H,0b8H,000H,0b1H,0b8H,0f8H,0b4H,0b8H,000H
	DB	04fH,0ddH,000H,04dH,0e5H,0fbH,04cH,0e2H,0a1H,05fH,05aH,057H
	DB	002H,090H,050H,06cH,0b6H,026H,05fH,0acH,022H,007H,0d8H,020H
	DB	05eH,05dH,041H,00cH,01cH,091H,045H,0d8H,015H,00cH,01dH,08fH
	DB	031H,000H,02eH,005H,002H,0a4H,05fH,02cH,000H,006H,0c5H,000H
	DB	000H,005H,009H,044H,0d8H,000H,045H,0e5H,000H,021H,006H,000H
	DB	021H,087H,000H,001H,027H,08dH,001H,024H,084H,0f0H,0b8H,000H
	DB	001H,027H,0f5H,001H,025H,0b2H,080H,0f8H,000H,001H,026H,0bdH
	DB	001H,024H,0baH,044H,0d8H,010H,043H,0d5H,000H,001H,027H,0f5H
	DB	001H,025H,0bcH,044H,0d8H,000H,001H,026H,0bdH,001H,024H,0b4H
	DB	044H,0d8H,010H,043H,05dH,000H,048H,05dH,000H,001H,027H,0adH
	DB	001H,024H,0a4H,0c0H,0f8H,010H,001H,027H,0adH,001H,024H,0aaH
	DB	044H,0d8H,010H,00cH,01eH,048H,060H,0f4H,000H,000H,002H,004H
	DB	06dH,0b8H,000H,005H,002H,0a5H,0c0H,098H,000H,006H,00bH,080H
	DB	000H,005H,020H,001H,027H,0bdH,015H,09cH,000H,001H,024H,0baH
	DB	0e0H,0b8H,000H,045H,0e4H,0caH,0f0H,098H,0deH,048H,002H,000H
	DB	001H,027H,08dH,001H,024H,08aH,091H,0b8H,018H,048H,082H,000H
	DB	01cH,0ddH,000H,049H,05cH,0a8H,0d0H,098H,000H,00cH,01dH,089H
	DB	0c0H,098H,002H,049H,083H,000H,048H,009H,000H,001H,027H,09dH
	DB	017H,09cH,000H,001H,024H,09aH,0e0H,0b8H,000H,045H,0e4H,0c2H
	DB	044H,0d8H,000H,0f0H,098H,0d6H,049H,061H,000H,001H,027H,0adH
	DB	001H,024H,0aaH,091H,0b8H,010H,049H,0d9H,000H,020H,058H,000H
	DB	014H,0ddH,000H,048H,05cH,0a0H,00cH,01dH,008H,0d4H,019H,00aH
	DB	044H,0d8H,000H,021H,026H,000H,021H,0a7H,000H,001H,027H,08dH
	DB	001H,024H,084H,00cH,01dH,00aH,036H,0c0H,000H,011H,098H,000H
	DB	044H,0d8H,0c9H,045H,0d8H,04dH,002H,070H,048H,0c0H,098H,06dH
	DB	002H,090H,068H,048H,084H,000H,057H,070H,000H,000H,000H,072H
	DB	001H,027H,0bdH,015H,09cH,000H,001H,024H,0baH,0e0H,0b8H,000H
	DB	045H,0e4H,0caH,044H,0d8H,000H,0f0H,098H,0deH,048H,061H,000H
	DB	001H,027H,08dH,001H,024H,08aH,091H,0b8H,018H,048H,0e1H,000H
	DB	01cH,0ddH,000H,049H,05cH,0a8H,0d0H,098H,000H,00cH,01dH,089H
	DB	0c0H,098H,002H,001H,027H,0bdH,015H,09cH,000H,001H,024H,0baH
	DB	0e0H,0b8H,000H,045H,0e4H,0caH,044H,0d8H,000H,0f0H,098H,0deH
	DB	048H,061H,000H,001H,027H,08dH,001H,024H,08aH,091H,0b8H,018H
	DB	048H,0e1H,000H,01cH,0ddH,000H,049H,05cH,0a8H,0d0H,098H,000H
	DB	00cH,01dH,089H,044H,0d8H,002H,045H,0e6H,022H,043H,083H,000H
	DB	048H,005H,000H,001H,027H,0adH,001H,024H,0a4H,0f0H,0d8H,000H
	DB	001H,027H,0d5H,001H,025H,092H,080H,0f8H,000H,001H,026H,09dH
	DB	001H,024H,09aH,0f0H,098H,018H,043H,0d6H,000H,001H,027H,0d5H
	DB	001H,025H,09cH,044H,0d8H,000H,001H,026H,09dH,001H,024H,094H
	DB	044H,0d8H,018H,043H,05eH,000H,049H,066H,000H,001H,027H,08dH
	DB	001H,024H,084H,0c0H,0f8H,018H,001H,027H,08dH,001H,024H,08aH
	DB	044H,0d8H,018H,048H,085H,02aH,045H,0ddH,026H,049H,004H,000H
	DB	01cH,098H,000H,047H,0d8H,05dH,002H,070H,058H,000H,0feH,0b9H
	DB	001H,080H,058H,001H,080H,058H,001H,080H,058H,001H,080H,058H
	DB	001H,080H,058H,001H,080H,058H,001H,080H,058H,001H,080H,058H
	DB	001H,080H,058H,001H,080H,058H,001H,080H,058H,001H,080H,058H
	DB	037H,03dH,013H,021H,02cH,000H,050H,0c0H,046H,00cH,01dH,00fH
	DB	0e4H,0e0H,000H,00cH,01dH,016H,005H,03bH,0a4H,010H,0e7H,05cH
	DB	045H,081H,0abH,04dH,067H,02aH,005H,03bH,0a5H,021H,0e4H,0e8H
	DB	04eH,0ccH,0c1H,05fH,09bH,00bH,002H,070H,040H,06cH,036H,022H
	DB	004H,064H,0a0H,0d8H,020H,000H,056H,070H,000H,000H,002H,03fH
	DB	048H,089H,000H,030H,058H,000H,021H,0c6H,00bH,00aH,0f0H,0aaH
	DB	000H,005H,0cbH,034H,0daH,000H,044H,0d8H,000H,045H,0d8H,000H
	DB	006H,002H,080H,000H,005H,0bbH,0e1H,098H,0d8H,00cH,01eH,07dH
	DB	0f0H,098H,0ceH,0a0H,098H,0dfH,045H,0d8H,000H,0a3H,098H,0daH
	DB	044H,0d8H,0caH,00cH,01eH,05dH,014H,098H,000H,05fH,054H,000H
	DB	021H,0e4H,000H,048H,09aH,088H,0f0H,08cH,01cH,047H,09cH,000H
	DB	021H,024H,000H,021H,0a6H,000H,001H,027H,0eaH,001H,025H,0aeH
	DB	044H,0e0H,018H,05eH,0a6H,02aH,04eH,0e4H,044H,049H,01aH,075H
	DB	002H,090H,070H,000H,000H,000H,05cH,026H,000H,048H,08bH,098H
	DB	04fH,0bbH,01cH,04eH,0b0H,000H,021H,024H,000H,021H,0a5H,000H
	DB	001H,027H,0e4H,001H,025H,0afH,048H,096H,018H,068H,0b4H,000H
	DB	041H,00bH,01cH,004H,065H,0a0H,021H,024H,000H,021H,0a5H,000H
	DB	001H,027H,0edH,001H,025H,0a6H,049H,08bH,010H,04eH,0aeH,005H
	DB	002H,070H,000H,057H,098H,000H,040H,016H,000H,05eH,0a4H,000H
	DB	043H,089H,054H,040H,09dH,01dH,069H,0b5H,02aH,06cH,0b7H,000H
	DB	05fH,024H,000H,052H,09fH,000H,04cH,0a8H,000H,001H,027H,0bdH
	DB	001H,024H,0b4H,042H,0a0H,02aH,06dH,038H,000H,049H,003H,000H
	DB	043H,0a1H,000H,041H,09eH,000H,05bH,09fH,000H,000H,000H,004H
	DB	035H,002H,000H,037H,0c6H,000H,030H,070H,000H,000H,008H,0f8H
	DB	0c4H,0f8H,000H,007H,057H,068H,0e4H,0f8H,0e8H,0c0H,0f8H,000H
	DB	007H,0e0H,020H,056H,0e3H,0ebH,044H,058H,000H,057H,05bH,000H
	DB	05fH,0adH,000H,00cH,01cH,091H,045H,0d8H,015H,00cH,01dH,08fH
	DB	031H,000H,02eH,037H,0dbH,000H,05fH,02dH,000H,006H,0c5H,000H
	DB	000H,006H,021H,044H,0d8H,000H,045H,0e7H,000H,021H,006H,000H
	DB	021H,087H,000H,001H,027H,08dH,001H,024H,084H,0f0H,0f8H,000H
	DB	001H,027H,0f5H,001H,025H,0b2H,080H,0b8H,000H,001H,026H,0bdH
	DB	001H,024H,0baH,044H,0d8H,010H,043H,0d7H,000H,001H,027H,0f5H
	DB	001H,025H,0bcH,044H,0d8H,000H,001H,026H,0bdH,001H,024H,0b4H
	DB	044H,0d8H,010H,043H,05fH,000H,048H,05fH,000H,001H,027H,0adH
	DB	001H,024H,0a4H,0c0H,0b8H,010H,001H,027H,0adH,001H,024H,0aaH
	DB	044H,0d8H,010H,00cH,01eH,048H,06eH,0b9H,000H,005H,002H,0a6H
	DB	060H,0f4H,000H,000H,002H,05cH,06fH,0baH,000H,005H,002H,0a7H
	DB	0c0H,0d8H,000H,006H,00bH,080H,000H,006H,03aH,001H,027H,0bdH
	DB	015H,09eH,000H,001H,024H,0baH,0e0H,0f8H,000H,045H,0e6H,0caH
	DB	0f0H,0d8H,0deH,048H,002H,000H,001H,027H,08dH,001H,024H,08aH
	DB	091H,0f8H,018H,048H,082H,000H,01cH,0dfH,000H,049H,05eH,0a8H
	DB	0d0H,0d8H,000H,00cH,01dH,089H,0c0H,0d8H,002H,049H,086H,000H
	DB	048H,00aH,000H,001H,027H,09dH,017H,09eH,000H,001H,024H,09aH
	DB	0e0H,0f8H,000H,045H,0e6H,0c2H,044H,0d8H,000H,0f0H,0d8H,0d6H
	DB	049H,061H,000H,001H,027H,0adH,001H,024H,0aaH,091H,0f8H,010H
	DB	049H,0d9H,000H,020H,058H,000H,014H,0dfH,000H,048H,05eH,0a0H
	DB	00cH,01dH,008H,0d4H,059H,00aH,044H,0d8H,000H,021H,026H,000H
	DB	021H,0a7H,000H,001H,027H,08dH,001H,024H,084H,00cH,01dH,00aH
	DB	034H,0c2H,000H,011H,098H,000H,044H,0d8H,0c9H,045H,0d8H,04dH
	DB	002H,070H,048H,0c0H,0d8H,06dH,002H,090H,068H,048H,087H,000H
	DB	057H,026H,000H,001H,027H,0bdH,015H,09eH,000H,001H,024H,0baH
	DB	0e0H,0f8H,000H,045H,0e6H,0caH,044H,0d8H,000H,0f0H,0d8H,0deH
	DB	048H,061H,000H,001H,027H,08dH,001H,024H,08aH,091H,0f8H,018H
	DB	048H,0e1H,000H,01cH,0dfH,000H,049H,05eH,0a8H,0d0H,0d8H,000H
	DB	00cH,01dH,089H,0c0H,0d8H,002H,001H,027H,0bdH,015H,09eH,000H
	DB	001H,024H,0baH,0e0H,0f8H,000H,045H,0e6H,0caH,044H,0d8H,000H
	DB	0f0H,0d8H,0deH,048H,061H,000H,001H,027H,08dH,001H,024H,08aH
	DB	091H,0f8H,018H,048H,0e1H,000H,01cH,0dfH,000H,049H,05eH,0a8H
	DB	0d0H,0d8H,000H,00cH,01dH,089H,044H,0d8H,002H,045H,0e4H,022H
	DB	043H,086H,000H,048H,008H,000H,001H,027H,0adH,001H,024H,0a4H
	DB	0f0H,098H,000H,001H,027H,0d5H,001H,025H,092H,080H,0b8H,000H
	DB	001H,026H,09dH,001H,024H,09aH,0f0H,0d8H,018H,043H,0d4H,000H
	DB	001H,027H,0d5H,001H,025H,09cH,044H,0d8H,000H,001H,026H,09dH
	DB	001H,024H,094H,044H,0d8H,018H,043H,05cH,000H,049H,064H,000H
	DB	001H,027H,08dH,001H,024H,084H,0c0H,0b8H,018H,001H,027H,08dH
	DB	001H,024H,08aH,044H,0d8H,018H,048H,088H,02aH,045H,0dfH,026H
	DB	049H,007H,000H,01cH,098H,000H,047H,0d8H,05dH,002H,070H,058H
	DB	000H,0feH,0b9H,001H,080H,058H,001H,080H,058H,001H,080H,058H
	DB	001H,080H,058H,001H,080H,058H,001H,080H,058H,001H,080H,058H
	DB	001H,080H,058H,001H,080H,058H,001H,080H,058H,001H,080H,058H
	DB	001H,080H,058H,035H,03dH,013H,021H,02cH,000H,050H,0c0H,046H
	DB	00cH,01dH,00fH,0f4H,0a0H,000H,00cH,01dH,016H,005H,03bH,0a6H
	DB	010H,0e5H,05cH,045H,081H,0abH,04dH,065H,02aH,005H,03bH,0a7H
	DB	021H,0e4H,0e8H,04eH,0ceH,0c1H,05fH,093H,00bH,002H,070H,040H
	DB	06eH,039H,022H,004H,066H,0a0H,0d8H,060H,000H,056H,070H,000H
	DB	000H,002H,097H,048H,08aH,000H,030H,0a5H,000H,021H,0c6H,00bH
	DB	00aH,0f0H,0aaH,000H,006H,0e4H,034H,0edH,000H,044H,0d8H,000H
	DB	045H,0d8H,000H,006H,002H,080H,000H,006H,0d4H,0e1H,098H,0d8H
	DB	00cH,01eH,07dH,0f0H,098H,0ceH,0a0H,098H,0dfH,045H,0d8H,000H
	DB	0a3H,098H,0daH,044H,0d8H,0caH,00cH,01eH,05dH,014H,098H,000H
	DB	05fH,054H,000H,021H,0e4H,000H,048H,092H,088H,0f0H,08cH,01cH
	DB	047H,094H,000H,021H,024H,000H,021H,0a6H,000H,001H,027H,0eaH
	DB	001H,025H,0aeH,044H,0e0H,018H,05eH,0a7H,02aH,04eH,0e4H,044H
	DB	049H,012H,075H,002H,090H,070H,000H,000H,000H,05cH,027H,000H
	DB	048H,08cH,098H,04fH,0bbH,01cH,04eH,0b1H,000H,021H,024H,000H
	DB	021H,0a5H,000H,001H,027H,0e4H,001H,025H,0afH,048H,08eH,018H
	DB	068H,0b4H,000H,041H,00cH,01cH,004H,067H,0a0H,021H,024H,000H
	DB	021H,0a5H,000H,001H,027H,0edH,001H,025H,0a6H,049H,08cH,010H
	DB	04eH,0afH,005H,002H,070H,000H,057H,090H,000H,040H,00eH,000H
	DB	05eH,0a5H,000H,043H,08aH,054H,040H,09dH,01dH,069H,0b5H,02aH
	DB	06cH,0b7H,000H,05fH,025H,000H,052H,09fH,000H,04cH,0a9H,000H
	DB	001H,027H,0bdH,001H,024H,0b4H,042H,0a0H,02aH,06fH,03aH,000H
	DB	049H,006H,000H,043H,0a1H,000H,041H,09eH,000H,05bH,09fH,000H
	DB	000H,000H,004H,000H,015H,072H,07fH,0ffH,0f9H,000H,014H,000H
	DB	000H,016H,05eH,07fH,0ffH,0f8H,000H,014H,0dbH,000H,017H,0b2H
	DB	07fH,0ffH,0f7H,000H,016H,019H,000H,019H,01bH,07fH,0ffH,0f6H
	DB	000H,017H,069H,000H,01aH,099H,07fH,0ffH,0f5H,000H,018H,0ceH
	DB	000H,01cH,02eH,07fH,0ffH,0f4H,000H,01aH,047H,000H,01dH,0dbH
	DB	07fH,0ffH,0f2H,000H,01bH,0d7H,000H,01fH,0a1H,07fH,0ffH,0f0H
	DB	000H,01dH,07fH,000H,021H,083H,07fH,0ffH,0eeH,000H,01fH,040H
	DB	000H,023H,081H,07fH,0ffH,0ecH,000H,021H,01cH,000H,025H,09dH
	DB	07fH,0ffH,0eaH,000H,023H,014H,000H,027H,0daH,07fH,0ffH,0e7H
	DB	000H,025H,02aH,000H,02aH,038H,07fH,0ffH,0e4H,000H,027H,05fH
	DB	000H,02cH,0bbH,07fH,0ffH,0e1H,000H,029H,0b7H,000H,02fH,064H
	DB	07fH,0ffH,0ddH,000H,02cH,032H,000H,032H,035H,07fH,0ffH,0d9H
	DB	000H,02eH,0d2H,000H,035H,032H,07fH,0ffH,0d4H,000H,031H,09bH
	DB	000H,038H,05bH,07fH,0ffH,0ceH,000H,034H,08eH,000H,03bH,0b5H
	DB	07fH,0ffH,0c8H,000H,037H,0aeH,000H,03fH,042H,07fH,0ffH,0c2H
	DB	000H,03aH,0feH,000H,043H,005H,07fH,0ffH,0baH,000H,03eH,080H
	DB	000H,047H,002H,07fH,0ffH,0b1H,000H,042H,037H,000H,04bH,03aH
	DB	07fH,0ffH,0a8H,000H,046H,027H,000H,04fH,0b4H,07fH,0ffH,09dH
	DB	000H,04aH,053H,000H,054H,071H,07fH,0ffH,091H,000H,04eH,0bfH
	DB	000H,059H,076H,07fH,0ffH,083H,000H,053H,06dH,000H,05eH,0c8H
	DB	07fH,0ffH,074H,000H,058H,063H,000H,064H,06bH,07fH,0ffH,062H
	DB	000H,05dH,0a5H,000H,06aH,063H,07fH,0ffH,04fH,000H,063H,036H
	DB	000H,070H,0b7H,07fH,0ffH,03aH,000H,069H,01dH,000H,077H,06bH
	DB	07fH,0ffH,021H,000H,06fH,05dH,000H,07eH,085H,07fH,0ffH,006H
	DB	000H,075H,0fcH,000H,086H,00bH,07fH,0feH,0e7H,000H,07dH,000H
	DB	000H,08eH,003H,07fH,0feH,0c5H,000H,084H,06fH,000H,096H,075H
	DB	07fH,0feH,09eH,000H,08cH,04fH,000H,09fH,067H,07fH,0feH,073H
	DB	000H,094H,0a7H,000H,0a8H,0e2H,07fH,0feH,042H,000H,09dH,07dH
	DB	000H,0b2H,0ecH,07fH,0feH,00cH,000H,0a6H,0dbH,000H,0bdH,090H
	DB	07fH,0fdH,0cfH,000H,0b0H,0c7H,000H,0c8H,0d6H,07fH,0fdH,08aH
	DB	000H,0bbH,04aH,000H,0d4H,0c7H,07fH,0fdH,03dH,000H,0c6H,06dH
	DB	000H,0e1H,06eH,07fH,0fcH,0e6H,000H,0d2H,039H,000H,0eeH,0d6H
	DB	07fH,0fcH,085H,000H,0deH,0baH,000H,0fdH,009H,07fH,0fcH,018H
	DB	000H,0ebH,0f8H,001H,00cH,015H,07fH,0fbH,09dH,000H,0faH,000H
	DB	001H,01cH,006H,07fH,0fbH,014H,001H,008H,0deH,001H,02cH,0eaH
	DB	07fH,0faH,079H,001H,018H,09eH,001H,03eH,0ceH,07fH,0f9H,0ccH
	DB	001H,029H,04dH,001H,051H,0c3H,07fH,0f9H,00aH,001H,03aH,0fbH
	DB	001H,065H,0d9H,07fH,0f8H,02fH,001H,04dH,0b6H,001H,07bH,020H
	DB	07fH,0f7H,03aH,001H,061H,08eH,001H,091H,0abH,07fH,0f6H,027H
	DB	001H,076H,094H,001H,0a9H,08eH,07fH,0f4H,0f3H,001H,08cH,0daH
	DB	001H,0c2H,0dcH,07fH,0f3H,098H,001H,0a4H,073H,001H,0ddH,0abH
	DB	07fH,0f2H,013H,001H,0bdH,073H,001H,0faH,012H,07fH,0f0H,05fH
	DB	001H,0d7H,0f0H,002H,018H,02aH,07fH,0eeH,075H,001H,0f4H,000H
	DB	002H,038H,00cH,07fH,0ecH,04fH,002H,011H,0bbH,002H,059H,0d3H
	DB	07fH,0e9H,0e5H,002H,031H,03bH,002H,07dH,09cH,07fH,0e7H,030H
	DB	002H,052H,09bH,002H,0a3H,086H,07fH,0e4H,027H,002H,075H,0f6H
	DB	002H,0cbH,0b2H,07fH,0e0H,0beH,002H,09bH,06cH,002H,0f6H,040H
	DB	07fH,0dcH,0eaH,002H,0c3H,01bH,003H,023H,057H,07fH,0d8H,09eH
	DB	002H,0edH,027H,003H,053H,01cH,07fH,0d3H,0ccH,003H,019H,0b3H
	DB	003H,085H,0b8H,07fH,0ceH,063H,003H,048H,0e5H,003H,0bbH,056H
	DB	07fH,0c8H,050H,003H,07aH,0e6H,003H,0f4H,025H,07fH,0c1H,07eH
	DB	003H,0afH,0e0H,004H,030H,054H,07fH,0b9H,0d7H,003H,0e8H,000H
	DB	004H,070H,018H,07fH,0b1H,041H,004H,023H,077H,004H,0b3H,0a6H
	DB	07fH,0a7H,09dH,004H,062H,076H,004H,0fbH,039H,07fH,09cH,0ccH
	DB	004H,0a5H,035H,005H,047H,00dH,07fH,090H,0a7H,004H,0ebH,0ecH
	DB	005H,097H,063H,07fH,083H,007H,005H,036H,0d7H,005H,0ecH,081H
	DB	07fH,073H,0bcH,005H,086H,037H,006H,046H,0aeH,07fH,062H,092H
	DB	005H,0daH,04fH,006H,0a6H,037H,07fH,04fH,04fH,006H,033H,067H
	DB	007H,00bH,070H,07fH,039H,0b1H,006H,091H,0cbH,007H,076H,0adH
	DB	07fH,021H,06fH,006H,0f5H,0ccH,007H,0e8H,04aH,07fH,006H,036H
	DB	007H,05fH,0c0H,008H,060H,0a9H,07eH,0e7H,0aaH,007H,0d0H,000H
	DB	008H,0e0H,030H,07eH,0c5H,064H,008H,046H,0edH,009H,067H,04cH
	DB	07eH,09eH,0efH,008H,0c4H,0edH,009H,0f6H,072H,07eH,073H,0c8H
	DB	009H,04aH,06aH,00aH,08eH,01aH,07eH,043H,05fH,009H,0d7H,0d8H
	DB	00bH,02eH,0c7H,07eH,00dH,00fH,00aH,06dH,0aeH,00bH,0d9H,001H
	DB	07dH,0d0H,022H,00bH,00cH,06dH,00cH,08dH,05cH,07dH,08bH,0caH
	DB	00bH,0b4H,09dH,00dH,04cH,06fH,07dH,03fH,022H,00cH,066H,0cdH
	DB	00eH,016H,0dfH,07cH,0e9H,02aH,00dH,023H,096H,00eH,0edH,059H
	DB	07cH,088H,0c1H,00dH,0ebH,098H,00fH,0d0H,094H,07cH,01cH,0a8H
	DB	00eH,0bfH,07fH,010H,0c1H,051H,07bH,0a3H,076H,00fH,0a0H,000H
	DB	011H,0c0H,060H,07bH,01bH,09aH,010H,08dH,0daH,012H,0ceH,099H
	DB	07aH,083H,056H,011H,089H,0d9H,013H,0ecH,0e3H,079H,0d8H,0b6H
	DB	012H,094H,0d4H,015H,01cH,034H,079H,019H,08cH,013H,0afH,0afH
	DB	016H,05dH,08dH,078H,043H,06eH,014H,0dbH,05cH,017H,0b2H,003H
	DB	077H,053H,0a9H,016H,018H,0dbH,019H,01aH,0b7H,076H,047H,03eH
	DB	017H,069H,03aH,01aH,098H,0deH,075H,01aH,0dcH,018H,0cdH,09bH
	DB	01cH,02dH,0beH,073H,0caH,0d4H,01aH,047H,02cH,01dH,0daH,0b2H
	DB	072H,053H,011H,01bH,0d7H,031H,01fH,0a1H,027H,070H,0afH,016H
	DB	01dH,07eH,0ffH,021H,082H,0a3H,06eH,0d9H,0edH,01fH,040H,000H
	DB	023H,080H,0bfH,06cH,0ceH,025H,021H,01bH,0b4H,025H,09dH,031H
	DB	06aH,085H,0c6H,023H,013H,0b2H,027H,0d9H,0c6H,067H,0faH,04dH
	DB	025H,029H,0a8H,02aH,038H,067H,065H,024H,0a4H,027H,05fH,05eH
	DB	02cH,0bbH,01bH,061H,0fdH,022H,029H,0b6H,0b8H,02fH,064H,006H
	DB	05eH,07bH,088H,02cH,031H,0b5H,032H,035H,06eH,05aH,097H,005H
	DB	02eH,0d2H,075H,035H,031H,0bcH,056H,046H,040H,031H,09bH,035H
	DB	038H,05bH,07dH,051H,07fH,06bH,034H,08eH,058H,03bH,0b5H,064H
	DB	04cH,038H,05aH,037H,0aeH,061H,03fH,042H,04fH,046H,066H,0adH
	DB	03aH,0fdH,0fdH,043H,005H,045H,040H,000H,006H,03eH,080H,000H
	DB	047H,001H,07fH,038H,0faH,055H,042H,037H,069H,04bH,03aH,062H
	DB	031H,04cH,037H,046H,027H,065H,04fH,0b3H,08cH,028H,0edH,079H
	DB	04aH,053H,050H,053H,0c6H,096H,021H,021H,004H,04eH,020H,000H
	DB	07dH,0a9H,0e9H,0cfH,004H,03aH,075H,030H,000H,001H,033H,033H
	DB	07bH,074H,0f0H,001H,099H,09aH,045H,071H,0c7H,002H,000H,000H
	DB	02cH,071H,0c7H,002H,066H,066H,01eH,0ddH,03cH,002H,0ccH,0cdH
	DB	016H,0acH,0fdH,003H,033H,033H,011H,05cH,072H,003H,099H,09aH
	DB	00dH,0b7H,0a9H,004H,000H,000H,00bH,01cH,072H,004H,066H,066H
	DB	009H,02eH,0c8H,004H,0ccH,0cdH,007H,0b7H,04fH,005H,033H,033H
	DB	006H,093H,01aH,006H,000H,000H,004H,0f0H,033H,006H,066H,066H
	DB	004H,057H,01cH,007H,033H,033H,003H,06dH,0eaH,008H,000H,000H
	DB	002H,0c7H,01cH,008H,0ccH,0cdH,002H,04bH,0b2H,009H,099H,09aH
	DB	001H,0edH,0d4H,00aH,0ccH,0cdH,001H,086H,02fH,00cH,000H,000H
	DB	001H,03cH,00dH,00eH,000H,000H,000H,0e8H,033H,010H,000H,000H
	DB	000H,0b1H,0c7H,012H,000H,000H,000H,08cH,077H,014H,000H,000H
	DB	000H,071H,0c7H,016H,000H,000H,000H,05eH,008H,018H,000H,000H
	DB	000H,04fH,003H,01aH,000H,000H,000H,043H,053H,01cH,000H,000H
	DB	000H,03aH,00dH,01eH,000H,000H,000H,032H,091H,020H,000H,000H
	DB	000H,02cH,072H,022H,000H,000H,000H,027H,05fH,024H,000H,000H
	DB	000H,023H,01eH,026H,000H,000H,000H,01fH,084H,028H,000H,000H
	DB	000H,01cH,072H,02cH,000H,000H,000H,017H,082H,030H,000H,000H
	DB	000H,013H,0c1H,034H,000H,000H,000H,010H,0d5H,038H,000H,000H
	DB	000H,00eH,083H,03cH,000H,000H,000H,00cH,0a4H,000H,099H,09aH
	DB	07fH,0ffH,0ffH,000H,0ccH,0cdH,07fH,0ffH,0ffH,0fcH,000H,000H
	DB	010H,000H,000H,0fcH,066H,066H,07fH,0ffH,0ffH,0fcH,06cH,078H
	DB	07fH,0ffH,0ffH,0fcH,072H,0e5H,07fH,0ffH,0ffH,0fcH,079H,0b4H
	DB	07fH,0ffH,0ffH,0fcH,080H,0eaH,07fH,017H,0afH,0fcH,088H,08dH
	DB	077H,0fbH,0abH,0fcH,090H,0a5H,071H,045H,076H,0fcH,099H,037H
	DB	06aH,0efH,05eH,0fcH,0a2H,04bH,064H,0f4H,003H,0fcH,0abH,0e9H
	DB	05fH,04eH,052H,0fcH,0b6H,019H,059H,0f9H,080H,0fcH,0c0H,0e3H
	DB	054H,0f1H,007H,0fcH,0ccH,051H,050H,030H,0a1H,0fcH,0d8H,06cH
	DB	04bH,0b4H,047H,0fcH,0e5H,03fH,047H,078H,029H,0fcH,0f2H,0d4H
	DB	043H,078H,0b0H,0fdH,001H,038H,03fH,0b2H,078H,0fdH,010H,075H
	DB	03cH,022H,04dH,0fdH,020H,09aH,038H,0c5H,028H,0fdH,031H,0b4H
	DB	035H,098H,02fH,0fdH,043H,0d1H,032H,098H,0b0H,0fdH,057H,001H
	DB	02fH,0c4H,021H,0fdH,06bH,054H,02dH,018H,019H,0fdH,080H,0dcH
	DB	02aH,092H,054H,0fdH,097H,0a9H,028H,030H,0b0H,0fdH,0afH,0d1H
	DB	025H,0f1H,026H,0fdH,0c9H,067H,023H,0d1H,0cdH,0fdH,0e4H,082H
	DB	021H,0d0H,0daH,0feH,001H,037H,01fH,0ecH,098H,0feH,01fH,0a0H
	DB	01eH,023H,06dH,0feH,03fH,0d6H,01cH,073H,0d5H,0feH,061H,0f5H
	DB	01aH,0dcH,062H,0feH,086H,01aH,019H,05bH,0b9H,0feH,0acH,062H
	DB	017H,0f0H,095H,0feH,0d4H,0f0H,016H,099H,0c1H,0feH,0ffH,0e4H
	DB	015H,056H,01bH,0ffH,02dH,064H,014H,024H,08fH,0ffH,05dH,097H
	DB	013H,004H,01bH,0ffH,090H,0a4H,011H,0f3H,0caH,0ffH,0c6H,0b8H
	DB	010H,0f2H,0b4H,000H,000H,000H,010H,000H,000H,000H,03cH,0adH
	DB	010H,000H,000H,000H,07cH,0f2H,010H,000H,000H,000H,0c1H,007H
	DB	010H,000H,000H,001H,009H,024H,010H,000H,000H,001H,055H,087H
	DB	010H,000H,000H,001H,0a6H,070H,010H,000H,000H,001H,0fcH,025H
	DB	010H,000H,000H,002H,056H,0eeH,010H,000H,000H,002H,0b7H,018H
	DB	010H,000H,000H,003H,01cH,0f5H,010H,000H,000H,003H,088H,0dbH
	DB	010H,000H,000H,003H,0fbH,026H,010H,000H,000H,004H,074H,036H
	DB	010H,000H,000H,004H,0f4H,073H,010H,000H,000H,005H,07cH,049H
	DB	010H,000H,000H,006H,00cH,02cH,010H,000H,000H,006H,0a4H,095H
	DB	010H,000H,000H,007H,046H,006H,010H,000H,000H,007H,0f1H,008H
	DB	010H,000H,000H,008H,0a6H,02cH,010H,000H,000H,009H,066H,00cH
	DB	010H,000H,000H,00aH,031H,04aH,010H,000H,000H,00bH,008H,093H
	DB	010H,000H,000H,00bH,0ecH,09eH,010H,000H,000H,00cH,0deH,02cH
	DB	010H,000H,000H,00dH,0deH,00aH,010H,000H,000H,00eH,0edH,012H
	DB	010H,000H,000H,010H,00cH,028H,010H,000H,000H,011H,03cH,042H
	DB	010H,000H,000H,012H,07eH,060H,010H,000H,000H,013H,0d3H,095H
	DB	010H,000H,000H,015H,03dH,001H,010H,000H,000H,016H,0bbH,0d7H
	DB	010H,000H,000H,018H,051H,05dH,010H,000H,000H,019H,0feH,0ebH
	DB	010H,000H,000H,01bH,0c5H,0ecH,010H,000H,000H,01dH,0a7H,0e3H
	DB	010H,000H,000H,01fH,0a6H,069H,010H,000H,000H,021H,0c3H,02fH
	DB	010H,000H,000H,024H,000H,000H,010H,000H,000H,0fcH,020H,062H
	DB	000H,000H,000H,0fcH,024H,055H,000H,000H,000H,0fcH,028H,0c4H
	DB	000H,000H,000H,0fcH,02dH,0beH,000H,000H,000H,0fcH,033H,052H
	DB	000H,000H,000H,0fcH,039H,095H,000H,000H,000H,0fcH,040H,09cH
	DB	000H,000H,000H,0fcH,048H,07eH,000H,000H,000H,0fcH,051H,057H
	DB	000H,000H,000H,0fcH,05bH,044H,000H,000H,000H,028H,0e1H,078H
	DB	000H,000H,000H,02eH,05bH,065H,000H,000H,000H,034H,080H,062H
	DB	000H,000H,000H,03bH,065H,04eH,000H,000H,000H,043H,021H,095H
	DB	000H,000H,000H,04bH,0cfH,07cH,000H,000H,000H,055H,08cH,081H
	DB	000H,000H,000H,060H,079H,0b8H,000H,000H,000H,06cH,0bcH,03eH
	DB	000H,000H,000H,07aH,07dH,0b9H,000H,000H,000H,0ffH,040H,057H
	DB	000H,000H,000H,0feH,04dH,040H,000H,000H,000H,0fdH,0b4H,0d1H
	DB	000H,000H,000H,0fdH,0a1H,028H,000H,000H,000H,0fdH,053H,014H
	DB	000H,000H,000H,0fdH,035H,03eH,000H,000H,000H,0fdH,027H,053H
	DB	000H,000H,000H,0fcH,0f0H,00dH,000H,000H,000H,004H,041H,0d5H
	DB	004H,0c6H,0d0H,005H,05cH,005H,006H,003H,06eH,006H,0bfH,045H
	DB	007H,092H,007H,008H,07eH,081H,009H,087H,0d5H,00aH,0b1H,089H
	DB	00bH,0ffH,091H,00dH,076H,05bH,00fH,01aH,0e0H,010H,0f2H,0b4H
	DB	013H,004H,01bH,015H,056H,01bH,017H,0f0H,095H,01aH,0dcH,062H
	DB	01eH,023H,06dH,021H,0d0H,0daH,025H,0f1H,026H,02aH,092H,054H
	DB	02fH,0c4H,021H,035H,098H,02fH,03cH,022H,04dH,043H,078H,0b0H
	DB	07fH,0ffH,0ffH,08aH,0aeH,032H,0f7H,015H,024H,0edH,003H,0bfH
	DB	06dH,07aH,0baH,040H,037H,07eH,0a6H,00eH,0c8H,01eH,038H,03dH
	DB	05fH,067H,0ffH,04fH,025H,0a8H,01fH,035H,0e3H,009H,09cH,039H
	DB	0d9H,033H,08aH,0bfH,075H,0d3H,0e5H,0c1H,0d3H,021H,047H,00eH
	DB	0e9H,000H,02dH,0c0H,0d0H,0cfH,0bcH,073H,06aH,09dH,0f1H,01dH
	DB	029H,054H,0d5H,01bH,02bH,029H,0dcH,050H,080H,028H,0e8H,0d2H
	DB	047H,0f8H,098H,077H,0f5H,05dH,07dH,0f4H,07cH,078H,074H,028H
	DB	07fH,007H,03aH,042H,02dH,024H,09eH,010H,01fH,055H,091H,0feH
	DB	023H,0e7H,002H,06cH,080H,0f9H,05aH,0f3H,0a7H,0f3H,0d2H,058H
	DB	038H,01dH,03eH,030H,085H,0dbH,064H,06fH,076H,0b3H,00bH,062H
	DB	050H,0bfH,016H,01cH,01dH,0bdH,057H,07eH,0c2H,035H,037H,0ceH
	DB	065H,0bbH,0b9H,070H,0e2H,0f9H,0cfH,007H,035H,0f0H,0fcH,0d9H
	DB	053H,061H,073H,01eH,0cdH,0feH,0b5H,09fH,080H,015H,068H,0eaH
	DB	077H,0aaH,07dH,03bH,058H,021H,047H,04cH,06bH,036H,025H,0f3H
	DB	040H,041H,0dcH,0f8H,096H,0d5H,0deH,067H,0edH,0b8H,04aH,02dH
	DB	0bcH,011H,0b6H,096H,08fH,013H,07aH,0a6H,0aeH,0c5H,09dH,0d8H
	DB	01aH,09dH,0a2H,02bH,0c5H,0d1H,03eH,01fH,0b9H,055H,00dH,02dH
	DB	040H,07eH,03aH,021H,05bH,028H,0b4H,0a9H,047H,09cH,0f7H,07cH
	DB	096H,021H,096H,0a9H,07aH,0daH,05eH,0cdH,0dfH,0caH,0bdH,0ffH
	DB	00cH,094H,02aH,091H,040H,032H,038H,04eH,00bH,067H,085H,0c8H
	DB	065H,047H,04dH,05dH,0e2H,0e6H,082H,07bH,029H,06cH,0b2H,07bH
	DB	017H,04cH,0efH,001H,015H,092H,006H,094H,08aH,095H,000H,0ddH
	DB	0d9H,022H,0edH,069H,047H,0cdH,06fH,0bdH,0d0H,05eH,04dH,04dH
	DB	07bH,0deH,042H,08eH,0baH,093H,06eH,0f8H,0d6H,0e4H,068H,003H
	DB	0a9H,0c6H,017H,071H,0b5H,04bH,0baH,050H,0e0H,0b3H,040H,0c6H
	DB	068H,054H,035H,073H,071H,0dbH,05cH,0baH,095H,0e2H,018H,01aH
	DB	05eH,07aH,0d9H,048H,01aH,08cH,0adH,0e9H,02bH,04cH,055H,02fH
	DB	0fcH,0bbH,00cH,0ecH,09eH,0d9H,0efH,01aH,0e7H,070H,093H,0b3H
	DB	0bdH,0feH,0d7H,08dH,0c7H,045H,0b8H,081H,0acH,099H,02cH,065H
	DB	085H,04aH,01fH,003H,0d8H,0e8H,050H,0dcH,060H,0c5H,0ddH,0caH
	DB	081H,0ccH,09bH,0a9H,0c4H,011H,05eH,0ccH,002H,00dH,09eH,053H
	DB	064H,0d4H,08bH,036H,0f4H,091H,09fH,057H,013H,0bdH,0ccH,0bdH
	DB	085H,019H,045H,02eH,075H,077H,0d9H,0c8H,034H,03dH,0e4H,0b1H
	DB	0e4H,030H,00bH,060H,0f5H,0d9H,08fH,0e7H,077H,002H,0a3H,07fH
	DB	0bfH,0bcH,0b8H,0a9H,087H,051H,0aeH,0bbH,012H,052H,089H,011H
	DB	0d2H,065H,0bbH,0ffH,07dH,0fdH,005H,0adH,05fH,098H,065H,08bH
	DB	023H,0ebH,08dH,0b9H,058H,091H,04aH,0ffH,016H,01eH,042H,09dH
	DB	03dH,016H,043H,079H,058H,0c6H,05dH,0bdH,02bH,04fH,026H,045H
	DB	0b6H,0e9H,0daH,089H,0bcH,07bH,0bfH,09dH,093H,08eH,0b6H,0caH
	DB	070H,038H,002H,03cH,0a0H,086H,05eH,0d8H,05aH,02bH,0cbH,02cH
	DB	075H,05aH,0f7H,0eaH,06eH,021H,05fH,0c2H,09eH,031H,05bH,002H
	DB	091H,055H,084H,071H,00bH,0bfH,052H,06eH,0b5H,032H,0ffH,0d0H
	DB	086H,0bbH,0a4H,083H,01eH,0d1H,011H,0fcH,08aH,022H,0a1H,01cH
	DB	097H,038H,051H,03eH,079H,0e7H,00cH,036H,0dcH,039H,07bH,023H
	DB	009H,031H,066H,063H,087H,002H,0abH,054H,069H,0f9H,01dH,0cfH
	DB	0fbH,075H,0dcH,06aH,02eH,062H,08aH,048H,037H,001H,0dcH,08aH
	DB	019H,022H,0d6H,029H,0fbH,056H,03dH,095H,042H,03eH,011H,03cH
	DB	02bH,01fH,01cH,091H,0c3H,0eaH,00eH,054H,009H,0e8H,02dH,0e7H
	DB	012H,088H,06eH,03eH,021H,0abH,0dcH,08fH,01bH,032H,077H,04aH
	DB	021H,047H,004H,07eH,039H,085H,021H,09bH,0ceH,00eH,03dH,012H
	DB	0c6H,09eH,0cdH,04dH,0b6H,094H,037H,0bcH,0f7H,09bH,0ceH,065H
	DB	0eaH,06eH,0ecH,067H,0f0H,0a5H,008H,01cH,0d8H,02eH,041H,0d3H
	DB	0feH,09cH,04fH,0b6H,072H,08eH,07eH,0f0H,053H,032H,0beH,0c2H
	DB	085H,0c9H,095H,060H,031H,04fH,06cH,0dcH,07bH,0a8H,0cbH,0ceH
	DB	0e4H,0f0H,04eH,096H,0a8H,06eH,0baH,04fH,0b2H,00eH,0baH,0d3H
	DB	097H,0a8H,0c2H,091H,060H,087H,05bH,0fdH,08eH,049H,0d9H,0e1H
	DB	0ffH,0acH,0aeH,0aaH,0eaH,07eH,030H,03eH,0f1H,0b2H,024H,08bH
	DB	061H,09fH,0c8H,072H,0f5H,076H,0f5H,0d7H,048H,06cH,066H,02cH
	DB	041H,077H,023H,079H,021H,0b8H,07aH,0fdH,01dH,002H,056H,096H
	DB	082H,0f8H,027H,090H,031H,028H,01bH,0b4H,0c5H,0d7H,09eH,094H
	DB	02bH,064H,055H,0d3H,031H,0e4H,063H,018H,04dH,017H,034H,094H
	DB	025H,00fH,008H,02fH,0b3H,01fH,020H,0c8H,065H,043H,05bH,0a9H
	DB	0c2H,0c1H,0c2H,051H,034H,0f7H,06cH,025H,06bH,06fH,0eaH,0d7H
	DB	084H,044H,0c4H,085H,02bH,0d3H,011H,0abH,086H,0c8H,00fH,0b8H
	DB	053H,018H,0d1H,03eH,080H,06eH,0f5H,0f5H,08bH,0c8H,0a9H,087H
	DB	077H,093H,05bH,02bH,048H,083H,07aH,076H,0dbH,07dH,0b0H,082H
	DB	0f2H,09fH,01eH,024H,089H,057H,09fH,02cH,091H,050H,097H,0b0H
	DB	03fH,0cfH,07dH,03dH,05bH,067H,0d3H,0d0H,0daH,043H,0c0H,04aH
	DB	024H,01bH,06aH,017H,072H,017H,024H,0e6H,011H,0d5H,0bfH,08bH
	DB	055H,0c4H,0d2H,0eeH,02fH,02dH,00cH,096H,0edH,097H,0b8H,044H
	DB	068H,0daH,0f6H,0c4H,05aH,012H,08fH,0e3H,080H,072H,08cH,098H
	DB	01fH,03cH,0b3H,029H,027H,042H,0ffH,00dH,054H,071H,067H,0bdH
	DB	073H,08eH,060H,06bH,019H,028H,0f8H,061H,0ebH,0f7H,039H,08bH
	DB	0afH,0deH,08aH,0c7H,07dH,0a1H,0d0H,03cH,02bH,03bH,0bcH,02bH
	DB	020H,010H,0c6H,009H,0daH,004H,063H,0e4H,092H,0deH,0d6H,09bH
	DB	0caH,0c3H,05cH,07aH,0cbH,0acH,015H,078H,0fdH,09bH,0ecH,0d1H
	DB	03bH,0ddH,0bbH,0b9H,04fH,0beH,0edH,0e4H,06bH,0dcH,00cH,038H
	DB	03eH,056H,039H,066H,0dbH,0edH,0c9H,0b5H,0ecH,0bbH,0dfH,09bH
	DB	0bdH,042H,0faH,0b1H,06bH,0b5H,034H,0c1H,078H,06fH,085H,03bH
	DB	012H,08eH,02aH,012H,0c8H,067H,03dH,010H,0ccH,044H,0efH,061H
	DB	04cH,00dH,0b5H,091H,00cH,017H,012H,0dfH,05fH,02bH,069H,006H
	DB	08eH,012H,023H,073H,0beH,04bH,004H,026H,042H,0ebH,03cH,059H
	DB	025H,088H,014H,06eH,055H,02eH,007H,03fH,013H,031H,08dH,028H
	DB	027H,067H,0e1H,0f6H,0f1H,07cH,0b1H,093H,0e7H,019H,09fH,0f3H
	DB	040H,0baH,0e8H,00aH,086H,016H,003H,07dH,068H,047H,052H,05aH
	DB	0f9H,072H,06fH,002H,066H,0e8H,072H,037H,0d9H,073H,0b6H,08dH
	DB	062H,099H,080H,040H,0dbH,09aH,027H,0a8H,0ebH,06eH,048H,08cH
	DB	001H,027H,0f6H,0e9H,062H,0e1H,0dbH,092H,01cH,065H,074H,0b5H
	DB	057H,05fH,039H,0bbH,0d1H,02fH,077H,08fH,08cH,0afH,0cbH,06aH
	DB	0bbH,0a5H,0ecH,011H,03cH,025H,051H,016H,052H,02bH,051H,071H
	DB	02bH,005H,0a3H,0d3H,09eH,090H,03fH,0f2H,0d0H,036H,0bbH,059H
	DB	0a2H,06dH,094H,0bbH,09bH,0b1H,08fH,0feH,032H,065H,0ccH,0dcH
	DB	095H,06cH,0ceH,016H,0c8H,078H,014H,06cH,0bbH,02aH,0b9H,0ebH
	DB	04cH,07aH,028H,0e8H,0a4H,0abH,046H,093H,041H,022H,0b9H,036H
	DB	0bfH,0afH,001H,0f7H,0e7H,06bH,0d7H,0c9H,068H,08eH,060H,0cbH
	DB	0a5H,067H,00eH,078H,01cH,024H,0d5H,0b5H,09bH,06bH,05dH,099H
	DB	094H,04bH,0bfH,002H,0e8H,0aeH,0d1H,0baH,045H,039H,0d3H,07cH
	DB	024H,0dcH,0f0H,07cH,0cfH,0b5H,0eaH,0b9H,0c9H,0f3H,0c3H,0bdH
	DB	080H,05eH,0faH,07fH,063H,058H,022H,0c4H,067H,054H,048H,08dH
	DB	08eH,0b2H,038H,05cH,087H,0f4H,064H,02bH,0e3H,013H,040H,0a9H
	DB	08fH,01fH,0ebH,016H,029H,02aH,080H,027H,0a4H,03eH,044H,0e0H
	DB	010H,0d7H,07fH,0e7H,018H,0afH,0fdH,0f3H,03bH,0b4H,0e0H,0fcH
	DB	041H,0cfH,0fbH,040H,0e6H,0bcH,073H,04bH,023H,0e4H,0feH,0adH
	DB	04bH,0edH,09aH,02dH,030H,025H,079H,07cH,03bH,0a4H,088H,0b5H
	DB	0c8H,093H,06bH,0d5H,02eH,07aH,07cH,088H,0b0H,070H,028H,0ebH
	DB	045H,04aH,030H,00cH,01eH,032H,0adH,03aH,04fH,01aH,01bH,057H
	DB	097H,007H,026H,02dH,04aH,0e4H,00aH,0bcH,047H,0a9H,0e4H,01aH
	DB	044H,013H,008H,05bH,0e0H,03eH,010H,03fH,062H,0adH,057H,068H
	DB	002H,062H,078H,0a1H,09cH,030H,056H,0c0H,000H,03eH,028H,0b5H
	DB	020H,0afH,0baH,005H,08aH,0d7H,02fH,07cH,0f0H,06cH,009H,094H
	DB	0e7H,077H,001H,09cH,044H,0e3H,0bdH,0aaH,0f7H,07cH,0faH,083H
	DB	0c5H,0ceH,0ffH,0b5H,087H,025H,069H,0ebH,016H,01bH,02cH,008H
	DB	0c9H,0baH,03eH,07dH,0fbH,079H,0b7H,01bH,045H,0edH,081H,058H
	DB	094H,0f4H,0a8H,083H,076H,024H,01bH,095H,06aH,03fH,0f0H,075H
	DB	0e2H,059H,026H,0f4H,075H,083H,064H,0b7H,06dH,04aH,07cH,02aH
	DB	07aH,048H,0a1H,010H,0f1H,0ebH,055H,00dH,02eH,05bH,06dH,0aaH
	DB	04cH,090H,056H,0a8H,017H,056H,0fbH,0d0H,0d9H,086H,08fH,0a8H
	DB	0c2H,0d0H,0c4H,005H,08eH,06eH,094H,0f8H,0dcH,054H,063H,05fH
	DB	099H,01eH,038H,032H,033H,072H,0cbH,04fH,04fH,0e0H,053H,09dH
	DB	0acH,04eH,02fH,00bH,01aH,041H,071H,0b0H,054H,0a9H,0c5H,0e4H
	DB	0e7H,0e8H,0b7H,0e4H,0c9H,06bH,076H,0c6H,08fH,079H,07fH,038H
	DB	039H,047H,0e7H,08aH,09cH,069H,00eH,05dH,04aH,0a4H,087H,047H
	DB	021H,0f3H,0e3H,047H,0beH,08fH,0e1H,075H,060H,045H,0bbH,0d2H
	DB	0ccH,009H,044H,0feH,0b8H,020H,04aH,015H,01eH,063H,015H,0acH
	DB	039H,098H,01aH,076H,0a8H,0eaH,080H,000H,005H,062H,076H,0f1H
	DB	056H,070H,0ffH,072H,021H,0a8H,06cH,001H,0e4H,0f8H,06fH,0ecH
	DB	0ceH,034H,06aH,089H,005H,0e8H,020H,064H,0abH,01cH,03bH,0daH
	DB	080H,028H,013H,02eH,0a5H,048H,00cH,0ecH,043H,0e0H,0e5H,0dfH
	DB	059H,050H,08dH,0b3H,002H,06aH,08fH,018H,0f4H,0c3H,02eH,040H
	DB	078H,0f0H,098H,005H,028H,066H,03cH,07fH,05cH,084H,04aH,033H
	DB	037H,003H,0bbH,034H,0a6H,082H,08cH,0e7H,06cH,048H,01fH,0f9H
	DB	081H,064H,0feH,054H,0a1H,062H,053H,035H,010H,05cH,06aH,0abH
	DB	0c8H,059H,07eH,050H,0b1H,0eaH,01aH,09fH,049H,0deH,016H,05fH
	DB	04bH,029H,0bfH,045H,015H,035H,0caH,06dH,0c4H,0b6H,0ceH,0f0H
	DB	049H,05bH,077H,0c8H,0aeH,057H,0faH,0a8H,01dH,0e8H,0e2H,0dbH
	DB	03aH,0afH,008H,0a4H,082H,0ffH,0f4H,02eH,0a7H,0c1H,0b2H,0f2H
	DB	056H,01fH,012H,074H,0ccH,003H,0e3H,094H,078H,0ccH,0bdH,0faH
	DB	017H,0f0H,057H,053H,021H,08dH,031H,01aH,081H,049H,09dH,0dfH
	DB	0c6H,0dbH,0a6H,04bH,091H,055H,0e7H,078H,02cH,035H,00fH,0efH
	DB	094H,018H,03dH,02eH,0d9H,04bH,012H,0dcH,0aeH,01fH,09eH,05cH
	DB	0bcH,0ffH,004H,0f3H,073H,09bH,00eH,0a6H,07bH,093H,00dH,097H
	DB	0d1H,0feH,0c1H,026H,0d5H,02bH,0dcH,0eeH,053H,0d6H,0f8H,096H
	DB	039H,0a1H,087H,0aeH,0e8H,05dH,0b7H,00dH,075H,09dH,05fH,057H
	DB	092H,004H,0c5H,087H,09eH,05eH,0bcH,09cH,043H,0dcH,06cH,0dcH
	DB	03eH,007H,017H,040H,0e2H,05bH,059H,06fH,0bfH,01eH,0bbH,045H


SP_PRESETS:
	; Speaker specific EQ, biquad and limiter coeficients.

	; Byte1: filter options. 	Bit0: Low array correction enable
	;				Bit1: High freq correction enable
	;				Bit2: Part of active speaker
	;				Bift7-4: Array correction type
	; Byte2: Complementary model of active speaker

	; Bytes3-29: Speaker specific eq settings:
	; Indexes are in order freq, Q, gain
	; Sections 1..4 are user eq, not defined here!
	; Sections 5..11 filters for system eq. Do not use section 6 when Low array correction enabled!!! Do not use section 10 when High array correction enabled!!!
	; Sections 12 & 13 for excursion limiter:
	; Section 12 in signal path with negative gain (corrected in DSP software)
	; Section 13 Excursion simulation filter for detector

	; Bytes30-50: Excursion simulation biquad
	; gain, a2/2 (LW,HW)
	; a1/2 (LW,HW), b1/2 (SP), b2/2 (SP)

	; Bytes51-197: Crossover biquad filters:
	; n biquads
	; gain(incl rshifts), a2/2 (LW,HW), 
	; a1/2 (LW,HW), b1/2 (SP), b2/2 (SP), lshifts (rshifts-5) (6x)

	; Bytes198-215: Power limiter low detector filter:
	; biqgain, shifts, a2/2, a1/2, b1/2, b2/2

	; Bytes216-233: Power limiter high detector filter:
	; biqgain, shifts, a2/2, a1/2, b1/2, b2/2

	; Bytes234-257: Power/excursion limiter settings
	; Low time constant, high time constant, low release, high release, excursion release
	; Excursion threshold, Low threshold, High threshold. 
	
	;                        1
	;                      -----
	;                     -RC*fs
	; time constant=(1 - e       )*2^23
	; P Threshold levels are 33188/V
	; Ex Threshold levels are (10^(32dB - 20*log10(V/4.49) - (mathcad offset in dB))/20) * 0x7FFFFF

	; Bytes 258-263:
	; System delay in samples. Max $1000 samples = 42.67ms, safety clip level 1171592/V
	
	; Linear: model 0
	DB	000H,000H
	DB	68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	68,7,41,68,7,41

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,001H
	DB	004H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	07FH,0FFH,0FFH,07FH,0FFH,0FFH,000H,000H,000H
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BF151 100Hz: model 1
	DB	000H,000H
	DB	12,15,47,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,26,21

	DB	000H,000H,011H,090H,08AH,04EH,03FH,059H,027H
	DB	0A8H,0FCH,025H,080H,0A6H,0FAH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,003H
	DB	000H,000H,02DH,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP x=-3dB G=+9dB (+19x rshift)
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H	;
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02EH,062H,000H,048H,0A0H,000H,000H,000H ; Exc. 1.58V @64Hz ok, Power 0.56V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BF151 80Hz: model 2
	DB	000H,000H
	DB	12,15,47,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,26,21

	DB	000H,000H,011H,090H,08AH,04EH,03FH,059H,027H
	DB	0A8H,0FCH,025H,080H,0A6H,0FAH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,025H,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP x=-3dB G=+7.4dB (+19x rshift)
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH					; LR-6 80Hz LP x=-6dB G=0dB
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0A2H,04EH,059H,03FH,055H,05DH 					;
	DB	0B1H,09CH,061H,080H,0ABH,014H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02EH,062H,000H,048H,0A0H,000H,000H,000H ; Exc. 1.58V @64Hz ok, Power 0.56V
	DB	000H,000H,000H,07FH,0FFH,0FFH


	; BF181 100Hz: model 3
	DB	061H,000H
	DB	68,7,41,6,16,67,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,19

	DB	000H,000H,009H,01FH,0E6H,024H,03FH,09BH,0E8H
	DB	0B7H,0A3H,000H,080H,064H,029H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,003H
	DB	000H,000H,025H,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+7.6dB (+19x rshift
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,088H,000H,048H,0A0H,000H,000H,000H ; Exc. 1.42V @ 50Hz ok, Power 0.56V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BF181 80Hz: model 4
	DB	061H,000H
	DB	68,7,41,6,16,67,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,19

	DB	000H,000H,009H,01FH,0E6H,024H,03FH,09BH,0E8H
	DB	0B7H,0A3H,000H,080H,064H,029H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,036H,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+11dB (+19x rshift)
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH					; LR-6 80Hz LP x=-6dB G=0dB
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0A2H,04EH,059H,03FH,055H,05DH 					;
	DB	0B1H,09CH,061H,080H,0ABH,014H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,088H,000H,048H,0A0H,000H,000H,000H ; Exc. 1.42V @ 50Hz ok, Power 0.56V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BF181 100Hz cardioid: model 5
	DB	061H,000H
	DB	68,7,41,6,16,67,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,19

	DB	000H,000H,009H,01FH,0E6H,024H,03FH,09BH,0E8H
	DB	0B7H,0A3H,000H,080H,064H,029H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,005H
	DB	000H,000H,025H,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+7.6dB (+19x rshift
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	; 
	DB	07EH,086H,0ECH,000H,000H,000H,000H,000H,000H 					; Allpass delay RC=0.9E-3
	DB	0DEH,06AH,0A4H,0C0H,0BCH,089H,0BFH,041H,044H,000H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,06CH,017H,061H,07FH,03FH,059H,0C7H 					; Butt-2 110Hz LP 
	DB	0A9H,055H,0A8H,080H,0A7H,011H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,088H,000H,048H,0A0H,000H,000H,000H ; Exc. 1.42V @ 50Hz ok, Power 0.56V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BF181 80Hz: cardioid: model 6
	DB	061H,000H
	DB	68,7,41,6,16,67,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,19

	DB	000H,000H,009H,01FH,0E6H,024H,03FH,09BH,0E8H
	DB	0B7H,0A3H,000H,080H,064H,029H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,006H
	DB	000H,000H,036H,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+11dB (+19x rshift)
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	; 
	DB	07EH,086H,0ECH,000H,000H,000H,000H,000H,000H 					; Allpass delay RC=0.9E-3
	DB	0DEH,06AH,0A4H,0C0H,0BCH,089H,0BFH,041H,044H,000H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH					; LR-6 80Hz LP x=-6dB G=0dB
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0A2H,04EH,059H,03FH,055H,05DH 					;
	DB	0B1H,09CH,061H,080H,0ABH,014H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,06CH,017H,061H,07FH,03FH,059H,0C7H 					; Butt-2 110Hz LP 
	DB	0A9H,055H,0A8H,080H,0A7H,011H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,088H,000H,048H,0A0H,000H,000H,000H ; Exc. 1.42V @ 50Hz ok, Power 0.56V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BF302 100Hz: model 7
	DB	000H,000H
	DB	12,15,47,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,12,24,21

	DB	000H,000H,011H,090H,08AH,04EH,03FH,059H,027H
	DB	0A8H,0FCH,025H,080H,0A6H,0FAH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,003H
	DB	000H,000H,020H,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP x=-3dB G=+6dB (+19x rshift)
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,040H,0DDH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.10V @ 55Hz ok, Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BF302 80Hz: model 8
	DB	000H,000H
	DB	12,15,47,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,12,24,21

	DB	000H,000H,011H,090H,08AH,04EH,03FH,059H,027H
	DB	0A8H,0FCH,025H,080H,0A6H,0FAH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,024H,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP x=-3dB G=+7dB (+19x rshift)
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH					; LR-6 80Hz LP x=-6dB G=0dB
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0A2H,04EH,059H,03FH,055H,05DH 					;
	DB	0B1H,09CH,061H,080H,0ABH,014H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,040H,0DDH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.10V @ 55Hz ok, Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BF362 100Hz: model 9
	DB	061H,000H
	DB	68,7,41,6,16,67,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,15

	DB	000H,000H,009H,015H,0DDH,093H,03FH,0BBH,0E0H
	DB	014H,0C7H,042H,080H,044H,032H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,003H
	DB	000H,000H,01AH,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+4.6dB (+19x rshift
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04EH,03DH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BF362 80Hz: model 10
	DB	061H,000H
	DB	68,7,41,6,16,67,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,15

	DB	000H,000H,009H,015H,0DDH,093H,03FH,0BBH,0E0H
	DB	014H,0C7H,042H,080H,044H,032H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,01DH,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+5.6dB (+19x rshift)
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH					; LR-6 80Hz LP x=-6dB G=0dB
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0A2H,04EH,059H,03FH,055H,05DH 					;
	DB	0B1H,09CH,061H,080H,0ABH,014H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04EH,03DH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH
	
	; BF362 100Hz B: model 13
	DB	061H,000H
	DB	68,7,41,6,16,67,68,7,41,0,39,45,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,15

	DB	000H,000H,009H,015H,0DDH,093H,03FH,0BBH,0E0H
	DB	014H,0C7H,042H,080H,044H,032H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,01AH,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+4.6dB (+19x rshift
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	0A5H,062H,008H,000H,000H,000H,000H,000H,000H					;Invert polarity and pad -3dB
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04EH,03DH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,001H,06AH,07FH,0FFH,0FFH

; ;	BF362 80Hz B: model 14
	DB	061H,000H
	DB	68,7,41,6,16,67,68,7,41,0,39,45,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,15

	DB	000H,000H,009H,015H,0DDH,093H,03FH,0BBH,0E0H
	DB	014H,0C7H,042H,080H,044H,032H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,005H
	DB	000H,000H,01DH,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+5.6dB (+19x rshift)
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH					; LR-6 80Hz LP x=-6dB G=0dB
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0A2H,04EH,059H,03FH,055H,05DH 					;
	DB	0B1H,09CH,061H,080H,0ABH,014H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	0A5H,062H,008H,000H,000H,000H,000H,000H,000H					;Invert polarity and pad -3dB
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04EH,03DH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,001H,06AH,07FH,0FFH,0FFH

	; ;	BC543 100Hz: model 11
	DB	065H,063
	DB	68,7,41,6,16,67,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,15

	DB	000H,000H,009H,015H,0DDH,093H,03FH,0BBH,0E0H
	DB	014H,0C7H,042H,080H,044H,032H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,003H
	DB	000H,000H,01AH,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+4.6dB (+19x rshift
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04EH,03DH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH

; ;	BC543 80Hz: model 12
	DB	065H,064
	DB	68,7,41,6,16,67,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,15

	DB	000H,000H,009H,015H,0DDH,093H,03FH,0BBH,0E0H
	DB	014H,0C7H,042H,080H,044H,032H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,01DH,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+5.6dB (+19x rshift)
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH					; LR-6 80Hz LP x=-6dB G=0dB
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0A2H,04EH,059H,03FH,055H,05DH 					;
	DB	0B1H,09CH,061H,080H,0ABH,014H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04EH,03DH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	

	; BQ211 100Hz: model 15
	DB	061H,000H
	DB	23,14,30,6,16,67,68,7,41,44,22,17,68,7,41,68,7,41,68,7,41
	DB	0,0,255,9,26,21

	DB	000H,000H,01FH,0A8H,0CBH,028H,03FH,004H,0B7H ;74Hz, q5, -5.5dB
	DB	07AH,05DH,01DH,080H,0FBH,086H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,01DH,02DH,0DDH,054H,03FH,0CFH,08BH 					; Butt-2 32Hz HP x=-3dB G=+5.6dB (+19x rshift)
	DB	031H,020H,097H,080H,030H,087H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,053H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,064H,0CBH,000H,06AH,04DH,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; BQ211 80Hz: model 16
	DB	061H,000H
	DB	23,14,30,6,16,67,68,7,41,44,22,17,68,7,41,68,7,41,68,7,41
	DB	0,0,255,9,26,21

	DB	000H,000H,01FH,0A8H,0CBH,028H,03FH,004H,0B7H
	DB	07AH,05DH,01DH,080H,0FBH,086H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,003H
	DB	000H,000H,01DH,02DH,0DDH,054H,03FH,0CFH,08BH 					; Butt-2 32Hz HP x=-3dB G=+5.6dB (+19x rshift)
	DB	031H,020H,097H,080H,030H,087H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,037H,0B3H,0BBH,096H,03FH,087H,020H 					;
	DB	0DCH,0DBH,0A3H,080H,079H,051H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,064H,0CBH,000H,06AH,04DH,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH
	
	; BQ211 100Hz B: model 17
	DB	061H,000H
	DB	23,14,30,6,16,67,68,7,41,0,39,45,44,22,17,68,7,41,68,7,41
	DB	0,0,255,9,26,21

	DB	000H,000H,01FH,0A8H,0CBH,028H,03FH,004H,0B7H ;74Hz, q5, -5.5d
	DB	07AH,05DH,01DH,080H,0FBH,086H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,003H
	DB	000H,000H,01DH,02DH,0DDH,054H,03FH,0CFH,08BH 					; Butt-2 32Hz HP x=-3dB G=+5.6dB (+19x rshift)
	DB	031H,020H,097H,080H,030H,087H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,053H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	0A5H,062H,008H,000H,000H,000H,000H,000H,000H					;Invert polarity and pad -3dB
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,064H,0CBH,000H,06AH,04DH,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,001H,06AH,07FH,0FFH,0FFH ;362 samples, 1.31m
	
	; BQ211 80Hz B: model 18
	DB	061H,000H
	;
	DB	23,14,30,6,16,67,68,7,41,44,22,17,68,7,41,68,7,41,68,7,41
	DB	0,0,255,9,26,21

	DB	000H,000H,01FH,0A8H,0CBH,028H,03FH,004H,0B7H
	DB	07AH,05DH,01DH,080H,0FBH,086H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,01DH,02DH,0DDH,054H,03FH,0CFH,08BH 					; Butt-2 32Hz HP x=-3dB G=+5.6dB (+19x rshift)
	DB	031H,020H,097H,080H,030H,087H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,037H,0B3H,0BBH,096H,03FH,087H,020H 					;
	DB	0DCH,0DBH,0A3H,080H,079H,051H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	0A5H,062H,008H,000H,000H,000H,000H,000H,000H	;Invert polarity and pad -3dB
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,064H,0CBH,000H,06AH,04DH,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,001H,06AH,07FH,0FFH,0FFH ;362 samples, 1.31m
	
	;  LR7-120 Fullrange: model 19
	DB	073H,000H
	DB	56,14,47,23,38,47,45,16,38,84,12,31,98,16,31,68,7,41,117,15,64	; kopieer naar andere LR7 versies
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,010H,0A4H,04BH,0E8H,03FH,0DCH,01BH 					; G=0dB (+19x rshift)
	DB	0BCH,029H,078H,080H,024H,03CH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 75Hz +6.6dB
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	047H,0E6H,084H,0A4H,04BH,0E8H,03FH,0DCH,01BH 					; G=0dB
	DB	0BCH,029H,078H,080H,024H,03CH,080H,000H,000H,040H,000H,000H,000H,000H,00EH	; Bassboost 75Hz +6.6dB  +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,000H,011H,07FH,0FFH,0FFH	; Delay 0.18ms

;  LR7-120 80Hz: model 20
	DB	073H,000H
	DB	56,14,47,23,38,47,45,16,38,84,12,31,98,16,31,68,7,41,117,15,64	;
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,00FH,04CH,066H,0E3H,03FH,0C7H,032H; 					; Bassboost/Highpass 80Hz +2.5dB
	DB	01FH,0BDH,013H,080H,039H,01EH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H; 					; Allpass delay -180Deg @1.9kHz RC=94e-6H	;
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H; 					; Allpass delay -180Deg @1.9kHz RC=94e-6H	;
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H;
	DB	04AH,063H,016H,04CH,066H,0E3H,03FH,0C7H,032H; 					; Bassboost/Highpass 80Hz +2.5dB  +14x lshift
	DB	01FH,0BDH,013H,080H,039H,01EH,080H,000H,000H,040H,000H,000H,000H,000H,00EH;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,001H,028H,07FH,0FFH,0FFH	; Delay 3.08ms

	; LR7-120 160Hz: model 21
	DB	073H,000H
	DB	56,14,47,23,38,47,45,16,38,84,12,31,98,16,31,68,7,41,117,15,64	; 
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,010H,0C9H,00CH,090H,03FH,02DH,051H					; G=0dB (+19x rshift)
	DB	049H,097H,0A7H,080H,0D4H,0AFH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 300Hz +0.5dB
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	045H,0E3H,006H,0C9H,00CH,090H,03FH,02DH,051H					; G=-5.2dB
	DB	049H,097H,0A7H,080H,0D4H,0AFH,080H,000H,000H,040H,000H,000H,000H,000H,00EH	; Bassboost 300Hz +0.5dB +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,000H,0EEH,07FH,0FFH,0FFH	;Delay 2.48ms
	
	; LR7-90 Fullrange: model 22
	DB	073H,000H
	DB	56,14,45,23,38,47,45,16,38,84,9,35,94,7,27,68,7,41,117,18,63	;
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,010H,0A4H,04BH,0E8H,03FH,0DCH,01BH 					; G=0dB (+19x rshift)
	DB	0BCH,029H,078H,080H,024H,03CH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 75Hz +6.6dB
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	047H,0E6H,084H,0A4H,04BH,0E8H,03FH,0DCH,01BH 					; G=0dB
	DB	0BCH,029H,078H,080H,024H,03CH,080H,000H,000H,040H,000H,000H,000H,000H,00EH	; Bassboost 75Hz +6.6dB  +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,000H,011H,07FH,0FFH,0FFH	; Delay 0.18ms


; LR7-90 80Hz: model 23
	DB	073H,000H
	DB	56,14,45,23,38,47,45,16,38,84,9,35,94,7,27,68,7,41,117,18,63	; kopieer naar andere LR7 versies
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,00FH,04CH,066H,0E3H,03FH,0C7H,032H; 					; Bassboost/Highpass 80Hz +2.5dB
	DB	01FH,0BDH,013H,080H,039H,01EH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H; 					; Allpass delay -180Deg @1.9kHz RC=94e-6H	;
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H; 					; Allpass delay -180Deg @1.9kHz RC=94e-6H	;
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H;
	DB	04AH,063H,016H,04CH,066H,0E3H,03FH,0C7H,032H; 					; Bassboost/Highpass 80Hz +2.5dB  +14x lshift
	DB	01FH,0BDH,013H,080H,039H,01EH,080H,000H,000H,040H,000H,000H,000H,000H,00EH;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,001H,028H,07FH,0FFH,0FFH	; Delay 3.08ms

	; LR7-90 160Hz: model 24
	DB	073H,000H
	DB	56,14,45,23,38,47,45,16,38,84,9,35,94,7,27,68,7,41,117,18,63	; 
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,010H,0C9H,00CH,090H,03FH,02DH,051H					; G=0dB (+19x rshift)
	DB	049H,097H,0A7H,080H,0D4H,0AFH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 300Hz +0.5dB
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	045H,0E3H,006H,0C9H,00CH,090H,03FH,02DH,051H					; G=-5.2dB
	DB	049H,097H,0A7H,080H,0D4H,0AFH,080H,000H,000H,040H,000H,000H,000H,000H,00EH	; Bassboost 300Hz +0.5dB +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,000H,0EEH,07FH,0FFH,0FFH	;Delay 2.48ms

	; LR7B 160Hz: model 25
	DB	000H,000H
	DB	68,7,41,30,15,34,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,22,19

	DB	000H,000H,01AH,0BAH,079H,02DH,03FH,065H,0EDH
	DB	0A0H,0F3H,054H,080H,09AH,045H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,022H,0C2H,001H,0BDH,03FH,0E8H,0A3H 					; B=1 C=3.74 f0=119Hz G=+6.6dB (+19x rshift)
	DB	017H,004H,013H,080H,017H,07CH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 45Hz +6dB
	DB	07FH,0BEH,0DAH,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
    	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,03DH,0C8H,000H,067H,0B6H,000H,000H,000H ; Exc. 1.56V @63Hz ok, Power 0.80V
	DB	000H,000H,011H,07FH,0FFH,0FFH	; Delay 0.18ms

; LR7B 80Hz: model 26
	DB	000H,000H
	DB	68,7,41,30,15,34,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,22,19

	DB	000H,000H,01AH,0BAH,079H,02DH,03FH,065H,0EDH
	DB	0A0H,0F3H,054H,080H,09AH,045H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,005H
	DB	000H,000H,036H,0C2H,001H,0BDH,03FH,0E8H,0A3H;  					; B=1 C=3.74 f0=119Hz G=+10.6dB (+19x rshift)H	; Bassboost 45Hz +6dB
	DB	017H,004H,013H,080H,017H,07CH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	07FH,0BEH,0DAH,080H,025H,072H,03FH,0BEH,0EBH;  					; Butt-2 43Hz HPH 	; +14x lshift
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH;
	DB	000H,000H,039H,05BH,0D3H,0E3H,03FH,054H,093H;  					; LR-6 80Hz LP x=-6dB G=0dBH 	;
	DB	009H,03CH,081H,080H,0ABH,0E0H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,039H,022H,038H,07FH,03FH,0AAH,010H;  					;
	DB	090H,051H,042H,080H,056H,063H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,030H,022H,038H,07FH,03FH,0AAH,010H;  					;
	DB	090H,051H,042H,080H,056H,063H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,03DH,0C8H,000H,067H,0B6H,000H,000H,000H ; Exc. 1.56V @63Hz ok, Power 0.80V
	DB	000H,000H,0A1H,07FH,0FFH,0FFH	; Delay 1.68ms


	; LR7B 80-160Hz: model 27
	DB	000H,000H
	DB	31,15,46,30,15,34,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,22,19

	DB	000H,000H,01AH,0BAH,079H,02DH,03FH,065H,0EDH
	DB	0A0H,0F3H,054H,080H,09AH,045H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,005H
	DB	000H,000H,022H,05AH,020H,042H,03FH,0AAH,076H 					; LR-6 80Hz HP x=-6dB G=+6.6dB (+19x rshift)
	DB	0B2H,0BCH,0E8H,080H,055H,0FBH,080H,000H,000H,040H,000H,000H,000H,000H,000H  	;
	DB	07FH,0AAH,03DH,05AH,020H,042H,03FH,0AAH,076H 					;
	DB	0B2H,0BCH,0E8H,080H,055H,0FBH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,055H,024H,0A2H,04EH,059H,03FH,055H,05DH 					; 
	DB	0B1H,09CH,061H,080H,0ABH,014H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
    	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,03DH,0C8H,000H,067H,0B6H,000H,000H,000H ; Exc. 1.56V @63Hz ok, Power 0.80V
	DB	000H,000H,0A1H,07FH,0FFH,0FFH	; delay 1.68ms


	; 3x LR14-120 Fullrange: model 28
	DB	003H,000H
	DB	56,15,45,23,38,47,75,18,46,84,20,31,98,21,37,68,7,41,117,15,70
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,010H,0A4H,04BH,0E8H,03FH,0DCH,01BH 					; G=0dB (+19x rshift)
	DB	0BCH,029H,078H,080H,024H,03CH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 75Hz +6.6dB
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	047H,0E6H,084H,0A4H,04BH,0E8H,03FH,0DCH,01BH 					; G=0dB
	DB	0BCH,029H,078H,080H,024H,03CH,080H,000H,000H,040H,000H,000H,000H,000H,00EH	; Bassboost 75Hz +6.6dB  +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,000H,011H,07FH,0FFH,0FFH	; Delay 0.18ms

	; 3x LR14-120 80Hz: model 29
	DB	003H,000H
	DB	56,15,45,23,38,47,75,18,46,84,20,31,98,21,37,68,7,41,117,15,70
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,00FH,04CH,066H,0E3H,03FH,0C7H,032H; 					; Bassboost/Highpass 80Hz +2.5dB
	DB	01FH,0BDH,013H,080H,039H,01EH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H; 					; Allpass delay -180Deg @1.9kHz RC=94e-6H	;
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H; 					; Allpass delay -180Deg @1.9kHz RC=94e-6H	;
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H;
	DB	04AH,063H,016H,04CH,066H,0E3H,03FH,0C7H,032H; 					; Bassboost/Highpass 80Hz +2.5dB  +14x lshift
	DB	01FH,0BDH,013H,080H,039H,01EH,080H,000H,000H,040H,000H,000H,000H,000H,00EH;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,001H,028H,07FH,0FFH,0FFH	; Delay 3.08ms

	; 3x LR14-120 160Hz: model 30
	DB	003H,000H
	DB	56,15,45,23,38,47,75,18,46,84,20,31,98,21,37,68,7,41,117,15,70
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,010H,0C9H,00CH,090H,03FH,02DH,051H					; G=0dB (+19x rshift)
	DB	049H,097H,0A7H,080H,0D4H,0AFH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 300Hz +0.5dB
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	045H,0E3H,006H,0C9H,00CH,090H,03FH,02DH,051H					; G=-5.2dB
	DB	049H,097H,0A7H,080H,0D4H,0AFH,080H,000H,000H,040H,000H,000H,000H,000H,00EH	; Bassboost 300Hz +0.5dB +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,000H,0EEH,07FH,0FFH,0FFH	;Delay 2.48ms

	; 3x LR14-90 Fullrange: model 31
	DB	003H,000H
	DB	56,15,45,23,38,47,62,18,43,84,18,35,91,19,34,68,7,41,117,18,69
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,010H,0A4H,04BH,0E8H,03FH,0DCH,01BH 					; G=0dB (+19x rshift)
	DB	0BCH,029H,078H,080H,024H,03CH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 75Hz +6.6dB
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	047H,0E6H,084H,0A4H,04BH,0E8H,03FH,0DCH,01BH 					; G=0dB
	DB	0BCH,029H,078H,080H,024H,03CH,080H,000H,000H,040H,000H,000H,000H,000H,00EH	; Bassboost 75Hz +6.6dB  +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,000H,011H,07FH,0FFH,0FFH	; Delay 0.18ms

	; 3x LR14-90 80Hz: model 32
	DB	003H,000H
	DB	56,15,45,23,38,47,62,18,43,84,18,35,91,19,34,68,7,41,117,18,69
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,00FH,04CH,066H,0E3H,03FH,0C7H,032H; 					; Bassboost/Highpass 80Hz +2.5dB
	DB	01FH,0BDH,013H,080H,039H,01EH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H; 					; Allpass delay -180Deg @1.9kHz RC=94e-6H	;
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H; 					; Allpass delay -180Deg @1.9kHz RC=94e-6H	;
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H;
	DB	04AH,063H,016H,04CH,066H,0E3H,03FH,0C7H,032H; 					; Bassboost/Highpass 80Hz +2.5dB  +14x lshift
	DB	01FH,0BDH,013H,080H,039H,01EH,080H,000H,000H,040H,000H,000H,000H,000H,00EH;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,001H,028H,07FH,0FFH,0FFH	; Delay 3.08ms

	; 3x LR14-90 160Hz: model 33
	DB	003H,000H
	DB	56,15,45,23,38,47,62,18,43,84,18,35,91,19,34,68,7,41,117,18,69
	DB	16,5,82,22,24,17

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,010H,0C9H,00CH,090H,03FH,02DH,051H					; G=0dB (+19x rshift)
	DB	049H,097H,0A7H,080H,0D4H,0AFH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 300Hz +0.5dB
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	072H,08FH,06DH,000H,000H,000H,000H,000H,000H					; Allpass delay -180Deg @1.9kHz RC=94e-6
	DB	01CH,0B5H,00FH,0C6H,0B8H,049H,0B8H,07DH,0E5H,000H,000H,000H,000H,000H,000H	;
	DB	045H,0E3H,006H,0C9H,00CH,090H,03FH,02DH,051H					; G=-5.2dB
	DB	049H,097H,0A7H,080H,0D4H,0AFH,080H,000H,000H,040H,000H,000H,000H,000H,00EH	; Bassboost 300Hz +0.5dB +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,010H,02AH,000H,000H,004H,03EH,0B0H,080H,081H,06FH,0D3H,07FH,0FFH,0FFH,040H,000H,000H
	DB	07AH,01DH,03AH,000H,000H,00EH,03AH,03EH,07DH,086H,004H,007H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,005H,000H,062H,086H,000H,04CH,0EFH ; Exc. 0.95V @104Hz ok, Low 0.76V high 0.61V
	DB	000H,000H,0EEH,07FH,0FFH,0FFH	;Delay 2.48ms


	; LR14B 160Hz: model 34
	DB	000H,000H
	DB	68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,22,19

	DB	000H,000H,01AH,0BAH,079H,02DH,03FH,065H,0EDH
	DB	0A0H,0F3H,054H,080H,09AH,045H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,022H,0C2H,001H,0BDH,03FH,0E8H,0A3H 					; B=1 C=3.74 f0=119Hz G=+6.6dB (+19x rshift)
	DB	017H,004H,013H,080H,017H,07CH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 45Hz +6dB
	DB	07FH,0BEH,0DAH,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
    	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,03DH,0C8H,000H,067H,0B6H,000H,000H,000H ; Exc. 1.56V @63Hz ok, Power 0.80V
	DB	000H,000H,011H,07FH,0FFH,0FFH	; Delay 0.18ms

	; LR14B 80Hz: model 35
	DB	000H,000H
	DB	68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,22,19

	DB	000H,000H,01AH,0BAH,079H,02DH,03FH,065H,0EDH
	DB	0A0H,0F3H,054H,080H,09AH,045H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,005H
		DB	000H,000H,036H,0C2H,001H,0BDH,03FH,0E8H,0A3H;  					; B=1 C=3.74 f0=119Hz G=+10.6dB (+19x rshift)H	; Bassboost 45Hz +6dB
	DB	017H,004H,013H,080H,017H,07CH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	07FH,0BEH,0DAH,080H,025H,072H,03FH,0BEH,0EBH;  					; Butt-2 43Hz HPH 	; +14x lshift
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH;
	DB	000H,000H,039H,05BH,0D3H,0E3H,03FH,054H,093H;  					; LR-6 80Hz LP x=-6dB G=0dBH 	;
	DB	009H,03CH,081H,080H,0ABH,0E0H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,039H,022H,038H,07FH,03FH,0AAH,010H;  					;
	DB	090H,051H,042H,080H,056H,063H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,030H,022H,038H,07FH,03FH,0AAH,010H;  					;
	DB	090H,051H,042H,080H,056H,063H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,03DH,0C8H,000H,067H,0B6H,000H,000H,000H ; Exc. 1.56V @63Hz ok, Power 0.80V
	DB	000H,000H,0A1H,07FH,0FFH,0FFH	; Delay 1.68ms

	; LR14B 80-160Hz: model 36
	DB	000H,000H
	DB	31,15,46,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,22,19

	DB	000H,000H,01AH,0BAH,079H,02DH,03FH,065H,0EDH
	DB	0A0H,0F3H,054H,080H,09AH,045H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,005H
	DB	000H,000H,022H,05AH,020H,042H,03FH,0AAH,076H 					; LR-6 80Hz HP x=-6dB G=+6.6dB (+19x rshift)
	DB	0B2H,0BCH,0E8H,080H,055H,0FBH,080H,000H,000H,040H,000H,000H,000H,000H,000H  	;
	DB	07FH,0AAH,03DH,05AH,020H,042H,03FH,0AAH,076H 					;
	DB	0B2H,0BCH,0E8H,080H,055H,0FBH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,055H,024H,0A2H,04EH,059H,03FH,055H,05DH 					; 
	DB	0B1H,09CH,061H,080H,0ABH,014H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
   	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,03DH,0C8H,000H,067H,0B6H,000H,000H,000H ; Exc. 1.56V @63Hz ok, Power 0.80V
	DB	000H,000H,0A1H,07FH,0FFH,0FFH	; delay 1.68ms


	; 3x LR16LF Fullrange: model 37
	DB	017H,60
	DB	57,7,35,23,38,47,69,16,37,68,7,41,68,7,41,68,7,41,68,7,41
	DB	16,5,82,68,7,41

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,006H
	DB	000H,000H,010H,0F8H,0BBH,043H,03FH,0CCH,08CH 					; G=0dB  (+19x rshift)
	DB	097H,0B7H,027H,080H,033H,0BDH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	; Bassboost 75Hz +3.2dB
	DB	07FH,0CCH,068H,0F8H,0BBH,043H,03FH,0CCH,08CH 					; G=0dB
	DB	097H,0B7H,027H,080H,033H,0BDH,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; Bassboost 75Hz +3.2dB +14x lshift
	DB	000H,032H,086H,05CH,078H,00DH,03CH,041H,004H 					; LR-8 1230Hz LP x=-6dB G=0dB
	DB	006H,0FDH,042H,084H,024H,00AH,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,032H,087H,05CH,078H,00DH,03CH,041H,004H 					;
	DB	006H,0FDH,042H,084H,024H,00AH,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,02FH,094H,084H,09BH,028H,037H,067H,045H 					;
	DB	0AAH,075H,01FH,088H,0F7H,0E3H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,02FH,094H,084H,09BH,028H,037H,067H,045H 					;
	DB	0AAH,075H,01FH,088H,0F7H,0E3H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;


	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,034H,02AH,000H,033H,0DBH,000H,000H,000H ; Exc. 1.34V @96Hz ok, Power 0.40V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; 3x LR16LF 80Hz: model 38
	DB	017H,61
	DB	57,7,35,23,38,47,69,16,37,68,7,41,68,7,41,68,7,41,68,7,41
	DB	16,5,82,68,7,41

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,006H
	DB	000H,000H,00FH,089H,0CAH,0A5H,03FH,0ACH,0E4H; 					; G=0dB (+19x rshift)H	; Bassboost 105Hz +1.0dB
	DB	0A2H,0A8H,049H,080H,053H,080H,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	07FH,0AFH,0CBH,089H,0CAH,0A5H,03FH,0ACH,0E4H; 					; G=0dBH	; Bassboost 105Hz +1.0dB +14x lshift
	DB	0A2H,0A8H,049H,080H,053H,080H,080H,000H,000H,040H,000H,000H,000H,000H,00EH;
	DB	000H,032H,086H,05CH,078H,00DH,03CH,041H,004H;  					; LR-8 1230Hz LP x=-6dB G=0dBH 	;
	DB	006H,0FDH,042H,084H,024H,00AH,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,032H,087H,05CH,078H,00DH,03CH,041H,004H;  					;H 	;
	DB	006H,0FDH,042H,084H,024H,00AH,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,02FH,093H,084H,09BH,028H,037H,067H,045H;  					;H 	;
	DB	0AAH,075H,01FH,088H,0F7H,0E3H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,032H,065H,084H,09BH,028H,037H,067H,045H;  					;H 	;
	DB	0AAH,075H,01FH,088H,0F7H,0E3H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;


	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,034H,02AH,000H,033H,0DBH,000H,000H,000H ; Exc. 1.34V @96Hz ok, Power 0.40V
	DB	000H,001H,016H,07FH,0FFH,0FFH	; delay 2.9ms

	; 3x LR16LF 160Hz: model 39
	DB	017H,62
	DB	57,7,35,23,38,47,69,16,37,68,7,41,68,7,41,68,7,41,68,7,41
	DB	16,5,82,68,7,41

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,006H
	DB	000H,000H,010H,08FH,097H,0E4H,03FH,02DH,09CH					; G=0dB (+19x rshift)
	DB	0E3H,028H,04BH,080H,0D4H,027H,080H,000H,000H,040H,000H,000H,000H,000H,000 	; Bassboost 325Hz +0.2dB
	DB	07FH,02CH,0BAH,08FH,097H,0E4H,03FH,02DH,09CH					; G=0dB
	DB	0E3H,028H,04BH,080H,0D4H,027H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; Bassboost 325Hz +0.2dB +14x lshift
	DB	000H,032H,086H,05CH,078H,00DH,03CH,041H,004H 					; LR-8 1230Hz LP x=-6dB G=0dB
	DB	006H,0FDH,042H,084H,024H,00AH,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,032H,087H,05CH,078H,00DH,03CH,041H,004H 					;
	DB	006H,0FDH,042H,084H,024H,00AH,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,02FH,094H,084H,09BH,028H,037H,067H,045H 					;
	DB	0AAH,075H,01FH,088H,0F7H,0E3H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,02FH,094H,084H,09BH,028H,037H,067H,045H 					;
	DB	0AAH,075H,01FH,088H,0F7H,0E3H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;


	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,034H,02AH,000H,033H,0DBH,000H,000H,000H ; Exc. 1.34V @96Hz ok, Power 0.40V
	DB	000H,000H,0DDH,07FH,0FFH,0FFH	; Delay 2.3ms

	; LR16B 160Hz: model 40
	DB	000H,000H
	DB	26,16,43,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,24,13

	DB	000H,000H,00CH,072H,0A0H,0F8H,03FH,09AH,02DH
	DB	03CH,089H,00FH,080H,065H,0EBH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,01BH,0C2H,001H,0BDH,03FH,0E8H,0A3H 					; B=1 C=3.74 f0=119Hz G=+4.6dB (+19x rshift)
	DB	017H,004H,013H,080H,017H,07CH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 45Hz +6dB
	DB	07FH,0BEH,0DAH,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
    	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,001H,034H,0F8H,05AH,037H,03EH,07CH,0B5H 					;
	DB	058H,0C4H,0FFH,081H,085H,0B3H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,032H,0A6H,000H,067H,0B6H,000H,000H,000H ;  Exc. 2.14V @59Hz, Power 0.80V
	DB	000H,000H,01DH,07FH,0FFH,0FFH	; Delay 0.3ms

		; LR16B 80Hz: model 41
	DB	000H,000H
	DB	68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,24,13

	DB	000H,000H,00CH,072H,0A0H,0F8H,03FH,09AH,02DH
	DB	03CH,089H,00FH,080H,065H,0EBH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,005H
	DB	000H,000H,01FH,0C2H,001H,0BDH,03FH,0E8H,0A3H;  					; B=1 C=3.74 f0=119Hz G=+6dB (+19x rshift)H	; Bassboost 45Hz +6dB
	DB	017H,004H,013H,080H,017H,07CH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	07FH,0C6H,06CH,05CH,0DBH,073H,03FH,0C6H,079H;  					; Butt-2 38Hz HPH 	; +14x lshift
	DB	089H,041H,0CDH,080H,039H,0A0H,080H,000H,000H,040H,000H,000H,000H,000H,00EH;
	DB	000H,000H,039H,05BH,0D3H,0E3H,03FH,054H,093H;  					; LR-6 80Hz LP x=-6dB G=0dBH 	;
	DB	009H,03CH,081H,080H,0ABH,0E0H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,039H,022H,038H,07FH,03FH,0AAH,010H;  					;
	DB	090H,051H,042H,080H,056H,063H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,030H,022H,038H,07FH,03FH,0AAH,010H;  					;
	DB	090H,051H,042H,080H,056H,063H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,032H,0A6H,000H,067H,0B6H,000H,000H,000H ;  Exc. 2.14V @59Hz, Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH	;  Delay 0.0ms


	; LR16B 80-160Hz: model 42
	DB	000H,000H
	DB	25,10,51,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,14,24,13

	DB	000H,000H,00CH,072H,0A0H,0F8H,03FH,09AH,02DH
	DB	03CH,089H,00FH,080H,065H,0EBH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,005H
	DB	000H,000H,019H,05AH,020H,042H,03FH,0AAH,076H 					; LR-6 80Hz HP x=-6dB G=+4dB (+19x rshift)
	DB	0B2H,0BCH,0E8H,080H,055H,0FBH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,0AAH,03DH,05AH,020H,042H,03FH,0AAH,076H 					;
	DB	0B2H,0BCH,0E8H,080H,055H,0FBH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,055H,024H,0A2H,04EH,059H,03FH,055H,05DH 					; 
	DB	0B1H,09CH,061H,080H,0ABH,014H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
    	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 					; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,032H,0A6H,000H,067H,0B6H,000H,000H,000H ;  Exc. 2.14V @59Hz, Power 0.80V
	DB	000H,000H,0DDH,07FH,0FFH,0FFH	; Delay 2.3ms

	; QB363 100Hz: model 43
	DB	000H,000H
	DB	12,15,47,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,15,24,17

	DB	000H,000H,012H,0AEH,054H,01DH,03FH,04DH,066H
	DB	020H,0DAH,069H,080H,0B2H,0BDH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,003H
	DB	000H,000H,010H,09CH,0E0H,0AFH,03FH,0BAH,063H 					; Butt-2 46Hz HP x=-3dB G=0dB  (+19x rshift)
	DB	053H,020H,09AH,080H,045H,0C2H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H	;
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,001H	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,033H,089H,000H,07FH,00CH,000H,000H,000H ; Exc. 2.1V @66Hz, Power 0.98V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; QB363 80Hz: model 44
	DB	000H,000H
	DB	12,15,47,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	0,0,255,15,24,17

	DB	000H,000H,012H,0AEH,054H,01DH,03FH,04DH,066H
	DB	020H,0DAH,069H,080H,0B2H,0BDH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,00FH,09CH,0E0H,0AFH,03FH,0BAH,063H;  					; Butt-2 46Hz HP x=-3dB G=0dB  (+19x rshift)H 	; +14x lshift
	DB	053H,020H,09AH,080H,045H,0C2H,080H,000H,000H,040H,000H,000H,000H,000H,00EH;
	DB	000H,000H,039H,05BH,0D3H,0E3H,03FH,054H,093H;  					; LR-6 80Hz LP x=-6dB G=0dBH 	;
	DB	009H,03CH,081H,080H,0ABH,0E0H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,039H,022H,038H,07FH,03FH,0AAH,010H;  					;
	DB	090H,051H,042H,080H,056H,063H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H;
	DB	000H,000H,039H,022H,038H,07FH,03FH,0AAH,010H;  					;
	DB	090H,051H,042H,080H,056H,063H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,001H;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,033H,089H,000H,07FH,00CH,000H,000H,000H ; Exc. 2.1V @66Hz, Power 0.98V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; 0.5meter QR18/QR36 Fullrange: model 45
	DB	031H,000H
;	DB	46,0,33,68,7,41,61,17,51,66,21,37,87,4,15,116,14,51,45,18,35	;oud
	DB	45,18,35,68,7,41,46,0,33,60,17,53,75,21,37,87,5,7,105,18,35
	DB	16,5,82,22,24,5

	DB	000H,000H,027H,0A3H,0E0H,072H,03FH,08BH,05CH
	DB	01EH,05CH,0F7H,080H,074H,0F1H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,033H,018H,04BH,0F1H,03FH,0E2H,0B3H 					; B=1 C=6.14 f0=162.6Hz G=-2dB (+17x rshift)
	DB	019H,095H,0FFH,080H,01DH,09FH,080H,000H,000H,040H,000H,000H,000H,000H,000H	; Bassboost 70Hz +8dB
	DB	07FH,09DH,093H,021H,0AEH,0DBH,03FH,09DH,0B9H 					; Butt-2 65Hz HP
	DB	08DH,02EH,0F6H,080H,062H,092H,080H,000H,000H,040H,000H,000H,000H,000H,00DH 	; +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,00FH,023H,000H,000H,004H,03EH,080H,0E3H,081H,09DH,063H,07FH,0FFH,0FFH,040H,000H,000H
	DB	077H,0E5H,077H,000H,000H,00EH,038H,008H,029H,088H,03DH,03AH,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04AH,0E8H,000H,09EH,05DH,000H,0A8H,0AEH	; Exc. 2.28V @104Hz ok, Low 1.20V High 1.34V
	DB	000H,000H,000H,07FH,0FFH,0FFH

; 0.5meter QR18/QR36 80Hz: model 46
	DB	031H,000H
	DB	45,18,35,68,7,41,46,0,33,60,17,53,75,21,37,87,5,7,105,18,35
	DB	16,5,82,22,24,5

	DB	000H,000H,027H,0A3H,0E0H,072H,03FH,08BH,05CH
	DB	01EH,05CH,0F7H,080H,074H,0F1H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,03FH,06DH,0DAH,08CH,03FH,087H,017H;  					; LR-4 80Hz HP x=-6dB G=0dB (+17x rshift);
	DB	024H,0FDH,0B3H,080H,079H,05CH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	065H,04CH,053H,06DH,0DAH,08CH,03FH,087H,017H;  					; +12x lshift
	DB	024H,0FDH,0B3H,080H,079H,05CH,080H,000H,000H,040H,000H,000H,000H,000H,00DH;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,00FH,023H,000H,000H,004H,03EH,080H,0E3H,081H,09DH,063H,07FH,0FFH,0FFH,040H,000H,000H
	DB	077H,0E5H,077H,000H,000H,00EH,038H,008H,029H,088H,03DH,03AH,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04AH,0E8H,000H,09EH,05DH,000H,0A8H,0AEH	; Exc. 2.28V @104Hz ok, Low 1.20V High 1.34V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; 0.5meter QR18/QR36 100Hz: model 47
	DB	031H,000H
;	DB	46,0,33,68,7,41,61,17,51,66,21,37,87,4,15,116,14,51,45,18,35	;oud
	DB	45,18,35,68,7,41,46,0,33,60,17,53,75,21,37,87,5,7,105,18,35
	DB	16,5,82,22,24,5

	DB	000H,000H,027H,0A3H,0E0H,072H,03FH,08BH,05CH
	DB	01EH,05CH,0F7H,080H,074H,0F1H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,033H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP G=-2dB (+17x rshift)
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,068H,0B3H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,00DH 	; +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,00FH,023H,000H,000H,004H,03EH,080H,0E3H,081H,09DH,063H,07FH,0FFH,0FFH,040H,000H,000H
	DB	077H,0E5H,077H,000H,000H,00EH,038H,008H,029H,088H,03DH,03AH,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04AH,0E8H,000H,09EH,05DH,000H,0A8H,0AEH	; Exc. 2.28V @104Hz ok, Low 1.20V High 1.34V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; SR9 Fullrange: model 48
	DB	000H,000H
	DB	68,7,41,68,7,41,64,14,44,84,13,17,102,12,24,118,18,35,68,7,41
	DB	16,5,82,68,7,41

	DB	000H,000H,050H,0BBH,051H,041H,03FH,087H,088H
	DB	0E3H,0B4H,0FCH,080H,079H,017H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,001H
	DB	000H,000H,040H,0AEH,070H,0DBH,03FH,0CCH,054H 					; B=1 C=3.78 f0=182Hz G=0dB (+17x rshift)
	DB	025H,0BDH,059H,080H,034H,049H,080H,000H,000H,040H,000H,000H,000H,000H,00CH	; Bassboost 100Hz +6dB +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,09CH,028H,000H,052H,0F8H,000H,000H,000H	; Exc. 0.82V @40Hz ok, Power 640mV
	DB	000H,000H,000H,07FH,0FFH,0FFH		

	; TS3/TS7 Fullrange: model 49
	DB	000H,000H
	DB	68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	16,5,82,18,24,15

	DB	000H,000H,00CH,0D2H,07AH,021H,03FH,07DH,074H
	DB	00BH,014H,0A2H,080H,082H,0A4H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,010H,098H,0C1H,09DH,03FH,0B4H,059H 					; Butt-2 50Hz HP x=-3dB G=0dB (+19x rshift)
	DB	037H,09BH,0E4H,080H,04BH,0D3H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,0B4H,043H,098H,0C1H,09DH,03FH,0B4H,059H 					; Butt-2 50Hz HP x=-3dB G=0dB
	DB	037H,09BH,0E4H,080H,04BH,0D3H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,054H,094H,000H,000H,004H,03AH,020H,062H,086H,088H,0C6H,07FH,0FFH,0FFH,040H,000H,000H
	DB	070H,0D6H,0C3H,000H,000H,00EH,032H,03AH,0E9H,090H,08DH,062H,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,02EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,00DH,003H,000H,043H,0BDH,000H,03FH,08BH	; Exc. 0.54V @84Hz ok, Low 0.50V High 0.50V
	DB	000H,000H,000H,023H,0C1H,010H			; Clip level 2.0V

	; TS3/TS7 100Hz: model 50
	DB	000H,000H
	DB	68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41,68,7,41
	DB	16,5,82,18,24,15

	DB	000H,000H,00CH,0D2H,07AH,021H,03FH,07DH,074H
	DB	00BH,014H,0A2H,080H,082H,0A4H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,040H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP (+17x rshift)
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,068H,0B3H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,00CH 	; +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,054H,094H,000H,000H,004H,03AH,020H,062H,086H,088H,0C6H,07FH,0FFH,0FFH,040H,000H,000H
	DB	070H,0D6H,0C3H,000H,000H,00EH,032H,03AH,0E9H,090H,08DH,062H,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,02EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,00DH,003H,000H,043H,0BDH,000H,03FH,08BH	; Exc. 0.54V @84Hz ok, Low 0.50V High 0.50V
	DB	000H,000H,000H,023H,0C1H,010H			; Clip level 2.0V

	; VR8 Fullrange: model 51
	DB	041H,000H
	DB	23,16,63,68,7,41,67,20,36,75,13,35,87,15,29,102,18,28,68,7,41
	DB	16,5,82,23,26,15

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,010H,098H,0C1H,09DH,03FH,0B4H,059H 					; Butt-2 50Hz HP x=-3dB G=0dB (+19x rshift)
	DB	037H,09BH,0E4H,080H,04BH,0D3H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,0B4H,043H,098H,0C1H,09DH,03FH,0B4H,059H 					; Butt-2 50Hz HP x=-3dB G=0dB
	DB	037H,09BH,0E4H,080H,04BH,0D3H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,015H,0A6H,000H,000H,004H,03EH,05AH,07AH,081H,0D0H,0D2H,07FH,0FFH,0FFH,040H,000H,000H
	DB	078H,055H,0A4H,000H,000H,00EH,038H,095H,0ECH,087H,0EAH,0A2H,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,08EH,000H,024H,0A9H,000H,053H,016H	; Exc. 0.98V @107Hz ok, Low 0.28V high 0.61V
	DB	000H,000H,000H,07FH,0FFH,0FFH

; VR8 80Hz: model 52
	DB	000H,000H
	DB	23,16,63,68,7,41,67,20,36,75,13,35,87,15,29,102,18,28,68,7,41
	DB	16,5,82,23,26,15

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
		DB	000H,000H,03FH,06DH,0DAH,08CH,03FH,087H,017H;  					; LR-4 80Hz HP x=-6dB G=0dB (+17x rshift);
	DB	024H,0FDH,0B3H,080H,079H,05CH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	07FH,086H,0DCH,06DH,0DAH,08CH,03FH,087H,017H;  					; +12x lshift
	DB	024H,0FDH,0B3H,080H,079H,05CH,080H,000H,000H,040H,000H,000H,000H,000H,00CH;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,015H,0A6H,000H,000H,004H,03EH,05AH,07AH,081H,0D0H,0D2H,07FH,0FFH,0FFH,040H,000H,000H
	DB	078H,055H,0A4H,000H,000H,00EH,038H,095H,0ECH,087H,0EAH,0A2H,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,08EH,000H,024H,0A9H,000H,053H,016H	; Exc. 0.98V @107Hz ok, Low 0.28V high 0.61V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; VR8 100Hz: model 53
	DB	000H,000H
	DB	23,16,63,68,7,41,67,20,36,75,13,35,87,15,29,102,18,28,68,7,41
	DB	16,5,82,23,26,15

	DB	000H,000H,024H,0A5H,0FBH,0B5H,03FH,078H,008H
	DB	0DDH,0F0H,008H,080H,088H,03FH,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,040H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP (+17x rshift)
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,068H,0B3H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,00CH 	; +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,015H,0A6H,000H,000H,004H,03EH,05AH,07AH,081H,0D0H,0D2H,07FH,0FFH,0FFH,040H,000H,000H
	DB	078H,055H,0A4H,000H,000H,00EH,038H,095H,0ECH,087H,0EAH,0A2H,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,023H,08EH,000H,024H,0A9H,000H,053H,016H	; Exc. 0.98V @107Hz ok, Low 0.28V high 0.61V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; VR12 Fullrange: model 54
	DB	051H,000H
	DB	23,16,63,68,7,41,89,6,31,19,24,51,68,7,41,68,7,41,68,7,41
	DB	16,5,82,21,26,21

	DB	000H,000H,01CH,04AH,0B9H,0B4H,03FH,043H,076H
	DB	092H,039H,0A3H,080H,0BCH,0C1H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,010H,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP (+19x rshift)
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,0BEH,0DAH,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,00CH,01CH,000H,000H,004H,03EH,0A8H,08EH,081H,06FH,0AAH,07FH,0FFH,0FFH,03FH,0FFH,0FFH
	DB	079H,053H,06BH,000H,000H,00EH,039H,084H,043H,086H,0DDH,06CH,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,0F9H,000H,060H,034H,000H,05FH,041H	; Exc. 1.56V @84Hz ok, Low 0.70V High 0.75V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; VR12 80Hz: model 55
	DB	000H,000H
	DB	23,16,63,68,7,41,89,6,31,19,24,51,68,7,41,68,7,41,68,7,41
	DB	16,5,82,21,26,21

	DB	000H,000H,01CH,04AH,0B9H,0B4H,03FH,043H,076H
	DB	092H,039H,0A3H,080H,0BCH,0C1H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,03FH,06DH,0DAH,08CH,03FH,087H,017H;  					; LR-4 80Hz HP x=-6dB G=0dB (+17x rshift);
	DB	024H,0FDH,0B3H,080H,079H,05CH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	07FH,086H,0DCH,06DH,0DAH,08CH,03FH,087H,017H;  					; +12x lshift
	DB	024H,0FDH,0B3H,080H,079H,05CH,080H,000H,000H,040H,000H,000H,000H,000H,00CH;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,00CH,01CH,000H,000H,004H,03EH,0A8H,08EH,081H,06FH,0AAH,07FH,0FFH,0FFH,03FH,0FFH,0FFH
	DB	079H,053H,06BH,000H,000H,00EH,039H,084H,043H,086H,0DDH,06CH,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,0F9H,000H,060H,034H,000H,05FH,041H	; Exc. 1.56V @84Hz ok, Low 0.70V High 0.75V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; VR12 100Hz: model 56
	DB	000H,000H
	DB	23,16,63,68,7,41,89,6,31,19,24,51,68,7,41,68,7,41,68,7,41
	DB	16,5,82,21,26,21

	DB	000H,000H,01CH,04AH,0B9H,0B4H,03FH,043H,076H
	DB	092H,039H,0A3H,080H,0BCH,0C1H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,040H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP (+17x rshift)
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,068H,0B3H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,00CH 	; +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,00CH,01CH,000H,000H,004H,03EH,0A8H,08EH,081H,06FH,0AAH,07FH,0FFH,0FFH,03FH,0FFH,0FFH
	DB	079H,053H,06BH,000H,000H,00EH,039H,084H,043H,086H,0DDH,06CH,080H,000H,000H,03FH,0FFH,0FFH
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,0F9H,000H,060H,034H,000H,05FH,041H	; Exc. 1.56V @84Hz ok, Low 0.70V High 0.75V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; VR12-60 Fullrange: model 57
	DB	051H,000H
	DB	23,16,63,68,7,41,90,6,26,19,24,51,60,20,37,102,12,35,113,20,47
	DB	16,5,82,21,26,21

	DB	000H,000H,01CH,04AH,0B9H,0B4H,03FH,043H,076H
	DB	092H,039H,0A3H,080H,0BCH,0C1H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,010H,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP (+19x rshift)
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,0BEH,0DAH,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,00CH,01CH,000H,000H,004H,03EH,0A8H,08EH,081H,06FH,0AAH,07FH,0FFH,0FFH,03FH,0FFH,0FFH
	DB	079H,0B9H,08BH,000H,000H,00EH,039H,0E7H,07CH,086H,074H,065H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,0F9H,000H,060H,034H,000H,05FH,041H	; Exc. 1.56V @84Hz ok, Low 0.70V High 0.75V
	DB	000H,000H,000H,07FH,0FFH,0FFH

; VR12-60 80Hz: model 58
	DB	000H,000H
	DB	23,16,63,68,7,41,90,6,26,19,24,51,60,20,37,102,12,35,113,20,47
	DB	16,5,82,21,26,21

	DB	000H,000H,01CH,04AH,0B9H,0B4H,03FH,043H,076H
	DB	092H,039H,0A3H,080H,0BCH,0C1H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,03FH,06DH,0DAH,08CH,03FH,087H,017H;  					; LR-4 80Hz HP x=-6dB G=0dB (+17x rshift);
	DB	024H,0FDH,0B3H,080H,079H,05CH,080H,000H,000H,040H,000H,000H,000H,000H,000H;
	DB	07FH,086H,0DCH,06DH,0DAH,08CH,03FH,087H,017H;  					; +12x lshift
	DB	024H,0FDH,0B3H,080H,079H,05CH,080H,000H,000H,040H,000H,000H,000H,000H,00CH;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,00CH,01CH,000H,000H,004H,03EH,0A8H,08EH,081H,06FH,0AAH,07FH,0FFH,0FFH,03FH,0FFH,0FFH
	DB	079H,0B9H,08BH,000H,000H,00EH,039H,0E7H,07CH,086H,074H,065H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,0F9H,000H,060H,034H,000H,05FH,041H	; Exc. 1.56V @84Hz ok, Low 0.70V High 0.75V
	DB	000H,000H,000H,07FH,0FFH,0FFH

	; VR12-60 100Hz: model 59
	DB	000H,000H
	DB	23,16,63,68,7,41,90,6,26,19,24,51,60,20,37,102,12,35,113,20,47
	DB	16,5,82,21,26,21

	DB	000H,000H,01CH,04AH,0B9H,0B4H,03FH,043H,076H
	DB	092H,039H,0A3H,080H,0BCH,0C1H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,002H
	DB	000H,000H,040H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP (+17x rshift)
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07FH,068H,0B3H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz HP
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H,000H,000H,00CH 	; +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,00CH,01CH,000H,000H,004H,03EH,0A8H,08EH,081H,06FH,0AAH,07FH,0FFH,0FFH,03FH,0FFH,0FFH
	DB	079H,0B9H,08BH,000H,000H,00EH,039H,0E7H,07CH,086H,074H,065H,080H,000H,000H,040H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,02CH,0F9H,000H,060H,034H,000H,05FH,041H	; Exc. 1.56V @84Hz ok, Low 0.70V High 0.75V
	DB	000H,000H,000H,07FH,0FFH,0FFH

;--------




;* ------------------------------------------------------------------------
;*  End of selectable presets
;* ------------------------------------------------------------------------

	; LR16HF: model 60
	DB	017H,36
	DB	84,16,35,23,38,47,100,6,34,117,14,72,69,16,37,68,7,41,68,7,41
	DB	68,7,41,68,7,41

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,01FH,0DEH,005H,013H,03CH,0AEH,0CBH 					; LR-8 1065Hz HP x=-6dB G=-6dB (+17x rshift)
	DB	08BH,0A2H,081H,083H,09EH,0CCH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07CH,088H,000H,0DEH,005H,013H,03CH,0AEH,0CBH 					;
	DB	08BH,0A2H,081H,083H,09EH,0CCH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	078H,021H,094H,0D9H,053H,08DH,038H,046H,0E2H					;
	DB	0B3H,057H,048H,088H,003H,0BBH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	078H,021H,094H,0D9H,053H,08DH,038H,046H,0E2H					;
	DB	0B3H,057H,048H,088H,003H,0BBH,080H,000H,000H,040H,000H,000H,000H,000H,00CH 	; +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,08CH,000H,000H,03AH,000H,000H,0D2H,000H,000H,03AH,07EH,0F0H,000H
	DB	07FH,0FFH,0FFH,000H,032H,068H,000H,000H,000H ; Power 0.40V
	DB	000H,000H,000H,020H,02DH,0C1H			; Clip level 1.8V

	; LR16HF 80: model 61
	DB	017H,36
	DB	84,16,35,23,38,47,100,6,34,117,14,72,69,16,37,68,7,41,68,7,41
	DB	68,7,41,68,7,41

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,01FH,0DEH,005H,013H,03CH,0AEH,0CBH 					; LR-8 1065Hz HP x=-6dB G=-6dB (+17x rshift)
	DB	08BH,0A2H,081H,083H,09EH,0CCH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07CH,088H,000H,0DEH,005H,013H,03CH,0AEH,0CBH 					;
	DB	08BH,0A2H,081H,083H,09EH,0CCH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	078H,021H,094H,0D9H,053H,08DH,038H,046H,0E2H					;
	DB	0B3H,057H,048H,088H,003H,0BBH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	078H,021H,094H,0D9H,053H,08DH,038H,046H,0E2H					;
	DB	0B3H,057H,048H,088H,003H,0BBH,080H,000H,000H,040H,000H,000H,000H,000H,00CH 	; +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,08CH,000H,000H,03AH,000H,000H,0D2H,000H,000H,03AH,07EH,0F0H,000H
	DB	07FH,0FFH,0FFH,000H,032H,068H,000H,000H,000H 			; Power 0.40V
	DB	000H,001H,016H,020H,02DH,0C1H					; Delay 2.9ms, Clip level 1.8V

	; LR16HF 160: model 62
	DB	017H,36
	DB	84,16,35,23,38,47,100,6,34,117,14,72,69,16,37,68,7,41,68,7,41
	DB	68,7,41,68,7,41

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,01FH,0DEH,005H,013H,03CH,0AEH,0CBH 					; LR-8 1065Hz HP x=-6dB G=-6dB (+17x rshift)
	DB	08BH,0A2H,081H,083H,09EH,0CCH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	07CH,088H,000H,0DEH,005H,013H,03CH,0AEH,0CBH 					;
	DB	08BH,0A2H,081H,083H,09EH,0CCH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	078H,021H,094H,0D9H,053H,08DH,038H,046H,0E2H					;
	DB	0B3H,057H,048H,088H,003H,0BBH,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	078H,021H,094H,0D9H,053H,08DH,038H,046H,0E2H					;
	DB	0B3H,057H,048H,088H,003H,0BBH,080H,000H,000H,040H,000H,000H,000H,000H,00CH 	; +12x lshift
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H


	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,08CH,000H,000H,03AH,000H,000H,0D2H,000H,000H,03AH,07EH,0F0H,000H
	DB	07FH,0FFH,0FFH,000H,032H,068H,000H,000H,000H 			; Power 0.40V
	DB	000H,000H,0DDH,020H,02DH,0C1H					; Delay 2.3ms, Clip level 1.8V

; ;	BC543 100Hz B: model 13
	DB	061H,011
	DB	68,7,41,6,16,67,68,7,41,0,39,45,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,15

	DB	000H,000H,009H,015H,0DDH,093H,03FH,0BBH,0E0H
	DB	014H,0C7H,042H,080H,044H,032H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,004H
	DB	000H,000H,01AH,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+4.6dB (+19x rshift
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 					; Butt-2 100Hz LP G=0dB 
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	0A5H,062H,008H,000H,000H,000H,000H,000H,000H					;Invert polarity and pad -3dB
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04EH,03DH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,001H,06AH,07FH,0FFH,0FFH

; ;	BC543 80Hz B: model 14
	DB	061H,012
	DB	68,7,41,6,16,67,68,7,41,0,39,45,68,7,41,68,7,41,68,7,41
	DB	0,0,255,10,26,15

	DB	000H,000H,009H,015H,0DDH,093H,03FH,0BBH,0E0H
	DB	014H,0C7H,042H,080H,044H,032H,07FH,0FFH,0FFH,040H,000H,000H

	DB	000H,000H,005H
	DB	000H,000H,01DH,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=+5.6dB (+19x rshift)
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH					; LR-6 80Hz LP x=-6dB G=0dB
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 					;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0A2H,04EH,059H,03FH,055H,05DH 					;
	DB	0B1H,09CH,061H,080H,0ABH,014H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	0A5H,062H,008H,000H,000H,000H,000H,000H,000H					;Invert polarity and pad -3dB
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,07EH,0F0H,000H
	DB	000H,04EH,03DH,000H,067H,0B6H,000H,000H,000H ; Exc. 2.00V @ 50Hz ok, Power 0.80V
	DB	000H,001H,06AH,07FH,0FFH,0FFH

	CSEG  	AT 7BFFH	

	DB	001H

	END

;* ------------------------------------------------------------------------
;*  Second order LP filters:
;* ------------------------------------------------------------------------

; Butterworth:

	DB	000H,000H,039H,0B4H,000H,034H,03FH,087H,020H; Butt-2 80Hz LP x=-3dB G=0dB
	DB	0DCH,096H,084H,080H,079H,051H,07FH,0FFH,0FFH,040H,000H,000H 	;

	DB	000H,000H,059H,09DH,035H,0FAH,03FH,069H,00CH 			; Butt-2 100Hz LP x=-3dB G=0dB
	DB	03AH,06EH,00CH,080H,097H,0A6H,07FH,0FFH,0FFH,040H,000H,000H 	;

	DB	000H,000H,06CH,017H,061H,07FH,03FH,059H,0C7H 			; Butt-2 110Hz LP x=-3dB G=0dB
	DB	0A9H,055H,0A8H,080H,0A7H,011H,07FH,0FFH,0FFH,040H,000H,000H 	;

	DB	000H,000H,0C8H,0EAH,096H,065H,03FH,01EH,004H 			; Butt-2 150Hz LP x=-3dB G=0dB
	DB	0D3H,0C8H,08FH,080H,0E3H,08CH,07FH,0FFH,0FFH,040H,000H,000H 	;

	DB	000H,000H,0E4H,0B0H,069H,0A0H,03FH,00FH,025H 			; Butt-2 160Hz LP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,07FH,0FFH,0FFH,040H,000H,000H 	;

	DB	000H,001H,064H,042H,0ECH,00AH,03EH,0D3H,07DH 			; Butt-2 200Hz LP x=-3dB G=0dB
	DB	0D1H,0F4H,0C0H,081H,02FH,04AH,07FH,0FFH,0FFH,040H,000H,000H 	;

	DB	000H,001H,0FFH,046H,01DH,099H,03EH,098H,00DH 			; Butt-2 240Hz LP x=-3dB G=0dB
	DB	03DH,06DH,04FH,081H,06BH,0F2H,07FH,0FFH,0FFH,040H,000H,000H 	;

	DB	000H,021H,084H,011H,080H,063H,03AH,057H,0C9H 			; Butt-2 1kHz LP x=-3dB G=0dB
	DB	04EH,022H,05BH,085H,0EBH,040H,07FH,0FFH,0FFH,040H,000H,000H 	;

; Linkwitz-Riley:

	DB	000H,001H,05EH,0C9H,048H,019H,03EH,05AH,0D5H 			; LR-2 200Hz LP x=-6dB G=0dB
	DB	027H,0BDH,0C3H,081H,0A7H,0E8H,07FH,0FFH,0FFH,040H,000H,000H 	;

	DB	000H,020H,091H,083H,030H,05FH,038H,02FH,00EH 			; LR-2 1kHz LP x=-6dB G=0dB
	DB	003H,0DFH,0B7H,088H,012H,014H,07FH,0FFH,0FFH,040H,000H,000H 	;


;* ------------------------------------------------------------------------
;*  Second order HP filters:
;* ------------------------------------------------------------------------

; Butterworth:

	DB	07FH,0E1H,0AFH,0AEH,083H,084H,03FH,0E1H,0B2H 			; Butt-2 20Hz HP x=-3dB G=0dB
	DB	07FH,09CH,0BBH,080H,01EH,054H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,0D7H,014H,002H,0DAH,03EH,03FH,0D7H,01BH 			; Butt-2 27Hz HP x=-3dB G=0dB
	DB	012H,00CH,03AH,080H,028H,0F2H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,0D2H,089H,067H,083H,0B6H,03FH,0D2H,091H 			; Butt-2 30Hz HP x=-3dB G=0dB
	DB	0BEH,05BH,058H,080H,02DH,07EH,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,0C6H,06CH,05CH,0DBH,073H,03FH,0C6H,079H 			; Butt-2 38Hz HP x=-3dB G=0dB
	DB	089H,041H,0CDH,080H,039H,0A0H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,0C3H,065H,0B5H,0E0H,0D6H,03FH,0C3H,073H 			; Butt-2 40Hz HP x=-3dB G=0dB
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,0BEH,0DAH,080H,025H,072H,03FH,0BEH,0EBH 			; Butt-2 43Hz HP x=-3dB G=0dB
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,0BAH,051H,09CH,0E0H,0AFH,03FH,0BAH,063H 			; Butt-2 46Hz HP x=-3dB G=0dB
	DB	053H,020H,09AH,080H,045H,0C2H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,0B4H,043H,098H,0C1H,09DH,03FH,0B4H,059H 			; Butt-2 50Hz HP x=-3dB G=0dB
	DB	037H,09BH,0E4H,080H,04BH,0D3H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,0AFH,0C8H,004H,080H,0BDH,03FH,0AFH,0E2H 			; Butt-2 53Hz HP x=-3dB G=0dB
	DB	05EH,0DBH,06CH,080H,050H,050H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,0A5H,022H,00FH,04CH,0FBH,03FH,0A5H,043H 			; Butt-2 60Hz HP x=-3dB G=0dB
	DB	071H,046H,042H,080H,05AH,0FDH,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,09DH,093H,021H,0AEH,0DBH,03FH,09DH,0B9H 			; Butt-2 65Hz HP x=-3dB G=0dB
	DB	08DH,02EH,0F6H,080H,062H,092H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,096H,004H,018H,0AAH,011H,03FH,096H,030H 			; Butt-2 70Hz HP x=-3dB G=0dB
	DB	0A8H,068H,025H,080H,06AH,027H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,08EH,06BH,0D9H,05FH,03CH,03FH,08EH,09DH 			; Butt-2 75Hz HP x=-3dB G=0dB
	DB	0EFH,0A6H,0A8H,080H,071H,0C6H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,086H,0E7H,0B4H,000H,034H,03FH,087H,020H 			; Butt-2 80Hz HP x=-3dB G=0dB
	DB	0DCH,096H,084H,080H,079H,051H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,068H,0B3H,09DH,035H,0FAH,03FH,069H,00CH 			; Butt-2 100Hz HP x=-3dB G=0dB
	DB	03AH,06EH,00CH,080H,097H,0A6H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,04AH,07CH,05CH,056H,0D1H,03FH,04AH,0FDH 			; Butt-2 120Hz HP x=-3dB G=0dB
	DB	0F0H,05FH,099H,080H,0B6H,003H,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,01DH,03CH,0EAH,096H,065H,03FH,01EH,004H 			; Butt-2 150Hz HP x=-3dB G=0dB
	DB	0D3H,0C8H,08FH,080H,0E3H,08CH,080H,000H,000H,040H,000H,000H 	;

	DB	07FH,00EH,041H,0B0H,069H,0A0H,03FH,00FH,025H 			; Butt-2 160Hz HP x=-3dB G=0dB
	DB	0E2H,000H,0B1H,080H,0F2H,0A2H,080H,000H,000H,040H,000H,000H 	;

	DB	07EH,0D2H,019H,042H,0ECH,00AH,03EH,0D3H,07DH 			; Butt-2 200Hz HP x=-3dB G=0dB
	DB	0D1H,0F4H,0C0H,081H,02FH,04AH,080H,000H,000H,040H,000H,000H	;

	DB	07EH,00FH,05BH,095H,018H,07AH,03EH,013H,01EH 			; Butt-2 330Hz HP x=-3dB G=0dB
	DB	086H,099H,061H,081H,0F4H,068H,080H,000H,000H,040H,000H,000H	;

; Linkwitz-Riley:

	DB	07EH,059H,076H,0C9H,048H,019H,03EH,05AH,0D5H 			; LR-2 200Hz HP x=-6dB G=0dB
	DB	027H,0BDH,0C3H,081H,0A7H,0E8H,080H,000H,000H,040H,000H,000H	;

	DB	078H,00EH,07DH,083H,030H,05FH,038H,02FH,00EH 			; LR-2 1kHz HP x=-6dB G=0dB
	DB	003H,0DFH,0B7H,088H,012H,014H,080H,000H,000H,040H,000H,000H	;

; Special:
	DB	07FH,0F0H,0BEH,078H,0A8H,042H,03FH,0F0H,0C5H 			; B=1 C=3.78 f0=53.6Hz G=0dB
	DB	029H,021H,04CH,080H,00FH,048H,080H,000H,000H,040H,000H,000H	; Bassboost 30Hz +6dB

	DB	07FH,0E2H,089H,018H,04BH,0F1H,03FH,0E2H,0B3H 			; B=1 C=6.14 f0=162.6Hz G=0dB
	DB	019H,095H,0FFH,080H,01DH,09FH,080H,000H,000H,040H,000H,000H	; Bassboost 70Hz +8dB

	DB	07FH,0E8H,093H,0C2H,001H,0BDH,03FH,0E8H,0A3H 			; B=1 C=3.74 f0=119Hz G=0dB
	DB	017H,004H,013H,080H,017H,07CH,080H,000H,000H,040H,000H,000H	; Bassboost 45Hz +6dB

	DB	07FH,0CCH,005H,0AEH,070H,0DBH,03FH,0CCH,054H 			; B=1 C=3.78 f0=182Hz G=0dB
	DB	025H,0BDH,059H,080H,034H,049H,080H,000H,000H,040H,000H,000H	; Bassboost 100Hz +6dB

	DB	07FH,0D8H,0A3H,03BH,0D5H,07FH,03FH,0D8H,0D0H 			; G=0dB
	DB	0D9H,0B2H,09CH,080H,027H,089H,080H,000H,000H,040H,000H,000H	; Bassboost 75Hz +6dB

	DB	07FH,0D2H,065H,05EH,0F1H,067H,03FH,0D2H,08DH 			; G=0dB
	DB	06CH,0D7H,096H,080H,02DH,0C3H,080H,000H,000H,040H,000H,000H	; Bassboost 75Hz +4.5dB

	DB	07FH,0D5H,0BFH,080H,087H,09AH,03FH,0D5H,0EAH 			; G=0dB
	DB	017H,029H,059H,080H,02AH,06CH,080H,000H,000H,040H,000H,000H	; Bassboost 75Hz +5.3dB

	DB	07FH,0DBH,0EFH,0A4H,04BH,0E8H,03FH,0DCH,01BH 			; G=0dB
	DB	0BCH,029H,078H,080H,024H,03CH,080H,000H,000H,040H,000H,000H	; Bassboost 75Hz +6.6dB

	DB	07FH,0CCH,068H,0F8H,0BBH,043H,03FH,0CCH,08CH 			; G=0dB
	DB	097H,0B7H,027H,080H,033H,0BDH,080H,000H,000H,040H,000H,000H	; Bassboost 75Hz +3.2dB

	DB	07FH,05DH,003H,0CEH,055H,0EAH,03FH,05EH,044H 			; G=0dB
	DB	0FCH,00DH,0A4H,080H,0A4H,03CH,080H,000H,000H,040H,000H,000H	; Bassboost 225Hz +2.7dB

	DB	07FH,042H,02BH,00BH,059H,0DFH,03FH,043H,078H 			; G=0dB
	DB	0F7H,0E0H,0F7H,080H,0BFH,020H,080H,000H,000H,040H,000H,000H	; Bassboost 250Hz +1.8dB

	DB	07FH,031H,04FH,0FEH,029H,009H,03FH,032H,06DH			; G=0dB
	DB	0D3H,072H,0B1H,080H,0CFH,0CEH,080H,000H,000H,040H,000H,000H	; Bassboost 275Hz +0.85dB

	DB	07FH,02CH,051H,0C9H,00CH,090H,03FH,02DH,051H			; G=0dB
	DB	049H,097H,0A7H,080H,0D4H,0AFH,080H,000H,000H,040H,000H,000H	; Bassboost 300Hz +0.5dB

	DB	07FH,02CH,0BAH,08FH,097H,0E4H,03FH,02DH,09CH			; G=0dB
	DB	0E3H,028H,04BH,080H,0D4H,027H,080H,000H,000H,040H,000H,000H	; Bassboost 325Hz +0.2dB

	DB	07FH,0CAH,04AH,021H,04AH,0F5H,03FH,0CAH,06CH			; G=0dB
	DB	043H,05FH,0B0H,080H,035H,0D7H,080H,000H,000H,040H,000H,000H	; Bassboost 75Hz +2.5dB

	DB	07FH,0EBH,0C1H,073H,0E5H,0ACH,03FH,0EBH,0F2H			; G=0dB
	DB	092H,0F4H,01EH,080H,014H,070H,080H,000H,000H,040H,000H,000H	; Bassboost 75Hz +12dB

	DB	07FH,0E9H,05EH,072H,07CH,0B2H,03FH,0E9H,08FH			; G=0dB
	DB	0F8H,0EBH,07BH,080H,016H,0D2H,080H,000H,000H,040H,000H,000H	; Bassboost 75Hz +11dB

	DB	07FH,0E6H,0B5H,0D1H,045H,011H,03FH,0E6H,0E5H			; G=0dB
	DB	07AH,06AH,01AH,080H,019H,07BH,080H,000H,000H,040H,000H,000H	; Bassboost 75Hz +10dB

	DB	07FH,0BFH,0B5H,0D1H,05CH,098H,03FH,0BFH,0D8H			; G=0dB
	DB	0ABH,0E8H,002H,080H,040H,06FH,080H,000H,000H,040H,000H,000H	; Bassboost 85Hz +1.6dB

	DB	07FH,0B1H,0CCH,034H,09DH,0A5H,03FH,0B2H,00AH			; G=0dB
	DB	08AH,06CH,04BH,080H,04EH,071H,080H,000H,000H,040H,000H,000H	; Bassboost 105Hz +2.0dB

	DB	07FH,0AFH,0CBH,011H,041H,027H,03FH,0AFH,0F9H			; G=0dB
	DB	0B7H,0B5H,0F8H,080H,050H,063H,080H,000H,000H,040H,000H,000H	; Bassboost 105Hz +1.0dB

;* ------------------------------------------------------------------------
;*  Fourth order LP filters:
;* ------------------------------------------------------------------------



;* ------------------------------------------------------------------------
;*  Fourth order HP filters:
;* ------------------------------------------------------------------------

; Linkwitz-Riley:

	DB	07FH,08EH,06BH,0D9H,05FH,03CH,03FH,08EH,09DH 			; LR-4 75Hz HP x=-6dB G=0dB
	DB	0EFH,0A6H,0A8H,080H,071H,0C6H,080H,000H,000H,040H,000H,000H 	;
	DB	07FH,08EH,06BH,0D9H,05FH,03CH,03FH,08EH,09DH 			;
	DB	0EFH,0A6H,0A8H,080H,071H,0C6H,080H,000H,000H,040H,000H,000H 	;

;* ------------------------------------------------------------------------
;*  Sixth order LP filters:
;* ------------------------------------------------------------------------

;Bessel:

	DB	000H,000H,05FH,056H,0D9H,096H,03FH,094H,06BH 			; Bess-6 75Hz LP x=-6dB G=0dB
	DB	0C6H,04FH,04AH,080H,06CH,052H,07FH,0FFH,0FFH,040H,000H,000H 	;
	DB	000H,000H,047H,088H,08FH,093H,03FH,066H,084H 			;
	DB	0C7H,006H,0B0H,080H,09AH,009H,07FH,0FFH,0FFH,040H,000H,000H 	;
	DB	000H,000H,043H,0EAH,050H,0D9H,03FH,04AH,069H 			;
	DB	0BEH,01FH,0AAH,080H,0B6H,01CH,07FH,0FFH,0FFH,040H,000H,000H 	;

	DB	000H,001H,0B4H,05EH,08DH,0F0H,03FH,019H,09BH 			; Bess-6 160Hz LP x=-6dB G=0dB
	DB	031H,0F5H,0E0H,080H,0E9H,0CFH,07FH,0FFH,0FFH,040H,000H,000H 	;
	DB	000H,001H,056H,0A6H,08AH,06CH,03EH,0ABH,032H 			;
	DB	0B9H,02AH,020H,081H,057H,07AH,07FH,0FFH,0FFH,040H,000H,000H 	;
	DB	000H,001H,034H,0F8H,05AH,037H,03EH,07CH,0B5H 			;
	DB	058H,0C4H,0FFH,081H,085H,0B3H,07FH,0FFH,0FFH,040H,000H,000H 	;

; Linkwitz-Riley:

	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 			; LR-6 80Hz LP x=-6dB G=0dB
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H 	;
	DB	000H,000H,039H,0E2H,07DH,0E0H,03FH,0AAH,08BH 			;
	DB	091H,083H,012H,080H,055H,0E6H,07FH,0FFH,0FFH,040H,000H,000H 	;
	DB	000H,000H,039H,0A2H,04EH,059H,03FH,055H,05DH 			;
	DB	0B1H,09CH,061H,080H,0ABH,014H,07FH,0FFH,0FFH,040H,000H,000H 	;


;* ------------------------------------------------------------------------
;*  Sixth order HP filters:
;* ------------------------------------------------------------------------

; Linkwitz-Riley:

	DB	07FH,0AAH,03DH,05AH,020H,042H,03FH,0AAH,076H 			; LR-6 80Hz HP x=-6dB G=0dB
	DB	0B2H,0BCH,0E8H,080H,055H,0FBH,080H,000H,000H,040H,000H,000H 	;
	DB	07FH,0AAH,03DH,05AH,020H,042H,03FH,0AAH,076H 			;
	DB	0B2H,0BCH,0E8H,080H,055H,0FBH,080H,000H,000H,040H,000H,000H 	;
	DB	07FH,055H,024H,0A2H,04EH,059H,03FH,055H,05DH 			; 
	DB	0B1H,09CH,061H,080H,0ABH,014H,080H,000H,000H,040H,000H,000H 	;

;* ------------------------------------------------------------------------
;*  Eigth order LP filters:
;* ------------------------------------------------------------------------

; Linkwitz-Riley:

	DB	000H,032H,087H,05CH,078H,00DH,03CH,041H,004H 			; LR-8 1230Hz LP x=-6dB G=0dB
	DB	006H,0FDH,042H,084H,024H,00AH,07FH,0FFH,0FFH,040H,000H,000H 	;
	DB	000H,032H,087H,05CH,078H,00DH,03CH,041H,004H 			;
	DB	006H,0FDH,042H,084H,024H,00AH,07FH,0FFH,0FFH,040H,000H,000H 	;
	DB	000H,02FH,094H,084H,09BH,028H,037H,067H,045H 			;
	DB	0AAH,075H,01FH,088H,0F7H,0E3H,07FH,0FFH,0FFH,040H,000H,000H 	;
	DB	000H,02FH,094H,084H,09BH,028H,037H,067H,045H 			;
	DB	0AAH,075H,01FH,088H,0F7H,0E3H,07FH,0FFH,0FFH,040H,000H,000H 	;

;* ------------------------------------------------------------------------
;*  Eigth order HP filters:
;* ------------------------------------------------------------------------

; Linkwitz-Riley:
	DB	07CH,088H,000H,0DEH,005H,013H,03CH,0AEH,0CBH 			; LR-8 1065Hz HP x=-6dB G=0dB
	DB	08BH,0A2H,081H,083H,09EH,0CCH,080H,000H,000H,040H,000H,000H 	;
	DB	07CH,088H,000H,0DEH,005H,013H,03CH,0AEH,0CBH 			;
	DB	08BH,0A2H,081H,083H,09EH,0CCH,080H,000H,000H,040H,000H,000H 	;
	DB	078H,021H,094H,0D9H,053H,08DH,038H,046H,0E2H			;
	DB	0B3H,057H,048H,088H,003H,0BBH,080H,000H,000H,040H,000H,000H 	;
	DB	078H,021H,094H,0D9H,053H,08DH,038H,046H,0E2H			;
	DB	0B3H,057H,048H,088H,003H,0BBH,080H,000H,000H,040H,000H,000H 	;



	DB	07BH,0FAH,059H,0D9H,072H,060H,03CH,02DH,0CFH 			; LR-8 1230Hz HP x=-6dB G=0dB
	DB	0A6H,0BBH,01FH,084H,039H,01CH,080H,000H,000H,040H,000H,000H 	;
	DB	07BH,0FAH,059H,0D9H,072H,060H,03CH,02DH,0CFH 			;
	DB	0A6H,0BBH,01FH,084H,039H,01CH,080H,000H,000H,040H,000H,000H 	;
	DB	076H,0F6H,013H,0E5H,07BH,06CH,037H,027H,06CH			;
	DB	052H,0EDH,013H,089H,03BH,046H,080H,000H,000H,040H,000H,000H 	;
	DB	076H,0F6H,013H,0E5H,07BH,06CH,037H,027H,06CH			;
	DB	052H,0EDH,013H,089H,03BH,046H,080H,000H,000H,040H,000H,000H 	;


;* ------------------------------------------------------------------------
;*  Test presets:
;* ------------------------------------------------------------------------

	; SB1000 80Hz imitatie 
	DB	000H,000H
	DB	2,16,27,45,7,20,45,7,20,45,7,20,45,7,20,45,7,20
	DB	85,5,43,85,5,58,30,9,6,3,34,6,85,5,43		;BF362

	DB	000H,000H,004H
	DB	000H,000H,024H,080H,025H,072H,03FH,0BEH,0EBH 					; Butt-2 43Hz HP x=-3dB G=+7dB (+19x rshift)
	DB	0A7H,08FH,074H,080H,041H,035H,080H,000H,000H,040H,000H,000H,000H,000H,00EH 	; +14x lshift
	DB	07FH,0C3H,065H,0B5H,0E0H,0D6H,03FH,0C3H,073H 					; Butt-2 40Hz HP x=-3dB G=0dB
	DB	0FBH,0D4H,060H,080H,03CH,0A8H,080H,000H,000H,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0B4H,000H,034H,03FH,087H,020H 					; Butt-2 80Hz LP x=-3dB G=0dB
	DB	0DCH,096H,084H,080H,079H,051H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,039H,0B4H,000H,034H,03FH,087H,020H 					; Butt-2 80Hz LP x=-3dB G=0dB
	DB	0DCH,096H,084H,080H,079H,051H,07FH,0FFH,0FFH,040H,000H,000H,000H,000H,000H 	;
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H

	DB	000H,000H,001H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,001H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H,000H
	DB	000H,000H,00EH,000H,000H,02EH,000H,000H,015H,000H,000H,03AH,03FH,0F0H,000H
	DB	006H,076H,0F2H,000H,067H,0B6H,000H,000H,000H ; Power 0.80V
	DB	000H,000H,000H,07FH,0FFH,0FFH

